@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -36,14 +36,14 @@ SKGAdviceBoardWidget::SKGAdviceBoardWidget(QWidget* iParent, SKGDocument* iDocum
     auto g = new QWidget(this);
     m_layout = new QFormLayout(g);
     m_layout->setContentsMargins(0, 0, 0, 0);
-    m_layout->setObjectName(QStringLiteral("Slayout"));
+    m_layout->setObjectName(QLatin1String("Slayout"));
     m_layout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
     m_layout->setHorizontalSpacing(1);
     m_layout->setVerticalSpacing(1);
     setMainWidget(g);
 
     // menu
-    auto menuResetAdvice = new QAction(SKGServices::fromTheme(QStringLiteral("edit-undo")), i18nc("Noun, a user action", "Activate all advice"), this);
+    auto menuResetAdvice = new QAction(SKGServices::fromTheme(QLatin1String("edit-undo")), i18nc("Noun, a user action", "Activate all advice"), this);
     connect(menuResetAdvice, &QAction::triggered, this, &SKGAdviceBoardWidget::activateAllAdvice);
     addAction(menuResetAdvice);
 
@@ -74,12 +74,12 @@ SKGAdviceBoardWidget::~SKGAdviceBoardWidget()
 
 QString SKGAdviceBoardWidget::getState()
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
-    root.setAttribute(QStringLiteral("maxAdvice"), SKGServices::intToString(m_maxAdvice));
-    root.setAttribute(QStringLiteral("automatic"), (m_menuAuto->isChecked() ? QStringLiteral("Y") : QStringLiteral("N")));
+    root.setAttribute(QLatin1String("maxAdvice"), SKGServices::intToString(m_maxAdvice));
+    root.setAttribute(QLatin1String("automatic"), (m_menuAuto->isChecked() ? QLatin1String("Y") : QLatin1String("N")));
     return doc.toString();
 }
 
@@ -87,24 +87,24 @@ void SKGAdviceBoardWidget::setState(const QString& iState)
 {
     SKGBoardWidget::setState(iState);
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString maxAdviceS = root.attribute(QStringLiteral("maxAdvice"));
+    QString maxAdviceS = root.attribute(QLatin1String("maxAdvice"));
     if (maxAdviceS.isEmpty()) {
         maxAdviceS = '7';
     }
     m_maxAdvice = SKGServices::stringToInt(maxAdviceS);
 
-    QString automatic = root.attribute(QStringLiteral("automatic"));
+    QString automatic = root.attribute(QLatin1String("automatic"));
     if (automatic.isEmpty()) {
         automatic = 'Y';
     }
 
     if (m_menuAuto != nullptr) {
         bool previous = m_menuAuto->blockSignals(true);
-        m_menuAuto->setChecked(automatic == QStringLiteral("Y"));
+        m_menuAuto->setChecked(automatic == QLatin1String("Y"));
         m_menuAuto->blockSignals(previous);
     }
 
@@ -158,11 +158,11 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
     elapse = SKGServices::getMicroTime() - elapse;
 
     // Get list of ignored advice
-    QString currentMonth = QDate::currentDate().toString(QStringLiteral("yyyy-MM"));
-    QStringList ignoredAdvice = getDocument()->getParameters(QStringLiteral("advice"), "t_value='I' OR t_value='I_" % currentMonth % '\'');
-    if (elapse > 3000 && m_menuAuto->isChecked() && !ignoredAdvice.contains(QStringLiteral("skgadviceboardwidget_verylong"))) {
+    QString currentMonth = QDate::currentDate().toString(QLatin1String("yyyy-MM"));
+    QStringList ignoredAdvice = getDocument()->getParameters(QLatin1String("advice"), "t_value='I' OR t_value='I_" % currentMonth % QLatin1Char('\''));
+    if (elapse > 3000 && m_menuAuto->isChecked() && !ignoredAdvice.contains(QLatin1String("skgadviceboardwidget_verylong"))) {
         SKGAdvice ad;
-        ad.setUUID(QStringLiteral("skgadviceboardwidget_verylong"));
+        ad.setUUID(QLatin1String("skgadviceboardwidget_verylong"));
         ad.setPriority(2);
         ad.setShortMessage(i18nc("Advice on making the best (short)", "Advice are very long to compute"));
         ad.setLongMessage(i18nc("Advice on making the best (long)", "To improve performances, you should switch the widget in 'Manual refresh' (see contextual menu)."));
@@ -178,7 +178,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         const SKGAdvice& ad = globalAdviceList.at(i);
 
         // Create icon
-        QString iconName = (ad.getPriority() == -1 ? QStringLiteral("dialog-information") : ad.getPriority() >= 8 ? QStringLiteral("security-low") : ad.getPriority() <= 4 ? QStringLiteral("security-high") : QStringLiteral("security-medium"));
+        QString iconName = (ad.getPriority() == -1 ? QLatin1String("dialog-information") : ad.getPriority() >= 8 ? QLatin1String("security-low") : ad.getPriority() <= 4 ? QLatin1String("security-high") : QLatin1String("security-medium"));
         QString toolTipString = i18n("<p><b>Priority %1:</b>%2</p>", SKGServices::intToString(ad.getPriority()), ad.getLongMessage());
 
         // Add ignored action
@@ -186,28 +186,28 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         {
             SKGAdvice::SKGAdviceAction dismiss;
             dismiss.Title = i18nc("Dismiss an advice provided", "Dismiss");
-            dismiss.IconName = QStringLiteral("edit-delete");
+            dismiss.IconName = QLatin1String("edit-delete");
             dismiss.IsRecommended = false;
             autoCorrections.push_back(dismiss);
         }
         {
             SKGAdvice::SKGAdviceAction dismiss;
             dismiss.Title = i18nc("Dismiss an advice provided", "Dismiss during current month");
-            dismiss.IconName = QStringLiteral("edit-delete");
+            dismiss.IconName = QLatin1String("edit-delete");
             dismiss.IsRecommended = false;
             autoCorrections.push_back(dismiss);
         }
         {
             SKGAdvice::SKGAdviceAction dismiss;
             dismiss.Title = i18nc("Dismiss an advice provided", "Dismiss this kind");
-            dismiss.IconName = QStringLiteral("edit-delete");
+            dismiss.IconName = QLatin1String("edit-delete");
             dismiss.IsRecommended = false;
             autoCorrections.push_back(dismiss);
         }
         {
             SKGAdvice::SKGAdviceAction dismiss;
             dismiss.Title = i18nc("Dismiss an advice provided", "Dismiss this kind during current month");
-            dismiss.IconName = QStringLiteral("edit-delete");
+            dismiss.IconName = QLatin1String("edit-delete");
             dismiss.IsRecommended = false;
             autoCorrections.push_back(dismiss);
         }
@@ -216,7 +216,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
 
         // Build button
         QStringList overlays;
-        overlays.push_back(nbSolution > 2 ? QStringLiteral("system-run") : QStringLiteral("edit-delete"));
+        overlays.push_back(nbSolution > 2 ? QLatin1String("system-run") : QLatin1String("edit-delete"));
         auto icon = new QToolButton(this);
         icon->setObjectName(ad.getUUID());
         icon->setIcon(SKGServices::fromTheme(iconName, overlays));
@@ -230,7 +230,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         for (int k = 0; k < nbSolution; ++k) {
             SKGAdvice::SKGAdviceAction adviceAction = autoCorrections.at(k);
             QString actionText = adviceAction.Title;
-            QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction(QString(actionText).remove(QStringLiteral("skg://")), false);
+            QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction(QString(actionText).remove(QLatin1String("skg://")), false);
             QAction* act;
             if (action != nullptr) {
                 // This is an action
@@ -238,7 +238,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
                 act->setData(actionText);
             } else {
                 // This is a text
-                act = menu->addAction(SKGServices::fromTheme(adviceAction.IconName.isEmpty() ?  QStringLiteral("system-run") : adviceAction.IconName), autoCorrections.at(k).Title, this, &SKGAdviceBoardWidget::adviceClicked);
+                act = menu->addAction(SKGServices::fromTheme(adviceAction.IconName.isEmpty() ?  QLatin1String("system-run") : adviceAction.IconName), autoCorrections.at(k).Title, this, &SKGAdviceBoardWidget::adviceClicked);
                 if (act != nullptr) {
                     act->setProperty("id", ad.getUUID());
                     act->setProperty("solution", k < nbSolution - 4 ? k : k - nbSolution);
@@ -273,7 +273,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
     int nb2 = m_recommendedActions.count();
     if (nb2 != 0) {
         apply = new QPushButton(this);
-        apply->setIcon(SKGServices::fromTheme(QStringLiteral("games-solve")));
+        apply->setIcon(SKGServices::fromTheme(QLatin1String("games-solve")));
         apply->setIconSize(QSize(22, 22));
         apply->setMaximumSize(QSize(22, 22));
         apply->setCursor(Qt::PointingHandCursor);
@@ -291,7 +291,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
     // Add more
     if (nb > m_maxAdvice) {
         auto more = new QPushButton(this);
-        more->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down-double")));
+        more->setIcon(SKGServices::fromTheme(QLatin1String("arrow-down-double")));
         more->setIconSize(QSize(22, 22));
         more->setMaximumSize(QSize(22, 22));
         more->setCursor(Qt::PointingHandCursor);
@@ -307,7 +307,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
     } else if (nbDisplayedAdvice > 7) {
         // Add less
         auto less = new QPushButton(this);
-        less->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-up-double")));
+        less->setIcon(SKGServices::fromTheme(QLatin1String("arrow-up-double")));
         less->setIconSize(QSize(22, 22));
         less->setMaximumSize(QSize(22, 22));
         less->setCursor(Qt::PointingHandCursor);
@@ -327,7 +327,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
 
     // Add manual refresh button
     m_refresh = new QPushButton(this);
-    m_refresh->setIcon(SKGServices::fromTheme(QStringLiteral("view-refresh")));
+    m_refresh->setIcon(SKGServices::fromTheme(QLatin1String("view-refresh")));
     m_refresh->setIconSize(QSize(22, 22));
     m_refresh->setMaximumSize(QSize(22, 22));
     m_refresh->setCursor(Qt::PointingHandCursor);
@@ -369,7 +369,7 @@ void SKGAdviceBoardWidget::activateAllAdvice()
     SKGError err;
     {
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Activate all advice"), err)
-        err = getDocument()->executeSqliteOrder(QStringLiteral("DELETE FROM parameters WHERE t_uuid_parent='advice'"));
+        err = getDocument()->executeSqliteOrder(QLatin1String("DELETE FROM parameters WHERE t_uuid_parent='advice'"));
     }
 
     // status bar
@@ -396,17 +396,17 @@ void SKGAdviceBoardWidget::adviceClicked()
                 SKGError err;
                 {
                     SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Dismiss advice"), err)
-                    QString currentMonth = QDate::currentDate().toString(QStringLiteral("yyyy-MM"));
+                    QString currentMonth = QDate::currentDate().toString(QLatin1String("yyyy-MM"));
 
                     // Create dismiss
                     if (solution == -1 || solution == -2) {
                         uuid = SKGServices::splitCSVLine(uuid, '|').at(0);
                     }
-                    IFOKDO(err, getDocument()->setParameter(uuid, solution == -2 || solution == -4 ? QStringLiteral("I") :
-                                                            QString("I_" % currentMonth), QVariant(), QStringLiteral("advice")))
+                    IFOKDO(err, getDocument()->setParameter(uuid, solution == -2 || solution == -4 ? QLatin1String("I") :
+                                                            QString("I_" % currentMonth), QVariant(), QLatin1String("advice")))
 
                     // Delete useless dismiss
-                    IFOKDO(err, getDocument()->executeSqliteOrder("DELETE FROM parameters WHERE t_uuid_parent='advice' AND t_value like 'I_ % ' AND t_value!='I_" % currentMonth % '\''))
+                    IFOKDO(err, getDocument()->executeSqliteOrder("DELETE FROM parameters WHERE t_uuid_parent='advice' AND t_value like 'I_ % ' AND t_value!='I_" % currentMonth % QLatin1Char('\'')))
                 }
 
                 // status bar
