@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -25,7 +25,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGAdvicePlugin, "metadata.json")
 
-SKGAdvicePlugin::SKGAdvicePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), currentDocument(nullptr)
+SKGAdvicePlugin::SKGAdvicePlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , currentDocument(nullptr)
 {
     SKGTRACEINFUNC(10)
     Q_UNUSED(iWidget)
@@ -43,8 +45,8 @@ bool SKGAdvicePlugin::setupActions(SKGDocument* iDocument)
 
     currentDocument = iDocument;
 
-    setComponentName(QStringLiteral("skg_advice"), title());
-    setXMLFile(QStringLiteral("skg_advice.rc"));
+    setComponentName(QLatin1String("skg_advice"), title());
+    setXMLFile(QLatin1String("skg_advice.rc"));
 
     // Create yours actions here
     return true;
@@ -80,7 +82,7 @@ QString SKGAdvicePlugin::title() const
 
 QString SKGAdvicePlugin::icon() const
 {
-    return QStringLiteral("help-hint");
+    return QLatin1String("help-hint");
 }
 
 QString SKGAdvicePlugin::toolTip() const
