@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -25,14 +25,18 @@
 #include "skgservices.h"
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
+#include <utility>
 
 /**
  * This plugin factory.
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGBookmarkPlugin, "metadata.json")
 
-SKGBookmarkPlugin::SKGBookmarkPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg) :
-    SKGInterfacePlugin(iParent), m_currentDocument(nullptr), m_dockWidget(nullptr), m_bookmarkMenu(nullptr)
+SKGBookmarkPlugin::SKGBookmarkPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList &iArg)
+    : SKGInterfacePlugin(iParent)
+    , m_currentDocument(nullptr)
+    , m_dockWidget(nullptr)
+    , m_bookmarkMenu(nullptr)
 {
     Q_UNUSED(iArg)
     Q_UNUSED(iWidget)
@@ -53,23 +57,23 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument)
 
     m_currentDocument = iDocument;
 
-    setComponentName(QStringLiteral("skg_bookmark"), title());
-    setXMLFile(QStringLiteral("skg_bookmark.rc"));
+    setComponentName(QLatin1String("skg_bookmark"), title());
+    setXMLFile(QLatin1String("skg_bookmark.rc"));
 
     m_dockWidget = new QDockWidget(SKGMainPanel::getMainPanel());
-    m_dockWidget->setObjectName(QStringLiteral("skg_bookmark_docwidget"));
+    m_dockWidget->setObjectName(QLatin1String("skg_bookmark_docwidget"));
     m_dockWidget->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
     m_dockWidget->setWindowTitle(title());
     m_dockWidget->setWidget(new SKGBookmarkPluginDockWidget(m_dockWidget, m_currentDocument));
 
     // add action to control hide / display of Bookmarks
     QAction* toggle = m_dockWidget->toggleViewAction();
-    QAction* panelAction = actionCollection()->addAction(QStringLiteral("view_bookmarks"));
-    registerGlobalAction(QStringLiteral("view_bookmarks"), panelAction);
+    QAction* panelAction = actionCollection()->addAction(QLatin1String("view_bookmarks"));
+    registerGlobalAction(QLatin1String("view_bookmarks"), panelAction);
     panelAction->setCheckable(true);
     panelAction->setChecked(toggle->isChecked());
     panelAction->setText(toggle->text());
-    actionCollection()->setDefaultShortcut(panelAction, Qt::SHIFT + Qt::Key_F10);
+    actionCollection()->setDefaultShortcut(panelAction, Qt::SHIFT | Qt::Key_F10);
     connect(panelAction, &QAction::triggered, toggle, &QAction::trigger);
     connect(toggle, &QAction::toggled, panelAction, &QAction::setChecked);
 
@@ -77,30 +81,33 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument)
     QStringList overlaybookmarks;
     overlaybookmarks.push_back(icon());
 
-    auto actImportStdBookmark = new QAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlaybookmarks), i18nc("Verb", "Import standard bookmarks"), this);
+    auto actImportStdBookmark = new QAction(SKGServices::fromTheme(QLatin1String("document-import"), overlaybookmarks), i18nc("Verb", "Import standard bookmarks"), this);
     connect(actImportStdBookmark, &QAction::triggered, this, &SKGBookmarkPlugin::importStandardBookmarks);
-    registerGlobalAction(QStringLiteral("import_standard_bookmarks"), actImportStdBookmark);
+    registerGlobalAction(QLatin1String("import_standard_bookmarks"), actImportStdBookmark);
 
     //
     QAction* goHomeAction = KStandardAction::home(this, SLOT(goHome()), actionCollection());
     goHomeAction->setPriority(QAction::LowPriority);
-    registerGlobalAction(QStringLiteral("go_home"), goHomeAction);
+    registerGlobalAction(QLatin1String("go_home"), goHomeAction);
 
     // Bookmark
-    auto actBookmark = new KToolBarPopupAction(SKGServices::fromTheme(QStringLiteral("bookmark-new-list")), i18nc("Verb, action to display bookmarks", "Bookmarks"), this);
+    auto actBookmark = new KToolBarPopupAction(SKGServices::fromTheme(QLatin1String("bookmark-new-list")), i18nc("Verb, action to display bookmarks", "Bookmarks"), this);
     connect(actBookmark, &KToolBarPopupAction::triggered, this, &SKGBookmarkPlugin::onOpenBookmark);
-    m_bookmarkMenu = actBookmark->menu();
+    m_bookmarkMenu = actBookmark->popupMenu();
     if (m_bookmarkMenu != nullptr) {
         m_bookmarkMenu->setProperty("id", 0);
         connect(m_bookmarkMenu, &QMenu::aboutToShow, this, &SKGBookmarkPlugin::onShowBookmarkMenu);
     }
+#ifdef SKG_QT6
 
+#else
     actBookmark->setStickyMenu(false);
     actBookmark->setDelayed(false);
+#endif
     actBookmark->setData(0);
     actBookmark->setPriority(QAction::LowPriority);
 
-    registerGlobalAction(QStringLiteral("edit_bookmark"), actBookmark);
+    registerGlobalAction(QLatin1String("edit_bookmark"), actBookmark);
 
     return true;
 }
@@ -136,7 +143,7 @@ void SKGBookmarkPlugin::refresh()
                 m_docUniqueIdentifier = std::move(doc_id);
 
                 bool exist = false;
-                SKGError err = m_currentDocument->existObjects(QStringLiteral("node"), QLatin1String(""), exist);
+                SKGError err = m_currentDocument->existObjects(QLatin1String("node"), QLatin1String(""), exist);
                 if (!err && !exist) {
                     importStandardBookmarks();
 
@@ -160,7 +167,7 @@ QString SKGBookmarkPlugin::title() const
 
 QString SKGBookmarkPlugin::icon() const
 {
-    return QStringLiteral("bookmarks");
+    return QLatin1String("bookmarks");
 }
 
 QStringList SKGBookmarkPlugin::tips() const
@@ -204,12 +211,12 @@ void SKGBookmarkPlugin::importStandardBookmarks()
         "&amp;#xa;&amp;lt;parameters zoomFactor=&amp;quot;0&amp;quot;/>&amp;#xa;&quot; sortOrder=&quot;0&quot;/>&#xa;\"\" mode=\"\"1\"\" period=\"\"0\"\" incomes=\"\"Y\"\" interval=\"\"2\"\" lines=\"\"#NOTHING#\"\" lines2=\"\"#NOTHING#\"\" nbLevelLines=\"\"0\"\" nbLevelColumns=\"\"0\"\" forecast=\"\"0\"\" columns=\"\"d_DATEMONTH\"\" nb_intervals=\"\"1\"\" forecastValue=\"\"20\"\" transfers=\"\"Y\"\" currentPage=\"\"0\"\"/>\"";
 
 
-    for (const auto& bk : qAsConst(bks)) {
+    for (const auto& bk : std::as_const(bks)) {
         QStringList line = SKGServices::splitCSVLine(bk, '|', false);
         if (line.count() == 4) {
             SKGNodeObject node;
             err = SKGNodeObject::createPathNode(m_currentDocument, line.at(0), node);
-            IFOKDO(err, node.setAutoStart(line.at(1) == QStringLiteral("Y")))
+            IFOKDO(err, node.setAutoStart(line.at(1) == QLatin1String("Y")))
             IFOKDO(err, node.setIcon(line.at(2)))
             IFOKDO(err, node.setData(line.at(3)))
             IFOKDO(err, node.save())
@@ -234,7 +241,7 @@ void SKGBookmarkPlugin::goHome()
 
     SKGObjectBase::SKGListSKGObjectBase oNodeList;
     if (m_currentDocument != nullptr) {
-        m_currentDocument->getObjects(QStringLiteral("v_node"), QStringLiteral("t_autostart='Y' ORDER BY f_sortorder, t_name"), oNodeList);
+        m_currentDocument->getObjects(QLatin1String("v_node"), QLatin1String("t_autostart='Y' ORDER BY f_sortorder, t_name"), oNodeList);
     }
     int nbAutoStartedBookmarks = oNodeList.count();
     for (int i = 0; i < nbAutoStartedBookmarks; ++i) {
@@ -287,7 +294,7 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
         callerMenu->clear();
 
         // Build query
-        QString wc = QStringLiteral("rd_node_id=0 OR rd_node_id IS NULL OR rd_node_id=''");
+        QString wc = QLatin1String("rd_node_id=0 OR rd_node_id IS NULL OR rd_node_id=''");
         int idParent = callerMenu->property("id").toInt();
         if (idParent != 0) {
             wc = "rd_node_id=" % SKGServices::intToString(idParent);
@@ -295,7 +302,7 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
 
         // Build new menu
         SKGObjectBase::SKGListSKGObjectBase listNode;
-        m_currentDocument->getObjects(QStringLiteral("v_node"), wc % " ORDER BY f_sortorder, t_name", listNode);
+        m_currentDocument->getObjects(QLatin1String("v_node"), wc % " ORDER BY f_sortorder, t_name", listNode);
         int nb = listNode.count();
         for (int i = 0; i < nb; ++i) {
             SKGNodeObject node(listNode.at(i));
@@ -334,7 +341,7 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
             if (act != nullptr) {
                 callerMenu->addAction(act);
                 act->setText(i18nc("Action", "Open all"));
-                act->setIcon(SKGServices::fromTheme(QStringLiteral("quickopen")));
+                act->setIcon(SKGServices::fromTheme(QLatin1String("quickopen")));
                 act->setData(idParent);
                 connect(act, &QAction::triggered, this, &SKGBookmarkPlugin::onOpenBookmark);
             }
@@ -344,7 +351,7 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
                 if (act2 != nullptr) {
                     callerMenu->addAction(act2);
                     act2->setText(i18nc("Action", "Bookmark current page here"));
-                    act2->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
+                    act2->setIcon(SKGServices::fromTheme(QLatin1String("list-add")));
                     act2->setData(idParent);
 
                     connect(act2, &QAction::triggered, this, &SKGBookmarkPlugin::onAddBookmark);
