@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -25,6 +25,7 @@
 #include "skgsortfilterproxymodel.h"
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
+#include <utility>
 
 bool SKGBookmarkPluginDockWidget::m_middleClick = false;
 
@@ -46,13 +47,13 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(QWidget* iParent, SKGDo
     ui.kBookmarksList->setAnimated(false);  // Not compatible with double click
     ui.kBookmarksList->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
-    ui.kTools->setIcon(SKGServices::fromTheme(QStringLiteral("configure")));
+    ui.kTools->setIcon(SKGServices::fromTheme(QLatin1String("configure")));
 
     ui.kBookmarksList->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui.kBookmarksList, &SKGTreeView::customContextMenuRequested, this, &SKGBookmarkPluginDockWidget::showMenu);
 
     // Add model
-    m_modelview = new SKGObjectModelBase(getDocument(), QStringLiteral("v_node"), QStringLiteral("1=1 ORDER BY f_sortorder, t_name"), this, QStringLiteral("rd_node_id"));
+    m_modelview = new SKGObjectModelBase(getDocument(), QLatin1String("v_node"), QLatin1String("1=1 ORDER BY f_sortorder, t_name"), this, QLatin1String("rd_node_id"));
     auto modelproxy = new SKGSortFilterProxyModel(this);
     modelproxy->setSourceModel(m_modelview);
     ui.kBookmarksList->setModel(modelproxy);
@@ -103,46 +104,46 @@ void SKGBookmarkPluginDockWidget::initMenu()
     if (m_mainMenu == nullptr) {
         // Build contextual menu
         m_mainMenu = new QMenu(ui.kBookmarksList);
-        QAction* actExpandAll = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("format-indent-more")), i18nc("Noun, user action", "Expand all"));
+        QAction* actExpandAll = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("format-indent-more")), i18nc("Noun, user action", "Expand all"));
         connect(actExpandAll, &QAction::triggered, ui.kBookmarksList, &SKGTreeView::expandAll);
 
-        QAction* actCollapseAll = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("format-indent-less")), i18nc("Noun, user action", "Collapse all"));
+        QAction* actCollapseAll = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("format-indent-less")), i18nc("Noun, user action", "Collapse all"));
         connect(actCollapseAll, &QAction::triggered, ui.kBookmarksList, &SKGTreeView::collapseAll);
         ui.kBookmarksList->insertAction(nullptr, actCollapseAll);
 
         m_mainMenu->addSeparator();
 
-        m_actAddBookmark = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("list-add")), i18nc("Verb", "Bookmark current page"));
+        m_actAddBookmark = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("list-add")), i18nc("Verb", "Bookmark current page"));
         connect(m_actAddBookmark, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onAddBookmark);
 
-        m_actAddBookmarks = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("list-add")), i18nc("Verb", "Bookmark all pages"));
+        m_actAddBookmarks = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("list-add")), i18nc("Verb", "Bookmark all pages"));
         connect(m_actAddBookmarks, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onAddBookmarks);
 
-        m_actAddBookmarkGroup = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("folder-new")), i18nc("Verb", "Add bookmark group"));
+        m_actAddBookmarkGroup = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("folder-new")), i18nc("Verb", "Add bookmark group"));
         connect(m_actAddBookmarkGroup, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onAddBookmarkGroup);
 
         m_mainMenu->addSeparator();
 
-        m_actDelete = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-delete")), i18nc("Verb, delete an item", "Delete"));
+        m_actDelete = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("edit-delete")), i18nc("Verb, delete an item", "Delete"));
         connect(m_actDelete, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onRemoveBookmark);
 
         m_mainMenu->addSeparator();
 
-        m_actSetAutostart = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("media-playback-start")), i18nc("Verb, automatically load when the application is started", "Autostart"));
+        m_actSetAutostart = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("media-playback-start")), i18nc("Verb, automatically load when the application is started", "Autostart"));
         connect(m_actSetAutostart, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onSetAutostart);
 
-        m_actUnsetAutostart = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("media-playback-stop")), i18nc("Verb", "Remove Autostart"));
+        m_actUnsetAutostart = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("media-playback-stop")), i18nc("Verb", "Remove Autostart"));
         connect(m_actUnsetAutostart, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onUnsetAutostart);
 
-        m_actRename = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-rename")), i18nc("Verb, change the name of an item", "Rename"));
+        m_actRename = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("edit-rename")), i18nc("Verb, change the name of an item", "Rename"));
         m_actRename->setShortcut(Qt::Key_F2);
         connect(m_actRename, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onRenameBookmark);
 
-        m_actChangeIcon = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-image-face-add")), i18nc("Verb, change the icon of an item", "Change icon…"));
+        m_actChangeIcon = m_mainMenu->addAction(SKGServices::fromTheme(QLatin1String("edit-image-face-add")), i18nc("Verb, change the icon of an item", "Change icon…"));
         connect(m_actChangeIcon, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onChangeIconBookmark);
 
         m_mainMenu->addSeparator();
-        m_mainMenu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("tab_overwritebookmark")));
+        m_mainMenu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("tab_overwritebookmark")));
 
         ui.kTools->setMenu(m_mainMenu);
     }
@@ -157,13 +158,13 @@ void SKGBookmarkPluginDockWidget::showMenu(const QPoint iPos)
 void SKGBookmarkPluginDockWidget::onSetAutostart()
 {
     SKGTRACEINFUNC(10)
-    setAutostart(QStringLiteral("Y"));
+    setAutostart(QLatin1String("Y"));
 }
 
 void SKGBookmarkPluginDockWidget::onUnsetAutostart()
 {
     SKGTRACEINFUNC(10)
-    setAutostart(QStringLiteral("N"));
+    setAutostart(QLatin1String("N"));
 }
 
 void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
@@ -176,10 +177,10 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
     // foreach selected bookmark, set the t_autostart attribute to 'y' or 'n'
     {
         int nb = selectedBookmarks.count();
-        SKGBEGINPROGRESSTRANSACTION(*getDocument(), value == QStringLiteral("Y") ? i18nc("Noun, name of the user action", "Autostart bookmarks") : i18nc("Noun, name of the user action", "Do not Autostart bookmarks"), err, nb)
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), value == QLatin1String("Y") ? i18nc("Noun, name of the user action", "Autostart bookmarks") : i18nc("Noun, name of the user action", "Do not Autostart bookmarks"), err, nb)
         for (int i = 0 ; !err && i < nb  ; ++i) {
             SKGNodeObject bookmark(selectedBookmarks.at(i));
-            err = bookmark.setAttribute(QStringLiteral("t_autostart"), value);
+            err = bookmark.setAttribute(QLatin1String("t_autostart"), value);
             IFOKDO(err, bookmark.save())
 
             // Send message
@@ -190,7 +191,7 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
     }
 
     // status bar
-    IFOKDO(err, SKGError(0, value == QStringLiteral("Y") ? i18nc("Successful message after an user action", "Autostart bookmarks") : i18nc("Successful message after an user action", "Do not Autostart bookmarks")))
+    IFOKDO(err, SKGError(0, value == QLatin1String("Y") ? i18nc("Successful message after an user action", "Autostart bookmarks") : i18nc("Successful message after an user action", "Do not Autostart bookmarks")))
     SKGMainPanel::displayErrorMessage(err);
 }
 
@@ -239,7 +240,7 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
             // This bookmark is a folder ==> we open children by recursion
             SKGObjectBase::SKGListSKGObjectBase children;
             selectedNode.getNodes(children);
-            for (const auto& item : qAsConst(children)) {
+            for (const auto& item : std::as_const(children)) {
                 nodes.push_back(SKGNodeObject(item));
             }
         }
@@ -442,8 +443,8 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
         SKGBEGINTRANSACTION(*iParentNode.getDocument(), i18nc("Noun, name of the user action", "Bookmark creation '%1'", name), err)
         err = SKGNodeObject::createPathNode(iParentNode.getDocument(), name, oCreatedNode, true);
         IFOK(err) {
-            QString value = SKGServices::stringToCsv(iPage->objectName()) % ';' %
-                            SKGServices::stringToCsv(defaultName) % ';' %
+            QString value = SKGServices::stringToCsv(iPage->objectName()) % QLatin1Char(';') %
+                            SKGServices::stringToCsv(defaultName) % QLatin1Char(';') %
                             SKGServices::stringToCsv(iPage->getState());
 
             err = oCreatedNode.setData(value);
@@ -482,8 +483,7 @@ void SKGBookmarkPluginDockWidget::onChangeIconBookmark()
     if (bookmarks.count() == 1) {
         SKGNodeObject node(bookmarks.at(0));
         KIconDialog diag(this);
-        diag.setup(KIconLoader::NoGroup);
-        QString icon = diag.openDialog();
+        QString icon = diag.getIcon(KIconLoader::NoGroup);
         if (!icon.isEmpty()) {
             SKGError err;
             {
@@ -558,10 +558,10 @@ void SKGBookmarkPluginDockWidget::refresh()
     if (nbSelectedObjects == 1) {
         SKGNodeObject node(bookmarks.at(0));
         if (m_actSetAutostart != nullptr) {
-            m_actSetAutostart->setEnabled(node.getAttribute(QStringLiteral("t_autostart")) != QStringLiteral("Y"));
+            m_actSetAutostart->setEnabled(node.getAttribute(QLatin1String("t_autostart")) != QLatin1String("Y"));
         }
         if (m_actUnsetAutostart != nullptr) {
-            m_actUnsetAutostart->setEnabled(node.getAttribute(QStringLiteral("t_autostart")) == QStringLiteral("Y"));
+            m_actUnsetAutostart->setEnabled(node.getAttribute(QLatin1String("t_autostart")) == QLatin1String("Y"));
         }
     } else {
         if (m_actSetAutostart != nullptr) {
