@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -25,7 +25,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGDashboardPlugin, "metadata.json")
 
-SKGDashboardPlugin::SKGDashboardPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg) : SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
+SKGDashboardPlugin::SKGDashboardPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList &iArg)
+    : SKGInterfacePlugin(iParent)
+    , m_currentDocument(nullptr)
 {
     Q_UNUSED(iArg)
     Q_UNUSED(iWidget)
@@ -44,8 +46,8 @@ bool SKGDashboardPlugin::setupActions(SKGDocument* iDocument)
 
     m_currentDocument = iDocument;
 
-    setComponentName(QStringLiteral("skg_dashboard"), title());
-    setXMLFile(QStringLiteral("skg_dashboard.rc"));
+    setComponentName(QLatin1String("skg_dashboard"), title());
+    setXMLFile(QLatin1String("skg_dashboard.rc"));
 
     // Create yours actions here
     return true;
@@ -82,7 +84,7 @@ QString SKGDashboardPlugin::title() const
 
 QString SKGDashboardPlugin::icon() const
 {
-    return QStringLiteral("dashboard-show");
+    return QLatin1String("dashboard-show");
 }
 
 QString SKGDashboardPlugin::toolTip() const
