@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -26,7 +26,7 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(QWidget* iParent, SKGDocument
     SKGTRACEINFUNC(1)
     auto verticalLayout = new QVBoxLayout(this);
     verticalLayout->setSpacing(2);
-    verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
+    verticalLayout->setObjectName(QLatin1String("verticalLayout"));
     m_widget = new SKGDashboardWidget(this, iDocument);
     verticalLayout->addWidget(m_widget);
 }
@@ -40,12 +40,12 @@ SKGDashboardPluginWidget::~SKGDashboardPluginWidget()
 QString SKGDashboardPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("zoomPosition"), SKGServices::intToString(zoomPosition()));
-    root.setAttribute(QStringLiteral("board"), m_widget->getState());
+    root.setAttribute(QLatin1String("zoomPosition"), SKGServices::intToString(zoomPosition()));
+    root.setAttribute(QLatin1String("board"), m_widget->getState());
     return doc.toString();
 }
 
@@ -53,19 +53,19 @@ void SKGDashboardPluginWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     // Compliance with old mode
-    auto board = root.attribute(QStringLiteral("board"));
+    auto board = root.attribute(QLatin1String("board"));
     if (board.isEmpty()) {
         board = iState;
     }
 
     m_widget->setState(board);
 
-    QString zoomPositionS = root.attribute(QStringLiteral("zoomPosition"));
+    QString zoomPositionS = root.attribute(QLatin1String("zoomPosition"));
     if (zoomPositionS.isEmpty()) {
         zoomPositionS = '0';
     }
@@ -74,7 +74,7 @@ void SKGDashboardPluginWidget::setState(const QString& iState)
 
 QString SKGDashboardPluginWidget::getDefaultStateAttribute()
 {
-    return QStringLiteral("SKGDASHBOARD_DEFAULT_PARAMETERS");
+    return QLatin1String("SKGDASHBOARD_DEFAULT_PARAMETERS");
 }
 
 void SKGDashboardPluginWidget::refresh()
