@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -11,17 +11,18 @@
 #include "skgdashboardwidget.h"
 
 #include <kaboutdata.h>
-#include <kservice.h>
 #include <ktitlewidget.h>
 
+#include <qactiongroup.h>
 #include <qdom.h>
 #include <qdrag.h>
 #include <qevent.h>
+#include <qgridlayout.h>
 #include <qmenu.h>
 #include <qmimedata.h>
-#include <qgridlayout.h>
 
 #include "skgboardwidget.h"
+#include "skgdashboardplugin.h"
 #include "skgdocument.h"
 #include "skgflowlayout.h"
 #include "skginterfaceplugin.h"
@@ -29,7 +30,7 @@
 #include "skgservices.h"
 #include "skgtraces.h"
 #include "skgzoomselector.h"
-#include "skgdashboardplugin.h"
+#include <utility>
 
 SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument, QMenu* iMenu)
     : SKGWidget(iParent, iDocument), m_flowLayout(nullptr), m_menu(nullptr), m_addMenu(nullptr),
@@ -51,7 +52,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         m_menu = new QMenu(this);
 
         connect(this, &SKGDashboardWidget::customContextMenuRequested, this, &SKGDashboardWidget::showHeaderMenu);
-        m_addMenu = m_menu->addMenu(SKGServices::fromTheme(QStringLiteral("configure")),  i18nc("Verb", "Configure the dashboard"));
+        m_addMenu = m_menu->addMenu(SKGServices::fromTheme(QLatin1String("configure")),  i18nc("Verb", "Configure the dashboard"));
     }
 
     auto verticalLayout = new QVBoxLayout(this);
@@ -63,9 +64,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
 
         auto kTitle = new KTitleWidget(this);
         kTitle->setIcon(QApplication::windowIcon(), KTitleWidget::ImageLeft);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
         kTitle->setIconSize(QSize(32, 32));
-#endif
 
         kTitle->setText(i18nc("Message", "Welcome to %1", KAboutData::applicationData().displayName()));
         kTitle->setLevel(1);
@@ -116,12 +115,12 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
     // Build menu
     if (m_addMenu != nullptr) {
         // Add layouts sub menu
-        auto layoutMenu = m_addMenu->addMenu(SKGServices::fromTheme(QStringLiteral("labplot-editbreaklayout")),  i18nc("Verb", "Choose layout …"));
+        auto layoutMenu = m_addMenu->addMenu(SKGServices::fromTheme(QLatin1String("labplot-editbreaklayout")),  i18nc("Verb", "Choose layout …"));
         auto alignmentGroup = new QActionGroup(this);
         {
             m_layoutF = layoutMenu->addAction(i18nc("Verb", "Flow"));
             if (m_layoutF != nullptr) {
-                m_layoutF->setIcon(SKGServices::fromTheme(QStringLiteral("text-flow-into-frame")));
+                m_layoutF->setIcon(SKGServices::fromTheme(QLatin1String("text-flow-into-frame")));
                 m_layoutF->setCheckable(true);
                 m_layoutF->setData(0);
                 connect(m_layoutF, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -132,7 +131,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         {
             m_layout1 = layoutMenu->addAction(i18nc("Verb", "1 column"));
             if (m_layout1 != nullptr) {
-                m_layout1->setIcon(SKGServices::fromTheme(QStringLiteral("object-columns")));
+                m_layout1->setIcon(SKGServices::fromTheme(QLatin1String("object-columns")));
                 m_layout1->setCheckable(true);
                 m_layout1->setData(1);
                 connect(m_layout1, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -143,7 +142,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         {
             m_layout2 = layoutMenu->addAction(i18nc("Verb", "2 columns"));
             if (m_layout2 != nullptr) {
-                m_layout2->setIcon(SKGServices::fromTheme(QStringLiteral("object-columns")));
+                m_layout2->setIcon(SKGServices::fromTheme(QLatin1String("object-columns")));
                 m_layout2->setCheckable(true);
                 m_layout2->setData(2);
                 connect(m_layout2, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -154,7 +153,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         {
             m_layout3 = layoutMenu->addAction(i18nc("Verb", "3 columns"));
             if (m_layout3 != nullptr) {
-                m_layout3->setIcon(SKGServices::fromTheme(QStringLiteral("object-columns")));
+                m_layout3->setIcon(SKGServices::fromTheme(QLatin1String("object-columns")));
                 m_layout3->setCheckable(true);
                 m_layout3->setData(3);
                 connect(m_layout3, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -165,7 +164,7 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
         {
             m_layout4 = layoutMenu->addAction(i18nc("Verb", "4 columns"));
             if (m_layout4 != nullptr) {
-                m_layout4->setIcon(SKGServices::fromTheme(QStringLiteral("object-columns")));
+                m_layout4->setIcon(SKGServices::fromTheme(QLatin1String("object-columns")));
                 m_layout4->setCheckable(true);
                 m_layout4->setData(4);
                 connect(m_layout4, &QAction::triggered, this, &SKGDashboardWidget::onChangeLayout);
@@ -190,14 +189,14 @@ SKGDashboardWidget::SKGDashboardWidget(QWidget* iParent, SKGDocument* iDocument,
                 for (int j = 0; j < nbdbw; ++j) {
                     added++;
                     if (added % 10 == 0) {
-                        currentMenu = currentMenu->addMenu(SKGServices::fromTheme(QStringLiteral("list-add")),  i18nc("Verb", "More …"));
+                        currentMenu = currentMenu->addMenu(SKGServices::fromTheme(QLatin1String("list-add")),  i18nc("Verb", "More …"));
                     }
 
                     // Create menu
                     QAction* act = currentMenu->addAction(plugin->getDashboardWidgetTitle(j));
                     if (act != nullptr) {
                         act->setIcon(SKGServices::fromTheme(plugin->icon()));
-                        act->setData(QString(plugin->objectName() % '-' % SKGServices::intToString(j)));
+                        act->setData(QString(plugin->objectName() % QLatin1Char('-') % SKGServices::intToString(j)));
 
                         connect(act, &QAction::triggered, this, &SKGDashboardWidget::onAddWidget);
                     }
@@ -230,10 +229,10 @@ SKGDashboardWidget::~SKGDashboardWidget()
 QString SKGDashboardWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
-    root.setAttribute(QStringLiteral("layout"), m_layout);
+    root.setAttribute(QLatin1String("layout"), m_layout);
 
     int nb = m_items.count();
     for (int i = 0; i < nb; ++i) {
@@ -243,10 +242,10 @@ QString SKGDashboardWidget::getState()
         QStringList param = SKGServices::splitCSVLine(m_items.at(i), '-');
         SKGBoardWidget* item = m_itemsPointers.at(i);
         if (item != nullptr) {
-            element.setAttribute(QStringLiteral("name"), param.at(0));
-            element.setAttribute(QStringLiteral("index"), param.at(1));
-            element.setAttribute(QStringLiteral("state"), item->getState());
-            element.setAttribute(QStringLiteral("zoom"), SKGServices::intToString(item->getZoomRatio() * 5 - 15));
+            element.setAttribute(QLatin1String("name"), param.at(0));
+            element.setAttribute(QLatin1String("index"), param.at(1));
+            element.setAttribute(QLatin1String("state"), item->getState());
+            element.setAttribute(QLatin1String("zoom"), SKGServices::intToString(item->getZoomRatio() * 5 - 15));
         }
     }
     return doc.toString();
@@ -256,11 +255,11 @@ void SKGDashboardWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString layout = root.attribute(QStringLiteral("layout"));
+    QString layout = root.attribute(QLatin1String("layout"));
     if (!layout.isEmpty()) {
         m_layout = SKGServices::stringToInt(layout);
     }
@@ -295,17 +294,17 @@ void SKGDashboardWidget::setState(const QString& iState)
     while (index > 0) {
         QDomElement element = root.firstChildElement("ITEM-" % SKGServices::intToString(index));
         if (!element.isNull()) {
-            SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByName(element.attribute(QStringLiteral("name")));
-            QString indexString = element.attribute(QStringLiteral("index"));
+            SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByName(element.attribute(QLatin1String("name")));
+            QString indexString = element.attribute(QLatin1String("index"));
             if (indexString.isEmpty()) {
                 indexString = '0';
             }
-            QString zoom = element.attribute(QStringLiteral("zoom"));
+            QString zoom = element.attribute(QLatin1String("zoom"));
             if (zoom.isEmpty()) {
                 zoom = '0';
             }
             if (plugin != nullptr) {
-                addItem(plugin, SKGServices::stringToInt(indexString), SKGServices::stringToInt(zoom), element.attribute(QStringLiteral("state")));
+                addItem(plugin, SKGServices::stringToInt(indexString), SKGServices::stringToInt(zoom), element.attribute(QLatin1String("state")));
             }
         } else {
             index = -1;
@@ -314,7 +313,7 @@ void SKGDashboardWidget::setState(const QString& iState)
     }
 
     // In case of reset
-    if (m_items.isEmpty() && root.attribute(QStringLiteral("zoomPosition")).isEmpty()) {
+    if (m_items.isEmpty() && root.attribute(QLatin1String("zoomPosition")).isEmpty()) {
         int index2 = 0;
         while (index2 >= 0) {
             SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index2);
@@ -335,7 +334,7 @@ QList< QWidget* > SKGDashboardWidget::printableWidgets()
 {
     QList< QWidget* > output;
     output.reserve(m_itemsPointers.count());
-    for (auto w : qAsConst(m_itemsPointers)) {
+    for (auto w : std::as_const(m_itemsPointers)) {
         output.push_back(w);
     }
 
@@ -391,7 +390,7 @@ bool SKGDashboardWidget::eventFilter(QObject* iObject, QEvent* iEvent)
                     int distance = (mevent->pos() - m_clickedPoint).manhattanLength();
                     if (distance >= QApplication::startDragDistance()) {
                         auto mimeData = new QMimeData;
-                        mimeData->setData(QStringLiteral("application/x-SKGDashboardWidget"), SKGServices::intToString(toMoveIndex).toLatin1());
+                        mimeData->setData(QLatin1String("application/x-SKGDashboardWidget"), SKGServices::intToString(toMoveIndex).toLatin1());
 
                         auto drag = new QDrag(this);
                         drag->setMimeData(mimeData);
@@ -404,7 +403,7 @@ bool SKGDashboardWidget::eventFilter(QObject* iObject, QEvent* iEvent)
         } else if (iEvent->type() == QEvent::DragEnter) {
             // Drop move
             auto* devent = dynamic_cast<QDragEnterEvent*>(iEvent);
-            if (devent && devent->mimeData()->hasFormat(QStringLiteral("application/x-SKGDashboardWidget"))) {
+            if (devent && devent->mimeData()->hasFormat(QLatin1String("application/x-SKGDashboardWidget"))) {
                 devent->accept();
 
                 return true;
@@ -412,8 +411,8 @@ bool SKGDashboardWidget::eventFilter(QObject* iObject, QEvent* iEvent)
         } else if (iEvent->type() == QEvent::DragMove) {
             // Drop move
             auto* devent = dynamic_cast<QDragMoveEvent*>(iEvent);
-            if (devent && devent->mimeData()->hasFormat(QStringLiteral("application/x-SKGDashboardWidget"))) {
-                int oldPos = SKGServices::stringToInt(devent->mimeData()->data(QStringLiteral("application/x-SKGDashboardWidget")));
+            if (devent && devent->mimeData()->hasFormat(QLatin1String("application/x-SKGDashboardWidget"))) {
+                int oldPos = SKGServices::stringToInt(devent->mimeData()->data(QLatin1String("application/x-SKGDashboardWidget")));
                 if (oldPos != toMoveIndex) {
                     devent->accept();
                 } else {
@@ -425,8 +424,8 @@ bool SKGDashboardWidget::eventFilter(QObject* iObject, QEvent* iEvent)
         } else if (iEvent->type() == QEvent::Drop) {
             // Drop
             auto* devent = dynamic_cast<QDropEvent*>(iEvent);
-            if (devent && devent->mimeData()->hasFormat(QStringLiteral("application/x-SKGDashboardWidget"))) {
-                int oldPos = SKGServices::stringToInt(devent->mimeData()->data(QStringLiteral("application/x-SKGDashboardWidget")));
+            if (devent && devent->mimeData()->hasFormat(QLatin1String("application/x-SKGDashboardWidget"))) {
+                int oldPos = SKGServices::stringToInt(devent->mimeData()->data(QLatin1String("application/x-SKGDashboardWidget")));
 
                 if (oldPos + 1 == toMoveIndex) {
                     ++toMoveIndex;
@@ -591,7 +590,7 @@ void SKGDashboardWidget::addItem(SKGInterfacePlugin* iDashboard, int iIndex, int
             // Set size
             dbw->setZoomRatio((iZoom + 15.0) / 5.0);
 
-            QString id = iDashboard->objectName() % '-' % SKGServices::intToString(iIndex);
+            QString id = iDashboard->objectName() % QLatin1Char('-') % SKGServices::intToString(iIndex);
             m_items.push_back(id);
             m_itemsPointers.push_back(dbw);
         }
