@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -23,7 +23,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGDebugPlugin, "metadata.json")
 
-SKGDebugPlugin::SKGDebugPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
+SKGDebugPlugin::SKGDebugPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -44,21 +46,21 @@ bool SKGDebugPlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skg_debug"), title());
-    setXMLFile(QStringLiteral("skg_debug.rc"));
+    setComponentName(QLatin1String("skg_debug"), title());
+    setXMLFile(QLatin1String("skg_debug.rc"));
 
     // Menu
-    auto restartProfiling = new QAction(SKGServices::fromTheme(QStringLiteral("fork")), i18nc("Restart the profiling, a method used for analysing performances", "Restart profiling"), this);
+    auto restartProfiling = new QAction(SKGServices::fromTheme(QLatin1String("fork")), i18nc("Restart the profiling, a method used for analysing performances", "Restart profiling"), this);
     connect(restartProfiling, &QAction::triggered, this, &SKGDebugPlugin::onRestartProfiling);
-    actionCollection()->setDefaultShortcut(restartProfiling, Qt::CTRL + Qt::Key_Pause);
-    registerGlobalAction(QStringLiteral("debug_restart_profiling"), restartProfiling);
+    actionCollection()->setDefaultShortcut(restartProfiling, Qt::CTRL | Qt::Key_Pause);
+    registerGlobalAction(QLatin1String("debug_restart_profiling"), restartProfiling);
 
     QStringList overlayopen;
-    overlayopen.push_back(QStringLiteral("quickopen"));
-    auto openProfiling = new QAction(SKGServices::fromTheme(QStringLiteral("fork"), overlayopen), i18nc("Open the profiling, a method used for analysing performances", "Open profiling"), this);
+    overlayopen.push_back(QLatin1String("quickopen"));
+    auto openProfiling = new QAction(SKGServices::fromTheme(QLatin1String("fork"), overlayopen), i18nc("Open the profiling, a method used for analysing performances", "Open profiling"), this);
     connect(openProfiling, &QAction::triggered, this, &SKGDebugPlugin::onOpenProfiling);
-    actionCollection()->setDefaultShortcut(openProfiling, Qt::ALT + Qt::Key_Pause);
-    registerGlobalAction(QStringLiteral("debug_open_profiling"), openProfiling);
+    actionCollection()->setDefaultShortcut(openProfiling, Qt::ALT | Qt::Key_Pause);
+    registerGlobalAction(QLatin1String("debug_open_profiling"), openProfiling);
     return true;
 }
 
@@ -75,7 +77,7 @@ QString SKGDebugPlugin::title() const
 
 QString SKGDebugPlugin::icon() const
 {
-    return QStringLiteral("tools-report-bug");
+    return QLatin1String("tools-report-bug");
 }
 
 QString SKGDebugPlugin::toolTip() const
