@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -11,8 +11,11 @@
 #include "skgdebugpluginwidget.h"
 
 #include <qdom.h>
+#ifdef SKG_QT6
 #include <qjsengine.h>
+#else
 #include <qscriptengine.h>
+#endif
 
 #include "skgdocument.h"
 #include "skgmainpanel.h"
@@ -31,16 +34,16 @@ SKGDebugPluginWidget::SKGDebugPluginWidget(QWidget* iParent, SKGDocument* iDocum
     ui.setupUi(this);
 
     // Set icons
-    ui.kSQLPushButton->setIcon(SKGServices::fromTheme(QStringLiteral("system-run")));
-    ui.kSQLTransactionPushButton->setIcon(SKGServices::fromTheme(QStringLiteral("system-run")));
-    ui.kRefreshViewsAndIndexes->setIcon(SKGServices::fromTheme(QStringLiteral("view-refresh")));
+    ui.kSQLPushButton->setIcon(SKGServices::fromTheme(QLatin1String("system-run")));
+    ui.kSQLTransactionPushButton->setIcon(SKGServices::fromTheme(QLatin1String("system-run")));
+    ui.kRefreshViewsAndIndexes->setIcon(SKGServices::fromTheme(QLatin1String("view-refresh")));
 
     // Fill combo box
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("system-run")), i18nc("Execute an SQL query", "Execute"));
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("system-run")), i18nc("Execute an SQL queries (one per line)", "Execute multi queries"));
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("help-hint")), i18nc("Explain an SQL query", "Explain"));
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("games-hint")), i18nc("Explain the SQL query plan", "Explain query plan"));
-    ui.kExplainCmb->addItem(SKGServices::fromTheme(QStringLiteral("media-playback-start")), i18nc("Execute script", "Execute script [%1]", "javascript"));
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QLatin1String("system-run")), i18nc("Execute an SQL query", "Execute"));
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QLatin1String("system-run")), i18nc("Execute an SQL queries (one per line)", "Execute multi queries"));
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QLatin1String("help-hint")), i18nc("Explain an SQL query", "Explain"));
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QLatin1String("games-hint")), i18nc("Explain the SQL query plan", "Explain query plan"));
+    ui.kExplainCmb->addItem(SKGServices::fromTheme(QLatin1String("media-playback-start")), i18nc("Execute script", "Execute script [%1]", "javascript"));
     ui.kInput->setVisible(false);
 
     // Set level trace
@@ -51,20 +54,20 @@ SKGDebugPluginWidget::SKGDebugPluginWidget(QWidget* iParent, SKGDocument* iDocum
 
     // Init debug page
     QStringList tables;
-    ui.kSQLInput->addItem(QStringLiteral("SELECT * FROM sqlite_master;"));
-    iDocument->getDistinctValues(QStringLiteral("sqlite_master"), QStringLiteral("name"), QStringLiteral("type in ('table', 'view')"), tables);
+    ui.kSQLInput->addItem(QLatin1String("SELECT * FROM sqlite_master;"));
+    iDocument->getDistinctValues(QLatin1String("sqlite_master"), QLatin1String("name"), QLatin1String("type in ('table', 'view')"), tables);
     int nb = tables.count();
     for (int i = 0; i < nb; ++i) {
-        ui.kSQLInput->addItem("SELECT * FROM " % tables.at(i) % ';');
+        ui.kSQLInput->addItem("SELECT * FROM " % tables.at(i) % QLatin1Char(';'));
     }
-    ui.kSQLInput->addItem(QStringLiteral("ANALYZE;"));
-    ui.kSQLInput->addItem(QStringLiteral("PRAGMA integrity_check;"));
+    ui.kSQLInput->addItem(QLatin1String("ANALYZE;"));
+    ui.kSQLInput->addItem(QLatin1String("PRAGMA integrity_check;"));
     for (int i = 0; i < nb; ++i) {
         ui.kSQLInput->addItem("PRAGMA table_info(" % tables.at(i) % ");");
         ui.kSQLInput->addItem("PRAGMA index_list(" % tables.at(i) % ");");
     }
 
-    iDocument->getDistinctValues(QStringLiteral("sqlite_master"), QStringLiteral("name"), QStringLiteral("type='index'"), tables);
+    iDocument->getDistinctValues(QLatin1String("sqlite_master"), QLatin1String("name"), QLatin1String("type='index'"), tables);
     nb = tables.count();
     for (int i = 0; i < nb; ++i) {
         ui.kSQLInput->addItem("PRAGMA index_info(" % tables.at(i) % ");");
@@ -85,14 +88,14 @@ SKGDebugPluginWidget::~SKGDebugPluginWidget()
 QString SKGDebugPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("explain"), ui.kExplainCmb->currentIndex());
-    root.setAttribute(QStringLiteral("enableProfiling"), ui.kEnableProfilingChk->checkState() == Qt::Checked ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("levelTraces"), ui.kTraceLevel->value());
-    root.setAttribute(QStringLiteral("sqlOrder"), ui.kSQLInput->currentText());
+    root.setAttribute(QLatin1String("explain"), ui.kExplainCmb->currentIndex());
+    root.setAttribute(QLatin1String("enableProfiling"), ui.kEnableProfilingChk->checkState() == Qt::Checked ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("levelTraces"), ui.kTraceLevel->value());
+    root.setAttribute(QLatin1String("sqlOrder"), ui.kSQLInput->currentText());
 
     return doc.toString();
 }
@@ -100,21 +103,21 @@ QString SKGDebugPluginWidget::getState()
 void SKGDebugPluginWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString explain = root.attribute(QStringLiteral("explain"));
-    QString enableProfiling = root.attribute(QStringLiteral("enableProfiling"));
-    QString levelTraces = root.attribute(QStringLiteral("levelTraces"));
-    QString sqlOrder = root.attribute(QStringLiteral("sqlOrder"));
-    QString sqlResult = root.attribute(QStringLiteral("sqlResult"));
+    QString explain = root.attribute(QLatin1String("explain"));
+    QString enableProfiling = root.attribute(QLatin1String("enableProfiling"));
+    QString levelTraces = root.attribute(QLatin1String("levelTraces"));
+    QString sqlOrder = root.attribute(QLatin1String("sqlOrder"));
+    QString sqlResult = root.attribute(QLatin1String("sqlResult"));
 
     if (!explain.isEmpty()) {
-        ui.kExplainCmb->setCurrentIndex(SKGServices::stringToInt(explain == QStringLiteral("Y") ? QStringLiteral("1") : std::move(explain)));
+        ui.kExplainCmb->setCurrentIndex(SKGServices::stringToInt(explain == QLatin1String("Y") ? QLatin1String("1") : std::move(explain)));
     }
     if (!enableProfiling.isEmpty()) {
-        ui.kEnableProfilingChk->setCheckState(enableProfiling == QStringLiteral("Y") ? Qt::Checked : Qt::Unchecked);
+        ui.kEnableProfilingChk->setCheckState(enableProfiling == QLatin1String("Y") ? Qt::Checked : Qt::Unchecked);
     }
     if (!levelTraces.isEmpty()) {
         ui.kTraceLevel->setValue(SKGServices::stringToInt(levelTraces));
@@ -162,16 +165,20 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
     if (exp == 4) {
         // Script execution
         ui.kSQLResult->clear();
+#ifdef SKG_QT6
         QJSEngine myEngine;
+#else
+        QScriptEngine myEngine;
+#endif
         // skgresult.setText(skgdocument.getUniqueIdentifier())
-        // skgerror=skgdocument.sendMessage(QStringLiteral("Hello"))
-        // skgerror=skgdocument.sendMessage(QStringLiteral("Hello"))
+        // skgerror=skgdocument.sendMessage(QLatin1String("Hello"))
+        // skgerror=skgdocument.sendMessage(QLatin1String("Hello"))
         // skgmainpanel.closeAllOtherPages(skgmainpanel.currentPage())
         auto t = myEngine.globalObject();
-        t.setProperty(QStringLiteral("skgresult"), myEngine.newQObject(ui.kSQLResult));
-        t.setProperty(QStringLiteral("skgdocument"), myEngine.newQObject(getDocument()));
-        // t.setProperty(QStringLiteral("skgerror"), myEngine.newQObject(&err));
-        t.setProperty(QStringLiteral("skgmainpanel"), myEngine.newQObject(SKGMainPanel::getMainPanel()));
+        t.setProperty(QLatin1String("skgresult"), myEngine.newQObject(ui.kSQLResult));
+        t.setProperty(QLatin1String("skgdocument"), myEngine.newQObject(getDocument()));
+        // t.setProperty(QLatin1String("skgerror"), myEngine.newQObject(&err));
+        t.setProperty(QLatin1String("skgmainpanel"), myEngine.newQObject(SKGMainPanel::getMainPanel()));
 
         // Finally execute the scripting code.
         myEngine.evaluate(ui.kInput->toPlainText());
