@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -30,8 +30,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGDeletePlugin, "metadata.json")
 
-SKGDeletePlugin::SKGDeletePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
+SKGDeletePlugin::SKGDeletePlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -49,16 +50,16 @@ bool SKGDeletePlugin::setupActions(SKGDocument* iDocument)
 
     m_currentDocument = iDocument;
 
-    setComponentName(QStringLiteral("skg_delete"), title());
-    setXMLFile(QStringLiteral("skg_delete.rc"));
+    setComponentName(QLatin1String("skg_delete"), title());
+    setXMLFile(QLatin1String("skg_delete.rc"));
 
     // Menu
     QStringList tmp;
-    m_currentDocument->getDistinctValues(QStringLiteral("sqlite_master"), QStringLiteral("name"), QStringLiteral("type='table' AND name!='parameters'"), tmp);
-    auto actDelete = new QAction(SKGServices::fromTheme(QStringLiteral("edit-delete")), i18nc("Verb, delete an item", "Delete"), this);
+    m_currentDocument->getDistinctValues(QLatin1String("sqlite_master"), QLatin1String("name"), QLatin1String("type='table' AND name!='parameters'"), tmp);
+    auto actDelete = new QAction(SKGServices::fromTheme(QLatin1String("edit-delete")), i18nc("Verb, delete an item", "Delete"), this);
     connect(actDelete, &QAction::triggered, this, &SKGDeletePlugin::onDelete);
     actionCollection()->setDefaultShortcut(actDelete, Qt::Key_Delete);
-    registerGlobalAction(QStringLiteral("edit_delete"), actDelete, tmp, 1, -1, 200, true);
+    registerGlobalAction(QLatin1String("edit_delete"), actDelete, tmp, 1, -1, 200, true);
     return true;
 }
 
@@ -80,9 +81,9 @@ void SKGDeletePlugin::onDelete()
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
         if (nb > 0) {
-            if (selection[0].getRealTable() == QStringLiteral("doctransaction")) {
-                err = m_currentDocument->beginTransaction(QStringLiteral("#INTERNAL#"));
-                IFOKDO(err, m_currentDocument->executeSqliteOrder(QStringLiteral("CREATE TRIGGER fkdc_doctransaction_doctransaction_i_parent_id "
+            if (selection[0].getRealTable() == QLatin1String("doctransaction")) {
+                err = m_currentDocument->beginTransaction(QLatin1String("#INTERNAL#"));
+                IFOKDO(err, m_currentDocument->executeSqliteOrder(QLatin1String("CREATE TRIGGER fkdc_doctransaction_doctransaction_i_parent_id "
                         "BEFORE DELETE ON doctransaction "
                         "FOR EACH ROW BEGIN "
                         "    DELETE FROM doctransaction WHERE OLD.t_name!='#INTERNAL#' AND doctransaction.id = OLD.i_parent; "
@@ -90,7 +91,7 @@ void SKGDeletePlugin::onDelete()
                 for (int i = 0; !err && i < nb; ++i) {
                     err = selection.at(i).remove();
                 }
-                m_currentDocument->executeSqliteOrder(QStringLiteral("DROP TRIGGER IF EXISTS fkdc_doctransaction_doctransaction_i_parent_id"));
+                m_currentDocument->executeSqliteOrder(QLatin1String("DROP TRIGGER IF EXISTS fkdc_doctransaction_doctransaction_i_parent_id"));
                 SKGENDTRANSACTION(m_currentDocument,  err)
             } else {
                 SKGBEGINPROGRESSTRANSACTION(*m_currentDocument, i18nc("Verb, delete an item", "Delete"), err, nb)
@@ -98,23 +99,13 @@ void SKGDeletePlugin::onDelete()
                     err = selection.at(i).remove();
                     if (err && err.getReturnCode() == ERR_FORCEABLE) {
                         QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-#ifdef SKG_KF_5102
                         int rc = KMessageBox::questionTwoActions(SKGMainPanel::getMainPanel(),
                                  err.getFullMessage() % '\n' % i18nc("Question",  "Do you want to force the deletion ?"),
                                  i18nc("Question",  "Do you want to force the deletion ?"),
                                  KStandardGuiItem::del(), KStandardGuiItem::cancel(),
-                                 QStringLiteral("forcedelete"));
+                                 QLatin1String("forcedelete"));
                         QApplication::restoreOverrideCursor();
                         if (rc == KMessageBox::PrimaryAction) {
-#else
-                        int rc = KMessageBox::questionYesNo(SKGMainPanel::getMainPanel(),
-                                                            err.getFullMessage() % '\n' % i18nc("Question",  "Do you want to force the deletion ?"),
-                                                            i18nc("Question",  "Do you want to force the deletion ?"),
-                                                            KStandardGuiItem::yes(), KStandardGuiItem::no(),
-                                                            QStringLiteral("forcedelete"));
-                        QApplication::restoreOverrideCursor();
-                        if (rc == KMessageBox::Yes) {
-#endif
                             err = selection.at(i).remove(true, true);
                         }
                     }
@@ -124,7 +115,7 @@ void SKGDeletePlugin::onDelete()
         }
 
         //
-        KMessageBox::enableMessage(QStringLiteral("forcedelete"));
+        KMessageBox::enableMessage(QLatin1String("forcedelete"));
 
         // status bar
         IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Objects deleted.")))
