@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -36,9 +36,11 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGFilePlugin, "metadata.json")
 
-SKGFilePlugin::SKGFilePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent),
-    m_saveAction(nullptr), m_recentFiles(nullptr), m_currentDocument(nullptr)
+SKGFilePlugin::SKGFilePlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_saveAction(nullptr)
+    , m_recentFiles(nullptr)
+    , m_currentDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -70,21 +72,21 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skg_file"), title());
-    setXMLFile(QStringLiteral("skg_file.rc"));
+    setComponentName(QLatin1String("skg_file"), title());
+    setXMLFile(QLatin1String("skg_file.rc"));
 
     // Menu
-    registerGlobalAction(QStringLiteral("file_new"), KStandardAction::openNew(this, SLOT(onNew()), actionCollection()));
-    registerGlobalAction(QStringLiteral("file_open"), KStandardAction::open(this, SLOT(onOpen()), actionCollection()));
+    registerGlobalAction(QLatin1String("file_new"), KStandardAction::openNew(this, SLOT(onNew()), actionCollection()));
+    registerGlobalAction(QLatin1String("file_open"), KStandardAction::open(this, SLOT(onOpen()), actionCollection()));
 
     m_saveAction = KStandardAction::save(this, SLOT(onSave()), actionCollection());
-    registerGlobalAction(QStringLiteral("file_save"), m_saveAction);
-    registerGlobalAction(QStringLiteral("file_save_as"), KStandardAction::saveAs(this, SLOT(onSaveAs()), actionCollection()));
+    registerGlobalAction(QLatin1String("file_save"), m_saveAction);
+    registerGlobalAction(QLatin1String("file_save_as"), KStandardAction::saveAs(this, SLOT(onSaveAs()), actionCollection()));
 
-    auto actChangePassword = new QAction(SKGServices::fromTheme(QStringLiteral("document-encrypt")),  i18nc("Action allowing the user to change his document password", "Change password…"), this);
+    auto actChangePassword = new QAction(SKGServices::fromTheme(QLatin1String("document-encrypt")),  i18nc("Action allowing the user to change his document password", "Change password…"), this);
     connect(actChangePassword, &QAction::triggered, this, &SKGFilePlugin::onChangePassword);
-    actionCollection()->setDefaultShortcut(actChangePassword, Qt::CTRL + Qt::Key_K);
-    registerGlobalAction(QStringLiteral("file_change_password"), actChangePassword);
+    actionCollection()->setDefaultShortcut(actChangePassword, Qt::CTRL | Qt::Key_K);
+    registerGlobalAction(QLatin1String("file_change_password"), actChangePassword);
 
     // Recent file
     m_recentFiles = KStandardAction::openRecent(this, SLOT(onOpen(QUrl)), actionCollection());
@@ -174,13 +176,13 @@ QWidget* SKGFilePlugin::getPreferenceWidget()
     connect(ui.kcfg_storeInKdeWallet, &QCheckBox::toggled, ui.kcfg_selectedWallet, &SKGComboBox::setEnabled);
 
     ui.kcfg_prefix->addItem(QLatin1String(""));
-    ui.kcfg_prefix->addItem(QStringLiteral("."));
+    ui.kcfg_prefix->addItem(QLatin1String("."));
 
-    ui.kcfg_suffix->addItem(QStringLiteral(".old"));
-    ui.kcfg_suffix->addItem(QStringLiteral(".back"));
-    ui.kcfg_suffix->addItem(QStringLiteral(".<DATE>.back"));
-    ui.kcfg_suffix->addItem(QStringLiteral(".<DATE>.old"));
-    ui.kcfg_suffix->addItem(QStringLiteral("~"));
+    ui.kcfg_suffix->addItem(QLatin1String(".old"));
+    ui.kcfg_suffix->addItem(QLatin1String(".back"));
+    ui.kcfg_suffix->addItem(QLatin1String(".<DATE>.back"));
+    ui.kcfg_suffix->addItem(QLatin1String(".<DATE>.old"));
+    ui.kcfg_suffix->addItem(QLatin1String("~"));
 
     ui.kcfg_selectedWallet->addItems(KWallet::Wallet::walletList());
 
@@ -234,7 +236,7 @@ QString SKGFilePlugin::title() const
 
 QString SKGFilePlugin::icon() const
 {
-    return QStringLiteral("document-save");
+    return QLatin1String("document-save");
 }
 
 QString SKGFilePlugin::toolTip() const
@@ -314,7 +316,7 @@ void SKGFilePlugin::onSaveAs()
     SKGTRACEINFUNCRC(10, err)
     if ((m_currentDocument != nullptr) && (SKGMainPanel::getMainPanel() != nullptr)) {
         QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///" % m_currentDocument->objectName(),
-                           "*." % m_currentDocument->getFileExtension() % '|' % i18nc("Associated with the file extension : for example, .csv --> CSV document", "%1 document", KAboutData::applicationData().displayName()),
+                           "*." % m_currentDocument->getFileExtension() % QLatin1Char('|') % i18nc("Associated with the file extension : for example, .csv --> CSV document", "%1 document", KAboutData::applicationData().displayName()),
                            SKGMainPanel::getMainPanel());
         if (fileName.isEmpty()) {
             return;
@@ -386,7 +388,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
             if (QFile(tmpFile).exists()) {
                 KMessageWidget* msg = SKGMainPanel::getMainPanel()->displayMessage(i18nc("Warning message", "Your document has been restored from its temporary file. You can decide to reopen the original document."), SKGDocument::Warning);
                 auto reopen = new QAction(i18nc("Noun", "Reopen"), msg);
-                reopen->setIcon(SKGServices::fromTheme(QStringLiteral("quickopen")));
+                reopen->setIcon(SKGServices::fromTheme(QLatin1String("quickopen")));
                 reopen->setData(fileName);
                 msg->addAction(reopen);
                 connect(reopen, &QAction::triggered, this, &SKGFilePlugin::onReOpen);
@@ -414,13 +416,13 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
 
                     // Get password
                     if (useKWallet) {
-                        SKGTRACEL(10) << "Use KWallet" << SKGENDL;
+                        SKGTRACEL(10) << "Use KWallet" << Qt::endl;
                         // Use KWallet
                         QString walletName = skgfile_settings::selectedWallet();
                         if (!KWallet::Wallet::walletList().contains(walletName)) {
                             walletName = KWallet::Wallet::walletList().value(SKGServices::stringToInt(skgfile_settings::selectedWallet()));
                             if (walletName.isEmpty()) {
-                                walletName = QStringLiteral("kdewallet");
+                                walletName = QLatin1String("kdewallet");
                             }
                         }
                         KWallet::Wallet* w = KWallet::Wallet::openWallet(walletName, SKGMainPanel::getMainPanel()->winId());
@@ -434,7 +436,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
                             // Read password
                             w->readPassword(fileName, pwd);
                             if (pwd.isEmpty()) {
-                                SKGTRACEL(10) << "Password not found in KWallet for " << fileName << SKGENDL;
+                                SKGTRACEL(10) << "Password not found in KWallet for " << fileName << Qt::endl;
                                 useKWallet = false;
                             }
 
@@ -444,7 +446,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
                     }
 
                     if (!useKWallet) {
-                        SKGTRACEL(10) << "Ask password" << SKGENDL;
+                        SKGTRACEL(10) << "Ask password" << Qt::endl;
                         // Use password dialog
                         QPointer<KPasswordDialog> dlg = new KPasswordDialog(SKGMainPanel::getMainPanel());
                         dlg->setPrompt(additionalMessage % i18nc("Question", "This file seems to be protected.\nPlease enter the password."));
@@ -504,7 +506,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
                     if (!KWallet::Wallet::walletList().contains(walletName)) {
                         walletName = KWallet::Wallet::walletList().value(SKGServices::stringToInt(skgfile_settings::selectedWallet()));
                         if (walletName.isEmpty()) {
-                            walletName = QStringLiteral("kdewallet");
+                            walletName = QLatin1String("kdewallet");
                         }
                     }
                     KWallet::Wallet* w = KWallet::Wallet::openWallet(walletName, SKGMainPanel::getMainPanel()->winId());
@@ -531,7 +533,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
 #ifdef Q_OS_UNIX
             if (true || err.getReturnCode() == ERR_CORRUPTION) {
                 recovery = new QAction(i18nc("Noun", "Try a recovery"), this);
-                recovery->setIcon(SKGServices::fromTheme(QStringLiteral("games-solve")));
+                recovery->setIcon(SKGServices::fromTheme(QLatin1String("games-solve")));
                 recovery->setData(SKGServices::stringsToCsv(QStringList() << fileName << pwd));
                 connect(recovery, &QAction::triggered, this, &SKGFilePlugin::onRecover);
             }
@@ -567,7 +569,7 @@ void SKGFilePlugin::onRecover()
             // Display recovery message
             KMessageWidget* msg = SKGMainPanel::getMainPanel()->displayMessage(i18nc("Positive message", "Your document has been recovered here: %1\nTake care the recovery could be not perfect", recoveredFileName), SKGDocument::Positive);
             auto reopen = new QAction(i18nc("Noun", "Open the recovered file"), msg);
-            reopen->setIcon(SKGServices::fromTheme(QStringLiteral("quickopen")));
+            reopen->setIcon(SKGServices::fromTheme(QLatin1String("quickopen")));
             reopen->setData(recoveredFileName);
             msg->addAction(reopen);
             connect(reopen, &QAction::triggered, this, &SKGFilePlugin::onReOpen);
@@ -611,9 +613,9 @@ SKGAdviceList SKGFilePlugin::advice(const QStringList& iIgnoredAdvice)
     SKGAdviceList output;
 
     // Backup
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgfileplugin_notvalidated"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgfileplugin_notvalidated"))) {
         SKGAdvice ad;
-        ad.setUUID(QStringLiteral("skgfileplugin_notvalidated"));
+        ad.setUUID(QLatin1String("skgfileplugin_notvalidated"));
         ad.setPriority(2);
         ad.setShortMessage(i18nc("Advice to the user that he should backup his document", "Backup your document"));
         ad.setLongMessage(i18nc("Explain the user that he should backup his document", "Do not forget to backup your document on another device."));
