@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -25,8 +25,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGHighlightPlugin, "metadata.json")
 
-SKGHighlightPlugin::SKGHighlightPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
+SKGHighlightPlugin::SKGHighlightPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -44,19 +45,19 @@ bool SKGHighlightPlugin::setupActions(SKGDocument* iDocument)
 
     m_currentDocument = iDocument;
 
-    setComponentName(QStringLiteral("skg_highlight"), title());
-    setXMLFile(QStringLiteral("skg_highlight.rc"));
+    setComponentName(QLatin1String("skg_highlight"), title());
+    setXMLFile(QLatin1String("skg_highlight.rc"));
 
     // ------------
-    auto actSwitchHighLight = new QAction(SKGServices::fromTheme(QStringLiteral("bookmarks")), i18nc("Verb", "Switch highlight"), this);
+    auto actSwitchHighLight = new QAction(SKGServices::fromTheme(QLatin1String("bookmarks")), i18nc("Verb", "Switch highlight"), this);
     connect(actSwitchHighLight, &QAction::triggered, this, &SKGHighlightPlugin::onSwitchHighLight);
-    actionCollection()->setDefaultShortcut(actSwitchHighLight, Qt::CTRL + Qt::Key_H);
-    registerGlobalAction(QStringLiteral("edit_switch_highlight"), actSwitchHighLight, QStringList() << QStringLiteral("query:type='table' AND sql LIKE '%t_bookmarked%'"), 1, -1, 301);
+    actionCollection()->setDefaultShortcut(actSwitchHighLight, Qt::CTRL | Qt::Key_H);
+    registerGlobalAction(QLatin1String("edit_switch_highlight"), actSwitchHighLight, QStringList() << QLatin1String("query:type='table' AND sql LIKE '%t_bookmarked%'"), 1, -1, 301);
 
     // ------------
-    auto actSwitchClose = new QAction(SKGServices::fromTheme(QStringLiteral("dialog-close")), i18nc("Verb", "Switch close"), this);
+    auto actSwitchClose = new QAction(SKGServices::fromTheme(QLatin1String("dialog-close")), i18nc("Verb", "Switch close"), this);
     connect(actSwitchClose, &QAction::triggered, this, &SKGHighlightPlugin::onSwitchClose);
-    registerGlobalAction(QStringLiteral("edit_switch_close"), actSwitchClose, QStringList() << QStringLiteral("query:type='table' AND sql LIKE '%t_close%'"), 1, -1, 301);
+    registerGlobalAction(QLatin1String("edit_switch_close"), actSwitchClose, QStringList() << QLatin1String("query:type='table' AND sql LIKE '%t_close%'"), 1, -1, 301);
 
     // Create yours actions here
     return true;
@@ -69,7 +70,7 @@ QString SKGHighlightPlugin::title() const
 
 QString SKGHighlightPlugin::icon() const
 {
-    return QStringLiteral("bookmarks");
+    return QLatin1String("bookmarks");
 }
 
 QString SKGHighlightPlugin::toolTip() const
@@ -94,7 +95,7 @@ void SKGHighlightPlugin::onSwitchClose()
             SKGBEGINPROGRESSTRANSACTION(*m_currentDocument, i18nc("Noun, name of the user action", "Close"), err, nb)
             for (int i = 0; !err && i < nb; ++i) {
                 SKGObjectBase obj(selection.at(i));
-                IFOKDO(err, obj.setAttribute(QStringLiteral("t_close"), obj.getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y") ? QStringLiteral("N") : QStringLiteral("Y")))
+                IFOKDO(err, obj.setAttribute(QLatin1String("t_close"), obj.getAttribute(QLatin1String("t_close")) == QLatin1String("Y") ? QLatin1String("N") : QLatin1String("Y")))
                 IFOKDO(err, obj.save())
 
                 // Send message
@@ -127,7 +128,7 @@ void SKGHighlightPlugin::onSwitchHighLight()
             SKGBEGINPROGRESSTRANSACTION(*m_currentDocument, i18nc("Noun, name of the user action", "Highlight"), err, nb)
             for (int i = 0; !err && i < nb; ++i) {
                 SKGObjectBase obj(selection.at(i));
-                IFOKDO(err, obj.setAttribute(QStringLiteral("t_bookmarked"), obj.getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y") ? QStringLiteral("N") : QStringLiteral("Y")))
+                IFOKDO(err, obj.setAttribute(QLatin1String("t_bookmarked"), obj.getAttribute(QLatin1String("t_bookmarked")) == QLatin1String("Y") ? QLatin1String("N") : QLatin1String("Y")))
                 IFOKDO(err, obj.save())
 
                 // Send message
