@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGDOCUMENTFILTER_H
@@ -10,13 +10,18 @@
  *
  * @author Stephane MANKOWSKI
  */
-#include <grantlee/filter.h>
 #include <qobject.h>
+#ifdef SKG_QT6
+#include <KTextTemplate/Filter>
+#else
+#include <grantlee/filter.h>
+#define KTextTemplate Grantlee
+#endif
 
 /**
  * The grantlee's filter to get items of a document table
  */
-class SKGDocumentTableFilter final : public Grantlee::Filter
+class SKGDocumentTableFilter final : public KTextTemplate::Filter
 {
 public:
     Q_DISABLE_COPY(SKGDocumentTableFilter)
@@ -45,7 +50,7 @@ public:
 /**
  * The grantlee's filter to execute a sql query on the document
  */
-class SKGDocumentQueryFilter final : public Grantlee::Filter
+class SKGDocumentQueryFilter final : public KTextTemplate::Filter
 {
 public:
     Q_DISABLE_COPY(SKGDocumentQueryFilter)
@@ -74,7 +79,7 @@ public:
 /**
  * The grantlee's filter to get display of an attribute
  */
-class SKGDocumentDisplayFilter final : public Grantlee::Filter
+class SKGDocumentDisplayFilter final : public KTextTemplate::Filter
 {
 public:
     Q_DISABLE_COPY(SKGDocumentDisplayFilter)
@@ -103,7 +108,7 @@ public:
 /**
  * The grantlee's filter to format percent
  */
-class SKGPercentFilter final : public Grantlee::Filter
+class SKGPercentFilter final : public KTextTemplate::Filter
 {
 public:
     Q_DISABLE_COPY(SKGPercentFilter)
@@ -132,7 +137,7 @@ public:
 /**
  * The grantlee's filter to format file size
  */
-class SKGFileSizeFilter final : public Grantlee::Filter
+class SKGFileSizeFilter final : public KTextTemplate::Filter
 {
 public:
     Q_DISABLE_COPY(SKGFileSizeFilter)
@@ -161,7 +166,7 @@ public:
 /**
  * The grantlee's filter to dump objects
  */
-class SKGDumpFilter final : public Grantlee::Filter
+class SKGDumpFilter final : public KTextTemplate::Filter
 {
 public:
     Q_DISABLE_COPY(SKGDumpFilter)
@@ -190,7 +195,7 @@ public:
 /**
  * The grantlee's filter to format money
  */
-class SKGMoneyFilter final : public Grantlee::Filter
+class SKGMoneyFilter final : public KTextTemplate::Filter
 {
 public:
     Q_DISABLE_COPY(SKGMoneyFilter)
@@ -219,7 +224,7 @@ public:
 /**
  * The grantlee's filter to encode url
  */
-class SKGUrlEncodeFilter final : public Grantlee::Filter
+class SKGUrlEncodeFilter final : public KTextTemplate::Filter
 {
 public:
     Q_DISABLE_COPY(SKGUrlEncodeFilter)
@@ -248,7 +253,7 @@ public:
 /**
  * The grantlee's filter to replace in strings
  */
-class SKGReplaceFilter final : public Grantlee::Filter
+class SKGReplaceFilter final : public KTextTemplate::Filter
 {
 public:
     Q_DISABLE_COPY(SKGReplaceFilter)
