@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGGRANTLEEFILTERS_H
@@ -10,16 +10,21 @@
  *
  * @author Stephane MANKOWSKI
  */
+#ifdef SKG_QT6
+#include <KTextTemplate/TagLibraryInterface>
+#else
 #include <grantlee/taglibraryinterface.h>
+#define KTextTemplate Grantlee
+#endif
 #include <qobject.h>
 
 /**
  * The grantlee's plugin to define filters
  */
-class SKGGrantleeFilters : public QObject, public Grantlee::TagLibraryInterface
+class SKGGrantleeFilters : public QObject, public KTextTemplate::TagLibraryInterface
 {
     Q_OBJECT
-    Q_INTERFACES(Grantlee::TagLibraryInterface)
+    Q_INTERFACES(KTextTemplate::TagLibraryInterface)
     Q_PLUGIN_METADATA(IID "org.grantlee.TagLibraryInterface")
 
 public:
@@ -38,7 +43,7 @@ public:
      * @param iName the name
      * @return the implementations
      */
-    QHash<QString, Grantlee::Filter*> filters(const QString& iName = QString()) override;
+    QHash<QString, KTextTemplate::Filter*> filters(const QString& iName = QString()) override;
 };
 
 #endif  // SKGGRANTLEEFILTERS_H
