@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGOBJECTFILTER_H
@@ -10,13 +10,18 @@
  *
  * @author Stephane MANKOWSKI
  */
-#include <grantlee/filter.h>
 #include <qobject.h>
+#ifdef SKG_QT6
+#include <KTextTemplate/Filter>
+#else
+#include <grantlee/filter.h>
+#define KTextTemplate Grantlee
+#endif
 
 /**
  * The grantlee's filter to get attribute of an object
  */
-class SKGObjectFilter : public Grantlee::Filter
+class SKGObjectFilter : public KTextTemplate::Filter
 {
 public:
     /**
