@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -33,9 +33,10 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGMonthlyPlugin, "metadata.json")
 
-SKGMonthlyPlugin::SKGMonthlyPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent),
-    m_currentBankDocument(nullptr), m_mainPage(nullptr)
+SKGMonthlyPlugin::SKGMonthlyPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
+    , m_mainPage(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -56,27 +57,27 @@ bool SKGMonthlyPlugin::setupActions(SKGDocument* iDocument)
     SKGTRACEINFUNC(10)
     m_currentBankDocument = iDocument;
 
-    setComponentName(QStringLiteral("skg_monthly"), title());
-    setXMLFile(QStringLiteral("skg_monthly.rc"));
+    setComponentName(QLatin1String("skg_monthly"), title());
+    setXMLFile(QLatin1String("skg_monthly.rc"));
 
     // Make needed paths
     QString writablePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-    QString path = writablePath % QLatin1Char('/') + KAboutData::applicationData().componentName() % QStringLiteral("/html/default");
-    if (!QDir(writablePath).mkpath(KAboutData::applicationData().componentName() % QStringLiteral("/html/default"))) {
-        SKGTRACE << "WARNING: Impossible to create  html/default in " << writablePath << SKGENDL;
+    QString path = writablePath % QLatin1Char('/') + KAboutData::applicationData().componentName() % QLatin1String("/html/default");
+    if (!QDir(writablePath).mkpath(KAboutData::applicationData().componentName() % QLatin1String("/html/default"))) {
+        SKGTRACE << "WARNING: Impossible to create  html/default in " << writablePath << Qt::endl;
     }
 
     // Copy "default" directory in locale
     const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, KAboutData::applicationData().componentName() % "/html/default", QStandardPaths::LocateDirectory);
     for (const auto& dir : dirs) {
-        QDirIterator it(dir, QStringList() << QStringLiteral("*.html"));
+        QDirIterator it(dir, QStringList() << QLatin1String("*.html"));
         while (it.hasNext()) {
             QString file = it.next();
 
             QString target = path % QLatin1Char('/') % QFileInfo(file).fileName();
             QFile(target).remove();
             if (file != target && !QFile(file).copy(target)) {
-                SKGTRACE << "WARNING: Impossible to copie " << file << " in " << target << SKGENDL;
+                SKGTRACE << "WARNING: Impossible to copie " << file << " in " << target << Qt::endl;
             }
         }
     }
@@ -92,14 +93,7 @@ QStringList SKGMonthlyPlugin::processArguments(const QStringList& iArgument)
 #ifdef SKG_WEBENGINE
         m_mainPage = new SKGWebView(SKGMainPanel::getMainPanel(), nullptr, false);
 #endif
-#ifdef SKG_WEBKIT
-        m_mainPage = new QWebView();
-        m_mainPage->page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
-        connect(m_mainPage, &QWebView::linkClicked, this, [ = ](const QUrl & val) {
-            SKGMainPanel::getMainPanel()->openPage(val);
-        });
-#endif
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#if !defined(SKG_WEBENGINE)
         m_mainPage = new QLabel(SKGMainPanel::getMainPanel());
         m_mainPage->setTextFormat(Qt::RichText);
         //m_mainPage->setOpenLinks(true);
@@ -138,10 +132,7 @@ void SKGMonthlyPlugin::refreshMainPage()
 #ifdef SKG_WEBENGINE
         m_mainPage->setHtml(html, QUrl("file://"));
 #endif
-#ifdef SKG_WEBKIT
-        m_mainPage->setHtml(html);
-#endif
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#if !defined(SKG_WEBENGINE)
         m_mainPage->setText(html);
 #endif
     }
@@ -160,7 +151,7 @@ QString SKGMonthlyPlugin::title() const
 
 QString SKGMonthlyPlugin::icon() const
 {
-    return QStringLiteral("view-calendar-journal");
+    return QLatin1String("view-calendar-journal");
 }
 
 QString SKGMonthlyPlugin::toolTip() const
