@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGMONTHLYPLUGIN_H
@@ -15,10 +15,7 @@
 #ifdef SKG_WEBENGINE
 class QWebEngineView;
 #endif
-#ifdef SKG_WEBKIT
-class QWebView;
-#endif
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#if !defined(SKG_WEBENGINE)
 class QLabel;
 #endif
 
@@ -35,7 +32,7 @@ public:
     /**
      * Default Constructor
      */
-    explicit SKGMonthlyPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
+    explicit SKGMonthlyPlugin(QWidget* iWidget, QObject* iParent, const KPluginMetaData& metaData, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -113,10 +110,7 @@ private:
 #ifdef SKG_WEBENGINE
     QWebEngineView* m_mainPage;
 #endif
-#ifdef SKG_WEBKIT
-    QWebView* m_mainPage;
-#endif
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#if !defined(SKG_WEBENGINE)
     QLabel* m_mainPage;
 #endif
 };
