@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -13,7 +13,11 @@
 #include <kaboutdata.h>
 #include <kzip.h>
 
+#ifdef SKG_QT6
+#include <KNSWidgets/Dialog>
+#else
 #include <kns3/qtquickdialogwrapper.h>
+#endif
 #include <qdesktopservices.h>
 #include <qdir.h>
 #include <qdom.h>
@@ -23,9 +27,6 @@
 #ifdef SKG_WEBENGINE
 #include <qwebenginepage.h>
 #endif
-#ifdef SKG_WEBKIT
-#include <qwebframe.h>
-#endif
 #include <qdiriterator.h>
 #include <qstandardpaths.h>
 #include <qvalidator.h>
@@ -47,19 +48,19 @@ SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(QWidget* iParent, SKGDocument* iD
     ui.kMonth->setMode(SKGSimplePeriodEdit::PREVIOUS_PERIODS | SKGSimplePeriodEdit::PREVIOUS_MONTHS);
     ui.kDeleteTemplate->hide();
 
-    ui.kRefresh->setIcon(SKGServices::fromTheme(QStringLiteral("view-refresh")));
-    ui.kGetNewHotStuff->setIcon(SKGServices::fromTheme(QStringLiteral("get-hot-new-stuff")));
-    ui.kDeleteTemplate->setIcon(SKGServices::fromTheme(QStringLiteral("edit-delete")));
+    ui.kRefresh->setIcon(SKGServices::fromTheme(QLatin1String("view-refresh")));
+    ui.kGetNewHotStuff->setIcon(SKGServices::fromTheme(QLatin1String("get-hot-new-stuff")));
+    ui.kDeleteTemplate->setIcon(SKGServices::fromTheme(QLatin1String("edit-delete")));
 
-    auto newValidator = new QRegularExpressionValidator(QRegularExpression(QStringLiteral("^[\\w\\s]+$")), this);
+    auto newValidator = new QRegularExpressionValidator(QRegularExpression(QLatin1String("^[\\w\\s]+$")), this);
     ui.kTemplate->setValidator(newValidator);
 
     connect(getDocument(), &SKGDocument::tableModified, this, &SKGMonthlyPluginWidget::dataModified, Qt::QueuedConnection);
     connect(ui.kMonth, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGMonthlyPluginWidget::onPeriodChanged, Qt::QueuedConnection);
 
     QStringList overlays;
-    overlays.push_back(QStringLiteral("list-add"));
-    m_upload = new QAction(SKGServices::fromTheme(QStringLiteral("get-hot-new-stuff"), overlays), i18n("Upload"), this);
+    overlays.push_back(QLatin1String("list-add"));
+    m_upload = new QAction(SKGServices::fromTheme(QLatin1String("get-hot-new-stuff"), overlays), i18n("Upload"), this);
     connect(m_upload, &QAction::triggered, this, &SKGMonthlyPluginWidget::onPutNewHotStuff);
 
     auto menu = new QMenu(this);
@@ -85,14 +86,14 @@ SKGMonthlyPluginWidget::~SKGMonthlyPluginWidget()
 QString SKGMonthlyPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
     // Get state
-    root.setAttribute(QStringLiteral("month"), ui.kMonth->text());
-    root.setAttribute(QStringLiteral("template"), ui.kTemplate->text());
-    root.setAttribute(QStringLiteral("web"), ui.kWebView->getState());
+    root.setAttribute(QLatin1String("month"), ui.kMonth->text());
+    root.setAttribute(QLatin1String("template"), ui.kTemplate->text());
+    root.setAttribute(QLatin1String("web"), ui.kWebView->getState());
 
     return doc.toString();
 }
@@ -100,17 +101,17 @@ QString SKGMonthlyPluginWidget::getState()
 void SKGMonthlyPluginWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     // Set state
-    QString webS = root.attribute(QStringLiteral("web"));
+    QString webS = root.attribute(QLatin1String("web"));
     if (!webS.isEmpty()) {
         ui.kWebView->setState(webS);
     }
 
-    QString templat = root.attribute(QStringLiteral("template"));
+    QString templat = root.attribute(QLatin1String("template"));
     if (!templat.isEmpty()) {
         bool p = ui.kTemplate->blockSignals(true);
         ui.kTemplate->setText(templat);
@@ -118,7 +119,7 @@ void SKGMonthlyPluginWidget::setState(const QString& iState)
         onTemplateChanged();
     }
 
-    QString month = root.attribute(QStringLiteral("month"));
+    QString month = root.attribute(QLatin1String("month"));
     if (!month.isEmpty()) {
         ui.kMonth->setText(month);
     }
@@ -127,7 +128,7 @@ void SKGMonthlyPluginWidget::setState(const QString& iState)
 
 QString SKGMonthlyPluginWidget::getDefaultStateAttribute()
 {
-    return QStringLiteral("SKGMONTHLY_DEFAULT_PARAMETERS");
+    return QLatin1String("SKGMONTHLY_DEFAULT_PARAMETERS");
 }
 
 QWidget* SKGMonthlyPluginWidget::mainWidget()
@@ -145,13 +146,13 @@ void SKGMonthlyPluginWidget::fillTemplateList()
     ui.kTemplate->clear();
     const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, KAboutData::applicationData().componentName() % "/html", QStandardPaths::LocateDirectory);
     for (const auto& dir : dirs) {
-        QDirIterator it(dir, QStringList() << QStringLiteral("*.txt"));
+        QDirIterator it(dir, QStringList() << QLatin1String("*.txt"));
         while (it.hasNext()) {
             QString file = it.next();
 
             QFileInfo f(file);
             QString file2 = f.completeBaseName();
-            if (!ui.kTemplate->contains(file2) && file2 != QStringLiteral("main")) {
+            if (!ui.kTemplate->contains(file2) && file2 != QLatin1String("main")) {
                 ui.kTemplate->addItem(file2, file);
             }
         }
@@ -172,7 +173,7 @@ void SKGMonthlyPluginWidget::onAddTemplate()
     QStringList templates;
     const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, KAboutData::applicationData().componentName() % "/html", QStandardPaths::LocateDirectory);
     for (const auto& dir : dirs) {
-        QDirIterator it(dir, QStringList() << QStringLiteral("*.txt"));
+        QDirIterator it(dir, QStringList() << QLatin1String("*.txt"));
         while (it.hasNext()) {
             templates.append(it.next());
         }
@@ -183,7 +184,7 @@ void SKGMonthlyPluginWidget::onAddTemplate()
         if (!templates.contains(templatFileName)) {
             // Create the new template
             QString source = QStandardPaths::locate(QStandardPaths::GenericDataLocation, KAboutData::applicationData().componentName() % "/html/tutorial.txt");
-            QDir(templateDir).mkpath(QStringLiteral("html"));
+            QDir(templateDir).mkpath(QLatin1String("html"));
             if (SKGServices::upload(QUrl::fromLocalFile(source), QUrl::fromLocalFile(templatFileName))) {
                 err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Impossible to copy file from '%1' to '%2'", source, templatFileName));
             } else {
@@ -239,13 +240,13 @@ void SKGMonthlyPluginWidget::dataModified(const QString& iTableName, int iIdTran
     QSqlDatabase* db = getDocument()->getMainDatabase();
     setEnabled(db != nullptr);
     // TODO(Stephane MANKOWSKI): v_operation_display must be generic
-    if (db != nullptr && (iTableName == QStringLiteral("v_operation_display") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QLatin1String("v_operation_display") || iTableName.isEmpty())) {
         // Fill combo
 
         QDate date = QDate::currentDate();
         QStringList list;
         // TODO(Stephane MANKOWSKI): v_operation_display must be generic
-        getDocument()->getDistinctValues(QStringLiteral("v_operation_display"), QStringLiteral("MIN(d_DATEMONTH)"), QStringLiteral("d_date<=CURRENT_DATE"), list);
+        getDocument()->getDistinctValues(QLatin1String("v_operation_display"), QLatin1String("MIN(d_DATEMONTH)"), QLatin1String("d_date<=CURRENT_DATE"), list);
         if (!list.isEmpty()) {
             if (!list[0].isEmpty()) {
                 date = SKGServices::periodToDate(list[0]);
@@ -280,11 +281,7 @@ void SKGMonthlyPluginWidget::onPeriodChanged()
 #ifdef SKG_WEBENGINE
         ui.kWebView->page()->setHtml(htmlReport, QUrl("file://"));
 #endif
-#ifdef SKG_WEBKIT
-        ui.kWebView->setHtml(htmlReport);
-        ui.kWebView->page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
-#endif
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#if !defined(SKG_WEBENGINE)
         ui.kWebView->setHtml(htmlReport);
 #endif
     }
@@ -292,7 +289,11 @@ void SKGMonthlyPluginWidget::onPeriodChanged()
 
 void SKGMonthlyPluginWidget::onGetNewHotStuff()
 {
+#ifdef SKG_QT6
+    QPointer<KNSWidgets::Dialog> dialog = new KNSWidgets::Dialog(KAboutData::applicationData().componentName() % "_monthly.knsrc", this);
+#else
     QPointer<KNS3::QtQuickDialogWrapper> dialog = new KNS3::QtQuickDialogWrapper(KAboutData::applicationData().componentName() % "_monthly.knsrc", this);
+#endif
     dialog->exec();
 
     fillTemplateList();
@@ -321,20 +322,7 @@ void SKGMonthlyPluginWidget::onPutNewHotStuff()
 #ifdef SKG_WEBENGINE
         // TODO(SMI): QWebEngine
 #endif
-#ifdef SKG_WEBKIT
-        bool previous = ui.kWebView->blockSignals(true);
-        QWebFrame* frame = ui.kWebView->page()->mainFrame();
-        frame->setScrollBarValue(Qt::Vertical, frame->scrollBarMaximum(Qt::Vertical));
-        ui.kWebView->exportInFile(preview2);
-
-        frame->setScrollBarValue(Qt::Vertical, frame->scrollBarMaximum(Qt::Vertical) / 2);
-        ui.kWebView->exportInFile(preview3);
-
-        frame->setScrollBarValue(Qt::Vertical, 0);
-        ui.kWebView->exportInFile(preview1);
-        ui.kWebView->blockSignals(previous);
-#endif
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#if !defined(SKG_WEBENGINE)
         // TODO(SMI): QTextBrowser
 #endif
         // Open dialog
