@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGPRINTPLUGIN_H
@@ -14,11 +14,7 @@
 #ifdef SKG_WEBENGINE
 #include <qwebengineview.h>
 #endif
-#ifdef SKG_WEBKIT
-#include <qwebframe.h>
-#include <qwebview.h>
-#endif
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#if !defined(SKG_WEBENGINE)
 #include <qtextbrowser.h>
 #endif
 
@@ -37,7 +33,7 @@ public:
     /**
      * Default Constructor
      */
-    explicit SKGPrintPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
+    explicit SKGPrintPlugin(QWidget* iWidget, QObject* iParent, const KPluginMetaData& metaData, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -91,10 +87,7 @@ private:
 #ifdef SKG_WEBENGINE
     QWebEngineView m_toPrint;
 #endif
-#ifdef SKG_WEBKIT
-    QWebView m_toPrint;
-#endif
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#if !defined(SKG_WEBENGINE)
     QTextEdit m_toPrint;
 #endif
     Ui::skgprintplugin_pref ui {};
