@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -29,16 +29,19 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGPropertiesPlugin, "metadata.json")
 
-SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent),
-    m_currentDocument(nullptr), m_dockWidget(nullptr), m_dockContent(nullptr), m_addPropertyMenu(nullptr)
+SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentDocument(nullptr)
+    , m_dockWidget(nullptr)
+    , m_dockContent(nullptr)
+    , m_addPropertyMenu(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
 
     // Get list of bills
     m_billsProcess.setStandardOutputFile(QDir::tempPath() % "/skg_bills.csv");
-    m_billsProcess.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << QStringLiteral("boobill bills  -q -f csv -v"));
+    m_billsProcess.start(QLatin1String("/bin/bash"), QStringList() << QLatin1String("-c") << QLatin1String("boobill bills  -q -f csv -v"));
 
     connect(&m_billsProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &SKGPropertiesPlugin::onBillsRetreived);
     connect(&m_billsProcess, static_cast<void (QProcess::*)(QProcess::ProcessError)>(&QProcess::errorOccurred), this, &SKGPropertiesPlugin::onBillsRetreived);
@@ -86,27 +89,27 @@ bool SKGPropertiesPlugin::setupActions(SKGDocument* iDocument)
 
     m_currentDocument = iDocument;
 
-    setComponentName(QStringLiteral("skg_properties"), title());
-    setXMLFile(QStringLiteral("skg_properties.rc"));
+    setComponentName(QLatin1String("skg_properties"), title());
+    setXMLFile(QLatin1String("skg_properties.rc"));
 
     m_dockContent = new SKGPropertiesPluginDockWidget(SKGMainPanel::getMainPanel(), m_currentDocument);
     if (m_dockContent != nullptr) {
         connect(m_dockContent, &SKGPropertiesPluginDockWidget::selectionChanged, SKGMainPanel::getMainPanel(), &SKGMainPanel::refresh);
         m_dockWidget = new QDockWidget(SKGMainPanel::getMainPanel());
         if (m_dockWidget != nullptr) {
-            m_dockWidget->setObjectName(QStringLiteral("skg_properties_docwidget"));
+            m_dockWidget->setObjectName(QLatin1String("skg_properties_docwidget"));
             m_dockWidget->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
             m_dockWidget->setWindowTitle(title());
             m_dockWidget->setWidget(m_dockContent);
 
             // add action to control hide / display of Bookmarks
             QAction* toggle = m_dockWidget->toggleViewAction();
-            QAction* panelAction = actionCollection()->addAction(QStringLiteral("view_properties"));
-            registerGlobalAction(QStringLiteral("view_properties"), panelAction);
+            QAction* panelAction = actionCollection()->addAction(QLatin1String("view_properties"));
+            registerGlobalAction(QLatin1String("view_properties"), panelAction);
             panelAction->setCheckable(true);
             panelAction->setChecked(toggle->isChecked());
             panelAction->setText(toggle->text());
-            actionCollection()->setDefaultShortcut(panelAction, Qt::SHIFT + Qt::Key_F12);
+            actionCollection()->setDefaultShortcut(panelAction, Qt::SHIFT | Qt::Key_F12);
             connect(panelAction, &QAction::triggered, toggle, &QAction::trigger);
             connect(toggle, &QAction::toggled, panelAction, &QAction::setChecked);
         }
@@ -114,11 +117,15 @@ bool SKGPropertiesPlugin::setupActions(SKGDocument* iDocument)
 
     // Menu
     auto actAddProperty = new KToolBarPopupAction(SKGServices::fromTheme(icon()), i18nc("Allows user to add a user defined property on an object", "Add property"), this);
-    m_addPropertyMenu = actAddProperty->menu();
+    m_addPropertyMenu = actAddProperty->popupMenu();
     connect(m_addPropertyMenu, &QMenu::aboutToShow, this, &SKGPropertiesPlugin::onShowAddPropertyMenu);
+#ifdef SKG_QT6
+
+#else
     actAddProperty->setStickyMenu(false);
     actAddProperty->setDelayed(false);
-    registerGlobalAction(QStringLiteral("add_property"), actAddProperty, QStringList() << QStringLiteral("query:type='table' AND name NOT LIKE 'doctransaction%'"), 1, -1, 450);
+#endif
+    registerGlobalAction(QLatin1String("add_property"), actAddProperty, QStringList() << QLatin1String("query:type='table' AND name NOT LIKE 'doctransaction%'"), 1, -1, 450);
     return true;
 }
 
@@ -163,7 +170,7 @@ void SKGPropertiesPlugin::onDownloadAndAddBills()
         // Get parameters
         QStringList list = act->data().toStringList();
         const QString& id = list.at(0);
-        QString fileName = QDir::tempPath() % '/' % list.at(3) % '.' % list.at(2);
+        QString fileName = QDir::tempPath() % QLatin1Char('/') % list.at(3) % QLatin1Char('.') % list.at(2);
 
         // Create properties
         IFOK(err) {
@@ -173,18 +180,18 @@ void SKGPropertiesPlugin::onDownloadAndAddBills()
             for (int i = 0; !err && i < nb; ++i) {
                 // Download the files
                 QFile::remove(fileName);
-                QString cmd = "boobill download " % id % " \"" % fileName % '"';
+                QString cmd = "boobill download " % id % " \"" % fileName % QLatin1Char('"');
                 QProcess p;
-                p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
+                p.start(QLatin1String("/bin/bash"), QStringList() << QLatin1String("-c") << cmd);
                 if (!p.waitForFinished(60000) || p.exitCode() != 0) {
                     err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, p.exitCode()));
                 } else {
                     IFOKDO(err, m_currentDocument->stepForward(2 * i))
 
                     IFOKDO(err, selection.at(i).setProperty(i18nc("Noun", "Bill"), id, fileName))
-                    QStringList importedBills = SKGServices::splitCSVLine(m_currentDocument->getParameter(QStringLiteral("SKG_IMPORTED_BILLS")));
+                    QStringList importedBills = SKGServices::splitCSVLine(m_currentDocument->getParameter(QLatin1String("SKG_IMPORTED_BILLS")));
                     importedBills.push_back(id);
-                    IFOKDO(err, m_currentDocument->setParameter(QStringLiteral("SKG_IMPORTED_BILLS"), SKGServices::stringsToCsv(importedBills)))
+                    IFOKDO(err, m_currentDocument->setParameter(QLatin1String("SKG_IMPORTED_BILLS"), SKGServices::stringsToCsv(importedBills)))
                     IFOKDO(err, m_currentDocument->stepForward(2 * i + 1))
 
                     QFile::remove(fileName);
@@ -260,10 +267,10 @@ void SKGPropertiesPlugin::onShowAddPropertyMenu()
                     }
 
                     // Create action
-                    QStringList importedBills = SKGServices::splitCSVLine(m_currentDocument->getParameter(QStringLiteral("SKG_IMPORTED_BILLS")));
+                    QStringList importedBills = SKGServices::splitCSVLine(m_currentDocument->getParameter(QLatin1String("SKG_IMPORTED_BILLS")));
 
                     QMenu* menuMore = nullptr;
-                    QIcon icond = SKGServices::fromTheme(icon(), QStringList() << QStringLiteral("download"));
+                    QIcon icond = SKGServices::fromTheme(icon(), QStringList() << QLatin1String("download"));
                     QSet<QString> backendDone;
                     for (int j = 1; j < nb2; ++j) {
                         // id;date;format;label;idparent;price;currency;deadline;startdate;finishdate
@@ -288,7 +295,7 @@ void SKGPropertiesPlugin::onShowAddPropertyMenu()
                                 }
 
                                 // Should the string below be translated ??? It contains no word…
-                                QAction* act = menu->addAction(icond, i18nc("Add a property (attribute=value)", "Download and add %1 (%2)", fields[3] % '.' % fields[2], fields[0]));
+                                QAction* act = menu->addAction(icond, i18nc("Add a property (attribute=value)", "Download and add %1 (%2)", fields[3] % QLatin1Char('.') % fields[2], fields[0]));
                                 if (act != nullptr) {
                                     act->setToolTip(fields[0]);
                                     act->setData(fields);
@@ -328,7 +335,7 @@ QString SKGPropertiesPlugin::title() const
 
 QString SKGPropertiesPlugin::icon() const
 {
-    return QStringLiteral("tag");
+    return QLatin1String("tag");
 }
 
 int SKGPropertiesPlugin::getOrder() const
