@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -44,11 +44,11 @@ SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget(QWidget* iParent, S
     ui.kRemove->setMaximumWidth(ui.kRemove->height());
     ui.kSelectFile->setMaximumWidth(ui.kSelectFile->height());
 
-    ui.kAdd->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
-    ui.kRename->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
-    ui.kRemove->setIcon(SKGServices::fromTheme(QStringLiteral("list-remove")));
-    ui.kSelectFile->setIcon(SKGServices::fromTheme(QStringLiteral("document-open")));
-    ui.kOpenBtn->setIcon(SKGServices::fromTheme(QStringLiteral("quickopen")));
+    ui.kAdd->setIcon(SKGServices::fromTheme(QLatin1String("list-add")));
+    ui.kRename->setIcon(SKGServices::fromTheme(QLatin1String("dialog-ok")));
+    ui.kRemove->setIcon(SKGServices::fromTheme(QLatin1String("list-remove")));
+    ui.kSelectFile->setIcon(SKGServices::fromTheme(QLatin1String("document-open")));
+    ui.kOpenBtn->setIcon(SKGServices::fromTheme(QLatin1String("quickopen")));
 
     ui.kAttribute->lineEdit()->setPlaceholderText(i18n("Name"));
     ui.kValue->lineEdit()->setPlaceholderText(i18n("Value"));
@@ -57,7 +57,7 @@ SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget(QWidget* iParent, S
     ui.kForCmb->addItem(i18n("All"));
 
     // Add model
-    auto modelview = new SKGObjectModelBase(getDocument(), QStringLiteral("parameters"), QStringLiteral("1=1 ORDER BY t_uuid_parent, t_name"), this, QLatin1String(""), false);
+    auto modelview = new SKGObjectModelBase(getDocument(), QLatin1String("parameters"), QLatin1String("1=1 ORDER BY t_uuid_parent, t_name"), this, QLatin1String(""), false);
     auto modelproxy = new SKGSortFilterProxyModel(this);
     modelproxy->setSourceModel(modelview);
     ui.kView->setModel(modelproxy);
@@ -68,11 +68,11 @@ SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget(QWidget* iParent, S
         modelproxy->setFilterFixedString(itext);
     });
 
-    auto actOpenPropertyFileAction = new QAction(QStringLiteral("internal action to open property file"), this);
+    auto actOpenPropertyFileAction = new QAction(QLatin1String("internal action to open property file"), this);
     connect(actOpenPropertyFileAction, &QAction::triggered, this, &SKGPropertiesPluginDockWidget::onOpenPropertyFileByUrl);
-    SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("open_property_file"), actOpenPropertyFileAction);
+    SKGMainPanel::getMainPanel()->registerGlobalAction(QLatin1String("open_property_file"), actOpenPropertyFileAction);
 
-    ui.kView->setDefaultSaveParameters(getDocument(), QStringLiteral("SKG_DEFAULT_PROPERTIES"));
+    ui.kView->setDefaultSaveParameters(getDocument(), QLatin1String("SKG_DEFAULT_PROPERTIES"));
     connect(modelview, &SKGObjectModelBase::beforeReset, ui.kView, &SKGTreeView::saveSelection);
     connect(modelview, &SKGObjectModelBase::afterReset, ui.kView, &SKGTreeView::resetSelection);
     connect(ui.kView, &SKGTableView::selectionChangedDelayed, this, &SKGPropertiesPluginDockWidget::onSelectionChanged);
@@ -101,14 +101,14 @@ void SKGPropertiesPluginDockWidget::refresh()
     if (model != nullptr) {
         QString filter;
         if (ui.kForCmb->currentIndex() == 1) {
-            filter = QStringLiteral("t_uuid_parent!='document' AND t_name NOT LIKE 'SKG_%'");
+            filter = QLatin1String("t_uuid_parent!='document' AND t_name NOT LIKE 'SKG_%'");
             ui.kAdd->setEnabled(false);
             ui.kSelectFile->setEnabled(false);
             ui.kRemove->setEnabled(false);
             ui.kAttribute->setEnabled(false);
             ui.kValue->setEnabled(false);
         } else if (ui.kForCmb->currentIndex() == 0) {
-            filter = QStringLiteral("t_uuid_parent IN (");
+            filter = QLatin1String("t_uuid_parent IN (");
             SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
             int nb = selection.count();
             if (nb != 0) {
@@ -125,7 +125,7 @@ void SKGPropertiesPluginDockWidget::refresh()
                     } else {
                         tableName = selection.at(i).getRealTable();
                     }
-                    filter += '\'' % selection.at(i).getUniqueID() % '\'';
+                    filter += '\'' % selection.at(i).getUniqueID() % QLatin1Char('\'');
                 }
 
                 // Fill combo box
@@ -133,19 +133,19 @@ void SKGPropertiesPluginDockWidget::refresh()
                 if (t.startsWith(QLatin1String("sub"))) {
                     t = t.right(t.length() - 3);
                 }
-                SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAttribute, getDocument(), QStringLiteral("parameters"), QStringLiteral("t_name"), "(t_uuid_parent like '%-" % t % "' OR t_uuid_parent like '%-sub" % t % "') AND t_name NOT LIKE 'SKG_%'");
-                SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kValue, getDocument(), QStringLiteral("parameters"), QStringLiteral("t_value"), "(t_uuid_parent like '%-" % t % "' OR t_uuid_parent like '%-sub" % t % "') AND t_name NOT LIKE 'SKG_%'");
+                SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAttribute, getDocument(), QLatin1String("parameters"), QLatin1String("t_name"), "(t_uuid_parent like '%-" % t % "' OR t_uuid_parent like '%-sub" % t % "') AND t_name NOT LIKE 'SKG_%'");
+                SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kValue, getDocument(), QLatin1String("parameters"), QLatin1String("t_value"), "(t_uuid_parent like '%-" % t % "' OR t_uuid_parent like '%-sub" % t % "') AND t_name NOT LIKE 'SKG_%'");
             } else {
-                filter += QStringLiteral("'XXX'");  // Always false
+                filter += QLatin1String("'XXX'");  // Always false
                 ui.kAdd->setEnabled(false);
                 ui.kSelectFile->setEnabled(false);
                 ui.kRemove->setEnabled(false);
                 ui.kAttribute->setEnabled(false);
                 ui.kValue->setEnabled(false);
             }
-            filter += QStringLiteral(") AND t_name NOT LIKE 'SKG_%'");
+            filter += QLatin1String(") AND t_name NOT LIKE 'SKG_%'");
         }
-        filter += QStringLiteral(" ORDER BY t_uuid_parent, t_name");
+        filter += QLatin1String(" ORDER BY t_uuid_parent, t_name");
         ui.kView->saveSelection();
 
         model->setFilter(filter);
@@ -172,14 +172,14 @@ void SKGPropertiesPluginDockWidget::onSelectionChanged()
     if (nbSelected > 0) {
         SKGObjectBase::SKGListSKGObjectBase objs = getSelectedObjects();
         SKGPropertyObject obj(objs.at(0));
-        ui.kAttribute->setText(obj.getAttribute(QStringLiteral("t_name")));
-        ui.kValue->setText(obj.getAttribute(QStringLiteral("t_value")));
+        ui.kAttribute->setText(obj.getAttribute(QLatin1String("t_name")));
+        ui.kValue->setText(obj.getAttribute(QLatin1String("t_value")));
 
         if (nbSelected == 1) {
             QUrl u = obj.getUrl(true);
 
             ui.kOpenBtn->show();
-            if (u.scheme() == QStringLiteral("file")) {
+            if (u.scheme() == QLatin1String("file")) {
                 ui.kPicture->show();
                 ui.kPicture->showPreview(u);
             }
@@ -198,7 +198,7 @@ void SKGPropertiesPluginDockWidget::openPropertyFile(const SKGPropertyObject& iP
     QUrl url = iProp.getUrl(true);
 
     if (!url.scheme().isEmpty() && !QDesktopServices::openUrl(url)) {
-        QString fileNameToSave = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"), QLatin1String(""), SKGMainPanel::getMainPanel());
+        QString fileNameToSave = SKGMainPanel::getSaveFileName(QLatin1String("kfiledialog:///IMPEXP"), QLatin1String(""), SKGMainPanel::getMainPanel());
         if (!fileNameToSave.isEmpty()) {
             QFile(url.toLocalFile()).copy(fileNameToSave);
         }
@@ -244,25 +244,14 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
         QVariant blob;
         QFile file(value);
         if (file.exists()) {
-#ifdef SKG_KF_5102
             int mode = KMessageBox::questionTwoActionsCancel(this, i18nc("Question", "Do you want copy or link the file?"),
                        QString(),
-                       KGuiItem(i18nc("Question", "Copy"), QStringLiteral("edit-copy")),
-                       KGuiItem(i18nc("Question", "Link"), QStringLiteral("edit-link")));
+                       KGuiItem(i18nc("Question", "Copy"), QLatin1String("edit-copy")),
+                       KGuiItem(i18nc("Question", "Link"), QLatin1String("edit-link")));
             if (mode == KMessageBox::Cancel) {
                 return;
             }
             if (mode == KMessageBox::PrimaryAction) {
-#else
-            int mode = KMessageBox::questionYesNoCancel(this, i18nc("Question", "Do you want copy or link the file?"),
-                       QString(),
-                       KGuiItem(i18nc("Question", "Copy"), QStringLiteral("edit-copy")),
-                       KGuiItem(i18nc("Question", "Link"), QStringLiteral("edit-link")));
-            if (mode == KMessageBox::Cancel) {
-                return;
-            }
-            if (mode == KMessageBox::Yes) {
-#endif
 
                 // Value is a file name ==> blob
                 if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) {
