@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -21,21 +21,22 @@
 
 #include <qapplication.h>
 #include <qcryptographichash.h>
-#include <qdesktopwidget.h>
 #include <qdir.h>
 #include <qjsondocument.h>
 #include <qscreen.h>
 
 #include "skgmainpanel.h"
 #include "skgtraces.h"
+#include <utility>
 
 /**
  * This plugin factory.
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGStatisticPlugin, "metadata.json")
 
-SKGStatisticPlugin::SKGStatisticPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
+SKGStatisticPlugin::SKGStatisticPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     m_timeInit = QDateTime::currentDateTime();
@@ -49,7 +50,7 @@ SKGStatisticPlugin::~SKGStatisticPlugin()
 {
     SKGTRACEINFUNC(10)
     // Set duration
-    m_stats[QStringLiteral("avg.exec_time_sec")] = (m_stats.value(QStringLiteral("avg.exec_time_sec")).toDouble() * (m_stats.value(QStringLiteral("nb_launch")).toInt() - 1) + m_timeInit.secsTo(QDateTime::currentDateTime())) / m_stats.value(QStringLiteral("nb_launch")).toInt();
+    m_stats[QLatin1String("avg.exec_time_sec")] = (m_stats.value(QLatin1String("avg.exec_time_sec")).toDouble() * (m_stats.value(QLatin1String("nb_launch")).toInt() - 1) + m_timeInit.secsTo(QDateTime::currentDateTime())) / m_stats.value(QLatin1String("nb_launch")).toInt();
 
     // Write stat file
     writeStats();
@@ -63,8 +64,8 @@ bool SKGStatisticPlugin::setupActions(SKGDocument* iDocument)
 
     m_currentDocument = iDocument;
 
-    setComponentName(QStringLiteral("skg_statistic"), title());
-    setXMLFile(QStringLiteral("skg_statistic.rc"));
+    setComponentName(QLatin1String("skg_statistic"), title());
+    setXMLFile(QLatin1String("skg_statistic.rc"));
     return true;
 }
 
@@ -78,7 +79,7 @@ void SKGStatisticPlugin::refresh()
                 // Connect actions
                 QMap<QString, QPointer<QAction> > actions = SKGMainPanel::getMainPanel()->getGlobalActions();
                 QStringList keys = actions.keys();
-                for (const auto& k : qAsConst(keys)) {
+                for (const auto& k : std::as_const(keys)) {
                     QPointer<QAction> act = actions[k];
                     connect(act.data(), &QAction::triggered, this, &SKGStatisticPlugin::triggerAction);
                 }
@@ -100,55 +101,55 @@ void SKGStatisticPlugin::refresh()
                 readStats();
 
                 // Initial values
-                if (!m_stats.contains(QStringLiteral("init.date"))) {
-                    m_stats[QStringLiteral("init.date")] = QDate::currentDate();
-                    m_stats[QStringLiteral("init.qt_version")] = qVersion();
-                    m_stats[QStringLiteral("init.app_name")] = appname;
-                    m_stats[QStringLiteral("init.app_version")] = KAboutData::applicationData().version();
+                if (!m_stats.contains(QLatin1String("init.date"))) {
+                    m_stats[QLatin1String("init.date")] = QDate::currentDate();
+                    m_stats[QLatin1String("init.qt_version")] = qVersion();
+                    m_stats[QLatin1String("init.app_name")] = appname;
+                    m_stats[QLatin1String("init.app_version")] = KAboutData::applicationData().version();
                 }
-                m_stats[QStringLiteral("nb_launch")] = m_stats.value(QStringLiteral("nb_launch")).toInt() + 1;
+                m_stats[QLatin1String("nb_launch")] = m_stats.value(QLatin1String("nb_launch")).toInt() + 1;
 
                 // Current values
-                m_stats[QStringLiteral("current.date")] = QDate::currentDate();
-                m_stats[QStringLiteral("current.qt_version")] = qVersion();
-                m_stats[QStringLiteral("current.app_version")] = KAboutData::applicationData().version();
-                m_stats[QStringLiteral("current.language")] = QLocale::languageToString(QLocale().language());
-                m_stats[QStringLiteral("current.country")] = QLocale::countryToString(QLocale().country());
-                m_stats[QStringLiteral("current.country.code")] = QLocale().name().split(QStringLiteral("_")).at(0);
-                m_stats[QStringLiteral("current.locale")] = QLocale().name();
+                m_stats[QLatin1String("current.date")] = QDate::currentDate();
+                m_stats[QLatin1String("current.qt_version")] = qVersion();
+                m_stats[QLatin1String("current.app_version")] = KAboutData::applicationData().version();
+                m_stats[QLatin1String("current.language")] = QLocale::languageToString(QLocale().language());
+                m_stats[QLatin1String("current.country")] = QLocale::countryToString(QLocale().country());
+                m_stats[QLatin1String("current.country.code")] = QLocale().name().split(QLatin1String("_")).at(0);
+                m_stats[QLatin1String("current.locale")] = QLocale().name();
 
                 // OS
 #ifdef Q_OS_WIN32
-                QString os = QStringLiteral("Windows");
+                QString os = QLatin1String("Windows");
 #elif defined(Q_OS_FREEBSD)
-                QString os = QStringLiteral("FreeBSD");
+                QString os = QLatin1String("FreeBSD");
 #elif defined(Q_OS_NETBSD)
-                QString os = QStringLiteral("NetBSD");
+                QString os = QLatin1String("NetBSD");
 #elif defined(Q_OS_OPENBSD)
-                QString os = QStringLiteral("OpenBSD");
+                QString os = QLatin1String("OpenBSD");
 #elif defined(Q_OS_LINUX)
-                QString os = QStringLiteral("Linux");
+                QString os = QLatin1String("Linux");
 #elif defined(Q_OS_MAC)
-                QString os = QStringLiteral("Mac OS");
+                QString os = QLatin1String("Mac OS");
 #else
-                QString os = QStringLiteral("Unknown");
+                QString os = QLatin1String("Unknown");
 #endif
-                m_stats[QStringLiteral("current.os")] = os;
+                m_stats[QLatin1String("current.os")] = os;
                 QRect scr = QGuiApplication::primaryScreen()->geometry();
-                m_stats[QStringLiteral("current.screen")] = QString(SKGServices::intToString(scr.width()) % 'x' % SKGServices::intToString(scr.height()));
+                m_stats[QLatin1String("current.screen")] = QString(SKGServices::intToString(scr.width()) % QLatin1Char('x') % SKGServices::intToString(scr.height()));
 
 #ifdef HAVE_UNAME
                 struct utsname buf {};
                 if (uname(&buf) != -1) {
-                    m_stats[QStringLiteral("current.os.machine")] = QString::fromLocal8Bit(buf.machine);
-                    m_stats[QStringLiteral("current.os.version")] = QString::fromLocal8Bit(buf.version);
+                    m_stats[QLatin1String("current.os.machine")] = QString::fromLocal8Bit(buf.machine);
+                    m_stats[QLatin1String("current.os.version")] = QString::fromLocal8Bit(buf.version);
                 }
 #endif
 
                 // Nb calls
                 QMap<QString, QPointer<QAction> > actions = SKGMainPanel::getMainPanel()->getGlobalActions();
                 QStringList keys = actions.keys();
-                for (const auto& k : qAsConst(keys)) {
+                for (const auto& k : std::as_const(keys)) {
                     QPointer<QAction> act = actions[k];
                     if (act != nullptr) {
                         QString id = "nb_call." % act->objectName();
@@ -157,12 +158,12 @@ void SKGStatisticPlugin::refresh()
                         }
                     }
                 }
-                m_stats[QStringLiteral("document.uuid")] = docUUID;
+                m_stats[QLatin1String("document.uuid")] = docUUID;
 
                 // Set tables sizes
                 QStringList tables;
                 m_currentDocument->getTablesList(tables);
-                for (const auto& t : qAsConst(tables)) {
+                for (const auto& t : std::as_const(tables)) {
                     QString r;
                     m_currentDocument->executeSingleSelectSqliteOrder("SELECT COUNT(1) FROM " % t, r);
                     m_stats["count." % t] = SKGServices::stringToInt(r);
@@ -197,7 +198,7 @@ void SKGStatisticPlugin::writeStats()
         data.write(doc);
         data.close();
     } else {
-        SKGTRACE << "ERROR: Impossible to write " << m_file << SKGENDL;
+        SKGTRACE << "ERROR: Impossible to write " << m_file << Qt::endl;
     }
 }
 
@@ -207,7 +208,7 @@ void SKGStatisticPlugin::triggerAction()
     auto* act = qobject_cast< QAction* >(sender());
     if (act != nullptr) {
         QString id = "nb_call." % act->objectName();
-        SKGTRACEL(10) << "SKGStatisticPlugin::triggerAction " << id << "++" << SKGENDL;
+        SKGTRACEL(10) << "SKGStatisticPlugin::triggerAction " << id << "++" << Qt::endl;
         m_stats[id] = m_stats[id].toInt() + 1;
     }
 }
@@ -216,7 +217,7 @@ void SKGStatisticPlugin::pageChanged()
 {
     SKGTabPage::SKGPageHistoryItem currentPage = SKGMainPanel::getMainPanel()->currentPageHistoryItem();
     if (!currentPage.plugin.isEmpty()) {
-        QString id = "nb_activated_" % QString(currentPage.bookmarkID.isEmpty() ? QStringLiteral("page") : QStringLiteral("bookmark")) % "." % currentPage.plugin;
+        QString id = "nb_activated_" % QString(currentPage.bookmarkID.isEmpty() ? QLatin1String("page") : QLatin1String("bookmark")) % "." % currentPage.plugin;
         m_stats[id] = m_stats[id].toInt() + 1;
     }
 }
@@ -225,7 +226,7 @@ void SKGStatisticPlugin::pageOpened()
 {
     SKGTabPage::SKGPageHistoryItem currentPage = SKGMainPanel::getMainPanel()->currentPageHistoryItem();
     if (!currentPage.plugin.isEmpty()) {
-        QString id = "nb_opened_" % QString(currentPage.bookmarkID.isEmpty() ? QStringLiteral("page") : QStringLiteral("bookmark")) % "." % currentPage.plugin;
+        QString id = "nb_opened_" % QString(currentPage.bookmarkID.isEmpty() ? QLatin1String("page") : QLatin1String("bookmark")) % "." % currentPage.plugin;
         m_stats[id] = m_stats[id].toInt() + 1;
     }
 }
@@ -237,7 +238,7 @@ QString SKGStatisticPlugin::title() const
 
 QString SKGStatisticPlugin::icon() const
 {
-    return QStringLiteral("dialog-information");
+    return QLatin1String("dialog-information");
 }
 
 QString SKGStatisticPlugin::toolTip() const
