@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -30,9 +30,15 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGUndoRedoPlugin, "metadata.json")
 
-SKGUndoRedoPlugin::SKGUndoRedoPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent),
-    m_undoSaveAction(nullptr), m_undoAction(nullptr), m_redoAction(nullptr), m_undoMenu(nullptr), m_redoMenu(nullptr), m_currentDocument(nullptr), m_dockWidget(nullptr)
+SKGUndoRedoPlugin::SKGUndoRedoPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_undoSaveAction(nullptr)
+    , m_undoAction(nullptr)
+    , m_redoAction(nullptr)
+    , m_undoMenu(nullptr)
+    , m_redoMenu(nullptr)
+    , m_currentDocument(nullptr)
+    , m_dockWidget(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -56,54 +62,62 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument)
 
     m_currentDocument = iDocument;
 
-    setComponentName(QStringLiteral("skg_undoredo"), title());
-    setXMLFile(QStringLiteral("skg_undoredo.rc"));
+    setComponentName(QLatin1String("skg_undoredo"), title());
+    setXMLFile(QLatin1String("skg_undoredo.rc"));
 
     // Menu
-    m_undoSaveAction = new QAction(SKGServices::fromTheme(QStringLiteral("document-revert")), i18nc("Verb, action to cancel previous action", "Revert document"), this);
+    m_undoSaveAction = new QAction(SKGServices::fromTheme(QLatin1String("document-revert")), i18nc("Verb, action to cancel previous action", "Revert document"), this);
     connect(m_undoSaveAction, &QAction::triggered, this, &SKGUndoRedoPlugin::onUndoSave);
-    actionCollection()->setDefaultShortcut(m_undoSaveAction, Qt::CTRL + Qt::ALT + Qt::Key_Z);
-    registerGlobalAction(QStringLiteral("edit_undolastsave"), m_undoSaveAction);
+    actionCollection()->setDefaultShortcut(m_undoSaveAction, Qt::CTRL | Qt::ALT | Qt::Key_Z);
+    registerGlobalAction(QLatin1String("edit_undolastsave"), m_undoSaveAction);
 
-    m_undoAction = new KToolBarPopupAction(SKGServices::fromTheme(QStringLiteral("edit-undo")), i18nc("Verb, action to cancel previous action", "Undo"), this);
+    m_undoAction = new KToolBarPopupAction(SKGServices::fromTheme(QLatin1String("edit-undo")), i18nc("Verb, action to cancel previous action", "Undo"), this);
     connect(m_undoAction, &KToolBarPopupAction::triggered, this, &SKGUndoRedoPlugin::onUndo);
-    actionCollection()->setDefaultShortcut(m_undoAction, Qt::CTRL + Qt::Key_Z);
+    actionCollection()->setDefaultShortcut(m_undoAction, Qt::CTRL | Qt::Key_Z);
     m_undoAction->setPriority(QAction::LowPriority);
-    m_undoMenu = m_undoAction->menu();
+    m_undoMenu = m_undoAction->popupMenu();
     connect(m_undoMenu, &QMenu::aboutToShow, this, &SKGUndoRedoPlugin::onShowUndoMenu);
-    m_undoAction->setStickyMenu(false);
-    m_undoAction->setData(1);
-    registerGlobalAction(QStringLiteral("edit_undo"), m_undoAction);
+#ifdef SKG_QT6
 
-    m_redoAction = new KToolBarPopupAction(SKGServices::fromTheme(QStringLiteral("edit-redo")), i18nc("Verb, action to redo previous cancelled action", "Redo"), this);
+#else
+    m_undoAction->setStickyMenu(false);
+#endif
+    m_undoAction->setData(1);
+    registerGlobalAction(QLatin1String("edit_undo"), m_undoAction);
+
+    m_redoAction = new KToolBarPopupAction(SKGServices::fromTheme(QLatin1String("edit-redo")), i18nc("Verb, action to redo previous cancelled action", "Redo"), this);
     connect(m_redoAction, &KToolBarPopupAction::triggered, this, &SKGUndoRedoPlugin::onRedo);
-    actionCollection()->setDefaultShortcut(m_redoAction, Qt::CTRL + Qt::SHIFT + Qt::Key_Z);
+    actionCollection()->setDefaultShortcut(m_redoAction, Qt::CTRL | Qt::SHIFT | Qt::Key_Z);
     m_redoAction->setPriority(QAction::LowPriority);
-    m_redoMenu = m_redoAction->menu();
+    m_redoMenu = m_redoAction->popupMenu();
     connect(m_redoMenu, &QMenu::aboutToShow, this, &SKGUndoRedoPlugin::onShowRedoMenu);
+#ifdef SKG_QT6
+
+#else
     m_redoAction->setStickyMenu(false);
+#endif
     m_redoAction->setData(1);
-    registerGlobalAction(QStringLiteral("edit_redo"), m_redoAction);
+    registerGlobalAction(QLatin1String("edit_redo"), m_redoAction);
 
     // Menu
-    auto act = new QAction(SKGServices::fromTheme(QStringLiteral("edit-clear-history")), i18nc("Verb, action to cancel previous action", "Clear history"), this);
+    auto act = new QAction(SKGServices::fromTheme(QLatin1String("edit-clear-history")), i18nc("Verb, action to cancel previous action", "Clear history"), this);
     connect(act, &QAction::triggered, this, &SKGUndoRedoPlugin::onClearHistory);
-    registerGlobalAction(QStringLiteral("edit_clear_history"), act);
+    registerGlobalAction(QLatin1String("edit_clear_history"), act);
 
     // Dock creation
     m_dockWidget = new QDockWidget(SKGMainPanel::getMainPanel());
-    m_dockWidget->setObjectName(QStringLiteral("skg_undoredo_docwidget"));
+    m_dockWidget->setObjectName(QLatin1String("skg_undoredo_docwidget"));
     m_dockWidget->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
     m_dockWidget->setWindowTitle(title());
 
     // add action to control hide / display of history
     QAction* toggle = m_dockWidget->toggleViewAction();
-    QAction* panelAction = actionCollection()->addAction(QStringLiteral("view_transactions"));
-    registerGlobalAction(QStringLiteral("view_transactions"), panelAction);
+    QAction* panelAction = actionCollection()->addAction(QLatin1String("view_transactions"));
+    registerGlobalAction(QLatin1String("view_transactions"), panelAction);
     panelAction->setCheckable(true);
     panelAction->setChecked(toggle->isChecked());
     panelAction->setText(toggle->text());
-    actionCollection()->setDefaultShortcut(panelAction, Qt::SHIFT + Qt::Key_F11);
+    actionCollection()->setDefaultShortcut(panelAction, Qt::SHIFT | Qt::Key_F11);
     connect(panelAction, &QAction::triggered, toggle, &QAction::trigger);
     connect(toggle, &QAction::toggled, panelAction, &QAction::setChecked);
 
@@ -160,8 +174,8 @@ void SKGUndoRedoPlugin::initPreferences()
     if (m_currentDocument != nullptr) {
         KSharedConfigPtr config = KSharedConfig::openConfig();
         KConfigGroup pref = config->group("skg_undoredo");
-        pref.writeEntry("maxNumberOfUndo", SKGServices::stringToInt(m_currentDocument->getParameter(QStringLiteral("SKG_UNDO_MAX_DEPTH"))));
-        pref.writeEntry("cleanHistoryOnSave", (m_currentDocument->getParameter(QStringLiteral("SKG_UNDO_CLEAN_AFTER_SAVE")) == QStringLiteral("Y")));
+        pref.writeEntry("maxNumberOfUndo", SKGServices::stringToInt(m_currentDocument->getParameter(QLatin1String("SKG_UNDO_MAX_DEPTH"))));
+        pref.writeEntry("cleanHistoryOnSave", (m_currentDocument->getParameter(QLatin1String("SKG_UNDO_CLEAN_AFTER_SAVE")) == QLatin1String("Y")));
 
         skgundoredo_settings::self()->read();
     }
@@ -189,14 +203,14 @@ SKGError SKGUndoRedoPlugin::savePreferences() const
     if (m_currentDocument != nullptr) {
         // Read Setting
         QString max = SKGServices::intToString(skgundoredo_settings::maxNumberOfUndo());
-        QString clean = (skgundoredo_settings::cleanHistoryOnSave() ? QStringLiteral("Y") : QStringLiteral("N"));
+        QString clean = (skgundoredo_settings::cleanHistoryOnSave() ? QLatin1String("Y") : QLatin1String("N"));
 
         // Save setting in document
-        if (max != m_currentDocument->getParameter(QStringLiteral("SKG_UNDO_MAX_DEPTH"))) {
-            err = m_currentDocument->setParameter(QStringLiteral("SKG_UNDO_MAX_DEPTH"), max);
+        if (max != m_currentDocument->getParameter(QLatin1String("SKG_UNDO_MAX_DEPTH"))) {
+            err = m_currentDocument->setParameter(QLatin1String("SKG_UNDO_MAX_DEPTH"), max);
         }
-        if (clean != m_currentDocument->getParameter(QStringLiteral("SKG_UNDO_CLEAN_AFTER_SAVE"))) {
-            err = m_currentDocument->setParameter(QStringLiteral("SKG_UNDO_CLEAN_AFTER_SAVE"), clean);
+        if (clean != m_currentDocument->getParameter(QLatin1String("SKG_UNDO_CLEAN_AFTER_SAVE"))) {
+            err = m_currentDocument->setParameter(QLatin1String("SKG_UNDO_CLEAN_AFTER_SAVE"), clean);
         }
     }
     return err;
@@ -209,7 +223,7 @@ QString SKGUndoRedoPlugin::title() const
 
 QString SKGUndoRedoPlugin::icon() const
 {
-    return QStringLiteral("edit-undo");
+    return QLatin1String("edit-undo");
 }
 
 QString SKGUndoRedoPlugin::toolTip() const
@@ -234,18 +248,18 @@ SKGAdviceList SKGUndoRedoPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEINFUNC(10)
     SKGAdviceList output;
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgundoredoplugin_too_big"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgundoredoplugin_too_big"))) {
         // Get nb transaction
         int nbObject = m_currentDocument->getNbTransaction();
         int priority = qMin(10, nbObject / 50);
         if (priority > 0) {
             SKGAdvice ad;
-            ad.setUUID(QStringLiteral("skgundoredoplugin_too_big"));
+            ad.setUUID(QLatin1String("skgundoredoplugin_too_big"));
             ad.setPriority(priority);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "History is too large"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by reducing your history size in settings."));
             QStringList autoCorrections;
-            autoCorrections.push_back(QStringLiteral("skg://edit_clear_history"));
+            autoCorrections.push_back(QLatin1String("skg://edit_clear_history"));
             autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open settings panel"));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
@@ -258,7 +272,7 @@ SKGAdviceList SKGUndoRedoPlugin::advice(const QStringList& iIgnoredAdvice)
 SKGError SKGUndoRedoPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     SKGError err;
-    if ((m_currentDocument != nullptr) && iAdviceIdentifier == QStringLiteral("skgundoredoplugin_too_big")) {
+    if ((m_currentDocument != nullptr) && iAdviceIdentifier == QLatin1String("skgundoredoplugin_too_big")) {
         SKGMainPanel::getMainPanel()->optionsPreferences(this->objectName());
         return err;
     }
@@ -334,11 +348,11 @@ void SKGUndoRedoPlugin::onShowUndoMenu()
         m_undoMenu->clear();
         SKGStringListList listTmp;
         m_currentDocument->executeSelectSqliteOrder(
-            QStringLiteral("SELECT t_name, t_savestep FROM doctransaction WHERE t_mode='U' ORDER BY d_date DESC LIMIT 7"),
+            QLatin1String("SELECT t_name, t_savestep FROM doctransaction WHERE t_mode='U' ORDER BY d_date DESC LIMIT 7"),
             listTmp);
         int nb = listTmp.count();
         for (int i = 1; i < nb; ++i) {
-            QAction* act = m_undoMenu->addAction(listTmp.at(i).at(1) == QStringLiteral("Y") ?  SKGServices::fromTheme(QStringLiteral("document-revert")) : SKGServices::fromTheme(QStringLiteral("edit-undo")), listTmp.at(i).at(0));
+            QAction* act = m_undoMenu->addAction(listTmp.at(i).at(1) == QLatin1String("Y") ?  SKGServices::fromTheme(QLatin1String("document-revert")) : SKGServices::fromTheme(QLatin1String("edit-undo")), listTmp.at(i).at(0));
             if (act != nullptr) {
                 act->setData(i);
                 connect(act, &QAction::triggered, this, &SKGUndoRedoPlugin::onUndo);
@@ -376,11 +390,11 @@ void SKGUndoRedoPlugin::onShowRedoMenu()
         m_redoMenu->clear();
         SKGStringListList listTmp;
         m_currentDocument->executeSelectSqliteOrder(
-            QStringLiteral("SELECT t_name FROM doctransaction WHERE t_mode='R' ORDER BY d_date ASC LIMIT 7"),
+            QLatin1String("SELECT t_name FROM doctransaction WHERE t_mode='R' ORDER BY d_date ASC LIMIT 7"),
             listTmp);
         int nb = listTmp.count();
         for (int i = 1; i < nb; ++i) {
-            QAction* act = m_redoMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-redo")), listTmp.at(i).at(0));
+            QAction* act = m_redoMenu->addAction(SKGServices::fromTheme(QLatin1String("edit-redo")), listTmp.at(i).at(0));
             if (act != nullptr) {
                 act->setData(i);
                 connect(act, &QAction::triggered, this, &SKGUndoRedoPlugin::onRedo);
