@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -31,17 +31,17 @@ SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(QWidget* iParent, SKGDo
     newPalette.setColor(QPalette::Base, Qt::transparent);
     ui.kTransactionList->setPalette(newPalette);
 
-    auto modelview = new SKGObjectModelBase(getDocument(), QStringLiteral("doctransaction"), QStringLiteral("1=1 ORDER BY d_date DESC, id DESC"), this);
+    auto modelview = new SKGObjectModelBase(getDocument(), QLatin1String("doctransaction"), QLatin1String("1=1 ORDER BY d_date DESC, id DESC"), this);
     ui.kTransactionList->setModel(modelview);
     ui.kTransactionList->header()->hide();
 
-    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("edit_clear_history"));
+    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("edit_clear_history"));
     if (act != nullptr) {
         ui.kClearHistoryBtn->setIcon(act->icon());
         connect(ui.kClearHistoryBtn, &QPushButton::clicked, act, &QAction::trigger);
     }
 
-    ui.kTransactionList->setDefaultSaveParameters(getDocument(), QStringLiteral("SKG_DEFAULT_UNDOREDO"));
+    ui.kTransactionList->setDefaultSaveParameters(getDocument(), QLatin1String("SKG_DEFAULT_UNDOREDO"));
 
     connect(ui.kTransactionList, &SKGTableView::doubleClicked, this, &SKGUndoRedoPluginDockWidget::onUndoRedo);
     connect(ui.kTransactionList, &SKGTableView::selectionChangedDelayed, this, &SKGUndoRedoPluginDockWidget::selectionChanged);
@@ -90,7 +90,7 @@ void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex& index)
         SKGObjectBase obj = model->getObject(index);
         int id = obj.getID();
         int lastExecuted = -1;
-        mode = (obj.getAttribute(QStringLiteral("t_mode")) == QStringLiteral("U") ? SKGDocument::UNDO : SKGDocument::REDO);
+        mode = (obj.getAttribute(QLatin1String("t_mode")) == QLatin1String("U") ? SKGDocument::UNDO : SKGDocument::REDO);
         do {
             lastExecuted = getDocument()->getTransactionToProcess(mode);
             err = getDocument()->undoRedoTransaction(mode);
