@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -39,7 +39,7 @@ SKGImportPluginAFB120::~SKGImportPluginAFB120()
 bool SKGImportPluginAFB120::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("AFB120") || m_importer->getFileNameExtension() == QStringLiteral("CFO"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("AFB120") || m_importer->getFileNameExtension() == QLatin1String("CFO"));
 }
 
 double SKGImportPluginAFB120::toAmount(const QString& iAmount, int iNbDecimal)
@@ -49,10 +49,10 @@ double SKGImportPluginAFB120::toAmount(const QString& iAmount, int iNbDecimal)
     int codeAscii = lastChar.toLatin1();
     int sign = (codeAscii > 79 && codeAscii != 123 ? -1 : 1);
     if (codeAscii == 123 || codeAscii == 125) {
-        amount[amount.count() - 1] = '0';
+        amount[amount.size() - 1] = '0';
     } else {
         bool ok = false;
-        amount[amount.count() - 1] = QChar(codeAscii + QChar('1').toLatin1() - QString(sign == -1 ? QStringLiteral("0x4A") : QStringLiteral("0x41")).toUInt(&ok, 16));
+        amount[amount.size() - 1] = QChar(codeAscii + QChar('1').toLatin1() - QString(sign == -1 ? QLatin1String("0x4A") : QLatin1String("0x41")).toUInt(&ok, 16));
     }
     return static_cast<double>(sign) * SKGServices::stringToDouble(amount) / qPow(10, iNbDecimal);
 }
@@ -79,7 +79,11 @@ SKGError SKGImportPluginAFB120::importFile()
                 {
                     QTextStream stream(&file);
                     if (!m_importer->getCodec().isEmpty()) {
+#ifdef SKG_QT6
+                        stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
                         stream.setCodec(m_importer->getCodec().toLatin1().constData());
+#endif
                     }
                     while (!stream.atEnd()) {
                         // Read line
@@ -98,7 +102,7 @@ SKGError SKGImportPluginAFB120::importFile()
                 // Read lines
                 SKGAccountObject account;
                 SKGUnitObject unit;
-                QString bankName = QStringLiteral("AFB120");
+                QString bankName = QLatin1String("AFB120");
                 QString inititalAmount;
 
                 int nb = lines.count();
@@ -113,7 +117,7 @@ SKGError SKGImportPluginAFB120::importFile()
                             inititalAmount = line.mid(91 - 1, 14);
 
                             SKGObjectBase::SKGListSKGObjectBase listAccount;
-                            err = m_importer->getDocument()->getObjects(QStringLiteral("v_account"), "t_number='" % accountNumber % '\'', listAccount);
+                            err = m_importer->getDocument()->getObjects(QLatin1String("v_account"), "t_number='" % accountNumber % QLatin1Char('\''), listAccount);
                             IFOK(err) {
                                 if (listAccount.count() == 1) {
                                     // Yes ! Only one account found
@@ -164,12 +168,12 @@ SKGError SKGImportPluginAFB120::importFile()
 
                             SKGOperationObject operation;
                             IFOKDO(err, account.addOperation(operation, true))
-                            IFOKDO(err, operation.setDate(SKGServices::stringToTime(SKGServices::dateToSqlString(dateJJMMAA, QStringLiteral("DDMMYYYY"))).date()))
+                            IFOKDO(err, operation.setDate(SKGServices::stringToDate(SKGServices::dateToSqlString(dateJJMMAA, QLatin1String("DDMMYYYY")))))
                             IFOKDO(err, operation.setUnit(unit))
-                            IFOKDO(err, operation.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
+                            IFOKDO(err, operation.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
                             IFOKDO(err, operation.setComment(comment))
                             QByteArray hash = QCryptographicHash::hash(line.toUtf8(), QCryptographicHash::Md5);
-                            IFOKDO(err, operation.setImportID(QStringLiteral("AFB120-") % hash.toHex()))
+                            IFOKDO(err, operation.setImportID(QLatin1String("AFB120-") % hash.toHex()))
                             IFOKDO(err, operation.save(false))
 
                             SKGSubOperationObject subop;
