@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -19,11 +19,11 @@
 #include <qstandardpaths.h>
 #include <qtconcurrentmap.h>
 #include <qregularexpression.h>
+#include <qvariant.h>
 
 #include <kaboutdata.h>
 #include <klocalizedstring.h>
 #include <kpluginfactory.h>
-#include <qvariant.h>
 
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
@@ -41,43 +41,34 @@ SKGImportPluginBackend::SKGImportPluginBackend(QObject* iImporter, const QVarian
     SKGTRACEINFUNC(10)
     Q_UNUSED(iArg)
 
-    m_listBackends = KServiceTypeTrader::self()->query(QStringLiteral("Skrooge/Import/Backend"));
-    SKGTRACEL(10) << m_listBackends.count() << " plugins found" << SKGENDL;
+    m_listBackends = SKGServices::findDataPlugins(QLatin1String("skrooge_import_backend"));
+    SKGTRACEL(10) << m_listBackends.count() << " plugins found" << Qt::endl;
 }
 
 SKGImportPluginBackend::~SKGImportPluginBackend()
     = default;
 
-QExplicitlySharedDataPointer<KService> SKGImportPluginBackend::getService() const
+const KPluginMetaData* SKGImportPluginBackend::getService() const
 {
     for (const auto& service : m_listBackends) {
-#ifdef SKG_KF_5102
-        if (service->property(QStringLiteral("X-Krunner-ID"), QMetaType::QString).toString().toUpper() == m_importer->getFileNameExtension()) {
-            return service;
+        const auto& id = service.pluginId().remove(QLatin1String("org.kde.skrooge-import-backend-")).toUpper();
+        if (id == m_importer->getFileNameExtension()) {
+            return &service;
         }
-#else
-        if (service->property(QStringLiteral("X-Krunner-ID"), QVariant::String).toString().toUpper() == m_importer->getFileNameExtension()) {
-            return service;
-        }
-#endif
     }
-    return QExplicitlySharedDataPointer<KService>(nullptr);
+    return nullptr;
 }
 
 QString SKGImportPluginBackend::getParameter(const QString& iAttribute)
 {
     auto service = getService();
-#ifdef SKG_KF_5102
-    auto output = service->property(iAttribute, QMetaType::QString).toString();
-#else
-    auto output = service->property(iAttribute, QVariant::String).toString();
-#endif
+    auto output = service ? service->value(iAttribute, QLatin1String("")) : QLatin1String("");
     QMap<QString, QString> parameters = this->getImportParameters();
 
     for (int i = 1; i <= 10; ++i) {
         QString param = "parameter" + SKGServices::intToString(i);
-        if (output.contains(QStringLiteral("%") % param)) {
-            output = output.replace(QStringLiteral("%") % param, parameters.value(param));
+        if (output.contains(QLatin1String("%") % param)) {
+            output = output.replace(QLatin1String("%") % param, parameters.value(param));
         }
     }
 
@@ -87,7 +78,7 @@ QString SKGImportPluginBackend::getParameter(const QString& iAttribute)
 bool SKGImportPluginBackend::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : getService().data() != nullptr);
+    return (m_importer->getDocument() == nullptr ? true : getService() != nullptr);
 }
 
 struct download {
@@ -103,30 +94,30 @@ struct download {
         QString file = m_path % "/" % iAccountId % ".csv";
         // Build cmd
         QString cmd = m_cmd;
-        cmd = cmd.replace(QStringLiteral("%2"), SKGServices::intToString(m_nbToDownload)).replace(QStringLiteral("%1"), iAccountId).replace(QStringLiteral("%3"), m_pwd).replace(QStringLiteral("%4"), m_date);
+        cmd = cmd.replace(QLatin1String("%2"), SKGServices::intToString(m_nbToDownload)).replace(QLatin1String("%1"), iAccountId).replace(QLatin1String("%3"), m_pwd).replace(QLatin1String("%4"), m_date);
 
         // Execute
         QProcess p;
-        if (cmd.contains(QStringLiteral("%4"))) {
-            cmd = cmd.replace(QStringLiteral("%4"), file);
+        if (cmd.contains(QLatin1String("%4"))) {
+            cmd = cmd.replace(QLatin1String("%4"), file);
             p.setProcessChannelMode(QProcess::ForwardedChannels);
         } else {
             p.setStandardOutputFile(file);
         }
         cmd = SKGServices::getFullPathCommandLine(cmd);
-        SKGTRACEL(1) << "Execute: " << cmd << SKGENDL;
+        SKGTRACEL(1) << "Execute: " << cmd << Qt::endl;
 
         int retry = 0;
         do {
-            p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
+            p.start(QLatin1String("/bin/bash"), QStringList() << QLatin1String("-c") << cmd);
             if (p.waitForFinished(1000 * 60 * 2)) {
                 if (p.exitCode() == 0) {
                     return iAccountId;
                 }
-                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed with code %2 (Retry %3)", cmd, p.exitCode(), retry + 1) << SKGENDL;
+                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed with code %2 (Retry %3)", cmd, p.exitCode(), retry + 1) << Qt::endl;
 
             } else {
-                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed due to a time out (Retry %2)", cmd, retry + 1) << SKGENDL;
+                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed due to a time out (Retry %2)", cmd, retry + 1) << Qt::endl;
                 p.terminate();
                 p.kill();
             }
@@ -134,9 +125,9 @@ struct download {
         } while (retry < 6);
 
         QString errorMsg = i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, p.exitCode());
-        SKGTRACE << errorMsg << SKGENDL;
+        SKGTRACE << errorMsg << Qt::endl;
 
-        return QStringLiteral("ERROR:") + errorMsg;
+        return QLatin1String("ERROR:") + errorMsg;
     }
 
     int m_nbToDownload;
@@ -159,24 +150,24 @@ SKGError SKGImportPluginBackend::importFile()
 
     // Get parameters
     QMap<QString, QString> parameters = this->getImportParameters();
-    QString pwd = parameters[QStringLiteral("password")];
+    QString pwd = parameters[QLatin1String("password")];
 
     // Get list of accounts
     QStringList backendAccounts;
     QMap<QString, QString> backendAccountsBalance;
     QMap<QString, QString> backendAccountsName;
     QString csvfile = m_tempDir.path() % "/skrooge_backend.csv";
-    QString cmd = getParameter(QStringLiteral("X-SKROOGE-getaccounts")).replace(QStringLiteral("%3"), pwd);
+    QString cmd = getParameter(QLatin1String("X-SKROOGE-getaccounts")).replace(QLatin1String("%3"), pwd);
     QProcess p;
-    if (cmd.contains(QStringLiteral("%4"))) {
-        cmd = cmd.replace(QStringLiteral("%4"), csvfile);
+    if (cmd.contains(QLatin1String("%4"))) {
+        cmd = cmd.replace(QLatin1String("%4"), csvfile);
         p.setProcessChannelMode(QProcess::ForwardedChannels);
     } else {
         p.setStandardOutputFile(csvfile);
     }
     cmd = SKGServices::getFullPathCommandLine(cmd);
-    SKGTRACEL(1) << "Execute: " << cmd << SKGENDL;
-    p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
+    SKGTRACEL(1) << "Execute: " << cmd << Qt::endl;
+    p.start(QLatin1String("/bin/bash"), QStringList() << QLatin1String("-c") << cmd);
     if (!p.waitForFinished(1000 * 60 * 2) || p.exitCode() != 0) {
         err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, p.exitCode()));
     } else {
@@ -184,9 +175,9 @@ SKGError SKGImportPluginBackend::importFile()
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", csvfile));
         } else {
-            QRegularExpression reggetaccounts(getParameter(QStringLiteral("X-SKROOGE-getaccountid")));
-            QRegularExpression reggetaccountbalance(getParameter(QStringLiteral("X-SKROOGE-getaccountbalance")));
-            QRegularExpression reggetaccountname(getParameter(QStringLiteral("X-SKROOGE-getaccountname")));
+            QRegularExpression reggetaccounts(getParameter(QLatin1String("X-SKROOGE-getaccountid")));
+            QRegularExpression reggetaccountbalance(getParameter(QLatin1String("X-SKROOGE-getaccountbalance")));
+            QRegularExpression reggetaccountname(getParameter(QLatin1String("X-SKROOGE-getaccountname")));
 
             QTextStream stream(&file);
             stream.readLine();  // To avoid header
@@ -194,7 +185,7 @@ SKGError SKGImportPluginBackend::importFile()
             while (!stream.atEnd()) {
                 // Read line
                 QString line = stream.readLine().trimmed();
-                SKGTRACEL(10) << "Read line: " << line << SKGENDL;
+                SKGTRACEL(10) << "Read line: " << line << Qt::endl;
 
                 // Get account id
                 auto match = reggetaccounts.match(line);
@@ -224,7 +215,7 @@ SKGError SKGImportPluginBackend::importFile()
                     }
                 } else {
                     // This is an error
-                    err.setReturnCode(ERR_FAIL).setMessage(line).addError(ERR_FAIL, i18nc("Error message",  "Impossible to find the account id with the regular expression '%1' in line '%2'", getParameter(QStringLiteral("X-SKROOGE-getaccountid")), line));
+                    err.setReturnCode(ERR_FAIL).setMessage(line).addError(ERR_FAIL, i18nc("Error message",  "Impossible to find the account id with the regular expression '%1' in line '%2'", getParameter(QLatin1String("X-SKROOGE-getaccountid")), line));
                     break;
                 }
             }
@@ -242,15 +233,15 @@ SKGError SKGImportPluginBackend::importFile()
             err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Your backend '%1' seems to be not well configure because no account has been found.", bankendName));
         } else {
             // Compute the begin date for download
-            QDate lastDownload = SKGServices::stringToTime(m_importer->getDocument()->getParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_DATE")).date();
+            QDate lastDownload = SKGServices::stringToDate(m_importer->getDocument()->getParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_DATE"));
             QString lastList = m_importer->getDocument()->getParameter("SKG_LAST_" % bankendName.toUpper() % "_IMPORT_LIST");
-            QString currentList = backendAccounts.join(QStringLiteral(";"));
+            QString currentList = backendAccounts.join(QLatin1String(";"));
 
             int nbToDownload = 0;
             QString fromDate;
             if (currentList != lastList || !lastDownload.isValid()) {
                 nbToDownload = 99999;
-                fromDate = QStringLiteral("2000-01-01");
+                fromDate = QLatin1String("2000-01-01");
             } else {
                 nbToDownload = qMax(lastDownload.daysTo(QDate::currentDate()) * 10, qint64(20));
                 fromDate = SKGServices::dateToSqlString(lastDownload.addDays(-4));
@@ -258,33 +249,33 @@ SKGError SKGImportPluginBackend::importFile()
 
             // Download
             QStringList listDownloadedId;
-            QString bulk = getParameter(QStringLiteral("X-SKROOGE-getbulk"));
+            QString bulk = getParameter(QLatin1String("X-SKROOGE-getbulk"));
             QString cmddownload;
             if (!bulk.isEmpty()) {
                 // mode bulk
-                SKGTRACEL(10) << "Mode getbulk" << SKGENDL;
+                SKGTRACEL(10) << "Mode getbulk" << Qt::endl;
                 QProcess pbulk;
-                QString cmd = bulk.replace(QStringLiteral("%1"), m_tempDir.path());
+                QString cmd = bulk.replace(QLatin1String("%1"), m_tempDir.path());
                 cmd = SKGServices::getFullPathCommandLine(cmd);
                 cmddownload = cmd;
-                SKGTRACEL(1) << "Execute: " << cmd << SKGENDL;
-                pbulk.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
+                SKGTRACEL(1) << "Execute: " << cmd << Qt::endl;
+                pbulk.start(QLatin1String("/bin/bash"), QStringList() << QLatin1String("-c") << cmd);
                 if (!pbulk.waitForFinished(1000 * 60 * 2) || pbulk.exitCode() != 0) {
                     err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, pbulk.exitCode()));
                 } else {
-                    SKGTRACEL(10) << "Searching csv files " << SKGENDL;
-                    QDirIterator it(m_tempDir.path(), QStringList() << QStringLiteral("*.csv"));
+                    SKGTRACEL(10) << "Searching csv files " << Qt::endl;
+                    QDirIterator it(m_tempDir.path(), QStringList() << QLatin1String("*.csv"));
                     while (it.hasNext()) {
                         auto id = QFileInfo(it.next()).baseName();
                         listDownloadedId.push_back(id);
 
-                        SKGTRACEL(10) << "Find id: " << id << SKGENDL;
+                        SKGTRACEL(10) << "Find id: " << id << Qt::endl;
                     }
                 }
             } else {
                 // mode getoperations
-                SKGTRACEL(10) << "Mode getoperations" << SKGENDL;
-                cmddownload = getParameter(QStringLiteral("X-SKROOGE-getoperations"));
+                SKGTRACEL(10) << "Mode getoperations" << Qt::endl;
+                cmddownload = getParameter(QLatin1String("X-SKROOGE-getoperations"));
                 QFuture<QString> f = QtConcurrent::mapped(backendAccounts, download(nbToDownload, fromDate, cmddownload, pwd, m_tempDir.path()));
                 f.waitForFinished();
                 listDownloadedId = f.results();
@@ -312,9 +303,9 @@ SKGError SKGImportPluginBackend::importFile()
                         err = SKGError(ERR_FAIL, i18nc("Error message", "No accounts downloaded with the following command:\n%1\nCheck your backend installation.", cmddownload));
                     } else {
                         // Warning
-                        m_importer->getDocument()->sendMessage(i18nc("Warning message", "Some accounts have not been downloaded. %1", errors.join(QStringLiteral(". "))), SKGDocument::Warning);
+                        m_importer->getDocument()->sendMessage(i18nc("Warning message", "Some accounts have not been downloaded. %1", errors.join(QLatin1String(". "))), SKGDocument::Warning);
                     }
-                    SKGTRACEL(10) << errors.count() << " accounts not imported => checkOK=false" << SKGENDL;
+                    SKGTRACEL(10) << errors.count() << " accounts not imported => checkOK=false" << Qt::endl;
                     checkOK = false;
                 }
 
@@ -328,7 +319,7 @@ SKGError SKGImportPluginBackend::importFile()
                     SKGDocument::SKGMessageList messages;
                     IFOKDO(err, m_importer->getDocument()->getMessages(m_importer->getDocument()->getCurrentTransaction(), messages, true))
 
-                    auto extension = getParameter(QStringLiteral("X-SKROOGE-extension")).toLower();
+                    auto extension = getParameter(QLatin1String("X-SKROOGE-extension")).toLower();
                     if (extension.length() == 0) {
                         extension = "csv";
                     }
@@ -337,8 +328,8 @@ SKGError SKGImportPluginBackend::importFile()
                     for (int i = 0; !err && i < nb; ++i) {
                         // Rename the imported name
                         QString file = m_tempDir.path() % "/" % listDownloadedId.at(i) % ".csv";
-                        if (!listDownloadedId.at(i).contains(QStringLiteral("-")) && !backendAccountsName[listDownloadedId.at(i)].isEmpty()) {
-                            QString newFileName = m_tempDir.path() % "/" % backendAccountsName[listDownloadedId.at(i)] % '-' % listDownloadedId.at(i) % "." % extension;
+                        if (!listDownloadedId.at(i).contains(QLatin1String("-")) && !backendAccountsName[listDownloadedId.at(i)].isEmpty()) {
+                            QString newFileName = m_tempDir.path() % "/" % backendAccountsName[listDownloadedId.at(i)] % QLatin1Char('-') % listDownloadedId.at(i) % "." % extension;
                             if (QFile::rename(file, newFileName)) {
                                 file = std::move(newFileName);
                             }
@@ -354,14 +345,14 @@ SKGError SKGImportPluginBackend::importFile()
 
                         if (extension == "csv") {
                             QMap<QString, QString> newParameters = imp1.getImportParameters();
-                            newParameters[QStringLiteral("automatic_search_header")] = 'N';
-                            newParameters[QStringLiteral("header_position")] = '1';
-                            newParameters[QStringLiteral("automatic_search_columns")] = 'N';
-                            newParameters[QStringLiteral("columns_positions")] = getParameter(QStringLiteral("X-SKROOGE-csvcolumns"));
-                            newParameters[QStringLiteral("mode_csv_unit")] = 'N';
-                            newParameters[QStringLiteral("mode_csv_rule")] = 'N';
-                            newParameters[QStringLiteral("balance")] = backendAccountsBalance[listDownloadedId.at(i)];
-                            newParameters[QStringLiteral("donotfinalize")] = 'Y';
+                            newParameters[QLatin1String("automatic_search_header")] = 'N';
+                            newParameters[QLatin1String("header_position")] = '1';
+                            newParameters[QLatin1String("automatic_search_columns")] = 'N';
+                            newParameters[QLatin1String("columns_positions")] = getParameter(QLatin1String("X-SKROOGE-csvcolumns"));
+                            newParameters[QLatin1String("mode_csv_unit")] = 'N';
+                            newParameters[QLatin1String("mode_csv_rule")] = 'N';
+                            newParameters[QLatin1String("balance")] = backendAccountsBalance[listDownloadedId.at(i)];
+                            newParameters[QLatin1String("donotfinalize")] = 'Y';
                             imp1.setImportParameters(newParameters);
                         }
                         IFOKDO(err, imp1.importFile())
@@ -393,7 +384,7 @@ SKGError SKGImportPluginBackend::importFile()
 
                     // Disable std finalisation
                     QMap<QString, QString> parameters = m_importer->getImportParameters();
-                    parameters[QStringLiteral("donotfinalize")] = 'Y';
+                    parameters[QLatin1String("donotfinalize")] = 'Y';
                     m_importer->setImportParameters(parameters);
 
                     // Check balances of accounts
@@ -405,7 +396,7 @@ SKGError SKGImportPluginBackend::importFile()
                         auto targetBalance = accountsToCheck[i].second;
                         auto soluces = act.getPossibleReconciliations(targetBalance, false);
                         if (soluces.isEmpty()) {
-                            SKGTRACEL(10) << "Account " << listDownloadedId.at(i) << " not reconciliable => checkOK=false" << SKGENDL;
+                            SKGTRACEL(10) << "Account " << listDownloadedId.at(i) << " not reconciliable => checkOK=false" << Qt::endl;
                             checkOK = false;
                         }
                     }
