@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -20,6 +20,7 @@
 #include "skgimportexportmanager.h"
 #include "skgservices.h"
 #include "skgtraces.h"
+#include <utility>
 
 /**
 * Opening balance string
@@ -86,7 +87,11 @@ SKGError SKGImportPluginIif::importFile()
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) {
+#ifdef SKG_QT6
+                stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
                 stream.setCodec(m_importer->getCodec().toLatin1().constData());
+#endif
             }
 
             // Import
@@ -104,10 +109,10 @@ SKGError SKGImportPluginIif::importFile()
                     } else {
                         // This is an item
                         QString t = vals[0].trimmed();
-                        if (t == QStringLiteral("ACCNT")) {
+                        if (t == QLatin1String("ACCNT")) {
                             // This is an account
-                            QString accountType = getVal(vals, QStringLiteral("ACCNTTYPE"));
-                            QString name = getVal(vals, QStringLiteral("NAME"));
+                            QString accountType = getVal(vals, QLatin1String("ACCNTTYPE"));
+                            QString name = getVal(vals, QLatin1String("NAME"));
                             /*
                             AP: Accounts payable            DONE: ACCOUNT
                             AR: Accounts receivable     DONE: ACCOUNT
@@ -125,13 +130,13 @@ SKGError SKGImportPluginIif::importFile()
                             OASSET: Other asset         DONE: ACCOUNT
                             OCASSET: Other current asset    DONE: ACCOUNT
                             OCLIAB: Other current liability DONE: ACCOUNT*/
-                            if (accountType == QStringLiteral("BANK") || accountType == QStringLiteral("AP") || accountType == QStringLiteral("AR") ||
-                                accountType == QStringLiteral("OCASSET") || accountType == QStringLiteral("FIXASSET") || accountType == QStringLiteral("OASSET") ||
-                                accountType == QStringLiteral("OCLIAB") || accountType == QStringLiteral("LTLIAB") ||
-                                accountType == QStringLiteral("CCARD") || accountType == QStringLiteral("NONPOSTING")) {
+                            if (accountType == QLatin1String("BANK") || accountType == QLatin1String("AP") || accountType == QLatin1String("AR") ||
+                                accountType == QLatin1String("OCASSET") || accountType == QLatin1String("FIXASSET") || accountType == QLatin1String("OASSET") ||
+                                accountType == QLatin1String("OCLIAB") || accountType == QLatin1String("LTLIAB") ||
+                                accountType == QLatin1String("CCARD") || accountType == QLatin1String("NONPOSTING")) {
                                 // Check if the account already exist
                                 SKGAccountObject account;
-                                err = SKGNamedObject::getObjectByName(m_importer->getDocument(), QStringLiteral("account"), name, account);
+                                err = SKGNamedObject::getObjectByName(m_importer->getDocument(), QLatin1String("account"), name, account);
                                 IFKO(err) {
                                     // Create account
                                     SKGBankObject bank(m_importer->getDocument());
@@ -142,13 +147,13 @@ SKGError SKGImportPluginIif::importFile()
                                     IFOKDO(err, bank.addAccount(account))
                                     IFOKDO(err, account.setName(name))
                                     if (!err && account.load().isFailed()) {
-                                        IFOKDO(err, account.setType(accountType == QStringLiteral("BANK") || accountType == QStringLiteral("AP") || accountType == QStringLiteral("AR") ? SKGAccountObject::CURRENT :
-                                                                    accountType == QStringLiteral("OCASSET") || accountType == QStringLiteral("FIXASSET") || accountType == QStringLiteral("OASSET") || accountType == QStringLiteral("EQUITY") ? SKGAccountObject::ASSETS :
-                                                                    accountType == QStringLiteral("OCLIAB") || accountType == QStringLiteral("LTLIAB") ? SKGAccountObject::LOAN :
-                                                                    accountType == QStringLiteral("CCARD") ? SKGAccountObject::CREDITCARD :
+                                        IFOKDO(err, account.setType(accountType == QLatin1String("BANK") || accountType == QLatin1String("AP") || accountType == QLatin1String("AR") ? SKGAccountObject::CURRENT :
+                                                                    accountType == QLatin1String("OCASSET") || accountType == QLatin1String("FIXASSET") || accountType == QLatin1String("OASSET") || accountType == QLatin1String("EQUITY") ? SKGAccountObject::ASSETS :
+                                                                    accountType == QLatin1String("OCLIAB") || accountType == QLatin1String("LTLIAB") ? SKGAccountObject::LOAN :
+                                                                    accountType == QLatin1String("CCARD") ? SKGAccountObject::CREDITCARD :
                                                                     SKGAccountObject::OTHER))
-                                        IFOKDO(err, account.setAgencyNumber(getVal(vals, QStringLiteral("ACCNUM"))))
-                                        IFOKDO(err, account.setComment(getVal(vals, QStringLiteral("DESC"))))
+                                        IFOKDO(err, account.setAgencyNumber(getVal(vals, QLatin1String("ACCNUM"))))
+                                        IFOKDO(err, account.setComment(getVal(vals, QLatin1String("DESC"))))
                                         IFOKDO(err, account.save())
                                         m_accounts[name] = account;
                                     }
@@ -160,56 +165,56 @@ SKGError SKGImportPluginIif::importFile()
                                 IFOKDO(err, SKGCategoryObject::createPathCategory(m_importer->getDocument(), name.replace(':', OBJECTSEPARATOR), category))
                                 m_categories[originalName] = category;
                             }
-                        } else if (t == QStringLiteral("CUST")) {
+                        } else if (t == QLatin1String("CUST")) {
                             // This is a payee
-                            QString name = getVal(vals, QStringLiteral("NAME"));
+                            QString name = getVal(vals, QLatin1String("NAME"));
                             SKGPayeeObject payee;
                             IFOKDO(err, SKGPayeeObject::createPayee(m_importer->getDocument(), name, payee))
 
-                            QString address = getVal(vals, QStringLiteral("BADDR1")) % " " %
-                                              getVal(vals, QStringLiteral("BADDR2")) % " " %
-                                              getVal(vals, QStringLiteral("BADDR3")) % " " %
-                                              getVal(vals, QStringLiteral("BADDR4")) % " " %
-                                              getVal(vals, QStringLiteral("BADDR5")) % " " %
-                                              getVal(vals, QStringLiteral("SADDR1")) % " " %
-                                              getVal(vals, QStringLiteral("SADDR2")) % " " %
-                                              getVal(vals, QStringLiteral("SADDR3")) % " " %
-                                              getVal(vals, QStringLiteral("SADDR4")) % " " %
-                                              getVal(vals, QStringLiteral("SADDR5"));
+                            QString address = getVal(vals, QLatin1String("BADDR1")) % " " %
+                                              getVal(vals, QLatin1String("BADDR2")) % " " %
+                                              getVal(vals, QLatin1String("BADDR3")) % " " %
+                                              getVal(vals, QLatin1String("BADDR4")) % " " %
+                                              getVal(vals, QLatin1String("BADDR5")) % " " %
+                                              getVal(vals, QLatin1String("SADDR1")) % " " %
+                                              getVal(vals, QLatin1String("SADDR2")) % " " %
+                                              getVal(vals, QLatin1String("SADDR3")) % " " %
+                                              getVal(vals, QLatin1String("SADDR4")) % " " %
+                                              getVal(vals, QLatin1String("SADDR5"));
                             address = address.trimmed();
 
                             IFOKDO(err, payee.setAddress(address))
                             IFOKDO(err, payee.save())
                             m_payees[name] = payee;
-                        } else if (t == QStringLiteral("VEND")) {
+                        } else if (t == QLatin1String("VEND")) {
                             // This is a payee
-                            QString name = getVal(vals, QStringLiteral("NAME"));
+                            QString name = getVal(vals, QLatin1String("NAME"));
                             SKGPayeeObject payee;
-                            IFOKDO(err, SKGPayeeObject::createPayee(m_importer->getDocument(), getVal(vals, QStringLiteral("NAME")), payee))
+                            IFOKDO(err, SKGPayeeObject::createPayee(m_importer->getDocument(), getVal(vals, QLatin1String("NAME")), payee))
 
-                            QString address = getVal(vals, QStringLiteral("ADDR1")) % " " %
-                                              getVal(vals, QStringLiteral("ADDR2")) % " " %
-                                              getVal(vals, QStringLiteral("ADDR3")) % " " %
-                                              getVal(vals, QStringLiteral("ADDR4")) % " " %
-                                              getVal(vals, QStringLiteral("ADDR5"));
+                            QString address = getVal(vals, QLatin1String("ADDR1")) % " " %
+                                              getVal(vals, QLatin1String("ADDR2")) % " " %
+                                              getVal(vals, QLatin1String("ADDR3")) % " " %
+                                              getVal(vals, QLatin1String("ADDR4")) % " " %
+                                              getVal(vals, QLatin1String("ADDR5"));
                             address = address.trimmed();
 
                             IFOKDO(err, payee.setAddress(address))
                             IFOKDO(err, payee.save())
                             m_payees[name] = payee;
-                        } else if (t == QStringLiteral("ENDTRNS")) {
+                        } else if (t == QLatin1String("ENDTRNS")) {
                             operation = SKGOperationObject();
                             suboperation = SKGSubOperationObject();
-                        } else if (t == QStringLiteral("TRNS")) {
+                        } else if (t == QLatin1String("TRNS")) {
                             // This is an operation
-                            SKGAccountObject account = m_accounts.value(getVal(vals, QStringLiteral("ACCNT")));
+                            SKGAccountObject account = m_accounts.value(getVal(vals, QLatin1String("ACCNT")));
                             IFOKDO(err, account.addOperation(operation))
 
-                            QDate date = SKGServices::stringToTime(SKGServices::dateToSqlString(getVal(vals, QStringLiteral("DATE")), QStringLiteral("MM/DD/YYYY"))).date();
+                            QDate date = SKGServices::stringToDate(SKGServices::dateToSqlString(getVal(vals, QLatin1String("DATE")), QLatin1String("MM/DD/YYYY")));
                             IFOKDO(err, operation.setDate(date))
-                            IFOKDO(err, operation.setStatus(getVal(vals, QStringLiteral("CLEAR")) == QStringLiteral("Y") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
+                            IFOKDO(err, operation.setStatus(getVal(vals, QLatin1String("CLEAR")) == QLatin1String("Y") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
 
-                            QString number = getVal(vals, QStringLiteral("DOCNUM"));
+                            QString number = getVal(vals, QLatin1String("DOCNUM"));
                             if (!number.isEmpty()) {
                                 IFOKDO(err, operation.setNumber(number))
                             }
@@ -223,23 +228,23 @@ SKGError SKGImportPluginIif::importFile()
                             }
                             IFOKDO(err, operation.setUnit(unit))
 
-                            IFOKDO(err, operation.setMode(getVal(vals, QStringLiteral("TRNSTYPE"))))
-                            QString p = getVal(vals, QStringLiteral("NAME"));
+                            IFOKDO(err, operation.setMode(getVal(vals, QLatin1String("TRNSTYPE"))))
+                            QString p = getVal(vals, QLatin1String("NAME"));
                             if (!p.isEmpty()) {
                                 IFOKDO(err, operation.setPayee(m_payees[p]))
                             }
-                            IFOKDO(err, operation.setComment(getVal(vals, QStringLiteral("MEMO"))))
+                            IFOKDO(err, operation.setComment(getVal(vals, QLatin1String("MEMO"))))
                             IFOKDO(err, operation.save())
-                        } else if (t == QStringLiteral("SPL")) {
+                        } else if (t == QLatin1String("SPL")) {
                             // This is a sub operation
-                            QString a = getVal(vals, QStringLiteral("ACCNT"));
+                            QString a = getVal(vals, QLatin1String("ACCNT"));
                             if (m_categories.contains(a)) {
                                 // This is a split
                                 SKGCategoryObject cat = m_categories.value(a);
                                 IFOKDO(err, operation.addSubOperation(suboperation))
-                                IFOKDO(err, suboperation.setQuantity(-SKGServices::stringToDouble(getVal(vals, QStringLiteral("AMOUNT")))))
+                                IFOKDO(err, suboperation.setQuantity(-SKGServices::stringToDouble(getVal(vals, QLatin1String("AMOUNT")))))
                                 IFOKDO(err, suboperation.setCategory(cat))
-                                IFOKDO(err, suboperation.setComment(getVal(vals, QStringLiteral("MEMO"))))
+                                IFOKDO(err, suboperation.setComment(getVal(vals, QLatin1String("MEMO"))))
                                 IFOKDO(err, suboperation.save())
                             } else if (m_accounts.contains(a)) {
                                 // This is a transfer
@@ -248,11 +253,11 @@ SKGError SKGImportPluginIif::importFile()
                                 SKGOperationObject operation2;
                                 IFOKDO(err, act.addOperation(operation2))
 
-                                QDate date = SKGServices::stringToTime(SKGServices::dateToSqlString(getVal(vals, QStringLiteral("DATE")), QStringLiteral("MM/DD/YYYY"))).date();
+                                QDate date = SKGServices::stringToDate(SKGServices::dateToSqlString(getVal(vals, QLatin1String("DATE")), QLatin1String("MM/DD/YYYY")));
                                 IFOKDO(err, operation2.setDate(date))
-                                IFOKDO(err, operation2.setStatus(getVal(vals, QStringLiteral("CLEAR")) == QStringLiteral("Y") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
+                                IFOKDO(err, operation2.setStatus(getVal(vals, QLatin1String("CLEAR")) == QLatin1String("Y") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
 
-                                QString number = getVal(vals, QStringLiteral("DOCNUM"));
+                                QString number = getVal(vals, QLatin1String("DOCNUM"));
                                 if (!number.isEmpty()) {
                                     IFOKDO(err, operation2.setNumber(number))
                                 }
@@ -261,29 +266,29 @@ SKGError SKGImportPluginIif::importFile()
                                 IFOKDO(err, operation.getUnit(unit))
                                 IFOKDO(err, operation2.setUnit(unit))
 
-                                IFOKDO(err, operation2.setMode(getVal(vals, QStringLiteral("TRNSTYPE"))))
-                                QString p = getVal(vals, QStringLiteral("NAME"));
+                                IFOKDO(err, operation2.setMode(getVal(vals, QLatin1String("TRNSTYPE"))))
+                                QString p = getVal(vals, QLatin1String("NAME"));
                                 if (!p.isEmpty()) {
                                     IFOKDO(err, operation2.setPayee(m_payees[p]))
                                 }
-                                IFOKDO(err, operation2.setComment(getVal(vals, QStringLiteral("MEMO"))))
+                                IFOKDO(err, operation2.setComment(getVal(vals, QLatin1String("MEMO"))))
                                 IFOKDO(err, operation2.save())
 
                                 SKGSubOperationObject suboperation2;
                                 SKGCategoryObject cat = m_categories.value(a);
                                 IFOKDO(err, operation2.addSubOperation(suboperation2))
-                                IFOKDO(err, suboperation2.setQuantity(SKGServices::stringToDouble(getVal(vals, QStringLiteral("AMOUNT")))))
+                                IFOKDO(err, suboperation2.setQuantity(SKGServices::stringToDouble(getVal(vals, QLatin1String("AMOUNT")))))
                                 IFOKDO(err, suboperation2.setCategory(cat))
-                                IFOKDO(err, suboperation2.setComment(getVal(vals, QStringLiteral("MEMO"))))
+                                IFOKDO(err, suboperation2.setComment(getVal(vals, QLatin1String("MEMO"))))
                                 IFOKDO(err, suboperation2.save())
 
                                 IFOKDO(err, operation2.setGroupOperation(operation))
                                 IFOKDO(err, operation2.save())
 
                                 IFOKDO(err, operation.addSubOperation(suboperation))
-                                IFOKDO(err, suboperation.setQuantity(-SKGServices::stringToDouble(getVal(vals, QStringLiteral("AMOUNT")))))
+                                IFOKDO(err, suboperation.setQuantity(-SKGServices::stringToDouble(getVal(vals, QLatin1String("AMOUNT")))))
                                 IFOKDO(err, suboperation.setCategory(cat))
-                                IFOKDO(err, suboperation.setComment(getVal(vals, QStringLiteral("MEMO"))))
+                                IFOKDO(err, suboperation.setComment(getVal(vals, QLatin1String("MEMO"))))
                                 IFOKDO(err, suboperation.save())
                             }
                         }
@@ -291,7 +296,7 @@ SKGError SKGImportPluginIif::importFile()
 
                     ++index;
                     if (!err && index % 500 == 0) {
-                        err = m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE"));
+                        err = m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE"));
                     }
                 }
 
@@ -311,7 +316,7 @@ SKGError SKGImportPluginIif::importFile()
 bool SKGImportPluginIif::isExportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("IIF"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("IIF"));
 }
 
 SKGError SKGImportPluginIif::exportFile()
@@ -323,13 +328,13 @@ SKGError SKGImportPluginIif::exportFile()
     SKGTRACEINFUNCRC(2, err)
 
     // Read parameters
-    auto listUUIDs = SKGServices::splitCSVLine(m_exportParameters.value(QStringLiteral("uuid_of_selected_accounts_or_operations")));
+    auto listUUIDs = SKGServices::splitCSVLine(m_exportParameters.value(QLatin1String("uuid_of_selected_accounts_or_operations")));
 
     QStringList listOperationsToExport;
     listOperationsToExport.reserve(listUUIDs.count());
     QStringList listAccountsToExport;
     listAccountsToExport.reserve(listUUIDs.count());
-    for (const auto& uuid : qAsConst(listUUIDs)) {
+    for (const auto& uuid : std::as_const(listUUIDs)) {
         if (uuid.endsWith(QLatin1String("-operation"))) {
             listOperationsToExport.push_back(uuid);
         } else if (uuid.endsWith(QLatin1String("-account"))) {
@@ -348,7 +353,11 @@ SKGError SKGImportPluginIif::exportFile()
     } else {
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) {
+#ifdef SKG_QT6
+            stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
             stream.setCodec(m_importer->getCodec().toLatin1().constData());
+#endif
         }
 
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export %1 file", "IIF"), 4);
@@ -356,7 +365,7 @@ SKGError SKGImportPluginIif::exportFile()
             // Export accounts
             stream << "!ACCNT\tNAME\tACCNTTYPE\tDESC\tACCNUM\tEXTRA\n";
             SKGObjectBase::SKGListSKGObjectBase accounts;
-            IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_account_display"), QStringLiteral("1=1 ORDER BY t_name, id"), accounts))
+            IFOKDO(err, m_importer->getDocument()->getObjects(QLatin1String("v_account_display"), QLatin1String("1=1 ORDER BY t_name, id"), accounts))
             int nbaccount = accounts.count();
             if (!err && (nbaccount != 0)) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export accounts"), nbaccount);
@@ -370,7 +379,7 @@ SKGError SKGImportPluginIif::exportFile()
                                << '\t' << act.getComment()
                                << '\t' << act.getAgencyNumber()
                                << '\t'
-                               << SKGENDL;
+                               << Qt::endl;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -381,7 +390,7 @@ SKGError SKGImportPluginIif::exportFile()
 
             // Export categories
             SKGObjectBase::SKGListSKGObjectBase categories;
-            IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_category_display_tmp"), QStringLiteral("1=1 ORDER BY t_fullname, id"), categories))
+            IFOKDO(err, m_importer->getDocument()->getObjects(QLatin1String("v_category_display_tmp"), QLatin1String("1=1 ORDER BY t_fullname, id"), categories))
             int nbcat = categories.count();
             if (!err && (nbcat != 0)) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export categories"), nbcat);
@@ -390,12 +399,12 @@ SKGError SKGImportPluginIif::exportFile()
                     QString catName = cat.getFullName();
                     if (!catName.isEmpty()) {
                         stream << "ACCNT"
-                               << '\t' << catName.replace(OBJECTSEPARATOR, QStringLiteral(":"))
-                               << '\t' << (SKGServices::stringToDouble(cat.getAttribute(QStringLiteral("f_REALCURRENTAMOUNT"))) < 0 ? "EXP" : "INC")
+                               << '\t' << catName.replace(OBJECTSEPARATOR, QLatin1String(":"))
+                               << '\t' << (SKGServices::stringToDouble(cat.getAttribute(QLatin1String("f_REALCURRENTAMOUNT"))) < 0 ? "EXP" : "INC")
                                << '\t'
                                << '\t'
                                << '\t'
-                               << SKGENDL;
+                               << Qt::endl;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -407,7 +416,7 @@ SKGError SKGImportPluginIif::exportFile()
             // Export payees
             stream << "!CUST\tNAME\tBADDR1\n";
             SKGObjectBase::SKGListSKGObjectBase payees;
-            IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_payee_display"), QStringLiteral("1=1 ORDER BY t_name, id"), payees))
+            IFOKDO(err, m_importer->getDocument()->getObjects(QLatin1String("v_payee_display"), QLatin1String("1=1 ORDER BY t_name, id"), payees))
             int nbpayee = payees.count();
             if (!err && (nbpayee != 0)) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export payees"), nbpayee);
@@ -416,7 +425,7 @@ SKGError SKGImportPluginIif::exportFile()
                     stream << "CUST"
                            << '\t' << payee.getName()
                            << '\t' << payee.getAddress()
-                           << SKGENDL;
+                           << Qt::endl;
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
@@ -429,7 +438,7 @@ SKGError SKGImportPluginIif::exportFile()
             stream << "!SPL\tSPLID\tTRNSTYPE\tDATE\tACCNT\tNAME\tCLASS\tAMOUNT\tDOCNUM\tCLEAR\tMEMO\n";
             stream << "!ENDTRNS\n";
             SKGObjectBase::SKGListSKGObjectBase transactions;
-            IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_operation_display"), QStringLiteral("1=1 ORDER BY d_date, id"), transactions))
+            IFOKDO(err, m_importer->getDocument()->getObjects(QLatin1String("v_operation_display"), QLatin1String("1=1 ORDER BY d_date, id"), transactions))
             int nbop = transactions.count();
             if (!err && (nbop != 0)) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export transactions"), nbop);
@@ -442,15 +451,15 @@ SKGError SKGImportPluginIif::exportFile()
                         stream << "TRNS"
                                << '\t' << SKGServices::intToString(op.getID())
                                << '\t' << "PAYMENT"
-                               << '\t' << op.getDate().toString(QStringLiteral("M/d/yyyy"))
-                               << '\t' << op.getAttribute(QStringLiteral("t_ACCOUNT"))
-                               << '\t' << op.getAttribute(QStringLiteral("t_PAYEE"))
-                               << '\t' << op.getAttribute(QStringLiteral("t_CATEGORY")).replace(OBJECTSEPARATOR, QStringLiteral(":"))
+                               << '\t' << op.getDate().toString(QLatin1String("M/d/yyyy"))
+                               << '\t' << op.getAttribute(QLatin1String("t_ACCOUNT"))
+                               << '\t' << op.getAttribute(QLatin1String("t_PAYEE"))
+                               << '\t' << op.getAttribute(QLatin1String("t_CATEGORY")).replace(OBJECTSEPARATOR, QLatin1String(":"))
                                << '\t' << SKGServices::doubleToString(op.getAmount(QDate::currentDate()))
                                << '\t' << op.getNumber()
-                               << '\t' << (op.getStatus() == SKGOperationObject::CHECKED ? QStringLiteral("Y") : QStringLiteral("N"))
+                               << '\t' << (op.getStatus() == SKGOperationObject::CHECKED ? QLatin1String("Y") : QLatin1String("N"))
                                << '\t' << op.getComment()
-                               << SKGENDL;
+                               << Qt::endl;
 
                         // Export sub transactions
                         SKGObjectBase::SKGListSKGObjectBase sops;
@@ -463,18 +472,18 @@ SKGError SKGImportPluginIif::exportFile()
                             stream << "SPL"
                                    << '\t' << SKGServices::intToString(sop.getID())
                                    << '\t' << "PAYMENT"
-                                   << '\t' << op.getDate().toString(QStringLiteral("M/d/yyyy"))
-                                   << '\t' << cat.getFullName().replace(OBJECTSEPARATOR, QStringLiteral(":"))
-                                   << '\t' << op.getAttribute(QStringLiteral("t_PAYEE"))
+                                   << '\t' << op.getDate().toString(QLatin1String("M/d/yyyy"))
+                                   << '\t' << cat.getFullName().replace(OBJECTSEPARATOR, QLatin1String(":"))
+                                   << '\t' << op.getAttribute(QLatin1String("t_PAYEE"))
                                    << '\t'
                                    << '\t' << SKGServices::doubleToString(-sop.getQuantity())
                                    << '\t' << op.getNumber()
-                                   << '\t' << (op.getStatus() == SKGOperationObject::CHECKED ? QStringLiteral("Y") : QStringLiteral("N"))
+                                   << '\t' << (op.getStatus() == SKGOperationObject::CHECKED ? QLatin1String("Y") : QLatin1String("N"))
                                    << '\t' << sop.getComment()
-                                   << SKGENDL;
+                                   << Qt::endl;
                         }
                     }
-                    stream << "ENDTRNS" << SKGENDL;
+                    stream << "ENDTRNS" << Qt::endl;
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
