@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -37,7 +37,7 @@ SKGImportPluginJson::~SKGImportPluginJson()
 bool SKGImportPluginJson::isExportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("JSON"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("JSON"));
 }
 
 SKGError SKGImportPluginJson::exportFile()
@@ -52,9 +52,13 @@ SKGError SKGImportPluginJson::exportFile()
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) {
+#ifdef SKG_QT6
+                stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
                 stream.setCodec(m_importer->getCodec().toLatin1().constData());
+#endif
             }
-            stream << doc << SKGENDL;
+            stream << doc << Qt::endl;
 
             // Close file
             file.commit();
