@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -23,6 +23,7 @@
 #include "skgdocumentbank.h"
 #include "skgservices.h"
 #include "skgtraces.h"
+#include <utility>
 
 /**
  * This plugin factory.
@@ -35,7 +36,7 @@ SKGImportPluginLedger::SKGImportPluginLedger(QObject* iImporter, const QVariantL
     SKGTRACEINFUNC(10)
     Q_UNUSED(iArg)
 
-    m_importParameters[QStringLiteral("ledger_account_identification")] = QStringLiteral("COMPTE,COMPTES,CAPITAUX,ASSETS,LIABILITIES,SAVING");
+    m_importParameters[QLatin1String("ledger_account_identification")] = QLatin1String("COMPTE,COMPTES,CAPITAUX,ASSETS,LIABILITIES,SAVING");
 }
 
 SKGImportPluginLedger::~SKGImportPluginLedger()
@@ -44,7 +45,7 @@ SKGImportPluginLedger::~SKGImportPluginLedger()
 bool SKGImportPluginLedger::isExportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("LEDGER"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("LEDGER"));
 }
 
 SKGError SKGImportPluginLedger::exportFile()
@@ -54,17 +55,17 @@ SKGError SKGImportPluginLedger::exportFile()
     if (!file.open(QIODevice::WriteOnly)) {
         err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().toDisplayString()));
     } else {
-        auto listUUIDs = SKGServices::splitCSVLine(m_exportParameters.value(QStringLiteral("uuid_of_selected_accounts_or_operations")));
+        auto listUUIDs = SKGServices::splitCSVLine(m_exportParameters.value(QLatin1String("uuid_of_selected_accounts_or_operations")));
 
         QString wc;
-        for (const auto& uuid : qAsConst(listUUIDs)) {
+        for (const auto& uuid : std::as_const(listUUIDs)) {
             auto items = SKGServices::splitCSVLine(uuid, '-');
-            if (items.at(1) == QStringLiteral("operation")) {
+            if (items.at(1) == QLatin1String("operation")) {
                 if (!wc.isEmpty()) {
                     wc += QLatin1String(" AND ");
                 }
                 wc += " i_OPID=" + items.at(0);
-            } else if (items.at(1) == QStringLiteral("account")) {
+            } else if (items.at(1) == QLatin1String("account")) {
                 if (!wc.isEmpty()) {
                     wc += QLatin1String(" AND ");
                 }
@@ -72,7 +73,7 @@ SKGError SKGImportPluginLedger::exportFile()
             }
         }
         if (wc.isEmpty()) {
-            wc = QStringLiteral("1=1");
+            wc = QLatin1String("1=1");
         }  else {
             IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Only selected accounts and transactions have been exported")))
         }
@@ -80,25 +81,29 @@ SKGError SKGImportPluginLedger::exportFile()
         QLocale en(QLocale::C);
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) {
+#ifdef SKG_QT6
+            stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
             stream.setCodec(m_importer->getCodec().toLatin1().constData());
+#endif
         }
-        stream << "; -*- ledger file generated by Skrooge -*-" << SKGENDL;
+        stream << "; -*- ledger file generated by Skrooge -*-" << Qt::endl;
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export %1 file", "ledger"), 2);
         IFOK(err) {
             auto punit = m_importer->getDocument()->getPrimaryUnit();
             SKGObjectBase::SKGListSKGObjectBase units;
-            err = m_importer->getDocument()->getObjects(QStringLiteral("v_unit"), QStringLiteral("t_type NOT IN ('C', '1', '2')"), units);
+            err = m_importer->getDocument()->getObjects(QLatin1String("v_unit"), QLatin1String("t_type NOT IN ('C', '1', '2')"), units);
             int nb = units.count();
             IFOK(err) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export units"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     SKGUnitObject unit(units.at(i));
-                    QString qs = en.toCurrencyString(SKGServices::stringToDouble(unit.getAttribute(QStringLiteral("f_CURRENTAMOUNT"))), punit.Symbol, punit.NbDecimal);
+                    QString qs = en.toCurrencyString(SKGServices::stringToDouble(unit.getAttribute(QLatin1String("f_CURRENTAMOUNT"))), punit.Symbol, punit.NbDecimal);
                     stream << "P " << SKGServices::dateToSqlString(QDate::currentDate()).replace('-', '/')
                            << " \"" << unit.getSymbol() << '"'
                            << " " << qs
-                           << SKGENDL;
-                    stream << SKGENDL;
+                           << Qt::endl;
+                    stream << Qt::endl;
 
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -111,7 +116,7 @@ SKGError SKGImportPluginLedger::exportFile()
 
         IFOK(err) {
             SKGObjectBase::SKGListSKGObjectBase transactions;
-            err = m_importer->getDocument()->getObjects(QStringLiteral("v_operation"), wc % QStringLiteral(" AND t_template='N' ORDER BY d_date"), transactions);
+            err = m_importer->getDocument()->getObjects(QLatin1String("v_operation"), wc % QLatin1String(" AND t_template='N' ORDER BY d_date"), transactions);
             int nb = transactions.count();
             IFOK(err) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export transactions"), nb);
@@ -132,15 +137,15 @@ SKGError SKGImportPluginLedger::exportFile()
                         payeeString = op.getComment();
                     }
 
-                    auto nbDec = SKGServices::stringToInt(op.getAttribute(QStringLiteral("i_NBDEC")));
+                    auto nbDec = SKGServices::stringToInt(op.getAttribute(QLatin1String("i_NBDEC")));
                     if (nbDec == 0) {
                         nbDec = 2;
                     }
                     QString symbol = unit.getSymbol();
-                    if (symbol.contains(QStringLiteral(" "))) {
+                    if (symbol.contains(QLatin1String(" "))) {
                         symbol = '"' + symbol + '"';
                     }
-                    QString qs = en.toCurrencyString(SKGServices::stringToDouble(op.getAttribute(QStringLiteral("f_QUANTITY"))), QStringLiteral(" "), nbDec);
+                    QString qs = en.toCurrencyString(SKGServices::stringToDouble(op.getAttribute(QLatin1String("f_QUANTITY"))), QLatin1String(" "), nbDec);
                     if (isCurrency) {
                         qs = symbol + qs;
                     } else {
@@ -149,18 +154,18 @@ SKGError SKGImportPluginLedger::exportFile()
 
                     stream << SKGServices::dateToSqlString(op.getDate()).replace('-', '/')
                            << (status == SKGOperationObject::CHECKED ? " *" : status == SKGOperationObject::MARKED ? " !" : "")
-                           << (!number.isEmpty() ? QStringLiteral(" (") % number % ")" : QString())
-                           << QStringLiteral(" ") << payeeString
-                           << SKGENDL;
-                    stream << "  ; Skrooge ID: " << op.getID() << SKGENDL;
-                    stream << "  ; Import ID: " << op.getImportID() << SKGENDL;
+                           << (!number.isEmpty() ? QLatin1String(" (") % number % ")" : QString())
+                           << QLatin1String(" ") << payeeString
+                           << Qt::endl;
+                    stream << "  ; Skrooge ID: " << op.getID() << Qt::endl;
+                    stream << "  ; Import ID: " << op.getImportID() << Qt::endl;
                     auto properties = op.getProperties();
-                    for (const auto& p : qAsConst(properties)) {
-                        stream << "  ; " << p << ": " << op.getProperty(p) << SKGENDL;
+                    for (const auto& p : std::as_const(properties)) {
+                        stream << "  ; " << p << ": " << op.getProperty(p) << Qt::endl;
                     }
-                    stream << "  " << i18nc("The default category for the accounts for ledger export", "Account") << ':' << op.getAttribute(QStringLiteral("t_ACCOUNT"))
+                    stream << "  " << i18nc("The default category for the accounts for ledger export", "Account") << ':' << op.getAttribute(QLatin1String("t_ACCOUNT"))
                            << "  " << qs
-                           << SKGENDL;
+                           << Qt::endl;
 
                     SKGObjectBase::SKGListSKGObjectBase subtransactions;
                     IFOKDO(err, op.getSubOperations(subtransactions))
@@ -173,7 +178,7 @@ SKGError SKGImportPluginLedger::exportFile()
                         if (catString.isEmpty()) {
                             catString = i18nc("Category not defined", "Not defined");
                         }
-                        QString qs = en.toCurrencyString(-sop.getQuantity(), QStringLiteral(" "), nbDec);
+                        QString qs = en.toCurrencyString(-sop.getQuantity(), QLatin1String(" "), nbDec);
                         if (isCurrency) {
                             qs = unit.getSymbol() + qs;
                         } else {
@@ -191,9 +196,9 @@ SKGError SKGImportPluginLedger::exportFile()
                             stream << "  ;comment=" << comment;
                         }
                         stream << "  ; Skrooge ID: " << sop.getID();
-                        stream << SKGENDL;
+                        stream << Qt::endl;
                     }
-                    stream << SKGENDL;
+                    stream << Qt::endl;
 
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -215,12 +220,12 @@ SKGError SKGImportPluginLedger::exportFile()
 bool SKGImportPluginLedger::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("LEDGER"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("LEDGER"));
 }
 
 bool SKGImportPluginLedger::isAccount(const QString& type)
 {
-    return m_importParameters.value(QStringLiteral("ledger_account_identification")).split(',').indexOf(type) != -1;
+    return m_importParameters.value(QLatin1String("ledger_account_identification")).split(QLatin1Char(',')).indexOf(type) != -1;
 }
 
 SKGError SKGImportPluginLedger::importFile()
@@ -236,9 +241,9 @@ SKGError SKGImportPluginLedger::importFile()
     QString uniqueId = QUuid::createUuid().toString();
     QString temporaryPath = QDir::tempPath() % "/" % uniqueId % ".xml";
     QString cmd = "ledger -f \"" % m_importer->getLocalFileName() % "\" xml --output " % temporaryPath;
-    SKGTRACEL(10) << "Execution of :" << cmd << SKGENDL;
+    SKGTRACEL(10) << "Execution of :" << cmd << Qt::endl;
     QProcess p;
-    p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
+    p.start(QLatin1String("/bin/bash"), QStringList() << QLatin1String("-c") << cmd);
     if (p.waitForFinished(1000 * 60 * 5) && p.exitCode() == 0) {
         // Open file
         QFile file(temporaryPath);
@@ -251,7 +256,18 @@ SKGError SKGImportPluginLedger::importFile()
             QString errorMsg;
             int errorLine = 0;
             int errorCol = 0;
-            bool contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
+            bool contentOK = false;        
+    #ifdef SKG_QT6
+            const auto& content = QString::fromUtf8(file.readAll());
+            const auto& result= doc.setContent(content);
+
+            contentOK = !!result;
+            errorLine =result.errorLine;
+            errorCol =result.errorColumn;
+            errorMsg =result.errorMessage;
+#else        
+            contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
+#endif
             file.close();
 
             // Get root
@@ -269,13 +285,13 @@ SKGError SKGImportPluginLedger::importFile()
 
                 // Step 1-Create units
                 IFOK(err) {
-                    auto commodityL = docElem.elementsByTagName(QStringLiteral("commodity"));
+                    auto commodityL = docElem.elementsByTagName(QLatin1String("commodity"));
                     int nb = commodityL.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         // Get unit object
                         auto commodity = commodityL.at(i).toElement();
-                        auto symbol = commodity.firstChildElement(QStringLiteral("symbol")).toElement().text();
+                        auto symbol = commodity.firstChildElement(QLatin1String("symbol")).toElement().text();
 
                         // Creation of the units
                         SKGUnitObject unitObj(m_importer->getDocument());
@@ -285,16 +301,16 @@ SKGError SKGImportPluginLedger::importFile()
                         IFOKDO(err, unitObj.save())
 
                         // Creation of the unit values
-                        auto annotation = commodity.firstChildElement(QStringLiteral("annotation")).toElement();
-                        auto price = annotation.firstChildElement(QStringLiteral("price")).toElement();
-                        auto commodity2 = price.firstChildElement(QStringLiteral("commodity")).toElement();
-                        auto quantity = price.firstChildElement(QStringLiteral("quantity")).toElement().text().trimmed();
-                        auto symbol2 = commodity2.firstChildElement(QStringLiteral("symbol")).toElement();
-                        auto date = annotation.firstChildElement(QStringLiteral("date")).toElement().text().trimmed();
+                        auto annotation = commodity.firstChildElement(QLatin1String("annotation")).toElement();
+                        auto price = annotation.firstChildElement(QLatin1String("price")).toElement();
+                        auto commodity2 = price.firstChildElement(QLatin1String("commodity")).toElement();
+                        auto quantity = price.firstChildElement(QLatin1String("quantity")).toElement().text().trimmed();
+                        auto symbol2 = commodity2.firstChildElement(QLatin1String("symbol")).toElement();
+                        auto date = annotation.firstChildElement(QLatin1String("date")).toElement().text().trimmed();
                         if (!date.isNull() && !symbol2.isNull() && !quantity.isNull()) {
                             SKGUnitValueObject unitValueObj;
                             IFOKDO(err, unitObj.addUnitValue(unitValueObj))
-                            IFOKDO(err, unitValueObj.setDate(QDate::fromString(date, QStringLiteral("yyyy/MM/dd"))))
+                            IFOKDO(err, unitValueObj.setDate(QDate::fromString(date, QLatin1String("yyyy/MM/dd"))))
                             IFOKDO(err, unitValueObj.setQuantity(1.0 / SKGServices::stringToDouble(quantity)))
                             IFOKDO(err, unitValueObj.save())
                         }
@@ -310,32 +326,32 @@ SKGError SKGImportPluginLedger::importFile()
 
                 // Step 2-Create transaction
                 IFOK(err) {
-                    auto transactionL = docElem.elementsByTagName(QStringLiteral("transaction"));
+                    auto transactionL = docElem.elementsByTagName(QLatin1String("transaction"));
                     int nb = transactionL.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         // Get account object
                         auto transaction = transactionL.at(i).toElement();
 
-                        auto date = transaction.firstChildElement(QStringLiteral("date")).toElement().text().trimmed();
-                        auto payee = transaction.firstChildElement(QStringLiteral("payee")).toElement().text().trimmed();
-                        auto note = transaction.firstChildElement(QStringLiteral("note")).toElement().text().trimmed();
-                        auto status = getAttribute(transaction, QStringLiteral("state"));
+                        auto date = transaction.firstChildElement(QLatin1String("date")).toElement().text().trimmed();
+                        auto payee = transaction.firstChildElement(QLatin1String("payee")).toElement().text().trimmed();
+                        auto note = transaction.firstChildElement(QLatin1String("note")).toElement().text().trimmed();
+                        auto status = getAttribute(transaction, QLatin1String("state"));
 
                         // Create transaction and suboperation
                         SKGOperationObject opObj;
                         SKGSubOperationObject subObj;
-                        auto postingL = transaction.elementsByTagName(QStringLiteral("posting"));
+                        auto postingL = transaction.elementsByTagName(QLatin1String("posting"));
 
-                        auto symbol = postingL.at(0).toElement().elementsByTagName(QStringLiteral("symbol")).at(0).toElement().text().trimmed();
+                        auto symbol = postingL.at(0).toElement().elementsByTagName(QLatin1String("symbol")).at(0).toElement().text().trimmed();
                         int nb2 = postingL.count();
 
                         //Put account in the first place
                         QList<QDomElement> list_porting;
                         for (int i2 = 0; !err && i2 < nb2; ++i2) {
                             auto posting = postingL.at(i2).toElement();
-                            auto account = posting.firstChildElement(QStringLiteral("account")).toElement();
-                            auto type = account.firstChildElement(QStringLiteral("name")).toElement().text().split(QStringLiteral(":"))[0].toUpper().trimmed();
+                            auto account = posting.firstChildElement(QLatin1String("account")).toElement();
+                            auto type = account.firstChildElement(QLatin1String("name")).toElement().text().split(QLatin1String(":"))[0].toUpper().trimmed();
 
                             if (isAccount(type)) {
                                 list_porting.insert(0, posting);
@@ -346,22 +362,22 @@ SKGError SKGImportPluginLedger::importFile()
                         SKGOperationObject opPreviousObj;
                         for (int i2 = 0; !err && i2 < nb2; ++i2) {
                             auto posting = list_porting.at(i2);
-                            auto account = posting.firstChildElement(QStringLiteral("account")).toElement();
-                            auto name = account.firstChildElement(QStringLiteral("name")).toElement().text().trimmed();
-                            auto snote = posting.firstChildElement(QStringLiteral("note")).toElement().text().trimmed();
+                            auto account = posting.firstChildElement(QLatin1String("account")).toElement();
+                            auto name = account.firstChildElement(QLatin1String("name")).toElement().text().trimmed();
+                            auto snote = posting.firstChildElement(QLatin1String("note")).toElement().text().trimmed();
 
-                            auto postamount = posting.firstChildElement(QStringLiteral("post-amount")).toElement();
+                            auto postamount = posting.firstChildElement(QLatin1String("post-amount")).toElement();
 
-                            auto amount = postamount.firstChildElement(QStringLiteral("amount")).toElement();
-                            auto quantity = amount.firstChildElement(QStringLiteral("quantity")).toElement().text().trimmed();
+                            auto amount = postamount.firstChildElement(QLatin1String("amount")).toElement();
+                            auto quantity = amount.firstChildElement(QLatin1String("quantity")).toElement().text().trimmed();
 
-                            auto names = name.split(QStringLiteral(":"));
+                            auto names = name.split(QLatin1String(":"));
                             QString type;
                             if (names.length() > 1) {
                                 type = names[0].toUpper();
                                 name = name.right(name.length() - type.length() - 1);
                             }
-                            SKGTRACEL(2) << "Sub transaction : " << name << ": " << date << ": " << payee << " | " << quantity << SKGENDL;
+                            SKGTRACEL(2) << "Sub transaction : " << name << ": " << date << ": " << payee << " | " << quantity << Qt::endl;
 
                             auto isaccount = isAccount(type);
                             if (i2 > 0) {
@@ -374,14 +390,14 @@ SKGError SKGImportPluginLedger::importFile()
                                 }
                             }
                             if (isaccount || !opObj.exist()) {
-                                auto account_id = getAttribute(account, QStringLiteral("ref"));
+                                auto account_id = getAttribute(account, QLatin1String("ref"));
 
                                 SKGAccountObject accountObj;
                                 if (!mapIdAccount.contains(account_id)) {
-                                    auto err2 = m_importer->getDocument()->getObject(QStringLiteral("v_account"), "t_name='" % SKGServices::stringToSqlString(name) % '\'', accountObj);
+                                    auto err2 = m_importer->getDocument()->getObject(QLatin1String("v_account"), "t_name='" % SKGServices::stringToSqlString(name) % QLatin1Char('\''), accountObj);
                                     if (!!err2) {
                                         SKGBankObject bankDefault(m_importer->getDocument());
-                                        IFOKDO(err, bankDefault.setName(QStringLiteral("LEDGER")))
+                                        IFOKDO(err, bankDefault.setName(QLatin1String("LEDGER")))
                                         IFOKDO(err, bankDefault.save())
                                         IFOK(err) {
                                             IFOKDO(err, bankDefault.addAccount(accountObj))
@@ -396,7 +412,7 @@ SKGError SKGImportPluginLedger::importFile()
 
                                 // Creation of the transaction
                                 IFOKDO(err, accountObj.addOperation(opObj, true))
-                                IFOKDO(err, opObj.setDate(QDate::fromString(date, QStringLiteral("yyyy/MM/dd"))))
+                                IFOKDO(err, opObj.setDate(QDate::fromString(date, QLatin1String("yyyy/MM/dd"))))
 
                                 IFOKDO(err, opObj.setUnit(mapIdUnit[symbol]))
                                 if (!payee.isEmpty()) {
@@ -412,9 +428,9 @@ SKGError SKGImportPluginLedger::importFile()
                                 }
                                 IFOKDO(err, opObj.setComment(note))
                                 IFOKDO(err, opObj.setImported(true))
-                                IFOKDO(err, opObj.setImportID(QStringLiteral("LEDGER-")))
-                                IFOKDO(err, opObj.setStatus(status == QStringLiteral("cleared") ? SKGOperationObject::CHECKED :
-                                                            status == QStringLiteral("pending") ? SKGOperationObject::MARKED : SKGOperationObject::NONE))
+                                IFOKDO(err, opObj.setImportID(QLatin1String("LEDGER-")))
+                                IFOKDO(err, opObj.setStatus(status == QLatin1String("cleared") ? SKGOperationObject::CHECKED :
+                                                            status == QLatin1String("pending") ? SKGOperationObject::MARKED : SKGOperationObject::NONE))
                                 IFOKDO(err, opObj.save())
 
                                 if (opPreviousObj.getID()) {
@@ -430,15 +446,15 @@ SKGError SKGImportPluginLedger::importFile()
                             if (!isaccount) {
                                 SKGCategoryObject catObj;
                                 if (!mapIdCategory.contains(name)) {
-                                    IFOKDO(err, SKGCategoryObject::createPathCategory(m_importer->getDocument(), name.replace(QStringLiteral(":"), QStringLiteral(" > ")), catObj))
+                                    IFOKDO(err, SKGCategoryObject::createPathCategory(m_importer->getDocument(), name.replace(QLatin1String(":"), QLatin1String(" > ")), catObj))
                                     mapIdCategory[name] = catObj;
                                 } else {
                                     catObj = mapIdCategory[name];
                                 }
                                 IFOKDO(err, subObj.setCategory(catObj))
                             }
-                            if (snote.startsWith(QStringLiteral("[=")) && snote.endsWith(QStringLiteral("]"))) {
-                                IFOKDO(err, subObj.setDate(QDate::fromString(snote.mid(2, snote.length() - 3), QStringLiteral("yyyy/MM/dd"))))
+                            if (snote.startsWith(QLatin1String("[=")) && snote.endsWith(QLatin1String("]"))) {
+                                IFOKDO(err, subObj.setDate(QDate::fromString(snote.mid(2, snote.length() - 3), QLatin1String("yyyy/MM/dd"))))
                             } else {
                                 IFOKDO(err, subObj.setComment(snote))
                             }
@@ -449,7 +465,7 @@ SKGError SKGImportPluginLedger::importFile()
                         }
 
                         if (!err && i % 500 == 0) {
-                            err = m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE"));
+                            err = m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE"));
                         }
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
@@ -459,7 +475,7 @@ SKGError SKGImportPluginLedger::importFile()
                 IFOKDO(err, m_importer->getDocument()->stepForward(2))
                 SKGENDTRANSACTION(m_importer->getDocument(),  err)
 
-                IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE")))
+                IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE")))
             }
         }
     } else {
@@ -476,7 +492,7 @@ QString SKGImportPluginLedger::getMimeTypeFilter() const
 QString SKGImportPluginLedger::getAttribute(const QDomElement& iElement, const QString& iAttribute)
 {
     QString val = iElement.attribute(iAttribute);
-    if (val == QStringLiteral("(null)")) {
+    if (val == QLatin1String("(null)")) {
         val = QString();
     }
     return val;
