@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -41,7 +41,7 @@ SKGImportPluginMmb::~SKGImportPluginMmb()
 bool SKGImportPluginMmb::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("MMB"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("MMB"));
 }
 
 SKGError SKGImportPluginMmb::importFile()
@@ -53,7 +53,7 @@ SKGError SKGImportPluginMmb::importFile()
     SKGTRACEINFUNCRC(2, err)
 
     {
-        QSqlDatabase originalDocument(QSqlDatabase::addDatabase(QStringLiteral("SKGSQLCIPHER"), QStringLiteral("originalDocument")));
+        QSqlDatabase originalDocument(QSqlDatabase::addDatabase(QLatin1String("SKGSQLCIPHER"), QLatin1String("originalDocument")));
         originalDocument.setDatabaseName(m_importer->getLocalFileName());
         if (!originalDocument.open()) {
             // Set error message
@@ -67,7 +67,7 @@ SKGError SKGImportPluginMmb::importFile()
             // Step 1 - units
             IFOK(err) {
                 SKGStringListList listUnits;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT CURRENCYID, CURRENCYNAME, PFX_SYMBOL, SFX_SYMBOL, DECIMAL_POINT, GROUP_SEPARATOR, UNIT_NAME, CENT_NAME, SCALE, BASECONVRATE, CURRENCY_SYMBOL, "
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT CURRENCYID, CURRENCYNAME, PFX_SYMBOL, SFX_SYMBOL, DECIMAL_POINT, GROUP_SEPARATOR, UNIT_NAME, CENT_NAME, SCALE, BASECONVRATE, CURRENCY_SYMBOL, "
                         "(CASE WHEN EXISTS (SELECT 1 FROM INFOTABLE_V1 WHERE INFONAME='BASECURRENCYID' AND INFOVALUE=CURRENCYID) THEN 'Y' ELSE 'N' END) AS PRIMARYUNIT FROM CURRENCYFORMATS_V1"), listUnits);
                 IFOK(err) {
                     int nb = listUnits.count() - 1;
@@ -84,7 +84,7 @@ SKGError SKGImportPluginMmb::importFile()
                             }
                             err = unit.setSymbol(symbol);
                         }
-                        if (!err && attributes.at(11) == QStringLiteral("Y")) {
+                        if (!err && attributes.at(11) == QLatin1String("Y")) {
                             err = unit.setType(SKGUnitObject::PRIMARY);
                         }
                         IFOKDO(err, unit.save())
@@ -103,7 +103,7 @@ SKGError SKGImportPluginMmb::importFile()
             QMap<QString, SKGAccountObject> mapAccount;
             IFOK(err) {
                 SKGStringListList listAccounts;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT ACCOUNTID, ACCOUNTNAME, ACCOUNTTYPE, ACCOUNTNUM, STATUS, NOTES, HELDAT, WEBSITE, CONTACTINFO, ACCESSINFO, INITIALBAL, FAVORITEACCT, CURRENCYID FROM ACCOUNTLIST_V1"), listAccounts);
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT ACCOUNTID, ACCOUNTNAME, ACCOUNTTYPE, ACCOUNTNUM, STATUS, NOTES, HELDAT, WEBSITE, CONTACTINFO, ACCESSINFO, INITIALBAL, FAVORITEACCT, CURRENCYID FROM ACCOUNTLIST_V1"), listAccounts);
                 IFOK(err) {
                     int nb = listAccounts.count() - 1;
                     IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks and accounts"), nb))
@@ -115,7 +115,7 @@ SKGError SKGImportPluginMmb::importFile()
                         IFOK(err) {
                             QString bankName = attributes.at(6);
                             if (bankName.isEmpty()) {
-                                bankName = QStringLiteral("MMEX");
+                                bankName = QLatin1String("MMEX");
                             }
                             err = bank.setName(bankName);
                         }
@@ -125,12 +125,12 @@ SKGError SKGImportPluginMmb::importFile()
                         SKGAccountObject account;
                         err = bank.addAccount(account);
                         IFOKDO(err, account.setName(attributes.at(1)))
-                        IFOKDO(err, account.setType(attributes.at(2) == QStringLiteral("Checking") ? SKGAccountObject::CURRENT : SKGAccountObject::INVESTMENT))
+                        IFOKDO(err, account.setType(attributes.at(2) == QLatin1String("Checking") ? SKGAccountObject::CURRENT : SKGAccountObject::INVESTMENT))
                         IFOKDO(err, account.setNumber(attributes.at(3)))
                         IFOKDO(err, account.setComment(attributes.at(5)))
                         IFOKDO(err, account.setAgencyAddress(attributes.at(8)))
-                        IFOKDO(err, account.bookmark(attributes.at(11) == QStringLiteral("TRUE")))
-                        IFOKDO(err, account.setClosed(attributes.at(4) != QStringLiteral("Open")))
+                        IFOKDO(err, account.bookmark(attributes.at(11) == QLatin1String("TRUE")))
+                        IFOKDO(err, account.setClosed(attributes.at(4) != QLatin1String("Open")))
                         IFOKDO(err, account.save())
                         IFOKDO(err, account.setInitialBalance(SKGServices::stringToDouble(attributes.at(10)), mapUnit[attributes.at(12)]))
                         IFOKDO(err, account.save())
@@ -149,7 +149,7 @@ SKGError SKGImportPluginMmb::importFile()
             QMap<QString, SKGCategoryObject> mapCategory;
             IFOK(err) {
                 SKGStringListList listCategories;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT CATEGID, CATEGNAME FROM CATEGORY_V1"), listCategories);
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT CATEGID, CATEGNAME FROM CATEGORY_V1"), listCategories);
                 IFOK(err) {
                     int nb = listCategories.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
@@ -174,7 +174,7 @@ SKGError SKGImportPluginMmb::importFile()
             QMap<QString, SKGCategoryObject> mapSubCategory;
             IFOK(err) {
                 SKGStringListList listCategories;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT SUBCATEGID, SUBCATEGNAME, CATEGID FROM SUBCATEGORY_V1"), listCategories);
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT SUBCATEGID, SUBCATEGNAME, CATEGID FROM SUBCATEGORY_V1"), listCategories);
                 IFOK(err) {
                     int nb = listCategories.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
@@ -200,7 +200,7 @@ SKGError SKGImportPluginMmb::importFile()
             QMap<QString, SKGPayeeObject> mapPayee;
             IFOK(err) {
                 SKGStringListList listPayee;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT PAYEEID, PAYEENAME FROM PAYEE_V1"), listPayee);
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT PAYEEID, PAYEENAME FROM PAYEE_V1"), listPayee);
                 IFOK(err) {
                     int nb = listPayee.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
@@ -225,7 +225,7 @@ SKGError SKGImportPluginMmb::importFile()
             QMap<QString, SKGOperationObject> mapOperation;
             IFOK(err) {
                 SKGStringListList listOperations;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT * FROM ("
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT * FROM ("
                         "SELECT TRANSID, ACCOUNTID, TOACCOUNTID, PAYEEID, TRANSCODE, TRANSAMOUNT, STATUS, TRANSACTIONNUMBER, NOTES, CATEGID, SUBCATEGID, TRANSDATE, FOLLOWUPID, TOTRANSAMOUNT, 'N/A'  , 'N/A', 'N/A' FROM CHECKINGACCOUNT_V1 UNION "
                         "SELECT BDID,    ACCOUNTID, TOACCOUNTID, PAYEEID, TRANSCODE, TRANSAMOUNT, STATUS, TRANSACTIONNUMBER, NOTES, CATEGID, SUBCATEGID, TRANSDATE, FOLLOWUPID, TOTRANSAMOUNT, REPEATS, NEXTOCCURRENCEDATE, NUMOCCURRENCES FROM BILLSDEPOSITS_V1)"), listOperations);
                 IFOK(err) {
@@ -233,8 +233,8 @@ SKGError SKGImportPluginMmb::importFile()
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         const QStringList& attributes = listOperations.at(i + 1);
-                        if (attributes.at(6) != QStringLiteral("V")) {  // Void
-                            bool recurrent = (attributes.at(14) != QStringLiteral("N/A"));
+                        if (attributes.at(6) != QLatin1String("V")) {  // Void
+                            bool recurrent = (attributes.at(14) != QLatin1String("N/A"));
                             const QString& idTarget = attributes.at(2);
                             SKGAccountObject acc = mapAccount[attributes.at(1)];
                             SKGUnitObject unit;
@@ -244,25 +244,25 @@ SKGError SKGImportPluginMmb::importFile()
                             IFOKDO(err, acc.addOperation(op, true))
                             IFOK(err) {
                                 const QString& id = attributes.at(3);
-                                if (id != QStringLiteral("-1")) {
+                                if (id != QLatin1String("-1")) {
                                     err = op.setPayee(mapPayee[id]);
                                 }
                             }
                             IFOKDO(err, op.setNumber(attributes.at(7)))
                             IFOKDO(err, op.setComment(attributes.at(8)))
-                            IFOKDO(err, op.setDate(SKGServices::stringToTime(attributes.at(11)).date()))
-                            IFOKDO(err, op.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
+                            IFOKDO(err, op.setDate(SKGServices::stringToDate(attributes.at(11))))
+                            IFOKDO(err, op.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
                             IFOKDO(err, op.setImportID("MMEX-" % attributes.at(0)))
                             IFOKDO(err, op.setUnit(unit))
-                            IFOKDO(err, op.bookmark(attributes.at(6) == QStringLiteral("F")))
+                            IFOKDO(err, op.bookmark(attributes.at(6) == QLatin1String("F")))
                             IFOKDO(err, op.setTemplate(recurrent))
-                            IFOKDO(err, op.setStatus(attributes.at(6) == QStringLiteral("R") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
+                            IFOKDO(err, op.setStatus(attributes.at(6) == QLatin1String("R") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
                             IFOKDO(err, op.save())
 
                             // Get splits
                             IFOK(err) {
                                 SKGStringListList listSubOperations;
-                                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT SPLITTRANSID, CATEGID, SUBCATEGID, SPLITTRANSAMOUNT FROM ") % (recurrent ? "BUDGET" : "") % "SPLITTRANSACTIONS_V1 WHERE TRANSID=" % attributes.at(0), listSubOperations);
+                                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT SPLITTRANSID, CATEGID, SUBCATEGID, SPLITTRANSAMOUNT FROM ") % (recurrent ? "BUDGET" : "") % "SPLITTRANSACTIONS_V1 WHERE TRANSID=" % attributes.at(0), listSubOperations);
                                 IFOK(err) {
                                     int nb2 = listSubOperations.count() - 1;
                                     if (nb2 <= 0) {
@@ -271,9 +271,9 @@ SKGError SKGImportPluginMmb::importFile()
                                         IFOKDO(err, op.addSubOperation(subop))
                                         IFOK(err) {
                                             QString id = attributes.at(10);
-                                            if (id == QStringLiteral("-1")) {
+                                            if (id == QLatin1String("-1")) {
                                                 id = attributes.at(9);
-                                                if (id != QStringLiteral("-1")) {
+                                                if (id != QLatin1String("-1")) {
                                                     err = subop.setCategory(mapSubCategory[id]);
                                                 }
                                             } else {
@@ -282,7 +282,7 @@ SKGError SKGImportPluginMmb::importFile()
                                         }
                                         IFOK(err) {
                                             double q = SKGServices::stringToDouble(attributes.at(5));
-                                            if (attributes.at(4) == QStringLiteral("Withdrawal") || idTarget != QStringLiteral("-1")) {
+                                            if (attributes.at(4) == QLatin1String("Withdrawal") || idTarget != QLatin1String("-1")) {
                                                 q = -q;
                                             }
                                             err = subop.setQuantity(q);
@@ -297,9 +297,9 @@ SKGError SKGImportPluginMmb::importFile()
                                             IFOKDO(err, op.addSubOperation(subop))
                                             IFOK(err) {
                                                 QString id = attributesSubOp.at(2);
-                                                if (id == QStringLiteral("-1")) {
+                                                if (id == QLatin1String("-1")) {
                                                     id = attributesSubOp.at(1);
-                                                    if (id != QStringLiteral("-1")) {
+                                                    if (id != QLatin1String("-1")) {
                                                         err = subop.setCategory(mapCategory[id]);
                                                     }
                                                 } else {
@@ -308,7 +308,7 @@ SKGError SKGImportPluginMmb::importFile()
                                             }
                                             IFOK(err) {
                                                 double q = SKGServices::stringToDouble(attributesSubOp.at(3));
-                                                if (attributes.at(4) == QStringLiteral("Withdrawal") || idTarget != QStringLiteral("-1")) {
+                                                if (attributes.at(4) == QLatin1String("Withdrawal") || idTarget != QLatin1String("-1")) {
                                                     q = -q;
                                                 }
                                                 err = subop.setQuantity(q);
@@ -320,12 +320,12 @@ SKGError SKGImportPluginMmb::importFile()
                             }
 
                             // Case Transfer
-                            if (!err && idTarget != QStringLiteral("-1")) {
+                            if (!err && idTarget != QLatin1String("-1")) {
                                 SKGOperationObject op2;
                                 err = op.duplicate(op2, op.getDate());
                                 IFOKDO(err, op2.setStatus(op.getStatus()))
                                 IFOKDO(err, op2.bookmark(op.isBookmarked()))
-                                IFOKDO(err, op2.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
+                                IFOKDO(err, op2.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
                                 IFOKDO(err, op2.setImportID("MMEX-" % attributes.at(0) % "_TR"))
                                 IFOKDO(err, op2.save())
 
@@ -345,7 +345,7 @@ SKGError SKGImportPluginMmb::importFile()
                             if (recurrent) {
                                 SKGRecurrentOperationObject recu;
                                 IFOKDO(err, op.addRecurrentOperation(recu))
-                                IFOKDO(err, recu.setDate(SKGServices::stringToTime(attributes.at(15)).date()))
+                                IFOKDO(err, recu.setDate(SKGServices::stringToDate(attributes.at(15))))
                                 int nbTimes = SKGServices::stringToInt(attributes.at(16));
                                 if (!err && nbTimes != -1) {
                                     err = recu.setTimeLimit(nbTimes);
@@ -425,7 +425,7 @@ SKGError SKGImportPluginMmb::importFile()
             // Step 7 - stock
             IFOK(err) {
                 SKGStringListList listStock;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT STOCKID, HELDAT, PURCHASEDATE, STOCKNAME, SYMBOL, NUMSHARES, PURCHASEPRICE, NOTES, CURRENTPRICE, VALUE, COMMISSION FROM STOCK_V1"), listStock);
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT STOCKID, HELDAT, PURCHASEDATE, STOCKNAME, SYMBOL, NUMSHARES, PURCHASEPRICE, NOTES, CURRENTPRICE, VALUE, COMMISSION FROM STOCK_V1"), listStock);
                 IFOK(err) {
                     int nb = listStock.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import stocks"), nb);
@@ -441,7 +441,7 @@ SKGError SKGImportPluginMmb::importFile()
 
                         SKGUnitValueObject unitValue;
                         IFOKDO(err, unit.addUnitValue(unitValue))
-                        IFOKDO(err, unitValue.setDate(SKGServices::stringToTime(attributes.at(2)).date()))
+                        IFOKDO(err, unitValue.setDate(SKGServices::stringToDate(attributes.at(2))))
                         IFOKDO(err, unitValue.setQuantity(SKGServices::stringToDouble(attributes.at(6))))
                         IFOKDO(err, unitValue.save(true, false))
 
@@ -459,8 +459,8 @@ SKGError SKGImportPluginMmb::importFile()
                         SKGOperationObject op;
                         IFOKDO(err, acc.addOperation(op, true))
                         IFOKDO(err, op.setComment(attributes.at(7)))
-                        IFOKDO(err, op.setDate(SKGServices::stringToTime(attributes.at(2)).date()))
-                        IFOKDO(err, op.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
+                        IFOKDO(err, op.setDate(SKGServices::stringToDate(attributes.at(2))))
+                        IFOKDO(err, op.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
                         IFOKDO(err, op.setImportID("MMEX-STOCK-" % attributes.at(0)))
                         IFOKDO(err, op.setUnit(unit))
                         IFOKDO(err, op.save())
@@ -473,8 +473,8 @@ SKGError SKGImportPluginMmb::importFile()
                         /*SKGOperationObject op2;
                         if(!err) err = acc.addOperation(op2, true);
                         if(!err) err = op2.setComment(attributes.at(7));
-                        if(!err) err = op2.setDate(SKGServices::stringToTime(attributes.at(2)).date());
-                        if(!err) err = op2.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T"));
+                        if(!err) err = op2.setDate(SKGServices::stringToDate(attributes.at(2)));
+                        if(!err) err = op2.setAttribute(QLatin1String("t_imported"), QLatin1String("T"));
                         if(!err) err = op2.setImportID("MMEX-STOCK-" % attributes.at(0)% "_TR");
                         if(!err) err = op2.setUnit(unitCurrency);
                         if(!err) err = op2.save();
@@ -498,14 +498,14 @@ SKGError SKGImportPluginMmb::importFile()
             // Step 8 - asset
             IFOK(err) {
                 SKGStringListList listAssets;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT ASSETID, STARTDATE, ASSETNAME, VALUE, VALUECHANGE, NOTES, VALUECHANGERATE, ASSETTYPE FROM ASSETS_V1"), listAssets);
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT ASSETID, STARTDATE, ASSETNAME, VALUE, VALUECHANGE, NOTES, VALUECHANGERATE, ASSETTYPE FROM ASSETS_V1"), listAssets);
                 IFOK(err) {
                     int nb = listAssets.count() - 1;
                     if (nb != 0) {
                         // Create account
                         // Create bank
                         SKGBankObject bank(m_importer->getDocument());
-                        IFOKDO(err, bank.setName(QStringLiteral("MMEX")))
+                        IFOKDO(err, bank.setName(QLatin1String("MMEX")))
                         IFOKDO(err, bank.save())
 
                         // Create account
@@ -524,12 +524,12 @@ SKGError SKGImportPluginMmb::importFile()
                             err = unit.setName(attributes.at(2));
                             IFOKDO(err, unit.setSymbol(attributes.at(2)))
                             IFOKDO(err, unit.setType(SKGUnitObject::OBJECT))
-                            IFOKDO(err, unit.setInternetCode(QStringLiteral("=") % (attributes.at(4) == QStringLiteral("Depreciates") ? QStringLiteral("-") : QStringLiteral("+")) % attributes.at(6)))
+                            IFOKDO(err, unit.setInternetCode(QLatin1String("=") % (attributes.at(4) == QLatin1String("Depreciates") ? QLatin1String("-") : QLatin1String("+")) % attributes.at(6)))
                             IFOKDO(err, unit.save())
 
                             SKGUnitValueObject unitValue;
                             IFOKDO(err, unit.addUnitValue(unitValue))
-                            IFOKDO(err, unitValue.setDate(SKGServices::stringToTime(attributes.at(1)).date()))
+                            IFOKDO(err, unitValue.setDate(SKGServices::stringToDate(attributes.at(1))))
                             IFOKDO(err, unitValue.setQuantity(SKGServices::stringToDouble(attributes.at(3))))
                             IFOKDO(err, unitValue.save(true, false))
 
@@ -537,8 +537,8 @@ SKGError SKGImportPluginMmb::importFile()
                             SKGOperationObject op;
                             IFOKDO(err, account.addOperation(op, true))
                             IFOKDO(err, op.setComment(attributes.at(5)))
-                            IFOKDO(err, op.setDate(SKGServices::stringToTime(attributes.at(1)).date()))
-                            IFOKDO(err, op.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
+                            IFOKDO(err, op.setDate(SKGServices::stringToDate(attributes.at(1))))
+                            IFOKDO(err, op.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
                             IFOKDO(err, op.setImportID("MMEX-ASSET-" % attributes.at(0)))
                             IFOKDO(err, op.setUnit(unit))
                             IFOKDO(err, op.save())
@@ -560,7 +560,7 @@ SKGError SKGImportPluginMmb::importFile()
             // Step 9 - budgets
             IFOK(err) {
                 SKGStringListList listBudgets;
-                err = SKGServices::executeSelectSqliteOrder(originalDocument, QStringLiteral("SELECT BUDGETENTRYID, (SELECT Y.BUDGETYEARNAME FROM BUDGETYEAR_V1 Y WHERE Y.BUDGETYEARID=BUDGETTABLE_V1.BUDGETYEARID), CATEGID, SUBCATEGID, PERIOD, AMOUNT FROM BUDGETTABLE_V1"), listBudgets);
+                err = SKGServices::executeSelectSqliteOrder(originalDocument, QLatin1String("SELECT BUDGETENTRYID, (SELECT Y.BUDGETYEARNAME FROM BUDGETYEAR_V1 Y WHERE Y.BUDGETYEARID=BUDGETTABLE_V1.BUDGETYEARID), CATEGID, SUBCATEGID, PERIOD, AMOUNT FROM BUDGETTABLE_V1"), listBudgets);
                 IFOK(err) {
                     int nb = listBudgets.count() - 1;
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import budgets"), nb);
@@ -571,25 +571,25 @@ SKGError SKGImportPluginMmb::importFile()
 
                         int step = 0;
                         double coef = 0;
-                        if (period == QStringLiteral("Weekly")) {
+                        if (period == QLatin1String("Weekly")) {
                             coef = 52.0 / 12.0;
                             step = 1;
-                        } else if (period == QStringLiteral("Monthly")) {
+                        } else if (period == QLatin1String("Monthly")) {
                             coef = 1;
                             step = 1;
-                        } else if (period == QStringLiteral("Bi-Weekly")) {
+                        } else if (period == QLatin1String("Bi-Weekly")) {
                             coef = 52.0 / 12.0 / 2.0;
                             step = 1;
-                        } else if (period == QStringLiteral("Bi-Monthly")) {
+                        } else if (period == QLatin1String("Bi-Monthly")) {
                             coef = 1;
                             step = 2;
-                        } else if (period == QStringLiteral("Quarterly")) {
+                        } else if (period == QLatin1String("Quarterly")) {
                             coef = 1;
                             step = 4;
-                        } else if (period == QStringLiteral("Half-Yearly")) {
+                        } else if (period == QLatin1String("Half-Yearly")) {
                             coef = 1;
                             step = 6;
-                        } else if (period == QStringLiteral("Yearly")) {
+                        } else if (period == QLatin1String("Yearly")) {
                             coef = 1;
                             step = 12;
                         }
@@ -601,9 +601,9 @@ SKGError SKGImportPluginMmb::importFile()
                                 IFOKDO(err, bug.setMonth(step == 12 ? 0 : j + 1))
                                 IFOK(err) {
                                     QString id = attributes.at(3);
-                                    if (id == QStringLiteral("-1")) {
+                                    if (id == QLatin1String("-1")) {
                                         id = attributes.at(2);
-                                        if (id != QStringLiteral("-1")) {
+                                        if (id != QLatin1String("-1")) {
                                             err = bug.setCategory(mapCategory[id]);
                                         }
                                     } else {
@@ -625,11 +625,11 @@ SKGError SKGImportPluginMmb::importFile()
 
             SKGENDTRANSACTION(m_importer->getDocument(),  err)
 
-            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE")))
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE")))
         }
         originalDocument.close();
     }
-    QSqlDatabase::removeDatabase(QStringLiteral("originalDocument"));
+    QSqlDatabase::removeDatabase(QLatin1String("originalDocument"));
     return err;
 }
 
