@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -42,8 +42,8 @@ SKGImportPluginMny::SKGImportPluginMny(QObject* iImporter, const QVariantList& i
     SKGTRACEINFUNC(10)
     Q_UNUSED(iArg)
 
-    m_importParameters[QStringLiteral("password")] = QString();
-    m_importParameters[QStringLiteral("install_sunriise")] = 'N';
+    m_importParameters[QLatin1String("password")] = QString();
+    m_importParameters[QLatin1String("install_sunriise")] = 'N';
 }
 
 SKGImportPluginMny::~SKGImportPluginMny()
@@ -79,7 +79,7 @@ bool SKGImportPluginMny::isImportPossible()
         return true;
     }
     QString extension = m_importer->getFileNameExtension();
-    return (extension == QStringLiteral("MNY"));
+    return (extension == QLatin1String("MNY"));
 }
 
 SKGError SKGImportPluginMny::readJsonFile(const QString& iFileName, QVariant& oVariant)
@@ -117,20 +117,20 @@ SKGError SKGImportPluginMny::importFile()
     }
 
     // Check install
-    if (QStandardPaths::findExecutable(QStringLiteral("java")).isEmpty()) {
+    if (QStandardPaths::findExecutable(QLatin1String("java")).isEmpty()) {
         err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "The java application is not installed. You must manually install it."));
         return err;
     }
 
     QString sunriise_jar = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) % "/sunriise.jar";
     if (!QFile(sunriise_jar).exists()) {
-        if (m_importParameters.value(QStringLiteral("install_sunriise")) == QStringLiteral("Y")) {
+        if (m_importParameters.value(QLatin1String("install_sunriise")) == QLatin1String("Y")) {
             QDir().mkpath(QFileInfo(sunriise_jar).dir().path());
-            err = SKGServices::upload(QUrl(QStringLiteral("https://skrooge.org/files/sunriise.jar")), QUrl::fromLocalFile(sunriise_jar));
+            err = SKGServices::upload(QUrl(QLatin1String("https://skrooge.org/files/sunriise.jar")), QUrl::fromLocalFile(sunriise_jar));
             IFKO(err) return err;
         } else {
             err.setReturnCode(ERR_INSTALL).setMessage(i18nc("Error message",  "The sunriise application is needed for Microsoft Money import but is not installed in '%1'", sunriise_jar));
-            err.setProperty(QStringLiteral("sunriise"));
+            err.setProperty(QLatin1String("sunriise"));
             return err;
         }
     }
@@ -148,10 +148,10 @@ SKGError SKGImportPluginMny::importFile()
     QDir::temp().mkdir(uniqueId);
     QDir temporaryDir(temporaryPath);
 
-    QString cmd = "java -cp \"" % sunriise_jar % "\" com/le/sunriise/export/ExportToJSON \"" % m_importer->getLocalFileName() % "\" \"" % m_importParameters.value(QStringLiteral("password")) % "\" " % temporaryPath;
-    SKGTRACEL(10) << "Execution of :" << cmd << SKGENDL;
+    QString cmd = "java -cp \"" % sunriise_jar % "\" com/le/sunriise/export/ExportToJSON \"" % m_importer->getLocalFileName() % "\" \"" % m_importParameters.value(QLatin1String("password")) % "\" " % temporaryPath;
+    SKGTRACEL(10) << "Execution of :" << cmd << Qt::endl;
     QProcess p;
-    p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
+    p.start(QLatin1String("/bin/bash"), QStringList() << QLatin1String("-c") << cmd);
     if (p.waitForFinished(1000 * 60 * 5) && p.exitCode() == 0) {
         // Import
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MNY"), 6);
@@ -177,10 +177,10 @@ SKGError SKGImportPluginMny::importFile()
                     for (int i = 0; !err && i < nb && index < nb; ++i) {
                         QVariantMap category = list.at(i).toMap();
 
-                        QString parentId = category[QStringLiteral("parentId")].toString();
-                        QString id = category[QStringLiteral("id")].toString();
-                        QString name = category[QStringLiteral("name")].toString();
-                        int level = category[QStringLiteral("level")].toInt();
+                        QString parentId = category[QLatin1String("parentId")].toString();
+                        QString id = category[QLatin1String("id")].toString();
+                        QString name = category[QLatin1String("name")].toString();
+                        int level = category[QLatin1String("level")].toInt();
 
                         if (level == t) {
                             SKGCategoryObject catObject(m_importer->getDocument());
@@ -216,8 +216,8 @@ SKGError SKGImportPluginMny::importFile()
                 for (int i = 0; !err && i < nb; ++i) {
                     QVariantMap payee = list.at(i).toMap();
 
-                    QString id = payee[QStringLiteral("id")].toString();
-                    QString name = payee[QStringLiteral("name")].toString();
+                    QString id = payee[QLatin1String("id")].toString();
+                    QString name = payee[QLatin1String("name")].toString();
 
                     // Is already created?
                     SKGPayeeObject payeeObject(m_importer->getDocument());
@@ -247,9 +247,9 @@ SKGError SKGImportPluginMny::importFile()
                 for (int i = 0; !err && i < nb; ++i) {
                     QVariantMap unit = list.at(i).toMap();
 
-                    QString id = unit[QStringLiteral("id")].toString();
-                    QString name = unit[QStringLiteral("name")].toString();
-                    QString symbol = unit[QStringLiteral("symbol")].toString();
+                    QString id = unit[QLatin1String("id")].toString();
+                    QString name = unit[QLatin1String("name")].toString();
+                    QString symbol = unit[QLatin1String("symbol")].toString();
                     if (symbol.isEmpty()) {
                         symbol = name;
                     }
@@ -294,13 +294,13 @@ SKGError SKGImportPluginMny::importFile()
                 "401k403b" : false
             }*/
             // List directories
-            QStringList list = temporaryDir.entryList(QStringList() << QStringLiteral("*.d"), QDir::Dirs);
+            QStringList list = temporaryDir.entryList(QStringList() << QLatin1String("*.d"), QDir::Dirs);
             SKGTRACEINFUNCRC(10, err)
             int nb = list.count();
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
 
             SKGBankObject bank(m_importer->getDocument());
-            IFOKDO(err, bank.setName(QStringLiteral("Microsof Money")))
+            IFOKDO(err, bank.setName(QLatin1String("Microsof Money")))
             IFOKDO(err, bank.save())
 
             // Create accounts
@@ -313,13 +313,13 @@ SKGError SKGImportPluginMny::importFile()
                 IFOK(err) {
                     // Create currency
                     SKGUnitObject unitObj;
-                    err = SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), account[QStringLiteral("currencyCode")].toString(), unitObj);
+                    err = SKGUnitObject::createCurrencyUnit(m_importer->getDocument(), account[QLatin1String("currencyCode")].toString(), unitObj);
 
                     // Create account
                     SKGAccountObject accountObj;
                     IFOKDO(err, bank.addAccount(accountObj))
-                    IFOKDO(err, accountObj.setName(account[QStringLiteral("name")].toString()))
-                    int type = account[QStringLiteral("type")].toInt();
+                    IFOKDO(err, accountObj.setName(account[QLatin1String("name")].toString()))
+                    int type = account[QLatin1String("type")].toInt();
                     IFOKDO(err, accountObj.setType(type == 0 ? SKGAccountObject::CURRENT :
                                                    type == 1 ? SKGAccountObject::CREDITCARD :
                                                    type == 3 ? SKGAccountObject::ASSETS :
@@ -329,12 +329,12 @@ SKGError SKGImportPluginMny::importFile()
                     IFOKDO(err, accountObj.save())
 
                     // Update initial balance
-                    IFOKDO(err, accountObj.setInitialBalance(account[QStringLiteral("startingBalance")].toDouble(), unitObj))
+                    IFOKDO(err, accountObj.setInitialBalance(account[QLatin1String("startingBalance")].toDouble(), unitObj))
 
-                    IFOKDO(err, accountObj.setClosed(account[QStringLiteral("closed")].toBool()))
+                    IFOKDO(err, accountObj.setClosed(account[QLatin1String("closed")].toBool()))
                     IFOKDO(err, accountObj.save())
 
-                    m_mapIdAccount[account[QStringLiteral("id")].toString()] = accountObj;
+                    m_mapIdAccount[account[QLatin1String("id")].toString()] = accountObj;
                 }
 
                 IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
@@ -347,7 +347,7 @@ SKGError SKGImportPluginMny::importFile()
         // Step 5-Import operation
         IFOK(err) {
             // List directories
-            QStringList list = temporaryDir.entryList(QStringList() << QStringLiteral("*.d"), QDir::Dirs);
+            QStringList list = temporaryDir.entryList(QStringList() << QLatin1String("*.d"), QDir::Dirs);
             SKGTRACEINFUNCRC(10, err)
             int nb = list.count();
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
@@ -365,9 +365,9 @@ SKGError SKGImportPluginMny::importFile()
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nbo);
                     for (int j = 0; !err && j < nbo; ++j) {
                         QVariantMap operation = transactions.at(j).toMap();
-                        if (!operation[QStringLiteral("void")].toBool()) {
-                            SKGAccountObject accountObj = m_mapIdAccount.value(operation[QStringLiteral("accountId")].toString());
-                            QString securityId = operation[QStringLiteral("securityId")].toString();
+                        if (!operation[QLatin1String("void")].toBool()) {
+                            SKGAccountObject accountObj = m_mapIdAccount.value(operation[QLatin1String("accountId")].toString());
+                            QString securityId = operation[QLatin1String("securityId")].toString();
 
                             SKGUnitObject unitObj;
                             if (securityId.isEmpty()) {
@@ -383,54 +383,54 @@ SKGError SKGImportPluginMny::importFile()
                             SKGOperationObject operationObj;
                             IFOKDO(err, accountObj.addOperation(operationObj, true))
                             IFOKDO(err, operationObj.setUnit(unitObj))
-                            IFOKDO(err, operationObj.setDate(QDateTime::fromMSecsSinceEpoch(operation[QStringLiteral("date")].toULongLong()).date()))
-                            IFOKDO(err, operationObj.setComment(operation[QStringLiteral("memo")].toString()))
+                            IFOKDO(err, operationObj.setDate(QDateTime::fromMSecsSinceEpoch(operation[QLatin1String("date")].toULongLong()).date()))
+                            IFOKDO(err, operationObj.setComment(operation[QLatin1String("memo")].toString()))
                             IFOK(err) {
                                 // The number is something like "0     4220725" or "1string"
-                                QString number = operation[QStringLiteral("number")].toString();
+                                QString number = operation[QLatin1String("number")].toString();
                                 if (!number.isEmpty()) {
                                     if (number.startsWith(QLatin1Char('1'))) {
-                                        err = operationObj.setMode(number.right(number.count() - 1));
+                                        err = operationObj.setMode(number.right(number.size() - 1));
                                     } else {
                                         QStringList ln = SKGServices::splitCSVLine(number, ' ');
                                         err = operationObj.setNumber(ln.at(ln.count() - 1));
                                     }
                                 }
                             }
-                            IFOKDO(err, operationObj.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T")))
-                            IFOKDO(err, operationObj.setImportID("MNY-" % operation[QStringLiteral("id")].toString()))
-                            QString payId = operation[QStringLiteral("payeeId")].toString();
+                            IFOKDO(err, operationObj.setAttribute(QLatin1String("t_imported"), QLatin1String("T")))
+                            IFOKDO(err, operationObj.setImportID("MNY-" % operation[QLatin1String("id")].toString()))
+                            QString payId = operation[QLatin1String("payeeId")].toString();
                             if (!payId.isEmpty() && !err) {
                                 err = operationObj.setPayee(m_mapIdPayee[payId]);
                             }
-                            IFOKDO(err, operationObj.setStatus(operation[QStringLiteral("reconciled")].toBool() ? SKGOperationObject::CHECKED :
-                                                               operation[QStringLiteral("cleared")].toBool() ? SKGOperationObject::MARKED :
+                            IFOKDO(err, operationObj.setStatus(operation[QLatin1String("reconciled")].toBool() ? SKGOperationObject::CHECKED :
+                                                               operation[QLatin1String("cleared")].toBool() ? SKGOperationObject::MARKED :
                                                                SKGOperationObject::NONE));
-                            if (operation[QStringLiteral("transfer")].toBool()) {
+                            if (operation[QLatin1String("transfer")].toBool()) {
                                 IFOKDO(err, operationObj.setComment("#MNYTRANSFER#" % operationObj.getComment()))
                             }
                             IFOKDO(err, operationObj.save(false))
 
-                            double amount = operation[QStringLiteral("amount")].toDouble();
+                            double amount = operation[QLatin1String("amount")].toDouble();
 
                             // Is it a split?
-                            QVariantList splits = operation[QStringLiteral("splits")].toList();
+                            QVariantList splits = operation[QLatin1String("splits")].toList();
                             int nbs = splits.count();
                             if (nbs != 0) {
                                 // Yes
                                 for (int k = 0; !err && k < nbs; ++k) {
                                     QVariantMap split = splits[k].toMap();
-                                    QVariantMap transaction = split[QStringLiteral("transaction")].toMap();
+                                    QVariantMap transaction = split[QLatin1String("transaction")].toMap();
 
                                     SKGSubOperationObject subOperationObj;
                                     IFOKDO(err, operationObj.addSubOperation(subOperationObj))
-                                    QString catId = transaction[QStringLiteral("categoryId")].toString();
+                                    QString catId = transaction[QLatin1String("categoryId")].toString();
                                     if (!catId.isEmpty() && !err) {
                                         err = subOperationObj.setCategory(m_mapIdCategory[catId]);
                                     }
-                                    double splitAmount = transaction[QStringLiteral("amount")].toDouble();
+                                    double splitAmount = transaction[QLatin1String("amount")].toDouble();
                                     IFOKDO(err, subOperationObj.setQuantity(splitAmount))
-                                    IFOKDO(err, subOperationObj.setComment(operation[QStringLiteral("memo")].toString()))
+                                    IFOKDO(err, subOperationObj.setComment(operation[QLatin1String("memo")].toString()))
                                     IFOKDO(err, subOperationObj.save(false, false))
                                     amount -= splitAmount;
                                 }
@@ -441,7 +441,7 @@ SKGError SKGImportPluginMny::importFile()
                                     SKGSubOperationObject subOperationObj;
                                     IFOKDO(err, operationObj.addSubOperation(subOperationObj))
                                     IFOKDO(err, subOperationObj.setQuantity(amount))
-                                    IFOKDO(err, subOperationObj.setComment(operation[QStringLiteral("memo")].toString()))
+                                    IFOKDO(err, subOperationObj.setComment(operation[QLatin1String("memo")].toString()))
                                     IFOKDO(err, subOperationObj.save(false, false))
 
                                     IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("Warning message", "The transaction '%1' has been repaired because its amount was not equal to the sum of the amounts of its splits", operationObj.getDisplayName()), SKGDocument::Warning))
@@ -450,18 +450,18 @@ SKGError SKGImportPluginMny::importFile()
                                 // No
                                 SKGSubOperationObject subOperationObj;
                                 IFOKDO(err, operationObj.addSubOperation(subOperationObj))
-                                QString catId = operation[QStringLiteral("categoryId")].toString();
+                                QString catId = operation[QLatin1String("categoryId")].toString();
                                 if (!catId.isEmpty() && !err) {
                                     err = subOperationObj.setCategory(m_mapIdCategory[catId]);
                                 }
                                 IFOKDO(err, subOperationObj.setQuantity(amount))
-                                IFOKDO(err, subOperationObj.setComment(operation[QStringLiteral("memo")].toString()))
+                                IFOKDO(err, subOperationObj.setComment(operation[QLatin1String("memo")].toString()))
                                 IFOKDO(err, subOperationObj.save(false, false))
                             }
                         }
 
                         if (!err && index % 500 == 0) {
-                            err = m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE"));
+                            err = m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE"));
                         }
                         ++index;
 
@@ -481,8 +481,8 @@ SKGError SKGImportPluginMny::importFile()
 
         // Step 6-Group operation
         int nbg = 0;
-        IFOKDO(err, m_importer->findAndGroupTransfers(nbg, QStringLiteral("A.t_comment LIKE '#MNYTRANSFER#%' AND B.t_comment LIKE '#MNYTRANSFER#%'")))
-        IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QStringLiteral("UPDATE operation SET t_comment=SUBSTR(t_comment, 14) WHERE t_comment LIKE '#MNYTRANSFER#%'")))
+        IFOKDO(err, m_importer->findAndGroupTransfers(nbg, QLatin1String("A.t_comment LIKE '#MNYTRANSFER#%' AND B.t_comment LIKE '#MNYTRANSFER#%'")))
+        IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QLatin1String("UPDATE operation SET t_comment=SUBSTR(t_comment, 14) WHERE t_comment LIKE '#MNYTRANSFER#%'")))
 
         IFOKDO(err, m_importer->getDocument()->stepForward(6))
 
