@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -10,6 +10,7 @@
  */
 #include "skgimportpluginofx.h"
 
+#include <qchar.h>
 #include <qcryptographichash.h>
 #include <qfile.h>
 
@@ -45,7 +46,7 @@ SKGImportPluginOfx::~SKGImportPluginOfx()
 bool SKGImportPluginOfx::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("OFX") || m_importer->getFileNameExtension() == QStringLiteral("QFX"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("OFX") || m_importer->getFileNameExtension() == QLatin1String("QFX"));
 }
 
 SKGError SKGImportPluginOfx::importFile()
@@ -60,7 +61,7 @@ SKGError SKGImportPluginOfx::importFile()
     if (!QFile(m_importer->getLocalFileName()).exists()) {
         err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().toDisplayString()));
     }
-    IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX")))
+    IFOKDO(err, m_importer->getDocument()->beginTransaction(QLatin1String("#INTERNAL#") % i18nc("Import step", "Import OFX file")))
     IFOK(err) {
         SKGImportPluginOfx::m_ofxError = SKGError();
         SKGImportPluginOfx::m_ofxInitialBalanceName.clear();
@@ -84,7 +85,7 @@ SKGError SKGImportPluginOfx::importFile()
                 int nb = SKGImportPluginOfx::m_ofxInitialBalanceName.count();
                 for (int i = 0; !err2 && i < nb; ++i) {
                     SKGAccountObject act;
-                    err2 = m_importer->getDocument()->getObject(QStringLiteral("v_account"), "t_number='" % SKGServices::stringToSqlString(m_ofxInitialBalanceName.at(i)) % '\'', act);
+                    err2 = m_importer->getDocument()->getObject(QLatin1String("v_account"), QLatin1String("t_number='") % SKGServices::stringToSqlString(m_ofxInitialBalanceName.at(i)) % QLatin1Char('\''), act);
 
                     // Date of balance
                     auto date = m_ofxInitialBalanceDate.at(i);
@@ -138,15 +139,15 @@ QString SKGImportPluginOfx::getAccountName(OfxAccountData* iAccountData)
             accountNumber = QString::fromUtf8(iAccountData->account_number);
         }
         // Correction BUG 234771 ^^^^^
-        if (accountNumber.startsWith(bankNumber % ' ')) {
+        if (accountNumber.startsWith(bankNumber % QLatin1Char(' '))) {
             accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
-            QStringList splitNumbers = accountNumber.split(' ');
+            QStringList splitNumbers = accountNumber.split(QLatin1Char(' '));
             if (splitNumbers.count() == 2) {
                 accountNumber = splitNumbers.at(1);
             }
         }
     }
-    SKGTRACEL(3) << "accountNumber=" << accountNumber << SKGENDL;
+    SKGTRACEL(3) << "accountNumber=" << accountNumber << Qt::endl;
     return accountNumber;
 }
 
@@ -158,12 +159,12 @@ SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumen
         // Check if account is already existing
         QString name = getAccountName(iAccountData);
         if (m_accounts.contains(name)) {
-            SKGTRACEL(3) << "Found in index" << SKGENDL;
+            SKGTRACEL(3) << "Found in index" << Qt::endl;
             oAccount = m_accounts[name];
         } else {
-            SKGTRACEL(3) << "NOT found in index" << SKGENDL;
-            QString wc = "t_number='" % SKGServices::stringToSqlString(name) % "' OR EXISTS(SELECT 1 FROM parameters WHERE t_uuid_parent=v_account.id||'-account' AND t_name='alias' AND t_value= '" % SKGServices::stringToSqlString(name) % "')";
-            err = iDoc->getObject(QStringLiteral("v_account"), wc, oAccount);
+            SKGTRACEL(3) << "NOT found in index" << Qt::endl;
+            QString wc = QLatin1String("t_number='") % SKGServices::stringToSqlString(name) % QLatin1String("' OR EXISTS(SELECT 1 FROM parameters WHERE t_uuid_parent=v_account.id||'-account' AND t_name='alias' AND t_value= '") % SKGServices::stringToSqlString(name) % QLatin1String("')");
+            err = iDoc->getObject(QLatin1String("v_account"), wc, oAccount);
         }
     }
 
@@ -240,9 +241,9 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
     if (accountNumber.isEmpty()) {
         accountNumber = QString::fromUtf8(data.account_number);
     }
-    if (accountNumber.startsWith(bankNumber % ' ')) {
+    if (accountNumber.startsWith(bankNumber % QLatin1Char(' '))) {
         accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
-        QStringList splitNumbers = accountNumber.split(' ');
+        QStringList splitNumbers = accountNumber.split(QLatin1Char(' '));
         if (splitNumbers.count() == 2) {
             agencyNumber = splitNumbers.at(0);
             accountNumber = splitNumbers.at(1);
@@ -265,7 +266,7 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
 
         // Check if bank is already existing
         SKGBankObject bank;
-        SKGImportPluginOfx::m_ofxError = doc->getObject(QStringLiteral("v_bank"), "t_bank_number='" % SKGServices::stringToSqlString(bankId) % '\'', tmp);
+        SKGImportPluginOfx::m_ofxError = doc->getObject(QLatin1String("v_bank"), QLatin1String("t_bank_number='") % SKGServices::stringToSqlString(bankId) % QLatin1Char('\''), tmp);
         if (!SKGImportPluginOfx::m_ofxError) {
             // Already existing
             bank = tmp;
@@ -286,7 +287,7 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
         if (name.isEmpty()) {
             name = QString::fromUtf8(data.account_id);
         } else {
-            name = name.remove(QStringLiteral("Bank account "));
+            name = name.remove(QLatin1String("Bank account "));
         }
         if (name.isEmpty()) {
             name = QString::fromUtf8(data.account_id);
@@ -334,20 +335,20 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
         if (!SKGImportPluginOfx::m_ofxError) {
             SKGImportPluginOfx::m_ofxError = account.save();
             m_accounts[accountNumber] = account;
-            SKGTRACEL(3) << "Add account '" << accountNumber << "' in index" << SKGENDL;
+            SKGTRACEL(3) << "Add account '" << accountNumber << "' in index" << Qt::endl;
         }
 
         if (!SKGImportPluginOfx::m_ofxError) {
             SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultAccount(&account);
         }
 
-        SKGTRACEL(10) << "Account [" << name << "] created" << SKGENDL;
+        SKGTRACEL(10) << "Account [" << name << "] created" << Qt::endl;
     }
 
     if (static_cast<bool>(data.currency_valid)) {
         // Check if unit is already existing
         SKGUnitObject unit(doc);
-        SKGImportPluginOfx::m_ofxError = doc->getObject(QStringLiteral("v_unit"), "t_name='" % SKGServices::stringToSqlString(QString::fromUtf8(data.currency)) % "' OR t_name like '%(" % SKGServices::stringToSqlString(QString::fromUtf8(data.currency)) % ")%'", tmp);
+        SKGImportPluginOfx::m_ofxError = doc->getObject(QLatin1String("v_unit"), QLatin1String("t_name='") % SKGServices::stringToSqlString(QString::fromUtf8(data.currency)) % QLatin1String("' OR t_name like '%(") % SKGServices::stringToSqlString(QString::fromUtf8(data.currency)) % QLatin1String(")%'"), tmp);
         if (!SKGImportPluginOfx::m_ofxError) {
             // Already existing
             unit = tmp;
@@ -402,18 +403,18 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
         // Create id
         QString ID;
         if (static_cast<bool>(data.fi_id_valid)) {
-            if (QString::fromUtf8(data.fi_id).count('0') != QString::fromUtf8(data.fi_id).count()) {
-                ID = QStringLiteral("ID-") % QString::fromUtf8(data.fi_id);
+            if (QString::fromUtf8(data.fi_id).count(QLatin1Char('0')) != QString::fromUtf8(data.fi_id).size()) {
+                ID = QLatin1String("ID-") % QString::fromUtf8(data.fi_id);
             }
         } else if (static_cast<bool>(data.reference_number_valid)) {
-            if (QString::fromUtf8(data.reference_number).count('0') != QString::fromUtf8(data.reference_number).count()) {
-                ID = QStringLiteral("REF-") % data.reference_number;
+            if (QString::fromUtf8(data.reference_number).count(QLatin1Char('0')) != QString::fromUtf8(data.reference_number).size()) {
+                ID = QLatin1String("REF-") % QString::fromUtf8(data.reference_number);
             }
         }
 
         if (ID.isEmpty()) {
             QByteArray hash = QCryptographicHash::hash(QString(SKGServices::dateToSqlString(date) % SKGServices::doubleToString(data.amount)).toUtf8(), QCryptographicHash::Md5);
-            ID = QStringLiteral("ID-") % hash.toHex();
+            ID = QLatin1String("ID-") % QString::fromLatin1(hash.toHex());
         }
 
         // Create operation
@@ -428,7 +429,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
             SKGImportPluginOfx::m_ofxError = ope.setUnit(unit);
         }
         if (!SKGImportPluginOfx::m_ofxError) {
-            SKGImportPluginOfx::m_ofxError = ope.setAttribute(QStringLiteral("t_imported"), QStringLiteral("T"));
+            SKGImportPluginOfx::m_ofxError = ope.setAttribute(QLatin1String("t_imported"), QLatin1String("T"));
         }
         if (!SKGImportPluginOfx::m_ofxError) {
             SKGImportPluginOfx::m_ofxError = ope.setImportID(ID);
@@ -452,7 +453,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
             SKGImportPluginOfx::m_ofxError = ope.setComment(QString::fromUtf8(data.memo));
         }
         if (!SKGImportPluginOfx::m_ofxError && static_cast<bool>(data.check_number_valid)) {
-            SKGImportPluginOfx::m_ofxError = ope.setNumber(data.check_number);
+            SKGImportPluginOfx::m_ofxError = ope.setNumber(QString::fromUtf8(data.check_number));
         }
         if (!SKGImportPluginOfx::m_ofxError && static_cast<bool>(data.invtransactiontype_valid)) {
             SKGImportPluginOfx::m_ofxError = ope.setMode(i18nc("Noun, the title of an item", "Title"));
@@ -542,7 +543,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
 
 QString SKGImportPluginOfx::getMimeTypeFilter() const
 {
-    return "*.ofx *.qfx|" % i18nc("A file format", "OFX file");
+    return QLatin1String("*.ofx *.qfx|") % i18nc("A file format", "OFX file");
 }
 
 #include <skgimportpluginofx.moc>
