@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -25,6 +25,7 @@
 #include "skgimportexportmanager.h"
 #include "skgservices.h"
 #include "skgtraces.h"
+#include <utility>
 
 /**
  * This plugin factory.
@@ -44,7 +45,7 @@ SKGImportPluginPDF::~SKGImportPluginPDF()
 bool SKGImportPluginPDF::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("PDF"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("PDF"));
 }
 
 QString SKGImportPluginPDF::extract(const QStringList& iLine, const QString& iSyntax)
@@ -55,7 +56,7 @@ QString SKGImportPluginPDF::extract(const QStringList& iLine, const QString& iSy
 
     // Interpret the syntax
     auto items = SKGServices::splitCSVLine(iSyntax, '|', false);
-    for (const auto& item : qAsConst(items)) {
+    for (const auto& item : std::as_const(items)) {
         if (item.startsWith(QLatin1String("REGEXPCAP:"))) {
             QRegularExpression regexp(item.right(item.length() - 10));
             if (output.isEmpty()) {
@@ -121,9 +122,9 @@ SKGError SKGImportPluginPDF::importFile()
             QStringList args = QStringList() << file << txtFile.fileName();
 
             QProcess p;
-            p.start(QStringLiteral("pdftotext"), args);
+            p.start(QLatin1String("pdftotext"), args);
             if (!p.waitForFinished(1000 * 60 * 2) || p.exitCode() != 0) {
-                QString cmd = "pdftotext " % args.join(QStringLiteral(" "));
+                QString cmd = "pdftotext " % args.join(QLatin1String(" "));
                 err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, p.exitCode()));
 
             } else {
@@ -141,10 +142,10 @@ SKGError SKGImportPluginPDF::importFile()
                 // Search extractors
                 QStringList listOfExtractors;
                 bool found = false;
-                QString a = QStringLiteral("skrooge/extractors");
+                QString a = QLatin1String("skrooge/extractors");
                 const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, a, QStandardPaths::LocateDirectory);
                 for (const auto& dir : dirs) {
-                    QDirIterator it(dir, QStringList() << QStringLiteral("*.extractor"));
+                    QDirIterator it(dir, QStringList() << QLatin1String("*.extractor"));
                     while (it.hasNext() && !found) {
                         // Read extractor
                         QString fileName = it.next();
@@ -154,38 +155,38 @@ SKGError SKGImportPluginPDF::importFile()
                         err = SKGServices::readPropertyFile(fileName, properties);
                         IFOK(err) {
                             // Check if this extractor is done for this file
-                            QString payee = extract(lines, properties[QStringLiteral("payee")]);
+                            QString payee = extract(lines, properties[QLatin1String("payee")]);
                             if (!payee.isEmpty()) {
                                 // Search the date
-                                QString date = extract(lines, properties[QStringLiteral("date")]);
-                                QString dateFormat = properties[QStringLiteral("dateformat")];
+                                QString date = extract(lines, properties[QLatin1String("date")]);
+                                QString dateFormat = properties[QLatin1String("dateformat")];
                                 auto d = QDate::fromString(date, dateFormat);
                                 if (!d.isValid()) {
                                     d = QDate::fromString(date);
                                     if (!d.isValid()) {
-                                        SKGTRACE << "WARNING: Impossible to parse the date [" << date << "] with [" << dateFormat << "]" << SKGENDL;
+                                        SKGTRACE << "WARNING: Impossible to parse the date [" << date << "] with [" << dateFormat << "]" << Qt::endl;
                                     }
                                 }
-                                if (!dateFormat.contains(QStringLiteral("yyyy")) && d.year() < 2000) {
+                                if (!dateFormat.contains(QLatin1String("yyyy")) && d.year() < 2000) {
                                     d = d.addYears(100);
                                 }
 
                                 // Search the amount
-                                double amount = SKGServices::stringToDouble(extract(lines, properties[QStringLiteral("amount")]));
+                                double amount = SKGServices::stringToDouble(extract(lines, properties[QLatin1String("amount")]));
 
                                 // Search the comment
-                                QString comment = extract(lines, properties[QStringLiteral("comment")]);
+                                QString comment = extract(lines, properties[QLatin1String("comment")]);
 
                                 // Search the number
-                                QString number = extract(lines, properties[QStringLiteral("number")]);
+                                QString number = extract(lines, properties[QLatin1String("number")]);
 
                                 // Search the mode
-                                QString mode = extract(lines, properties[QStringLiteral("mode")]);
+                                QString mode = extract(lines, properties[QLatin1String("mode")]);
 
                                 // Get account
                                 SKGAccountObject account;
                                 SKGOperationObject act;
-                                m_importer->getDocument()->getObject(QStringLiteral("v_account_display"), QStringLiteral("t_close='N' AND t_type='C' ORDER BY i_NBOPERATIONS DESC LIMIT 1"), act);
+                                m_importer->getDocument()->getObject(QLatin1String("v_account_display"), QLatin1String("t_close='N' AND t_type='C' ORDER BY i_NBOPERATIONS DESC LIMIT 1"), act);
                                 if (act.exist()) {
                                     account = act;
                                     IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Using account '%1' for import", account.getName())))
@@ -210,9 +211,9 @@ SKGError SKGImportPluginPDF::importFile()
                                     IFOKDO(err, operation.setPayee(payeeObj))
                                     IFOKDO(err, operation.setComment(comment))
                                     IFOKDO(err, operation.setMode(mode))
-                                    IFOKDO(err, operation.setImportID(QStringLiteral("PDF-") % extractor % QStringLiteral("-") % number))
+                                    IFOKDO(err, operation.setImportID(QLatin1String("PDF-") % extractor % QLatin1String("-") % number))
                                     // This is normal. PDF inport is for only one transaction, so no check if already imported
-                                    IFOKDO(err, operation.setAttribute(QStringLiteral("t_imported"), QStringLiteral("Y")))
+                                    IFOKDO(err, operation.setAttribute(QLatin1String("t_imported"), QLatin1String("Y")))
                                     IFOKDO(err, operation.save(false))
 
                                     SKGSubOperationObject subop;
@@ -234,7 +235,7 @@ SKGError SKGImportPluginPDF::importFile()
                 }
 
                 if (!found) {
-                    err = SKGError(ERR_FAIL, i18nc("An information message",  "Invoice %1 has not been imported because it is not recognized (List of recognized extractors: %2).", file, listOfExtractors.join(',')));
+                    err = SKGError(ERR_FAIL, i18nc("An information message",  "Invoice %1 has not been imported because it is not recognized (List of recognized extractors: %2).", file, listOfExtractors.join(QLatin1Char(','))));
                 }
 
                 // Step 2 done
