@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -22,11 +22,12 @@
 #include "skgimportexportmanager.h"
 #include "skgservices.h"
 #include "skgtraces.h"
+#include <utility>
 
 /**
 * Opening balance string
  */
-#define OPENINGBALANCE QStringLiteral("Opening Balance")
+#define OPENINGBALANCE QLatin1String("Opening Balance")
 
 /**
  * This plugin factory.
@@ -39,8 +40,8 @@ SKGImportPluginQif::SKGImportPluginQif(QObject* iImporter, const QVariantList& i
     SKGTRACEINFUNC(10)
     Q_UNUSED(iArg)
 
-    m_importParameters[QStringLiteral("date_format")] = QString();
-    m_exportParameters[QStringLiteral("uuid_of_selected_accounts_or_operations")] = QString();
+    m_importParameters[QLatin1String("date_format")] = QString();
+    m_exportParameters[QLatin1String("uuid_of_selected_accounts_or_operations")] = QString();
 }
 
 SKGImportPluginQif::~SKGImportPluginQif()
@@ -78,7 +79,11 @@ SKGError SKGImportPluginQif::importFile()
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) {
+#ifdef SKG_QT6
+                stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
                 stream.setCodec(m_importer->getCodec().toLatin1().constData());
+#endif
             }
 
             // load file in memory
@@ -98,12 +103,12 @@ SKGError SKGImportPluginQif::importFile()
                         inPriceSection = false;
                     }
 
-                    if (QString::compare(line, QStringLiteral("!account"), Qt::CaseInsensitive) == 0 ||
-                        QString::compare(line, QStringLiteral("!type:cat"), Qt::CaseInsensitive) == 0 ||
-                        QString::compare(line, QStringLiteral("!type:tag"), Qt::CaseInsensitive) == 0 ||
-                        QString::compare(line, QStringLiteral("!type:class"), Qt::CaseInsensitive) == 0) {
+                    if (QString::compare(line, QLatin1String("!account"), Qt::CaseInsensitive) == 0 ||
+                        QString::compare(line, QLatin1String("!type:cat"), Qt::CaseInsensitive) == 0 ||
+                        QString::compare(line, QLatin1String("!type:tag"), Qt::CaseInsensitive) == 0 ||
+                        QString::compare(line, QLatin1String("!type:class"), Qt::CaseInsensitive) == 0) {
                         inWrongSection = true;
-                    } else if (QString::compare(line, QStringLiteral("!type:prices"), Qt::CaseInsensitive) == 0) {
+                    } else if (QString::compare(line, QLatin1String("!type:prices"), Qt::CaseInsensitive) == 0) {
                         inPriceSection = true;
                     }
 
@@ -123,7 +128,7 @@ SKGError SKGImportPluginQif::importFile()
             file.close();
 
             // Select dateformat
-            QString dateFormat = m_importParameters.value(QStringLiteral("date_format"));
+            QString dateFormat = m_importParameters.value(QLatin1String("date_format"));
             if (dateFormat.isEmpty()) {
                 dateFormat = SKGServices::getDateFormat(dates);    // Automatic detection
             }
@@ -174,15 +179,15 @@ SKGError SKGImportPluginQif::importFile()
                     }
 
                     // Manage !Account section
-                    if (QString::compare(line, QStringLiteral("!type:bank"), Qt::CaseInsensitive) == 0 ||
-                        QString::compare(line, QStringLiteral("!type:cash"), Qt::CaseInsensitive) == 0 ||
-                        QString::compare(line, QStringLiteral("!type:ccard"), Qt::CaseInsensitive) == 0 ||
-                        QString::compare(line, QStringLiteral("!type:oth a"), Qt::CaseInsensitive) == 0 ||
-                        QString::compare(line, QStringLiteral("!type:oth l"), Qt::CaseInsensitive) == 0 ||
-                        QString::compare(line, QStringLiteral("!type:invst"), Qt::CaseInsensitive) == 0) {
+                    if (QString::compare(line, QLatin1String("!type:bank"), Qt::CaseInsensitive) == 0 ||
+                        QString::compare(line, QLatin1String("!type:cash"), Qt::CaseInsensitive) == 0 ||
+                        QString::compare(line, QLatin1String("!type:ccard"), Qt::CaseInsensitive) == 0 ||
+                        QString::compare(line, QLatin1String("!type:oth a"), Qt::CaseInsensitive) == 0 ||
+                        QString::compare(line, QLatin1String("!type:oth l"), Qt::CaseInsensitive) == 0 ||
+                        QString::compare(line, QLatin1String("!type:invst"), Qt::CaseInsensitive) == 0) {
                         inSection = 'B';
                         openingbalancecreated = false;
-                        investmentAccount = (QString::compare(val, QStringLiteral("type:invst"), Qt::CaseInsensitive) == 0);
+                        investmentAccount = (QString::compare(val, QLatin1String("type:invst"), Qt::CaseInsensitive) == 0);
 
                         // Set type of account
                         if (account == nullptr) {
@@ -193,30 +198,30 @@ SKGError SKGImportPluginQif::importFile()
                         }
 
                         if (!err && (account != nullptr) && account->getType() == SKGAccountObject::OTHER) {
-                            err = account->setType(QString::compare(line, QStringLiteral("!type:bank"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::CURRENT :
-                                                   (QString::compare(line, QStringLiteral("!type:cash"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::WALLET :
-                                                    (QString::compare(line, QStringLiteral("!type:ccard"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::CREDITCARD :
-                                                     (QString::compare(line, QStringLiteral("!type:invst"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::INVESTMENT :
-                                                      (QString::compare(line, QStringLiteral("!type:oth a"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::ASSETS : SKGAccountObject::OTHER
+                            err = account->setType(QString::compare(line, QLatin1String("!type:bank"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::CURRENT :
+                                                   (QString::compare(line, QLatin1String("!type:cash"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::WALLET :
+                                                    (QString::compare(line, QLatin1String("!type:ccard"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::CREDITCARD :
+                                                     (QString::compare(line, QLatin1String("!type:invst"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::INVESTMENT :
+                                                      (QString::compare(line, QLatin1String("!type:oth a"), Qt::CaseInsensitive) == 0 ? SKGAccountObject::ASSETS : SKGAccountObject::OTHER
                                                       )))));
                             IFOKDO(err, account->save())
                         }
-                    } else if (QString::compare(line, QStringLiteral("!account"), Qt::CaseInsensitive) == 0) {
+                    } else if (QString::compare(line, QLatin1String("!account"), Qt::CaseInsensitive) == 0) {
                         inSection = 'A';
                         openingbalancecreated = false;
                         automaticAccount = false;
-                    } else if (QString::compare(line, QStringLiteral("!type:cat"), Qt::CaseInsensitive) == 0) {
+                    } else if (QString::compare(line, QLatin1String("!type:cat"), Qt::CaseInsensitive) == 0) {
                         inSection = 'C';
                         openingbalancecreated = false;
                         IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Categories found and imported")))
-                    } else if (QString::compare(line, QStringLiteral("!type:prices"), Qt::CaseInsensitive) == 0) {
+                    } else if (QString::compare(line, QLatin1String("!type:prices"), Qt::CaseInsensitive) == 0) {
                         inSection = 'U';
                         openingbalancecreated = false;
                         IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Units prices found and imported")))
-                    } else if (QString::compare(line, QStringLiteral("!type:security"), Qt::CaseInsensitive) == 0) {
+                    } else if (QString::compare(line, QLatin1String("!type:security"), Qt::CaseInsensitive) == 0) {
                         inSection = 'S';
                         IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Units found and imported")))
-                    } else if (QString::compare(line, QStringLiteral("!type:tag"), Qt::CaseInsensitive) == 0) {
+                    } else if (QString::compare(line, QLatin1String("!type:tag"), Qt::CaseInsensitive) == 0) {
                         inSection = 'T';
                         IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Trackers found and imported")))
                     } else if (line.at(0) == '!') {
@@ -227,7 +232,7 @@ SKGError SKGImportPluginQif::importFile()
                         openingbalancecreated = false;
                         QStringList vals = SKGServices::splitCSVLine(line, ',');
                         if (vals.count() == 3 && !vals.at(0).isEmpty()) {
-                            err = m_importer->getDocument()->addOrModifyUnitValue(vals.at(0), SKGServices::stringToTime(SKGServices::dateToSqlString(vals.at(2), dateFormat)).date(), SKGServices::stringToDouble(vals.at(1)));
+                            err = m_importer->getDocument()->addOrModifyUnitValue(vals.at(0), SKGServices::stringToDate(SKGServices::dateToSqlString(vals.at(2), dateFormat)), SKGServices::stringToDouble(vals.at(1)));
                         }
 
                     } else if (inSection == 'T') {
@@ -251,7 +256,7 @@ SKGError SKGImportPluginQif::importFile()
                             IFOKDO(err, currentUnit.setSymbol(val))
                             IFOKDO(err, currentUnit.save())
                         } else if (op == 'T') {
-                            if (QString::compare(val, QStringLiteral("stock"), Qt::CaseInsensitive) == 0) {
+                            if (QString::compare(val, QLatin1String("stock"), Qt::CaseInsensitive) == 0) {
                                 IFOKDO(err, currentUnit.setType(SKGUnitObject::SHARE))
                                 IFOKDO(err, currentUnit.setNumberDecimal(4))
                                 IFOKDO(err, currentUnit.save())
@@ -272,7 +277,7 @@ SKGError SKGImportPluginQif::importFile()
                         if (op == 'N') {
                             // Check if the account already exist
                             SKGAccountObject account2;
-                            err = SKGNamedObject::getObjectByName(m_importer->getDocument(), QStringLiteral("account"), val, account2);
+                            err = SKGNamedObject::getObjectByName(m_importer->getDocument(), QLatin1String("account"), val, account2);
                             IFKO(err) {
                                 // Create account
                                 SKGBankObject bank(m_importer->getDocument());
@@ -297,7 +302,7 @@ SKGError SKGImportPluginQif::importFile()
                             }
                         } else if (op == 'T') {
                             if (account != nullptr) {
-                                err = account->setType(val == QStringLiteral("Bank") ? SKGAccountObject::CURRENT : (val == QStringLiteral("CCard") ? SKGAccountObject::CREDITCARD : (val == QStringLiteral("Invst") ? SKGAccountObject::INVESTMENT : (val == QStringLiteral("Oth A") ? SKGAccountObject::ASSETS : SKGAccountObject::OTHER))));
+                                err = account->setType(val == QLatin1String("Bank") ? SKGAccountObject::CURRENT : (val == QLatin1String("CCard") ? SKGAccountObject::CREDITCARD : (val == QLatin1String("Invst") ? SKGAccountObject::INVESTMENT : (val == QLatin1String("Oth A") ? SKGAccountObject::ASSETS : SKGAccountObject::OTHER))));
                             }
                         } else if (op == '^') {
                             // ^     End of entry
@@ -376,7 +381,7 @@ SKGError SKGImportPluginQif::importFile()
                             }
 
                             // Set date
-                            currentOperationDate = SKGServices::stringToTime(SKGServices::dateToSqlString(val, dateFormat)).date();
+                            currentOperationDate = SKGServices::stringToDate(SKGServices::dateToSqlString(val, dateFormat));
                             IFOKDO(err, currentOperation.setDate(currentOperationDate))
 
                             // Set unit
@@ -532,13 +537,13 @@ SKGError SKGImportPluginQif::importFile()
                                 XOut          Transfer cash to another account.
                                 */
                                 val = val.toLower();
-                                if (val.contains(QStringLiteral("div")) && val != QStringLiteral("reinvdiv")) {
+                                if (val.contains(QLatin1String("div")) && val != QLatin1String("reinvdiv")) {
                                     // TODO(Stephane MANKOWSKI) err=currentOperation.setProperty ( "SKG_OP_ORIGINAL_AMOUNT", "" );
                                     div = true;
-                                } else if (val.contains(QStringLiteral("sell")) ||
-                                           val.contains(QStringLiteral("verkauf")) ||
-                                           val.contains(QStringLiteral("miscexp")) ||
-                                           val.contains(QStringLiteral("shrsout"))
+                                } else if (val.contains(QLatin1String("sell")) ||
+                                           val.contains(QLatin1String("verkauf")) ||
+                                           val.contains(QLatin1String("miscexp")) ||
+                                           val.contains(QLatin1String("shrsout"))
                                           ) {
                                     quantityFactor = -1;
                                 }
@@ -602,7 +607,7 @@ SKGError SKGImportPluginQif::importFile()
                             checkOperationAmount = SKGServices::stringToDouble(val);
                             err = currentSubOperation.setQuantity(checkOperationAmount / currentUnitPrice);
                             if (!err && investmentAccount) {
-                                err = currentOperation.setProperty(QStringLiteral("SKG_OP_ORIGINAL_AMOUNT"), val);
+                                err = currentOperation.setProperty(QLatin1String("SKG_OP_ORIGINAL_AMOUNT"), val);
                             }
                         } else if (op == '$') {
                             // Dollar amount of split
@@ -629,7 +634,7 @@ SKGError SKGImportPluginQif::importFile()
                             // P Payee
                             // Set Payee
                             // Clean QIF coming from bankperfect
-                            val.remove(QStringLiteral("[auto]"));
+                            val.remove(QLatin1String("[auto]"));
 
                             err = SKGPayeeObject::createPayee(m_importer->getDocument(), val, currentPayee);
                             IFOKDO(err, currentOperation.setPayee(currentPayee))
@@ -728,7 +733,7 @@ SKGError SKGImportPluginQif::importFile()
                         } else if (op == 'C') {
                             // C     Cleared status
                             // Set status
-                            err = currentOperation.setStatus((val == QStringLiteral("C") || val == QStringLiteral("*") ? SKGOperationObject::MARKED : (val == QStringLiteral("R") || val == QStringLiteral("X") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE)));
+                            err = currentOperation.setStatus((val == QLatin1String("C") || val == QLatin1String("*") ? SKGOperationObject::MARKED : (val == QLatin1String("R") || val == QLatin1String("X") ? SKGOperationObject::CHECKED : SKGOperationObject::NONE)));
                         } else if (op == '^') {
                             // ^     End of entry
                             // save
@@ -741,8 +746,8 @@ SKGError SKGImportPluginQif::importFile()
                                 if (!err && opening) {
                                     // Specific values for initial balance
                                     err = currentOperation.setStatus(SKGOperationObject::CHECKED);
-                                    IFOKDO(err, currentOperation.setAttribute(QStringLiteral("d_date"), QStringLiteral("0000-00-00")))
-                                    IFOKDO(err, currentSubOperation.setAttribute(QStringLiteral("d_date"), QStringLiteral("0000-00-00")))
+                                    IFOKDO(err, currentOperation.setAttribute(QLatin1String("d_date"), QLatin1String("0000-00-00")))
+                                    IFOKDO(err, currentSubOperation.setAttribute(QLatin1String("d_date"), QLatin1String("0000-00-00")))
                                     openingbalancecreated = true;
                                 }
 
@@ -763,14 +768,14 @@ SKGError SKGImportPluginQif::importFile()
                                     double tq = transferQuantity.at(j);
                                     const QString& ta = transferAccount.at(j);
                                     // Is the transfert transaction already existing?
-                                    double qua = tq == 0.0 && addNextAmountToTransferQuantity ? SKGServices::stringToDouble(opOrigin.getAttribute(QStringLiteral("f_QUANTITY"))) : tq;
+                                    double qua = tq == 0.0 && addNextAmountToTransferQuantity ? SKGServices::stringToDouble(opOrigin.getAttribute(QLatin1String("f_QUANTITY"))) : tq;
                                     QString wc = "t_ACCOUNT='" % SKGServices::stringToSqlString(ta) %
                                                  "' AND t_TOACCOUNT='" % SKGServices::stringToSqlString(accountOrigin.getName()) %
                                                  "' AND ABS(f_QUANTITY-(" % SKGServices::doubleToString(-qua) % "))<0.0001"
                                                  " AND ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate()) % "'))<1"
                                                  " ORDER BY ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate()) % "')) ASC";
                                     SKGObjectBase::SKGListSKGObjectBase obs;
-                                    m_importer->getDocument()->getObjects(QStringLiteral("v_operation_display"), wc, obs);
+                                    m_importer->getDocument()->getObjects(QLatin1String("v_operation_display"), wc, obs);
                                     if (!obs.isEmpty()) {
                                         // We have to merge them and we do not need to create the transfer
                                         SKGOperationObject firstOne(obs.at(0));
@@ -778,7 +783,7 @@ SKGError SKGImportPluginQif::importFile()
                                         // Remove all transaction attached to this transfer
                                         SKGObjectBase::SKGListSKGObjectBase list;
                                         IFOKDO(err, firstOne.getGroupedOperations(list))
-                                        for (const auto& o : qAsConst(list)) {
+                                        for (const auto& o : std::as_const(list)) {
                                             SKGOperationObject op2(o);
                                             if (op2 != firstOne && op2 != currentOperation) {
                                                 IFOKDO(err, op2.setStatus(SKGOperationObject::NONE))
@@ -797,7 +802,7 @@ SKGError SKGImportPluginQif::importFile()
                                                      "' AND (ABS(f_CURRENTAMOUNT-(" % SKGServices::doubleToString(opOrigin.getCurrentAmount()) % "))<0.0001 OR f_QUANTITY=" % SKGServices::doubleToString(qua) % ")"
                                                      " AND ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate()) % "'))<1"
                                                      " ORDER BY ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate()) % "')) ASC";
-                                        m_importer->getDocument()->getObjects(QStringLiteral("v_operation_display"), wc, obs);
+                                        m_importer->getDocument()->getObjects(QLatin1String("v_operation_display"), wc, obs);
                                         if (!obs.isEmpty()) {
                                             // We have to merge them and we do not need to create the transfer
                                             SKGOperationObject firstOne(obs.at(0));
@@ -807,7 +812,7 @@ SKGError SKGImportPluginQif::importFile()
 
                                             SKGObjectBase::SKGListSKGObjectBase list;
                                             IFOKDO(err, currentOperation.getGroupedOperations(list))
-                                            for (const auto& o : qAsConst(list)) {
+                                            for (const auto& o : std::as_const(list)) {
                                                 SKGOperationObject op2(o);
                                                 IFOKDO(err, op2.setStatus(SKGOperationObject::NONE))
                                                 IFOKDO(err, op2.remove(false, true))
@@ -895,7 +900,7 @@ SKGError SKGImportPluginQif::importFile()
                     }
 
                     if (!err && i % 500 == 0) {
-                        err = m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE"));
+                        err = m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE"));
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -917,7 +922,7 @@ SKGError SKGImportPluginQif::importFile()
 bool SKGImportPluginQif::isExportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("QIF"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("QIF"));
 }
 
 SKGError SKGImportPluginQif::exportFile()
@@ -929,13 +934,13 @@ SKGError SKGImportPluginQif::exportFile()
     SKGTRACEINFUNCRC(2, err)
 
     // Read parameters
-    auto listUUIDs = SKGServices::splitCSVLine(m_exportParameters.value(QStringLiteral("uuid_of_selected_accounts_or_operations")));
+    auto listUUIDs = SKGServices::splitCSVLine(m_exportParameters.value(QLatin1String("uuid_of_selected_accounts_or_operations")));
 
     QStringList listOperationsToExport;
     listOperationsToExport.reserve(listUUIDs.count());
     QStringList listAccountsToExport;
     listAccountsToExport.reserve(listUUIDs.count());
-    for (const auto& uuid : qAsConst(listUUIDs)) {
+    for (const auto& uuid : std::as_const(listUUIDs)) {
         if (uuid.endsWith(QLatin1String("-operation"))) {
             listOperationsToExport.push_back(uuid);
         } else if (uuid.endsWith(QLatin1String("-account"))) {
@@ -954,14 +959,18 @@ SKGError SKGImportPluginQif::exportFile()
     } else {
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) {
+#ifdef SKG_QT6
+            stream.setEncoding(QStringConverter::encodingForName(m_importer->getCodec().toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
             stream.setCodec(m_importer->getCodec().toLatin1().constData());
+#endif
         }
 
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export %1 file", "QIF"), 3);
         IFOK(err) {
             // Export categories
             SKGObjectBase::SKGListSKGObjectBase categories;
-            IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_category_display_tmp"), QStringLiteral("1=1 ORDER BY t_fullname, id"), categories))
+            IFOKDO(err, m_importer->getDocument()->getObjects(QLatin1String("v_category_display_tmp"), QLatin1String("1=1 ORDER BY t_fullname, id"), categories))
             int nbcat = categories.count();
             if (!err && (nbcat != 0)) {
                 stream << "!Type:Cat\n";
@@ -970,13 +979,13 @@ SKGError SKGImportPluginQif::exportFile()
                     SKGCategoryObject cat(categories.at(i));
                     QString catName = cat.getFullName();
                     if (!catName.isEmpty()) {
-                        stream << QStringLiteral("N") << catName.replace(OBJECTSEPARATOR, QStringLiteral(":")) << SKGENDL;
-                        if (SKGServices::stringToDouble(cat.getAttribute(QStringLiteral("f_REALCURRENTAMOUNT"))) < 0) {
-                            stream << "E" << SKGENDL;
+                        stream << QLatin1String("N") << catName.replace(OBJECTSEPARATOR, QLatin1String(":")) << Qt::endl;
+                        if (SKGServices::stringToDouble(cat.getAttribute(QLatin1String("f_REALCURRENTAMOUNT"))) < 0) {
+                            stream << "E" << Qt::endl;
                         } else {
-                            stream << "I" << SKGENDL;
+                            stream << "I" << Qt::endl;
                         }
-                        stream << "^" << SKGENDL;
+                        stream << "^" << Qt::endl;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -990,7 +999,7 @@ SKGError SKGImportPluginQif::exportFile()
             // Get transactions
             QString currentAccountName;
             SKGObjectBase::SKGListSKGObjectBase transactions;
-            IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_operation_display_all"), QStringLiteral("t_template='N' ORDER BY t_ACCOUNT, d_date, id"), transactions))
+            IFOKDO(err, m_importer->getDocument()->getObjects(QLatin1String("v_operation_display_all"), QLatin1String("t_template='N' ORDER BY t_ACCOUNT, d_date, id"), transactions))
             int nb = transactions.count();
             IFOK(err) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export transactions"), nb);
@@ -1001,7 +1010,7 @@ SKGError SKGImportPluginQif::exportFile()
                     if ((listOperationsToExport.isEmpty() || listOperationsToExport.contains(operation.getUniqueID())) &&
                         (listAccountsToExport.isEmpty() || listAccountsToExport.contains(a.getUniqueID()))) {
                         // Get account name
-                        QString accountName = operation.getAttribute(QStringLiteral("t_ACCOUNT"));
+                        QString accountName = operation.getAttribute(QLatin1String("t_ACCOUNT"));
 
                         // In the same account ?
                         if (accountName != currentAccountName) {
@@ -1014,9 +1023,9 @@ SKGError SKGImportPluginQif::exportFile()
 
                             // Write header
                             stream << "!Account\n";
-                            stream << 'N' << accountName << SKGENDL;
-                            QString type = (account.getType() == SKGAccountObject::CURRENT ? QStringLiteral("Bank") : (account.getType() == SKGAccountObject::CREDITCARD ? QStringLiteral("CCard") : (account.getType() == SKGAccountObject::INVESTMENT ? QStringLiteral("Invst") : (account.getType() == SKGAccountObject::ASSETS ? QStringLiteral("Oth A") : QStringLiteral("Cash")))));
-                            stream << 'T' << type << SKGENDL;
+                            stream << 'N' << accountName << Qt::endl;
+                            QString type = (account.getType() == SKGAccountObject::CURRENT ? QLatin1String("Bank") : (account.getType() == SKGAccountObject::CREDITCARD ? QLatin1String("CCard") : (account.getType() == SKGAccountObject::INVESTMENT ? QLatin1String("Invst") : (account.getType() == SKGAccountObject::ASSETS ? QLatin1String("Oth A") : QLatin1String("Cash")))));
+                            stream << 'T' << type << Qt::endl;
                             QString number = bank.getNumber();
                             QString bnumber = account.getAgencyNumber();
                             QString cnumber = account.getNumber();
@@ -1032,10 +1041,10 @@ SKGError SKGImportPluginQif::exportFile()
                                 }
                                 number += cnumber;
                             }
-                            stream << 'D' << number << SKGENDL;
+                            stream << 'D' << number << Qt::endl;
                             // stream << "/"      Statement balance date
                             // stream << "$"      Statement balance amount
-                            stream << '^' << SKGENDL;
+                            stream << '^' << Qt::endl;
                             currentAccountName = accountName;
 
                             stream << "!Type:" << type << "\n";
@@ -1080,48 +1089,48 @@ SKGError SKGImportPluginQif::exportFile()
                         QString date = SKGServices::dateToSqlString(operation.getDate());
                         if (date.isEmpty()) {
                             // This is an opening balance
-                            date = QStringLiteral("0000-00-00");
+                            date = QLatin1String("0000-00-00");
                         }
-                        stream << 'D' << date << SKGENDL;
+                        stream << 'D' << date << Qt::endl;
                         if (!unitExported) {
-                            stream << 'T' << SKGServices::doubleToString(operation.getCurrentAmount()) << SKGENDL;
+                            stream << 'T' << SKGServices::doubleToString(operation.getCurrentAmount()) << Qt::endl;
                         }
 
                         if (!investment) {
                             auto number = operation.getNumber();
                             if (!number.isEmpty()) {
-                                stream << 'N' << operation.getNumber() << SKGENDL;
+                                stream << 'N' << operation.getNumber() << Qt::endl;
                             }
                         } else {
-                            stream << 'N' << (operation.getCurrentAmount() > 0 ? "Buy" : "Sell") << SKGENDL;
+                            stream << 'N' << (operation.getCurrentAmount() > 0 ? "Buy" : "Sell") << Qt::endl;
                         }
 
                         if (unitExported) {
-                            stream << 'Y' << unit.getSymbol() << SKGENDL;
+                            stream << 'Y' << unit.getSymbol() << Qt::endl;
                         }
 
                         SKGPayeeObject payeeObj;
                         operation.getPayee(payeeObj);
                         QString payee = payeeObj.getName();
                         QString address = payeeObj.getAddress();
-                        if (date == QStringLiteral("0000-00-00")) {
+                        if (date == QLatin1String("0000-00-00")) {
                             payee = OPENINGBALANCE;
                         }
                         if (!payee.isEmpty()) {
-                            stream << 'P' << payee << SKGENDL;
+                            stream << 'P' << payee << Qt::endl;
                         }
                         if (!address.isEmpty()) {
-                            stream << 'A' << address << SKGENDL;
+                            stream << 'A' << address << Qt::endl;
                         }
 
                         QString memo = operation.getMode() % "  " % operation.getComment();
                         memo = memo.trimmed();
                         if (!memo.isEmpty()) {
-                            stream << 'M' << memo << SKGENDL;
+                            stream << 'M' << memo << Qt::endl;
                         }
 
                         SKGOperationObject::OperationStatus status = operation.getStatus();
-                        stream << 'C' << (status == SKGOperationObject::MARKED ? "C" : (status == SKGOperationObject::CHECKED ? "R" : "")) << SKGENDL;
+                        stream << 'C' << (status == SKGOperationObject::MARKED ? "C" : (status == SKGOperationObject::CHECKED ? "R" : "")) << Qt::endl;
 
                         // Get sub transactions
                         SKGObjectBase::SKGListSKGObjectBase subtransactions;
@@ -1133,14 +1142,14 @@ SKGError SKGImportPluginQif::exportFile()
                                 SKGSubOperationObject suboperation(subtransactions.at(0));
                                 // Dump quantity
                                 if (unitExported) {
-                                    stream << 'Q' << SKGServices::doubleToString(qAbs(suboperation.getQuantity())) << SKGENDL;
-                                    stream << 'I' << SKGServices::doubleToString(qAbs(operation.getCurrentAmount() / suboperation.getQuantity())) << SKGENDL;
+                                    stream << 'Q' << SKGServices::doubleToString(qAbs(suboperation.getQuantity())) << Qt::endl;
+                                    stream << 'I' << SKGServices::doubleToString(qAbs(operation.getCurrentAmount() / suboperation.getQuantity())) << Qt::endl;
                                 }
 
                                 // Get category of this simple operation
                                 SKGCategoryObject cat;
                                 suboperation.getCategory(cat);
-                                category = cat.getFullName().replace(OBJECTSEPARATOR, QStringLiteral(":"));
+                                category = cat.getFullName().replace(OBJECTSEPARATOR, QLatin1String(":"));
                             }
 
                             // Is it a transfer
@@ -1152,10 +1161,10 @@ SKGError SKGImportPluginQif::exportFile()
 
                                 SKGAccountObject transferAccount;
                                 err = transfer.getParentAccount(transferAccount);
-                                IFOK(err) category.prepend('[' % transferAccount.getName() % ']');
+                                IFOK(err) category.prepend(QLatin1Char('[') % transferAccount.getName() % QLatin1Char(']'));
                             }
                             if (!category.isEmpty()) {
-                                stream << 'L' << category << SKGENDL;
+                                stream << 'L' << category << Qt::endl;
                             }
 
                             if (nbSubOps > 1) {
@@ -1165,21 +1174,21 @@ SKGError SKGImportPluginQif::exportFile()
                                     SKGCategoryObject cat;
                                     suboperation.getCategory(cat);
 
-                                    QString category2 = cat.getFullName().replace(OBJECTSEPARATOR, QStringLiteral(":"));
+                                    QString category2 = cat.getFullName().replace(OBJECTSEPARATOR, QLatin1String(":"));
                                     if (!category2.isEmpty()) {
-                                        stream << 'S' << category2 << SKGENDL;
+                                        stream << 'S' << category2 << Qt::endl;
                                     }
                                     QString memo2 = suboperation.getComment();
                                     memo2 = memo2.trimmed();
                                     if (!memo2.isEmpty()) {
-                                        stream << 'E' << memo2 << SKGENDL;
+                                        stream << 'E' << memo2 << Qt::endl;
                                     }
-                                    stream << '$' << SKGServices::doubleToString(suboperation.getQuantity()) << SKGENDL;
+                                    stream << '$' << SKGServices::doubleToString(suboperation.getQuantity()) << Qt::endl;
                                 }
                             }
                         }
 
-                        stream << '^' << SKGENDL;
+                        stream << '^' << Qt::endl;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -1190,7 +1199,7 @@ SKGError SKGImportPluginQif::exportFile()
 
             // Export prices
             SKGObjectBase::SKGListSKGObjectBase unitvalues;
-            IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_unitvalue"), QStringLiteral("1=1 ORDER BY (select t_name from unit where v_unitvalue.rd_unit_id=unit.id), d_date"), unitvalues))
+            IFOKDO(err, m_importer->getDocument()->getObjects(QLatin1String("v_unitvalue"), QLatin1String("1=1 ORDER BY (select t_name from unit where v_unitvalue.rd_unit_id=unit.id), d_date"), unitvalues))
             nb = unitvalues.count();
             if (!err && (nb != 0)) {
                 stream << "!Type:Prices\n";
@@ -1209,11 +1218,11 @@ SKGError SKGImportPluginQif::exportFile()
                         vals.push_back(SKGServices::doubleToString(unitVal.getQuantity()));
                         vals.push_back(SKGServices::dateToSqlString(unitVal.getDate()));
 
-                        stream << SKGServices::stringsToCsv(vals) << SKGENDL;
+                        stream << SKGServices::stringsToCsv(vals) << Qt::endl;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
-                stream << "^" << SKGENDL;
+                stream << "^" << Qt::endl;
 
                 SKGENDTRANSACTION(m_importer->getDocument(),  err)
             }
