@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -27,7 +27,7 @@
 #include "skgservices.h"
 #include "skgtraces.h"
 
-#define SQLDRIVERNAME QStringLiteral("SKGSQLCIPHER")
+#define SQLDRIVERNAME QLatin1String("SKGSQLCIPHER")
 /**
  * This plugin factory.
  */
@@ -39,7 +39,7 @@ SKGImportPluginSkg::SKGImportPluginSkg(QObject* iImporter, const QVariantList& i
     SKGTRACEINFUNC(10)
     Q_UNUSED(iArg)
 
-    m_importParameters[QStringLiteral("password")] = QString();
+    m_importParameters[QLatin1String("password")] = QString();
 }
 
 SKGImportPluginSkg::~SKGImportPluginSkg()
@@ -48,7 +48,7 @@ SKGImportPluginSkg::~SKGImportPluginSkg()
 bool SKGImportPluginSkg::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("SKG") || m_importer->getFileNameExtension() == QStringLiteral("SQLITE") || m_importer->getFileNameExtension() == QStringLiteral("SQLCIPHER"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("SKG") || m_importer->getFileNameExtension() == QLatin1String("SQLITE") || m_importer->getFileNameExtension() == QLatin1String("SQLCIPHER"));
 }
 
 SKGError SKGImportPluginSkg::importFile()
@@ -63,7 +63,7 @@ SKGError SKGImportPluginSkg::importFile()
         err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().toDisplayString()));
     } else {
         SKGDocumentBank docOrigin;
-        err = docOrigin.load(lfile, m_importParameters.value(QStringLiteral("password")));
+        err = docOrigin.load(lfile, m_importParameters.value(QLatin1String("password")));
         IFOK(err) {
             QMap<QString, SKGObjectBase> mapOriginNew;
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "SKG"), 10);
@@ -71,7 +71,7 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 1 - units
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listUnits;
-                err = docOrigin.getObjects(QStringLiteral("v_unit"), QStringLiteral("1=1 order by rd_unit_id, t_type"), listUnits);
+                err = docOrigin.getObjects(QLatin1String("v_unit"), QLatin1String("1=1 order by rd_unit_id, t_type"), listUnits);
                 IFOK(err) {
                     int nb = listUnits.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
@@ -130,7 +130,7 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 2 - bank and accounts
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listBanks;
-                err = docOrigin.getObjects(QStringLiteral("v_bank"), QString(), listBanks);
+                err = docOrigin.getObjects(QLatin1String("v_bank"), QString(), listBanks);
                 IFOK(err) {
                     int nb = listBanks.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import banks and accounts"), nb);
@@ -175,7 +175,7 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 3 - categories
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listCategories;
-                err = docOrigin.getObjects(QStringLiteral("v_category"), QString(), listCategories);
+                err = docOrigin.getObjects(QLatin1String("v_category"), QString(), listCategories);
                 IFOK(err) {
                     int nb = listCategories.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
@@ -198,7 +198,7 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 4 - trackers
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listRefund;
-                err = docOrigin.getObjects(QStringLiteral("v_refund"), QString(), listRefund);
+                err = docOrigin.getObjects(QLatin1String("v_refund"), QString(), listRefund);
                 IFOK(err) {
                     int nb = listRefund.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import trackers"), nb);
@@ -220,7 +220,7 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 5 - rules
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listRules;
-                err = docOrigin.getObjects(QStringLiteral("v_rule"), QString(), listRules);
+                err = docOrigin.getObjects(QLatin1String("v_rule"), QString(), listRules);
                 IFOK(err) {
                     int nb = listRules.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import rules"), nb);
@@ -241,7 +241,7 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 6 - payee
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listPayee;
-                err = docOrigin.getObjects(QStringLiteral("v_payee"), QString(), listPayee);
+                err = docOrigin.getObjects(QLatin1String("v_payee"), QString(), listPayee);
                 IFOK(err) {
                     int nb = listPayee.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
@@ -266,14 +266,14 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 7 - transactions and suboperation
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listOperations;
-                err = docOrigin.getObjects(QStringLiteral("v_operation"), QString(), listOperations);
+                err = docOrigin.getObjects(QLatin1String("v_operation"), QString(), listOperations);
                 IFOK(err) {
                     int nb = listOperations.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
                         SKGOperationObject operationOrigin(listOperations.at(i));
                         SKGOperationObject operation(operationOrigin.cloneInto(m_importer->getDocument()));
-                        IFOKDO(err, operation.setAttribute(QStringLiteral("r_recurrentoperation_id"), QString()))
+                        IFOKDO(err, operation.setAttribute(QLatin1String("r_recurrentoperation_id"), QString()))
                         IFOKDO(err, operation.setImported(true))
                         IFOK(err) {
                             QString importID = operationOrigin.getImportID();
@@ -340,7 +340,7 @@ SKGError SKGImportPluginSkg::importFile()
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
 
                         if (!err && i % 500 == 0) {
-                            err = m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE"));
+                            err = m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE"));
                         }
                     }
 
@@ -354,7 +354,7 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 8 - recurrent
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase ListRecurrentOperations;
-                err = docOrigin.getObjects(QStringLiteral("v_recurrentoperation"), QString(), ListRecurrentOperations);
+                err = docOrigin.getObjects(QLatin1String("v_recurrentoperation"), QString(), ListRecurrentOperations);
                 IFOK(err) {
                     int nb = ListRecurrentOperations.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import scheduled transactions"), nb);
@@ -381,7 +381,7 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 9 - nodes
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listNodes;
-                err = docOrigin.getObjects(QStringLiteral("v_node"), QString(), listNodes);
+                err = docOrigin.getObjects(QLatin1String("v_node"), QString(), listNodes);
                 IFOK(err) {
                     int nb = listNodes.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import bookmarks"), nb);
@@ -405,7 +405,7 @@ SKGError SKGImportPluginSkg::importFile()
             // Step 10 - interest
             IFOK(err) {
                 SKGObjectBase::SKGListSKGObjectBase listInterests;
-                err = docOrigin.getObjects(QStringLiteral("v_interest"), QString(), listInterests);
+                err = docOrigin.getObjects(QLatin1String("v_interest"), QString(), listInterests);
                 IFOK(err) {
                     int nb = listInterests.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import interests"), nb);
@@ -432,7 +432,7 @@ SKGError SKGImportPluginSkg::importFile()
 
             SKGENDTRANSACTION(m_importer->getDocument(),  err)
 
-            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE")))
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE")))
         }
     }
     return err;
@@ -476,38 +476,38 @@ SKGError SKGImportPluginSkg::exportFile()
 
     QString tempFile = m_importer->getDocument()->getCurrentTemporaryFile();
     bool removeTempFile = false;
-    QString DBMode = m_importer->getDocument()->getParameter(QStringLiteral("SKG_DATABASE_TYPE"));
+    QString DBMode = m_importer->getDocument()->getParameter(QLatin1String("SKG_DATABASE_TYPE"));
 
-    if (m_importer->getDocument()->getCurrentFileName().isEmpty() || DBMode != QStringLiteral("QSQLITE") || (ext == QStringLiteral("SQLCIPHER") && !pwd.isEmpty())) {
+    if (m_importer->getDocument()->getCurrentFileName().isEmpty() || DBMode != QLatin1String("QSQLITE") || (ext == QLatin1String("SQLCIPHER") && !pwd.isEmpty())) {
         // The database is only in memory
         tempFile = QDir::tempPath() % "/skg_" % QUuid::createUuid().toString() % ".skg";
         removeTempFile = true;
 
-        auto fileDb = QSqlDatabase::addDatabase(ext == QStringLiteral("SQLITE") ? QStringLiteral("QSQLITE") : SQLDRIVERNAME, tempFile);
+        auto fileDb = QSqlDatabase::addDatabase(ext == QLatin1String("SQLITE") ? QLatin1String("QSQLITE") : SQLDRIVERNAME, tempFile);
         fileDb.setDatabaseName(tempFile);
         if (!fileDb.open()) {
             // Set error message
             QSqlError sqlErr = fileDb.lastError();
             err = SKGError(SQLLITEERROR + sqlErr.nativeErrorCode().toInt(), sqlErr.text());
         } else {
-            if (ext == QStringLiteral("SQLCIPHER") && !pwd.isEmpty()) {
+            if (ext == QLatin1String("SQLCIPHER") && !pwd.isEmpty()) {
                 IFOKDO(err, SKGServices::executeSqliteOrder(fileDb, "PRAGMA KEY = '" % SKGServices::stringToSqlString(pwd) % "'"))
                 IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message", "The sqlcipher database has been protected with the same password than your document"), SKGDocument::Information))
             }
 
             m_importer->getDocument()->getMainDatabase()->commit();
-            if (DBMode == QStringLiteral("QSQLITE") && ext == QStringLiteral("QSQLITE")) {
+            if (DBMode == QLatin1String("QSQLITE") && ext == QLatin1String("QSQLITE")) {
                 // The source database is a sqlite DB
                 IFOKDO(err, SKGServices::copySqliteDatabase(fileDb, *(m_importer->getDocument()->getMainDatabase()), false))
 
             } else {
                 // The source database is a sqcipher DB
-                if (ext == QStringLiteral("SQLITE")) {
+                if (ext == QLatin1String("SQLITE")) {
                     pwd = QString();
                 }
                 IFOKDO(err, m_importer->getDocument()->executeSqliteOrders(QStringList() << "ATTACH DATABASE '" % tempFile % "' AS sqlcipher KEY '" % SKGServices::stringToSqlString(pwd) % "'"
-                        << QStringLiteral("SELECT SQLCIPHER_EXPORT('sqlcipher')")
-                        << QStringLiteral("DETACH DATABASE sqlcipher")));
+                        << QLatin1String("SELECT SQLCIPHER_EXPORT('sqlcipher')")
+                        << QLatin1String("DETACH DATABASE sqlcipher")));
             }
             m_importer->getDocument()->getMainDatabase()->transaction();
 
@@ -518,7 +518,7 @@ SKGError SKGImportPluginSkg::exportFile()
 
     // Copy file to file
     IFOK(err) {
-        if (ext != QStringLiteral("SKG")) {
+        if (ext != QLatin1String("SKG")) {
             if (SKGServices::upload(QUrl::fromLocalFile(tempFile), QUrl::fromLocalFile(file))) {
                 err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Creation file '%1' failed", file));
             }
@@ -546,14 +546,14 @@ SKGError SKGImportPluginSkg::copyParameters(const SKGObjectBase& iFrom, const SK
     SKGError err;
 
     SKGObjectBase::SKGListSKGObjectBase params;
-    err = iFrom.getDocument()->getObjects(QStringLiteral("parameters"), "t_uuid_parent='" % SKGServices::stringToSqlString(iFrom.getUniqueID()) % '\'', params);
+    err = iFrom.getDocument()->getObjects(QLatin1String("parameters"), "t_uuid_parent='" % SKGServices::stringToSqlString(iFrom.getUniqueID()) % QLatin1Char('\''), params);
     IFOK(err) {
         int nb = params.count();
         SKGDocument* documentTarget = iTo.getDocument();
         for (int i = 0; !err && i < nb; ++i) {
             SKGPropertyObject orig(params.at(i));
             SKGPropertyObject param(orig.cloneInto(documentTarget));
-            err = param.setAttribute(QStringLiteral("t_uuid_parent"), iTo.getUniqueID());
+            err = param.setAttribute(QLatin1String("t_uuid_parent"), iTo.getUniqueID());
             IFOKDO(err, param.save(true, false))
         }
     }
