@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -39,7 +39,7 @@ SKGImportPluginXhb::~SKGImportPluginXhb()
 bool SKGImportPluginXhb::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("XHB"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QLatin1String("XHB"));
 }
 
 SKGError SKGImportPluginXhb::importFile()
@@ -62,7 +62,18 @@ SKGError SKGImportPluginXhb::importFile()
         QString errorMsg;
         int errorLine = 0;
         int errorCol = 0;
-        bool contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
+        bool contentOK = false;        
+#ifdef SKG_QT6
+        const auto& content = QString::fromUtf8(file.readAll());
+        const auto& result= doc.setContent(content);
+
+        contentOK = !!result;
+        errorLine =result.errorLine;
+        errorCol =result.errorColumn;
+        errorMsg =result.errorMessage;
+#else        
+        contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
+#endif
         file.close();
 
         // Get root
@@ -85,7 +96,7 @@ SKGError SKGImportPluginXhb::importFile()
 
             // Step 1-Create accounts
             IFOK(err) {
-                QDomNodeList accountList = docElem.elementsByTagName(QStringLiteral("account"));
+                QDomNodeList accountList = docElem.elementsByTagName(QLatin1String("account"));
                 int nb = accountList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
@@ -94,9 +105,9 @@ SKGError SKGImportPluginXhb::importFile()
 
                     // Create the bank
                     SKGBankObject bank(m_importer->getDocument());
-                    QString bname = getAttribute(account,  QStringLiteral("bankname"));
+                    QString bname = getAttribute(account,  QLatin1String("bankname"));
                     if (bname.isEmpty()) {
-                        bname = QStringLiteral("HOMEBANK");
+                        bname = QLatin1String("HOMEBANK");
                     }
                     IFOKDO(err, bank.setName(bname))
                     IFOKDO(err, bank.save())
@@ -104,15 +115,15 @@ SKGError SKGImportPluginXhb::importFile()
                     // Creation of the account
                     SKGAccountObject accountObj;
                     IFOKDO(err, bank.addAccount(accountObj))
-                    IFOKDO(err, accountObj.setName(getAttribute(account,  QStringLiteral("name"))))
-                    IFOKDO(err, accountObj.setNumber(getAttribute(account,  QStringLiteral("number"))))
-                    IFOKDO(err, accountObj.setMinLimitAmount(SKGServices::stringToDouble(getAttribute(account,  QStringLiteral("minimum")))))
+                    IFOKDO(err, accountObj.setName(getAttribute(account,  QLatin1String("name"))))
+                    IFOKDO(err, accountObj.setNumber(getAttribute(account,  QLatin1String("number"))))
+                    IFOKDO(err, accountObj.setMinLimitAmount(SKGServices::stringToDouble(getAttribute(account,  QLatin1String("minimum")))))
                     IFOKDO(err, accountObj.minLimitAmountEnabled(accountObj.getMinLimitAmount() != 0.0))
-                    QString type = getAttribute(account,  QStringLiteral("type"));
-                    IFOKDO(err, accountObj.setType(type == QStringLiteral("2") ? SKGAccountObject::WALLET : (type == QStringLiteral("3") ? SKGAccountObject::ASSETS : (type == QStringLiteral("4") ? SKGAccountObject::CREDITCARD : (type == QStringLiteral("5") ? SKGAccountObject::LOAN : SKGAccountObject::CURRENT)))))
+                    QString type = getAttribute(account,  QLatin1String("type"));
+                    IFOKDO(err, accountObj.setType(type == QLatin1String("2") ? SKGAccountObject::WALLET : (type == QLatin1String("3") ? SKGAccountObject::ASSETS : (type == QLatin1String("4") ? SKGAccountObject::CREDITCARD : (type == QLatin1String("5") ? SKGAccountObject::LOAN : SKGAccountObject::CURRENT)))))
                     IFOK(err) {
-                        QString flags = getAttribute(account,  QStringLiteral("flags"));
-                        err = accountObj.setClosed(flags == QStringLiteral("2") ||  flags == QStringLiteral("3"));
+                        QString flags = getAttribute(account,  QLatin1String("flags"));
+                        err = accountObj.setClosed(flags == QLatin1String("2") ||  flags == QLatin1String("3"));
                     }
                     IFOKDO(err, accountObj.save())
 
@@ -131,9 +142,9 @@ SKGError SKGImportPluginXhb::importFile()
                     }
 
                     // Set initial balance
-                    IFOKDO(err, accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  QStringLiteral("initial"))), unit))
+                    IFOKDO(err, accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  QLatin1String("initial"))), unit))
 
-                    mapIdAccount[getAttribute(account,  QStringLiteral("key"))] = accountObj;
+                    mapIdAccount[getAttribute(account,  QLatin1String("key"))] = accountObj;
 
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -144,15 +155,15 @@ SKGError SKGImportPluginXhb::importFile()
 
             // Step 2-Get payees
             IFOK(err) {
-                QDomNodeList partyList = docElem.elementsByTagName(QStringLiteral("pay"));
+                QDomNodeList partyList = docElem.elementsByTagName(QLatin1String("pay"));
                 int nb = partyList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     // Get payee object
                     QDomElement party = partyList.at(i).toElement();
                     SKGPayeeObject payeeObject;
-                    err = SKGPayeeObject::createPayee(m_importer->getDocument(), getAttribute(party,  QStringLiteral("name")), payeeObject);
-                    mapIdPayee[getAttribute(party,  QStringLiteral("key"))] = payeeObject;
+                    err = SKGPayeeObject::createPayee(m_importer->getDocument(), getAttribute(party,  QLatin1String("name")), payeeObject);
+                    mapIdPayee[getAttribute(party,  QLatin1String("key"))] = payeeObject;
 
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -163,7 +174,7 @@ SKGError SKGImportPluginXhb::importFile()
 
             // Step 3-Create categories
             IFOK(err) {
-                QDomNodeList categoryList = docElem.elementsByTagName(QStringLiteral("cat"));
+                QDomNodeList categoryList = docElem.elementsByTagName(QLatin1String("cat"));
                 int nb = categoryList.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), 2 * nb);
                 for (int j = 0; !err && j < 2; ++j) {
@@ -174,31 +185,31 @@ SKGError SKGImportPluginXhb::importFile()
                         // Creation of the category
                         bool catCreated = false;
                         SKGCategoryObject catObj(m_importer->getDocument());
-                        QString parent2 = getAttribute(category,  QStringLiteral("parent"));
+                        QString parent2 = getAttribute(category,  QLatin1String("parent"));
                         if (parent2.isEmpty()) {
                             parent2 = '0';
                         }
-                        if (parent2 == QStringLiteral("0") && j == 0) {
-                            IFOKDO(err, catObj.setName(getAttribute(category,  QStringLiteral("name"))))
+                        if (parent2 == QLatin1String("0") && j == 0) {
+                            IFOKDO(err, catObj.setName(getAttribute(category,  QLatin1String("name"))))
                             IFOKDO(err, catObj.save())
 
-                            mapIdCategory[getAttribute(category,  QStringLiteral("key"))] = catObj;
+                            mapIdCategory[getAttribute(category,  QLatin1String("key"))] = catObj;
                             catCreated = true;
 
-                        } else if (parent2 != QStringLiteral("0") && j == 1) {
+                        } else if (parent2 != QLatin1String("0") && j == 1) {
                             SKGCategoryObject catParentObj = mapIdCategory[parent2];
-                            IFOKDO(err, catObj.setName(getAttribute(category,  QStringLiteral("name"))))
+                            IFOKDO(err, catObj.setName(getAttribute(category,  QLatin1String("name"))))
                             IFOKDO(err, catObj.setParentCategory(catParentObj))
                             IFOKDO(err, catObj.save())
 
-                            mapIdCategory[getAttribute(category,  QStringLiteral("key"))] = catObj;
+                            mapIdCategory[getAttribute(category,  QLatin1String("key"))] = catObj;
                             catCreated = true;
                         }
 
                         // Creation of the attached budget
                         if (!err && catCreated) {
-                            QString b0 = getAttribute(category,  QStringLiteral("b0"));
-                            QString b1 = getAttribute(category,  QStringLiteral("b1"));
+                            QString b0 = getAttribute(category,  QLatin1String("b0"));
+                            QString b1 = getAttribute(category,  QLatin1String("b1"));
                             if (!b0.isEmpty() || !b1.isEmpty()) {
                                 for (int m = 1; !err && m <= 12; ++m) {
                                     SKGBudgetObject budget(m_importer->getDocument());
@@ -207,7 +218,7 @@ SKGError SKGImportPluginXhb::importFile()
                                     IFOKDO(err, budget.setCategory(catObj))
                                     IFOKDO(err, budget.setYear(year))
                                     IFOKDO(err, budget.setMonth(m))
-                                    IFOKDO(err, budget.setBudgetedAmount(SKGServices::stringToDouble(getAttribute(category,  'b' % SKGServices::intToString(b0.isEmpty() ? m : 0)))))
+                                    IFOKDO(err, budget.setBudgetedAmount(SKGServices::stringToDouble(getAttribute(category,  QLatin1Char('b') % SKGServices::intToString(b0.isEmpty() ? m : 0)))))
                                     IFOKDO(err, budget.save())
                                 }
                             }
@@ -225,7 +236,7 @@ SKGError SKGImportPluginXhb::importFile()
             IFOK(err) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), 2);
                 for (int j = 1; !err && j <= 2; ++j) {
-                    QDomNodeList transactionList = docElem.elementsByTagName(j == 1 ? QStringLiteral("ope") : QStringLiteral("fav"));
+                    QDomNodeList transactionList = docElem.elementsByTagName(j == 1 ? QLatin1String("ope") : QLatin1String("fav"));
                     int nb = transactionList.count();
                     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import transactions"), nb);
                     for (int i = 0; !err && i < nb; ++i) {
@@ -233,29 +244,29 @@ SKGError SKGImportPluginXhb::importFile()
                         QDomElement transaction = transactionList.at(i).toElement();
 
                         // Get attributes
-                        QString idAccount = getAttribute(transaction,  QStringLiteral("account"));
-                        // QString dst_account = getAttribute(transaction,  QStringLiteral("dst_account"));
-                        if (idAccount != QStringLiteral("0")) {
+                        QString idAccount = getAttribute(transaction,  QLatin1String("account"));
+                        // QString dst_account = getAttribute(transaction,  QLatin1String("dst_account"));
+                        if (idAccount != QLatin1String("0")) {
                             SKGAccountObject account = mapIdAccount[idAccount];
-                            QDate date = QDate(1, 1, 1).addDays(1 + SKGServices::stringToInt(getAttribute(transaction,  j == 1 ? QStringLiteral("date") : QStringLiteral("nextdate"))));
-                            QString mode = getAttribute(transaction,  QStringLiteral("paymode"));
-                            if (mode == QStringLiteral("1")) {
+                            QDate date = QDate(1, 1, 1).addDays(1 + SKGServices::stringToInt(getAttribute(transaction,  j == 1 ? QLatin1String("date") : QLatin1String("nextdate"))));
+                            QString mode = getAttribute(transaction,  QLatin1String("paymode"));
+                            if (mode == QLatin1String("1")) {
                                 mode = i18nc("Noun: type of payement", "Credit card");
-                            } else if (mode == QStringLiteral("2")) {
+                            } else if (mode == QLatin1String("2")) {
                                 mode = i18nc("Noun: type of payement", "Check");
-                            } else if (mode == QStringLiteral("3")) {
+                            } else if (mode == QLatin1String("3")) {
                                 mode = i18nc("Noun: type of payement", "Cash");
-                            } else if (mode == QStringLiteral("4") || mode == QStringLiteral("5")) {
+                            } else if (mode == QLatin1String("4") || mode == QLatin1String("5")) {
                                 mode = i18nc("Noun: type of payement", "Transfer");
                             } else {
                                 mode = i18nc("Noun: type of payement", "Other");
                             }
-                            QString comment = QString(getAttribute(transaction,  QStringLiteral("wording")) % ' ' % getAttribute(transaction,  QStringLiteral("info"))).trimmed();
-                            int flags = SKGServices::stringToInt(getAttribute(transaction,  QStringLiteral("flags")));
-                            double amount = SKGServices::stringToDouble(getAttribute(transaction,  QStringLiteral("amount")));
+                            QString comment = QString(getAttribute(transaction,  QLatin1String("wording")) % QLatin1Char(' ') % getAttribute(transaction,  QLatin1String("info"))).trimmed();
+                            int flags = SKGServices::stringToInt(getAttribute(transaction,  QLatin1String("flags")));
+                            double amount = SKGServices::stringToDouble(getAttribute(transaction,  QLatin1String("amount")));
                             SKGOperationObject::OperationStatus status = (flags == 1 ||  flags == 3 ? SKGOperationObject::CHECKED : SKGOperationObject::NONE);
-                            SKGPayeeObject payee = mapIdPayee[ getAttribute(transaction,  QStringLiteral("payee"))];
-                            SKGCategoryObject category = mapIdCategory[getAttribute(transaction,  QStringLiteral("category"))];
+                            SKGPayeeObject payee = mapIdPayee[ getAttribute(transaction,  QLatin1String("payee"))];
+                            SKGCategoryObject category = mapIdCategory[getAttribute(transaction,  QLatin1String("category"))];
 
                             // Creation of the transaction
                             SKGOperationObject opObj;
@@ -279,7 +290,7 @@ SKGError SKGImportPluginXhb::importFile()
                             IFOKDO(err, subObj.setQuantity(amount))
                             IFOKDO(err, subObj.save())
 
-                            QString tags = getAttribute(transaction,  QStringLiteral("tags"));
+                            QString tags = getAttribute(transaction,  QLatin1String("tags"));
                             if (!tags.isEmpty()) {
                                 SKGTrackerObject tracker;
                                 IFOKDO(err, SKGTrackerObject::createTracker(m_importer->getDocument(), tags, tracker))
@@ -320,11 +331,11 @@ SKGError SKGImportPluginXhb::importFile()
                                 // Creation of scheduled transaction
                                 SKGRecurrentOperationObject recu;
                                 IFOKDO(err, opObj.addRecurrentOperation(recu))
-                                int limit = SKGServices::stringToInt(getAttribute(transaction,  QStringLiteral("limit")));
+                                int limit = SKGServices::stringToInt(getAttribute(transaction,  QLatin1String("limit")));
                                 IFOKDO(err, recu.timeLimit(flags & (1 << 7)))
                                 IFOKDO(err, recu.setTimeLimit(limit))
-                                int punit = SKGServices::stringToInt(getAttribute(transaction,  QStringLiteral("unit")));
-                                int pstep = SKGServices::stringToInt(getAttribute(transaction,  QStringLiteral("every")));
+                                int punit = SKGServices::stringToInt(getAttribute(transaction,  QLatin1String("unit")));
+                                int pstep = SKGServices::stringToInt(getAttribute(transaction,  QLatin1String("every")));
                                 SKGRecurrentOperationObject::PeriodUnit p = SKGRecurrentOperationObject::MONTH;
                                 if (punit == 0) {
                                     p = SKGRecurrentOperationObject::DAY;
@@ -350,7 +361,7 @@ SKGError SKGImportPluginXhb::importFile()
                         }
 
                         if (!err && i % 500 == 0) {
-                            err = m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE"));
+                            err = m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE"));
                         }
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
@@ -365,7 +376,7 @@ SKGError SKGImportPluginXhb::importFile()
 
             SKGENDTRANSACTION(m_importer->getDocument(),  err)
 
-            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE")))
+            IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QLatin1String("ANALYZE")))
         }
     }
 
@@ -375,7 +386,7 @@ SKGError SKGImportPluginXhb::importFile()
 QString SKGImportPluginXhb::getAttribute(const QDomElement& iElement, const QString& iAttribute)
 {
     QString val = iElement.attribute(iAttribute);
-    if (val == QStringLiteral("(null)")) {
+    if (val == QLatin1String("(null)")) {
         val = QString();
     }
     return val;
