@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGIMPORTPLUGINXML_H
@@ -67,6 +67,14 @@ public:
      */
     QString getMimeTypeFilter() const override;
 
+    /**
+     * Get the document as an XML object
+     * @param iFileName File to load.
+     * @param oDocument The output XML document.
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    SKGError getXMLDocument(const QString& iFileName, QDomElement& oDocument);
 
 private:
     Q_DISABLE_COPY(SKGImportPluginXml)
