@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGADDOPERATION_H
@@ -8,22 +8,27 @@
 
 #include <krunner/abstractrunner.h>
 
+#ifndef SKG_QT6
+#define KRunner Plasma
+#endif
 /**
  * @brief An KRunner addon to create a new transaction
  *
  */
-class SKGAddOperation : public Plasma::AbstractRunner
+class SKGAddOperation : public KRunner::AbstractRunner
 {
     Q_OBJECT
 
 public:
+
     /**
      * @brief The constructor
      *
      * @param iParent The parent object
+     * @param pluginMetaData Plugin metadata from metadata.json
      * @param args The list of arguments
      */
-    SKGAddOperation(QObject* iParent, const QVariantList& args);
+    SKGAddOperation(QObject* iParent, const KPluginMetaData& pluginMetaData, const QVariantList& args);
 
     /**
      * @brief Check if the user input match
@@ -31,7 +36,7 @@ public:
      * @param iContext The KRunner context
      * @return void
      */
-    void match(Plasma::RunnerContext& iContext) override;
+    void match(KRunner::RunnerContext& iContext) override;
 
     /**
      * @brief Execute the creation of operation
@@ -40,7 +45,7 @@ public:
      * @param iMatch The query match
      * @return void
      */
-    void run(const Plasma::RunnerContext& iContext, const Plasma::QueryMatch& iMatch) override;
+    void run(const KRunner::RunnerContext& iContext, const KRunner::QueryMatch& iMatch) override;
 
     /**
      * @brief Reload the configuration
