@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -31,7 +31,7 @@ SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDoc
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
     // menu
-    m_menuFavorite = new QAction(SKGServices::fromTheme(QStringLiteral("bookmarks")), i18nc("Display only favorite accounts", "Highlighted only"), this);
+    m_menuFavorite = new QAction(SKGServices::fromTheme(QLatin1String("bookmarks")), i18nc("Display only favorite accounts", "Highlighted only"), this);
     m_menuFavorite->setCheckable(true);
     m_menuFavorite->setChecked(false);
     connect(m_menuFavorite, &QAction::triggered, this, [ = ]() {
@@ -154,21 +154,21 @@ SKGAccountBoardWidget::~SKGAccountBoardWidget()
 
 QString SKGAccountBoardWidget::getState()
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
-    root.setAttribute(QStringLiteral("menuFavorite"), (m_menuFavorite != nullptr) && m_menuFavorite->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuAssets"), (m_menuAssets != nullptr) && m_menuAssets->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuCurrent"), (m_menuCurrent != nullptr) && m_menuCurrent->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuCreditCard"), (m_menuCreditCard != nullptr) && m_menuCreditCard->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuSaving"), (m_menuSaving != nullptr) && m_menuSaving->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuInvestment"), (m_menuInvestment != nullptr) && m_menuInvestment->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuWallet"), (m_menuWallet != nullptr) && m_menuWallet->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuLoan"), (m_menuLoan != nullptr) && m_menuLoan->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuPension"), (m_menuPension != nullptr) && m_menuPension->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuOther"), (m_menuOther != nullptr) && m_menuOther->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuPastOperations"), (m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QLatin1String("menuFavorite"), (m_menuFavorite != nullptr) && m_menuFavorite->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuAssets"), (m_menuAssets != nullptr) && m_menuAssets->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuCurrent"), (m_menuCurrent != nullptr) && m_menuCurrent->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuCreditCard"), (m_menuCreditCard != nullptr) && m_menuCreditCard->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuSaving"), (m_menuSaving != nullptr) && m_menuSaving->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuInvestment"), (m_menuInvestment != nullptr) && m_menuInvestment->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuWallet"), (m_menuWallet != nullptr) && m_menuWallet->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuLoan"), (m_menuLoan != nullptr) && m_menuLoan->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuPension"), (m_menuPension != nullptr) && m_menuPension->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuOther"), (m_menuOther != nullptr) && m_menuOther->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuPastOperations"), (m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
 
     return doc.toString();
 }
@@ -177,42 +177,42 @@ void SKGAccountBoardWidget::setState(const QString& iState)
 {
     SKGBoardWidget::setState(iState);
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     if (m_menuFavorite != nullptr) {
-        m_menuFavorite->setChecked(root.attribute(QStringLiteral("menuFavorite")) == QStringLiteral("Y"));
+        m_menuFavorite->setChecked(root.attribute(QLatin1String("menuFavorite")) == QLatin1String("Y"));
     }
     if (m_menuAssets != nullptr) {
-        m_menuAssets->setChecked(root.attribute(QStringLiteral("menuAssets")) != QStringLiteral("N"));
+        m_menuAssets->setChecked(root.attribute(QLatin1String("menuAssets")) != QLatin1String("N"));
     }
     if (m_menuCurrent != nullptr) {
-        m_menuCurrent->setChecked(root.attribute(QStringLiteral("menuCurrent")) != QStringLiteral("N"));
+        m_menuCurrent->setChecked(root.attribute(QLatin1String("menuCurrent")) != QLatin1String("N"));
     }
     if (m_menuCreditCard != nullptr) {
-        m_menuCreditCard->setChecked(root.attribute(QStringLiteral("menuCreditCard")) != QStringLiteral("N"));
+        m_menuCreditCard->setChecked(root.attribute(QLatin1String("menuCreditCard")) != QLatin1String("N"));
     }
     if (m_menuSaving != nullptr) {
-        m_menuSaving->setChecked(root.attribute(QStringLiteral("menuSaving")) != QStringLiteral("N"));
+        m_menuSaving->setChecked(root.attribute(QLatin1String("menuSaving")) != QLatin1String("N"));
     }
     if (m_menuInvestment != nullptr) {
-        m_menuInvestment->setChecked(root.attribute(QStringLiteral("menuInvestment")) != QStringLiteral("N"));
+        m_menuInvestment->setChecked(root.attribute(QLatin1String("menuInvestment")) != QLatin1String("N"));
     }
     if (m_menuWallet != nullptr) {
-        m_menuWallet->setChecked(root.attribute(QStringLiteral("menuWallet")) != QStringLiteral("N"));
+        m_menuWallet->setChecked(root.attribute(QLatin1String("menuWallet")) != QLatin1String("N"));
     }
     if (m_menuLoan != nullptr) {
-        m_menuLoan->setChecked(root.attribute(QStringLiteral("menuLoan")) != QStringLiteral("N"));
+        m_menuLoan->setChecked(root.attribute(QLatin1String("menuLoan")) != QLatin1String("N"));
     }
     if (m_menuPension != nullptr) {
-        m_menuPension->setChecked(root.attribute(QStringLiteral("menuPension")) != QStringLiteral("N"));
+        m_menuPension->setChecked(root.attribute(QLatin1String("menuPension")) != QLatin1String("N"));
     }
     if (m_menuOther != nullptr) {
-        m_menuOther->setChecked(root.attribute(QStringLiteral("menuOther")) != QStringLiteral("N"));
+        m_menuOther->setChecked(root.attribute(QLatin1String("menuOther")) != QLatin1String("N"));
     }
     if (m_menuPastOperations != nullptr) {
-        m_menuPastOperations->setChecked(root.attribute(QStringLiteral("menuPastOperations")) == QStringLiteral("Y"));
+        m_menuPastOperations->setChecked(root.attribute(QLatin1String("menuPastOperations")) == QLatin1String("Y"));
     }
 
     dataModified(QLatin1String(""), 0);
@@ -229,7 +229,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
 {
     Q_UNUSED(iIdTransaction)
 
-    if (iTableName == QStringLiteral("v_account_display") || iTableName.isEmpty()) {
+    if (iTableName == QLatin1String("v_account_display") || iTableName.isEmpty()) {
         SKGTRACEINFUNC(10)
         SKGTabPage* page = SKGTabPage::parentTabPage(this);
         if (page != nullptr && page != SKGMainPanel::getMainPanel()->currentPage()) {
@@ -242,7 +242,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
         if (doc != nullptr) {
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
             bool exist = false;
-            SKGError err = doc->existObjects(QStringLiteral("account"), QLatin1String(""), exist);
+            SKGError err = doc->existObjects(QLatin1String("account"), QLatin1String(""), exist);
             IFOK(err) {
                 QString html;
                 if (!exist) {
@@ -251,73 +251,73 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                     // Build where clause
                     QString wc;
                     if ((m_menuAssets != nullptr) && m_menuAssets->isChecked()) {
-                        wc = QStringLiteral("t_type='A'");
+                        wc = QLatin1String("t_type='A'");
                     }
                     if ((m_menuCurrent != nullptr) && m_menuCurrent->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QStringLiteral(" OR ");
+                            wc += QLatin1String(" OR ");
                         }
-                        wc += QStringLiteral("t_type='C'");
+                        wc += QLatin1String("t_type='C'");
                     }
                     if ((m_menuCreditCard != nullptr) && m_menuCreditCard->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QStringLiteral(" OR ");
+                            wc += QLatin1String(" OR ");
                         }
-                        wc += QStringLiteral("t_type='D'");
+                        wc += QLatin1String("t_type='D'");
                     }
                     if ((m_menuSaving != nullptr) && m_menuSaving->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QStringLiteral(" OR ");
+                            wc += QLatin1String(" OR ");
                         }
-                        wc += QStringLiteral("t_type='S'");
+                        wc += QLatin1String("t_type='S'");
                     }
                     if ((m_menuInvestment != nullptr) && m_menuInvestment->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QStringLiteral(" OR ");
+                            wc += QLatin1String(" OR ");
                         }
-                        wc += QStringLiteral("t_type='I'");
+                        wc += QLatin1String("t_type='I'");
                     }
                     if ((m_menuWallet != nullptr) && m_menuWallet->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QStringLiteral(" OR ");
+                            wc += QLatin1String(" OR ");
                         }
-                        wc += QStringLiteral("t_type='W'");
+                        wc += QLatin1String("t_type='W'");
                     }
                     if ((m_menuOther != nullptr) && m_menuOther->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QStringLiteral(" OR ");
+                            wc += QLatin1String(" OR ");
                         }
-                        wc += QStringLiteral("t_type='O'");
+                        wc += QLatin1String("t_type='O'");
                     }
                     if ((m_menuLoan != nullptr) && m_menuLoan->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QStringLiteral(" OR ");
+                            wc += QLatin1String(" OR ");
                         }
-                        wc += QStringLiteral("t_type='L'");
+                        wc += QLatin1String("t_type='L'");
                     }
                     if ((m_menuPension != nullptr) && m_menuPension->isChecked()) {
                         if (!wc.isEmpty()) {
-                            wc += QStringLiteral(" OR ");
+                            wc += QLatin1String(" OR ");
                         }
-                        wc += QStringLiteral("t_type='P'");
+                        wc += QLatin1String("t_type='P'");
                     }
 
                     if (wc.isEmpty()) {
-                        wc = QStringLiteral("1=0");
+                        wc = QLatin1String("1=0");
                     } else if ((m_menuFavorite != nullptr) && m_menuFavorite->isChecked()) {
-                        wc = "t_bookmarked='Y' AND (" % wc % ')';
+                        wc = "t_bookmarked='Y' AND (" % wc % QLatin1Char(')');
                     }
 
                     // Build display
                     SKGStringListList listTmp;
                     err = doc->executeSelectSqliteOrder(
-                              QStringLiteral("SELECT t_name, t_TYPENLS, t_UNIT, ") % ((m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? "f_TODAYAMOUNT" : "f_CURRENTAMOUNT") % ", t_close  from v_account_display WHERE (" % wc % ") ORDER BY t_TYPENLS, t_name",
+                              QLatin1String("SELECT t_name, t_TYPENLS, t_UNIT, ") % ((m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? "f_TODAYAMOUNT" : "f_CURRENTAMOUNT") % ", t_close  from v_account_display WHERE (" % wc % ") ORDER BY t_TYPENLS, t_name",
                               listTmp);
                     IFOK(err) {
                         KColorScheme scheme(QPalette::Normal, KColorScheme::Window);
                         auto color = scheme.foreground(KColorScheme::NormalText).color().name().right(6);
 
-                        html += QStringLiteral("<html><head><style>a {color: #") + color + ";}</style></head><body><table>";
+                        html += QLatin1String("<html><head><style>a {color: #") + color + ";}</style></head><body><table>";
                         double sumTypeV1 = 0;
                         double sumV1 = 0;
                         int nbAdded = 0;
@@ -329,7 +329,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                             const QString& type = r.at(1);
                             const QString& unitAccountSymbol = r.at(2);
                             double v1 = SKGServices::stringToDouble(r.at(3));
-                            bool closed = (r.at(4) == QStringLiteral("Y"));
+                            bool closed = (r.at(4) == QLatin1String("Y"));
 
                             if (type != currentType) {
                                 if (!currentType.isEmpty() && nbAdded > 0) {
@@ -349,7 +349,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                     unitAccount.setSymbol(unitAccountSymbol);
                                     unitAccount.load();
 
-                                    double unitAccountValue = SKGServices::stringToDouble(unitAccount.getAttribute(QStringLiteral("f_CURRENTAMOUNT")));
+                                    double unitAccountValue = SKGServices::stringToDouble(unitAccount.getAttribute(QLatin1String("f_CURRENTAMOUNT")));
                                     SKGServices::SKGUnitInfo u2 = primary;
                                     u2.Symbol = unitAccountSymbol;
                                     u2.NbDecimal = unitAccount.getNumberDecimal();
@@ -357,7 +357,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                                     html += '=';
                                 }
                                 html += doc->formatMoney(v1, primary);
-                                html += QStringLiteral("</td></tr>");
+                                html += QLatin1String("</td></tr>");
                                 ++nbAdded;
                             }
                             sumTypeV1 += v1;
@@ -372,7 +372,7 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                         html += "<tr><td><b>" % SKGServices::stringToHtml(i18nc("Noun, the numerical total of a sum of values", "Total")) % "</b></td>"
                                 "<td align=\"right\"><b>" % doc->formatMoney(sumV1, primary) % "</b></td>"
                                 "</tr>";
-                        html += QStringLiteral("</table></body></html>");
+                        html += QLatin1String("</table></body></html>");
                     }
                 }
                 m_label->setText(html);
