@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -34,8 +34,10 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGBankPlugin, "metadata.json")
 
-SKGBankPlugin::SKGBankPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
-    : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr), m_reconcileAction(nullptr)
+SKGBankPlugin::SKGBankPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
+    , m_reconcileAction(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -56,14 +58,14 @@ bool SKGBankPlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skrooge_bank"), title());
-    setXMLFile(QStringLiteral("skrooge_bank.rc"));
+    setComponentName(QLatin1String("skrooge_bank"), title());
+    setXMLFile(QLatin1String("skrooge_bank.rc"));
 
     // Menu
-    auto actReconciliate = new QAction(SKGServices::fromTheme(QStringLiteral("window-duplicate")), i18nc("Verb: Reconciliation is process through which you ensure compliance with your bank's statement", "Reconcile…"), this);
+    auto actReconciliate = new QAction(SKGServices::fromTheme(QLatin1String("window-duplicate")), i18nc("Verb: Reconciliation is process through which you ensure compliance with your bank's statement", "Reconcile…"), this);
     connect(actReconciliate, &QAction::triggered, this, &SKGBankPlugin::onReconciliate);
-    actionCollection()->setDefaultShortcut(actReconciliate, Qt::ALT + Qt::Key_R);
-    registerGlobalAction(QStringLiteral("edit_reconcile"), actReconciliate, QStringList() << QStringLiteral("account"), 1, -1, 320);
+    actionCollection()->setDefaultShortcut(actReconciliate, Qt::ALT | Qt::Key_R);
+    registerGlobalAction(QLatin1String("edit_reconcile"), actReconciliate, QStringList() << QLatin1String("account"), 1, -1, 320);
     return true;
 }
 
@@ -92,42 +94,42 @@ QString SKGBankPlugin::getDashboardWidgetTitle(int iIndex)
 SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
 {
     auto listForFilter = QStringList()
-                         << QStringLiteral("t_name")
-                         << QStringLiteral("t_number")
-                         << QStringLiteral("t_agency_number")
-                         << QStringLiteral("t_agency_address")
-                         << QStringLiteral("t_comment")
-                         << QStringLiteral("t_bookmarked")
-                         << QStringLiteral("t_TYPENLS")
-                         << QStringLiteral("t_BANK")
-                         << QStringLiteral("t_BANK_NUMBER");
+                         << QLatin1String("t_name")
+                         << QLatin1String("t_number")
+                         << QLatin1String("t_agency_number")
+                         << QLatin1String("t_agency_address")
+                         << QLatin1String("t_comment")
+                         << QLatin1String("t_bookmarked")
+                         << QLatin1String("t_TYPENLS")
+                         << QLatin1String("t_BANK")
+                         << QLatin1String("t_BANK_NUMBER");
     if (iIndex == 0) {
         return new SKGAccountBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
     }
     if (iIndex == 1) {
         return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex),
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/account_table.qml")),
-                                      QStringList() << QStringLiteral("v_account_display"),
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/account_table.qml")),
+                                      QStringList() << QLatin1String("v_account_display"),
                                       SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS,
                                       listForFilter);
     }
     if (iIndex == 2) {
         auto w = new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                         getDashboardWidgetTitle(iIndex),
-                                        QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/bank_table_light.qml")),
-                                        QStringList() << QStringLiteral("v_account_display"),
+                                        QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/bank_table_light.qml")),
+                                        QStringList() << QLatin1String("v_account_display"),
                                         SKGSimplePeriodEdit::NONE,
                                         listForFilter);
 
         QStringList overlayopen;
-        overlayopen.push_back(QStringLiteral("quickopen"));
-        auto open = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), w);
+        overlayopen.push_back(QLatin1String("quickopen"));
+        auto open = new QAction(SKGServices::fromTheme(QLatin1String("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), w);
         connect(open, &QAction::triggered, SKGMainPanel::getMainPanel(), [ = ]() {
             SKGMainPanel::getMainPanel()->SKGMainPanel::openPage();
         });
-        QString u = QStringLiteral("skg://skrooge_report_plugin/?grouped=Y&transfers=Y&tracked=Y&expenses=Y&incomes=Y&lines2=t_BANK&currentPage=-1&mode=0&interval=3&period=0") %
-                    "&tableAndGraphState.graphMode=2&tableAndGraphState.allPositive=N&tableAndGraphState.show=graph&columns=" % SKGServices::encodeForUrl(QStringLiteral("#NOTHING#"));
+        QString u = QLatin1String("skg://skrooge_report_plugin/?grouped=Y&transfers=Y&tracked=Y&expenses=Y&incomes=Y&lines2=t_BANK&currentPage=-1&mode=0&interval=3&period=0") %
+                    "&tableAndGraphState.graphMode=2&tableAndGraphState.allPositive=N&tableAndGraphState.show=graph&columns=" % SKGServices::encodeForUrl(QLatin1String("#NOTHING#"));
         open->setData(u);
 
         w->addAction(open);
@@ -136,28 +138,28 @@ SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
     if (iIndex == 3) {
         return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex),
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/bank_table.qml")),
-                                      QStringList() << QStringLiteral("v_account_display"),
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/bank_table.qml")),
+                                      QStringList() << QLatin1String("v_account_display"),
                                       SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS,
                                       listForFilter);
     }
 
     listForFilter = QStringList()
-                    << QStringLiteral("t_name")
-                    << QStringLiteral("t_number")
-                    << QStringLiteral("t_agency_number")
-                    << QStringLiteral("t_agency_address")
-                    << QStringLiteral("t_comment")
-                    << QStringLiteral("t_TYPENLS")
-                    << QStringLiteral("t_BANK")
-                    << QStringLiteral("t_BANK_NUMBER")
-                    << QStringLiteral("t_close")
-                    << QStringLiteral("t_type")
-                    << QStringLiteral("t_bookmarked");
+                    << QLatin1String("t_name")
+                    << QLatin1String("t_number")
+                    << QLatin1String("t_agency_number")
+                    << QLatin1String("t_agency_address")
+                    << QLatin1String("t_comment")
+                    << QLatin1String("t_TYPENLS")
+                    << QLatin1String("t_BANK")
+                    << QLatin1String("t_BANK_NUMBER")
+                    << QLatin1String("t_close")
+                    << QLatin1String("t_type")
+                    << QLatin1String("t_bookmarked");
     return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
-                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/account_table_light.qml")),
-                                  QStringList() << QStringLiteral("v_account_display"),
+                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/account_table_light.qml")),
+                                  QStringList() << QLatin1String("v_account_display"),
                                   SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS,
                                   listForFilter);
 }
@@ -175,7 +177,7 @@ QString SKGBankPlugin::title() const
 
 QString SKGBankPlugin::icon() const
 {
-    return QStringLiteral("view-bank");
+    return QLatin1String("view-bank");
 }
 
 QString SKGBankPlugin::toolTip() const
@@ -223,9 +225,9 @@ SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
     output.reserve(40);
 
     // Get bank without accounts
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgbankplugin_withoutaccount"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgbankplugin_withoutaccount"))) {
         SKGStringListList result;
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT bank.t_name FROM bank WHERE NOT EXISTS (SELECT 1 FROM account WHERE account.rd_bank_id=bank.id)"), result);
+        m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT bank.t_name FROM bank WHERE NOT EXISTS (SELECT 1 FROM account WHERE account.rd_bank_id=bank.id)"), result);
         int nb = result.count();
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
@@ -245,9 +247,9 @@ SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Get accounts closed with money
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgbankplugin_closedaccount"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgbankplugin_closedaccount"))) {
         SKGStringListList result;
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name FROM v_account_amount WHERE f_CURRENTAMOUNT>0.1 AND t_close='Y'"), result);
+        m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT t_name FROM v_account_amount WHERE f_CURRENTAMOUNT>0.1 AND t_close='Y'"), result);
         int nb = result.count();
         SKGAdvice::SKGAdviceActionList autoCorrections;
         for (int i = 1; i < nb; ++i) {  // Ignore header
@@ -264,14 +266,14 @@ SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Action to reopen the account", "Reopen '%1'", account);
-                a.IconName = QStringLiteral("edit_undo");
+                a.IconName = QLatin1String("edit_undo");
                 a.IsRecommended = false;
                 autoCorrections.push_back(a);
             }
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Action to create a fake transaction to set the amount of the account to 0", "Create fake transaction");
-                a.IconName = QStringLiteral("edit-delete");
+                a.IconName = QLatin1String("edit-delete");
                 a.IsRecommended = true;
                 autoCorrections.push_back(a);
             }
