@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -43,7 +43,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     ui.setupUi(this);
 
     // Add report
-    SKGInterfacePlugin* reportPlugin = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge report plugin"));
+    SKGInterfacePlugin* reportPlugin = SKGMainPanel::getMainPanel()->getPluginByName(QLatin1String("Skrooge report plugin"));
     if (reportPlugin != nullptr) {
         m_graph = reportPlugin->getDashboardWidget(0);
         if (m_graph != nullptr) {
@@ -58,39 +58,39 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
             // Set initial state
             m_graph->hide();
 
-            QDomDocument doc(QStringLiteral("SKGML"));
-            QDomElement root = doc.createElement(QStringLiteral("parameters"));
+            QDomDocument doc(QLatin1String("SKGML"));
+            QDomElement root = doc.createElement(QLatin1String("parameters"));
             doc.appendChild(root);
             {
-                QDomDocument doc1(QStringLiteral("SKGML"));
-                QDomElement root1 = doc1.createElement(QStringLiteral("parameters"));
+                QDomDocument doc1(QLatin1String("SKGML"));
+                QDomElement root1 = doc1.createElement(QLatin1String("parameters"));
                 doc1.appendChild(root1);
 
-                root1.setAttribute(QStringLiteral("period"), QStringLiteral("0"));
-                root1.setAttribute(QStringLiteral("columns"), QStringLiteral("d_DATEMONTH"));
-                root1.setAttribute(QStringLiteral("mode"), QStringLiteral("1"));
-                root1.setAttribute(QStringLiteral("currentPage"), QStringLiteral("-2"));
-                root1.setAttribute(QStringLiteral("operationWhereClause"), QStringLiteral("1=0"));
-                root1.setAttribute(QStringLiteral("title"), QStringLiteral("none"));
+                root1.setAttribute(QLatin1String("period"), QLatin1String("0"));
+                root1.setAttribute(QLatin1String("columns"), QLatin1String("d_DATEMONTH"));
+                root1.setAttribute(QLatin1String("mode"), QLatin1String("1"));
+                root1.setAttribute(QLatin1String("currentPage"), QLatin1String("-2"));
+                root1.setAttribute(QLatin1String("operationWhereClause"), QLatin1String("1=0"));
+                root1.setAttribute(QLatin1String("title"), QLatin1String("none"));
 
                 {
-                    QDomDocument doc2(QStringLiteral("SKGML"));
-                    QDomElement root2 = doc2.createElement(QStringLiteral("parameters"));
+                    QDomDocument doc2(QLatin1String("SKGML"));
+                    QDomElement root2 = doc2.createElement(QLatin1String("parameters"));
                     doc2.appendChild(root2);
-                    root2.setAttribute(QStringLiteral("graphMode"), SKGServices::intToString(static_cast<int>(SKGTableWithGraph::LINE)));
+                    root2.setAttribute(QLatin1String("graphMode"), SKGServices::intToString(static_cast<int>(SKGTableWithGraph::LINE)));
 
                     {
-                        QDomDocument doc3(QStringLiteral("SKGML"));
-                        QDomElement root3 = doc3.createElement(QStringLiteral("parameters"));
+                        QDomDocument doc3(QLatin1String("SKGML"));
+                        QDomElement root3 = doc3.createElement(QLatin1String("parameters"));
                         doc3.appendChild(root3);
-                        root3.setAttribute(QStringLiteral("isToolBarVisible"), QStringLiteral("N"));
+                        root3.setAttribute(QLatin1String("isToolBarVisible"), QLatin1String("N"));
 
-                        root2.setAttribute(QStringLiteral("graphicViewState"), doc3.toString());
+                        root2.setAttribute(QLatin1String("graphicViewState"), doc3.toString());
                     }
 
-                    root1.setAttribute(QStringLiteral("tableAndGraphState"), doc2.toString());
+                    root1.setAttribute(QLatin1String("tableAndGraphState"), doc2.toString());
                 }
-                root.setAttribute(QStringLiteral("graph"), doc1.toString());
+                root.setAttribute(QLatin1String("graph"), doc1.toString());
             }
 
             m_graph->setState(doc.toString());
@@ -104,64 +104,64 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     }
 
     // Set label titles
-    ui.kBankLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_bank"))));
-    ui.kAccountLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_ACCOUNT"))));
-    ui.kTypeLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_type"))));
-    ui.kBankNumberLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_bank_number"))));
-    ui.kAgencyNumberLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_agency_number"))));
-    ui.kNumberLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_number"))));
-    ui.kAgencyAddressLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_agency_address"))));
-    ui.kMaxLimit->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("f_maxamount"))));
-    ui.kMinLimit->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("f_minamount"))));
-    ui.kCommentLabel->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_comment"))));
+    ui.kBankLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_bank"))));
+    ui.kAccountLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_ACCOUNT"))));
+    ui.kTypeLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_type"))));
+    ui.kBankNumberLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_bank_number"))));
+    ui.kAgencyNumberLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_agency_number"))));
+    ui.kNumberLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_number"))));
+    ui.kAgencyAddressLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_agency_address"))));
+    ui.kMaxLimit->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("f_maxamount"))));
+    ui.kMinLimit->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("f_minamount"))));
+    ui.kCommentLabel->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_comment"))));
 
     // Set show widget
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("all"), i18n("All"), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META + Qt::Key_A);
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("opened"), i18n("Opened"), QStringLiteral("vcs-normal"), QStringLiteral("t_close='N'"), QLatin1String(""), Qt::META + Qt::Key_O);
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("closed"), i18n("Closed"), QStringLiteral("vcs-conflicting"), QStringLiteral("t_close='Y'"), QLatin1String(""), Qt::META + Qt::Key_C);
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("highlighted"), i18n("Highlighted only"), QStringLiteral("bookmarks"), QStringLiteral("t_bookmarked='Y'"), QLatin1String(""), Qt::META + Qt::Key_H);
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("all"), i18n("All"), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META | Qt::Key_A);
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("opened"), i18n("Opened"), QLatin1String("vcs-normal"), QLatin1String("t_close='N'"), QLatin1String(""), Qt::META | Qt::Key_O);
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("closed"), i18n("Closed"), QLatin1String("vcs-conflicting"), QLatin1String("t_close='Y'"), QLatin1String(""), Qt::META | Qt::Key_C);
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("highlighted"), i18n("Highlighted only"), QLatin1String("bookmarks"), QLatin1String("t_bookmarked='Y'"), QLatin1String(""), Qt::META | Qt::Key_H);
     if (m_graph != nullptr) {
         ui.kView->getShowWidget()->addSeparator();
-        ui.kView->getShowWidget()->addItem(QStringLiteral("graph"), i18n("Graph"), QStringLiteral("view-statistics"), QStringLiteral("1=0"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META + Qt::Key_G);
+        ui.kView->getShowWidget()->addItem(QLatin1String("graph"), i18n("Graph"), QLatin1String("view-statistics"), QLatin1String("1=0"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META | Qt::Key_G);
     }
 
-    ui.kView->getShowWidget()->setDefaultState(QStringLiteral("opened"));
+    ui.kView->getShowWidget()->setDefaultState(QLatin1String("opened"));
 
     m_timer.setSingleShot(true);
     connect(&m_timer, &QTimer::timeout, this, &SKGBankPluginWidget::refreshInfoZone, Qt::QueuedConnection);
 
     // Add Standard KDE Icons to buttons to Accounts
-    ui.kAccountCreatorUpdate->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
-    ui.kAccountCreatorAdd->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
+    ui.kAccountCreatorUpdate->setIcon(SKGServices::fromTheme(QLatin1String("dialog-ok")));
+    ui.kAccountCreatorAdd->setIcon(SKGServices::fromTheme(QLatin1String("list-add")));
 
     SKGWidgetSelector::SKGListQWidget list;
     list.push_back(ui.SKGEditionWidget);
     list.push_back(ui.SKGEditionButtonswidget);
-    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("configure")), i18n("Edit"), i18n("Display the account edit panel"), list);
+    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("configure")), i18n("Edit"), i18n("Display the account edit panel"), list);
 
     // Add NLS values for type of account
     // C=current D=credit card P=passif (for objects) I=Investment O=other
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-checking")), i18nc("Noun, a type of account", "Current"), static_cast<int>(SKGAccountObject::CURRENT));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("skrooge_credit_card")), i18nc("Noun, a type of account", "Credit card"), static_cast<int>(SKGAccountObject::CREDITCARD));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Saving"), static_cast<int>(SKGAccountObject::SAVING));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Investment"), static_cast<int>(SKGAccountObject::INVESTMENT));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Assets"), static_cast<int>(SKGAccountObject::ASSETS));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Loan"), static_cast<int>(SKGAccountObject::LOAN));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Pension"), static_cast<int>(SKGAccountObject::PENSION));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("wallet-closed")), i18nc("Noun, a type of account", "Wallet"), static_cast<int>(SKGAccountObject::WALLET));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QLatin1String("view-bank-account-checking")), i18nc("Noun, a type of account", "Current"), static_cast<int>(SKGAccountObject::CURRENT));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QLatin1String("skrooge_credit_card")), i18nc("Noun, a type of account", "Credit card"), static_cast<int>(SKGAccountObject::CREDITCARD));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QLatin1String("view-bank-account-savings")), i18nc("Noun, a type of account", "Saving"), static_cast<int>(SKGAccountObject::SAVING));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QLatin1String("view-bank-account-savings")), i18nc("Noun, a type of account", "Investment"), static_cast<int>(SKGAccountObject::INVESTMENT));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QLatin1String("view-bank-account-savings")), i18nc("Noun, a type of account", "Assets"), static_cast<int>(SKGAccountObject::ASSETS));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QLatin1String("view-bank-account-savings")), i18nc("Noun, a type of account", "Loan"), static_cast<int>(SKGAccountObject::LOAN));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QLatin1String("view-bank-account-savings")), i18nc("Noun, a type of account", "Pension"), static_cast<int>(SKGAccountObject::PENSION));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QLatin1String("wallet-closed")), i18nc("Noun, a type of account", "Wallet"), static_cast<int>(SKGAccountObject::WALLET));
     ui.kAccountCreatorType->addItem(i18nc("Noun, a type of account", "Other"), static_cast<int>(SKGAccountObject::OTHER));
 
     // Bind account creation view
-    ui.kView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_account_display"), QStringLiteral("1=0"), this, QLatin1String(""), false));
+    ui.kView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("v_account_display"), QLatin1String("1=0"), this, QLatin1String(""), false));
 
     connect(ui.kView->getView(), &SKGTreeView::clickEmptyArea, this, &SKGBankPluginWidget::cleanEditor);
-    connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open")).data(), &QAction::trigger);
+    connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("open")).data(), &QAction::trigger);
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, this, [ = ] {this->onSelectionChanged();});
 
     // Search file list
-    QString listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/l10n/" % QLocale().name().split(QStringLiteral("_")).at(0) % "/list_bank.txt");
+    QString listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/l10n/" % QLocale().name().split(QLatin1String("_")).at(0) % "/list_bank.txt");
     if (listIconFile.isEmpty()) {
-        listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/images/logo/list_bank.txt"));
+        listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/images/logo/list_bank.txt"));
     }
 
     // Logo for banks
@@ -174,10 +174,10 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
             if (!line.isEmpty()) {
                 QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/" % line);
                 QString bankName = std::move(line);
-                bankName.remove(QStringLiteral(".png"));
+                bankName.remove(QLatin1String(".png"));
                 bankName.replace('_', ' ');
 
-                auto rx = QRegularExpression(QStringLiteral("(.+) {2,}(.+)")).match(bankName);
+                auto rx = QRegularExpression(QLatin1String("(.+) {2,}(.+)")).match(bankName);
                 if (rx.hasMatch()) {
                     // Icon is something like <bank name>__<banknumber>.png
                     ui.kAccountCreatorIcon->addItem(QIcon(fileName), rx.captured(1), rx.captured(2));
@@ -186,7 +186,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
                 }
             }
         }
-        ui.kAccountCreatorIcon->addItem(SKGServices::fromTheme(QStringLiteral("document-open-folder")), i18nc("Other type of bank account", "Other…"));
+        ui.kAccountCreatorIcon->addItem(SKGServices::fromTheme(QLatin1String("document-open-folder")), i18nc("Other type of bank account", "Other…"));
 
         file.close();
     }
@@ -257,10 +257,10 @@ void SKGBankPluginWidget::onSelectionChanged()
         QString fileName = bank.getIcon();
         QString iconName = fileName;
         if (!iconName.isEmpty()) {
-            iconName.remove(QStringLiteral(".png"));
+            iconName.remove(QLatin1String(".png"));
             iconName.replace('_', ' ');
 
-            auto rx = QRegularExpression(QStringLiteral("(.+) {2,}(.+)")).match(iconName);
+            auto rx = QRegularExpression(QLatin1String("(.+) {2,}(.+)")).match(iconName);
             if (rx.hasMatch()) {
                 iconName = rx.captured(1);
             }
@@ -279,16 +279,16 @@ void SKGBankPluginWidget::onSelectionChanged()
             ui.kAccountCreatorIcon->setText(QLatin1String(""));
         }
 
-        ui.kAccountCreatorBank->setText(account.getAttribute(QStringLiteral("t_BANK")));
-        ui.kAccountCreatorAccount->setText(account.getAttribute(QStringLiteral("t_name")));
-        ui.kAccountCreatorBankNumber->setText(account.getAttribute(QStringLiteral("t_BANK_NUMBER")));
-        ui.kAccountCreatorAgencyNumber->setText(account.getAttribute(QStringLiteral("t_agency_number")));
-        ui.kAccountCreatorNumber->setText(account.getAttribute(QStringLiteral("t_number")));
-        ui.kAccountCreatorType->setText(account.getAttribute(QStringLiteral("t_TYPENLS")));
-        ui.kAccountCreatorAddress->setText(account.getAttribute(QStringLiteral("t_agency_address")));
-        ui.kAccountCreatorComment->setText(account.getAttribute(QStringLiteral("t_comment")));
-        ui.kMinLimitAmout->setText(account.getAttribute(QStringLiteral("f_minamount")));
-        ui.kMaxLimitAmout->setText(account.getAttribute(QStringLiteral("f_maxamount")));
+        ui.kAccountCreatorBank->setText(account.getAttribute(QLatin1String("t_BANK")));
+        ui.kAccountCreatorAccount->setText(account.getAttribute(QLatin1String("t_name")));
+        ui.kAccountCreatorBankNumber->setText(account.getAttribute(QLatin1String("t_BANK_NUMBER")));
+        ui.kAccountCreatorAgencyNumber->setText(account.getAttribute(QLatin1String("t_agency_number")));
+        ui.kAccountCreatorNumber->setText(account.getAttribute(QLatin1String("t_number")));
+        ui.kAccountCreatorType->setText(account.getAttribute(QLatin1String("t_TYPENLS")));
+        ui.kAccountCreatorAddress->setText(account.getAttribute(QLatin1String("t_agency_address")));
+        ui.kAccountCreatorComment->setText(account.getAttribute(QLatin1String("t_comment")));
+        ui.kMinLimitAmout->setText(account.getAttribute(QLatin1String("f_minamount")));
+        ui.kMaxLimitAmout->setText(account.getAttribute(QLatin1String("f_maxamount")));
         ui.kMaxLimit->setTristate(false);
         ui.kMaxLimit->setCheckState(account.isMaxLimitAmountEnabled() ? Qt::Checked : Qt::Unchecked);
         ui.kMinLimit->setTristate(false);
@@ -349,15 +349,15 @@ void SKGBankPluginWidget::onRefreshGraph()
 {
     SKGTRACEINFUNC(10)
     if (m_graph != nullptr) {
-        bool visible = ui.kView->getShowWidget()->getState().contains(QStringLiteral("graph"));
+        bool visible = ui.kView->getShowWidget()->getState().contains(QLatin1String("graph"));
 
-        QDomDocument doc(QStringLiteral("SKGML"));
+        QDomDocument doc(QLatin1String("SKGML"));
         if (doc.setContent(m_graph->getState())) {
             QDomElement root = doc.documentElement();
 
-            QString graphS = root.attribute(QStringLiteral("graph"));
+            QString graphS = root.attribute(QLatin1String("graph"));
 
-            QDomDocument doc2(QStringLiteral("SKGML"));
+            QDomDocument doc2(QLatin1String("SKGML"));
             if (doc2.setContent(graphS)) {
                 QDomElement root2 = doc2.documentElement();
                 QString wc;
@@ -367,7 +367,7 @@ void SKGBankPluginWidget::onRefreshGraph()
                     SKGObjectBase::SKGListSKGObjectBase objs = ui.kView->getView()->getSelectedObjects();
                     nbSelect = objs.count();
                     if (nbSelect != 0) {
-                        wc = QStringLiteral("t_ACCOUNT IN (");
+                        wc = QLatin1String("t_ACCOUNT IN (");
                         title = i18nc("Noun, a list of items", "Transactions of account ");
                         for (int i = 0; i < nbSelect; ++i) {
                             if (i != 0) {
@@ -375,20 +375,20 @@ void SKGBankPluginWidget::onRefreshGraph()
                                 title += ',';
                             }
                             SKGAccountObject act(objs.at(i));
-                            wc += '\'' % SKGServices::stringToSqlString(act.getName()) % '\'';
+                            wc += '\'' % SKGServices::stringToSqlString(act.getName()) % QLatin1Char('\'');
                             title += i18n("'%1'", act.getName());
                         }
                         wc += ')';
                     }
                 } else {
-                    wc = QStringLiteral("1=0");
-                    title = QStringLiteral("none");
+                    wc = QLatin1String("1=0");
+                    title = QLatin1String("none");
                 }
-                root2.setAttribute(QStringLiteral("operationWhereClause"), wc);
-                root2.setAttribute(QStringLiteral("title"), title);
-                root2.setAttribute(QStringLiteral("lines"), nbSelect != 0 ? QStringLiteral("t_ACCOUNT") : QStringLiteral("#NOTHING#"));
+                root2.setAttribute(QLatin1String("operationWhereClause"), wc);
+                root2.setAttribute(QLatin1String("title"), title);
+                root2.setAttribute(QLatin1String("lines"), nbSelect != 0 ? QLatin1String("t_ACCOUNT") : QLatin1String("#NOTHING#"));
             }
-            root.setAttribute(QStringLiteral("graph"), doc2.toString());
+            root.setAttribute(QLatin1String("graph"), doc2.toString());
         }
         QString newGraphState = doc.toString();
         if (newGraphState != m_graphState) {
@@ -408,7 +408,7 @@ void SKGBankPluginWidget::onIconChanged()
     if ((c != 0) && c == ui.kAccountCreatorIcon->count() - 1) {
         QString fileName = QFileDialog::getOpenFileName(this,
                            i18nc("Title of panel", "Select a bank icon"),
-                           QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/images/logo/"), QStandardPaths::LocateDirectory),
+                           QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/images/logo/"), QStandardPaths::LocateDirectory),
                            i18nc("File format for open dialog panel", "Image files") % " (*.png *.jpeg *.jpg *.gif *.tiff)");
         if (!fileName.isEmpty()) {
             if (ui.kAccountCreatorIcon->contains(fileName)) {
@@ -487,7 +487,7 @@ void SKGBankPluginWidget::onAddAccountClicked()
 
         QString bankName = ui.kAccountCreatorBank->text();
         QString accountName = ui.kAccountCreatorAccount->text();
-        QString name = bankName % '-' % accountName;
+        QString name = bankName % QLatin1Char('-') % accountName;
         SKGAccountObject::AccountType accountType = static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt());
         const bool wallet = (accountType == SKGAccountObject::WALLET);
         if (wallet) {
@@ -509,7 +509,7 @@ void SKGBankPluginWidget::onAddAccountClicked()
                     }
 
                     icon.replace(' ', '_');
-                    icon += QStringLiteral(".png");
+                    icon += QLatin1String(".png");
                 }
                 err = bankObj.setIcon(icon);
             }
@@ -645,17 +645,13 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             if (bankName == NOUPDATE) {
                 accountObj.getBank(bankObj);
             } else {
-                if (SKGNamedObject::getObjectByName(getDocument(), QStringLiteral("bank"), bankName, bankObj).isSucceeded()) {
+                if (SKGNamedObject::getObjectByName(getDocument(), QLatin1String("bank"), bankName, bankObj).isSucceeded()) {
                     // The created bank already exist ==> update parent bank
                     IFOKDO(err, accountObj.setBank(bankObj))
                     IFOKDO(err, accountObj.save())
                 } else {
                     // The bank does not exist
-#ifdef SKG_KF_5102
                     int code = KMessageBox::PrimaryAction;
-#else
-                    int code = KMessageBox::Yes;
-#endif
                     SKGBankObject currentBank;
                     err = accountObj.getBank(currentBank);
                     IFOK(err) {
@@ -663,25 +659,17 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                         err = currentBank.getAccounts(accounts);
                         if (!err && accounts.count() > 1) {
                             QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-#ifdef SKG_KF_5102
                             code = KMessageBox::questionTwoActions(this,
                                                                    i18nc("Question", "You are trying to modify bank name of account named '%1'.\nDo you want to do this modification for all accounts of this bank ? ",  accountObj.getName()),
                                                                    i18nc("Question",  "Do you want to modify the account ?"),
                                                                    KStandardGuiItem::apply(), KStandardGuiItem::cancel()
                                                                   );
-#else
-                            code = KMessageBox::questionYesNo(this, i18nc("Question", "You are trying to modify bank name of account named '%1'.\nDo you want to do this modification for all accounts of this bank ? ",  accountObj.getName()));
-#endif
                             QApplication::restoreOverrideCursor();
                         }
                     }
 
                     IFOKDO(err, accountObj.getBank(bankObj))
-#ifdef SKG_KF_5102
                     if (code == KMessageBox::PrimaryAction) {
-#else
-                    if (code == KMessageBox::Yes) {
-#endif
                         // The bank does not exist ==> update this one
                         IFOKDO(err, bankObj.setName(bankName))
                     } else {
@@ -704,7 +692,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                             icon += "  " % code;
                         }
                         icon.replace(' ', '_');
-                        icon += QStringLiteral(".png");
+                        icon += QLatin1String(".png");
                     }
                     err = bankObj.setIcon(icon);
                 }
@@ -717,7 +705,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
 
         // Remove bank without account
         IFOK(err) {
-            err = getDocument()->executeSqliteOrder(QStringLiteral("DELETE FROM bank WHERE NOT EXISTS(SELECT 1 FROM account WHERE account.rd_bank_id = bank.id)"));
+            err = getDocument()->executeSqliteOrder(QLatin1String("DELETE FROM bank WHERE NOT EXISTS(SELECT 1 FROM account WHERE account.rd_bank_id = bank.id)"));
         }
     }
 
@@ -745,7 +733,7 @@ void SKGBankPluginWidget::cleanEditor()
         ui.kAccountCreatorType->setText(i18nc("Noun, a type of account", "Current"));
         ui.kAccountCreatorAddress->setText(QLatin1String(""));
         ui.kAccountCreatorComment->setText(QLatin1String(""));
-        ui.kAmountEdit->setText(QStringLiteral("0"));
+        ui.kAmountEdit->setText(QLatin1String("0"));
         ui.kUnitEdit->refershList();
     }
 }
@@ -753,12 +741,12 @@ void SKGBankPluginWidget::cleanEditor()
 QString SKGBankPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
-    root.setAttribute(QStringLiteral("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
-    root.setAttribute(QStringLiteral("view"), ui.kView->getState());
-    root.setAttribute(QStringLiteral("graph"), m_graph->getState());
+    root.setAttribute(QLatin1String("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
+    root.setAttribute(QLatin1String("view"), ui.kView->getState());
+    root.setAttribute(QLatin1String("graph"), m_graph->getState());
     return doc.toString();
 }
 
@@ -766,25 +754,25 @@ void SKGBankPluginWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString currentPage = root.attribute(QStringLiteral("currentPage"));
+    QString currentPage = root.attribute(QLatin1String("currentPage"));
     if (currentPage.isEmpty()) {
         currentPage = '0';
     }
     ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
 
-    ui.kView->setState(root.attribute(QStringLiteral("view")));
-    m_graph->setState(root.attribute(QStringLiteral("graph")));
+    ui.kView->setState(root.attribute(QLatin1String("view")));
+    m_graph->setState(root.attribute(QLatin1String("graph")));
 
     onRefreshGraph();
 }
 
 QString SKGBankPluginWidget::getDefaultStateAttribute()
 {
-    return QStringLiteral("SKGBANK_DEFAULT_PARAMETERS");
+    return QLatin1String("SKGBANK_DEFAULT_PARAMETERS");
 }
 
 void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
@@ -793,25 +781,25 @@ void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransac
     Q_UNUSED(iIdTransaction)
 
     // Refresh widgets
-    if (iTableName == QStringLiteral("v_account_display") || iTableName.isEmpty()) {
+    if (iTableName == QLatin1String("v_account_display") || iTableName.isEmpty()) {
         // Refresh info area
         m_timer.start(300);
     }
 
     if (!iLightTransaction) {
-        if (iTableName == QStringLiteral("bank") || iTableName.isEmpty()) {
+        if (iTableName == QLatin1String("bank") || iTableName.isEmpty()) {
             // Set completions
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorBank, getDocument(), QStringLiteral("bank"), QStringLiteral("t_name"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorBank, getDocument(), QLatin1String("bank"), QLatin1String("t_name"), QLatin1String(""), true);
         }
 
-        if (iTableName == QStringLiteral("account") || iTableName.isEmpty()) {
+        if (iTableName == QLatin1String("account") || iTableName.isEmpty()) {
             // Set completions
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorAccount, getDocument(), QStringLiteral("account"), QStringLiteral("t_name"), QLatin1String(""), true);
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorBankNumber, getDocument(), QStringLiteral("bank"), QStringLiteral("t_bank_number"), QLatin1String(""), true);
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorAgencyNumber, getDocument(), QStringLiteral("account"), QStringLiteral("t_agency_number"), QLatin1String(""), true);
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorNumber, getDocument(), QStringLiteral("account"), QStringLiteral("t_number"), QLatin1String(""), true);
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorAddress, getDocument(), QStringLiteral("account"), QStringLiteral("t_agency_address"), QLatin1String(""), true);
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorComment, getDocument(), QStringLiteral("account"), QStringLiteral("t_comment"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorAccount, getDocument(), QLatin1String("account"), QLatin1String("t_name"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorBankNumber, getDocument(), QLatin1String("bank"), QLatin1String("t_bank_number"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorAgencyNumber, getDocument(), QLatin1String("account"), QLatin1String("t_agency_number"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorNumber, getDocument(), QLatin1String("account"), QLatin1String("t_number"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorAddress, getDocument(), QLatin1String("account"), QLatin1String("t_agency_address"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAccountCreatorComment, getDocument(), QLatin1String("account"), QLatin1String("t_comment"), QLatin1String(""), true);
         }
     }
 }
@@ -822,7 +810,7 @@ void SKGBankPluginWidget::refreshInfoZone()
     auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
     if (doc != nullptr) {
         ui.kInfo->setText(i18nc("Message", "Computing…"));
-        doc->concurrentExecuteSelectSqliteOrder(QStringLiteral("SELECT TOTAL(f_TODAYAMOUNT), TOTAL(f_CURRENTAMOUNT), TOTAL(f_CHECKED), TOTAL(f_COMING_SOON) from v_account_display"), [ = ](const SKGStringListList & iResult) {
+        doc->concurrentExecuteSelectSqliteOrder(QLatin1String("SELECT TOTAL(f_TODAYAMOUNT), TOTAL(f_CURRENTAMOUNT), TOTAL(f_CHECKED), TOTAL(f_COMING_SOON) from v_account_display"), [ = ](const SKGStringListList & iResult) {
             if (iResult.count() == 2 && SKGMainPanel::getMainPanel()->pageIndex(this) != -1) {
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
                 double v1 = SKGServices::stringToDouble(iResult.at(1).at(0));
