@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -11,6 +11,9 @@
 #include "skgbudgetdelegate.h"
 
 #include <kcolorscheme.h>
+#ifdef SKG_QT6
+#include <kstatefulbrush.h>
+#endif
 
 #include <qpainter.h>
 #include <qsortfilterproxymodel.h>
@@ -46,8 +49,8 @@ void SKGBudgetDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opt
             }
             SKGObjectBase obj = m->getObject(idxs);
 
-            int year = SKGServices::stringToDouble(obj.getAttribute(QStringLiteral("i_year")));
-            int month = SKGServices::stringToDouble(obj.getAttribute(QStringLiteral("i_month")));
+            int year = SKGServices::stringToDouble(obj.getAttribute(QLatin1String("i_year")));
+            int month = SKGServices::stringToDouble(obj.getAttribute(QLatin1String("i_month")));
             QDate today = QDate::currentDate();
             double pourcent = 1;
             bool actif = true;
@@ -67,9 +70,9 @@ void SKGBudgetDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opt
                 actif = false;
             }
 
-            if ((att == QStringLiteral("f_budgeted") || att == QStringLiteral("f_budgeted_modified")) && actif) {
+            if ((att == QLatin1String("f_budgeted") || att == QLatin1String("f_budgeted_modified")) && actif) {
                 double budgeted = SKGServices::stringToDouble(obj.getAttribute(att));
-                double amount = SKGServices::stringToDouble(obj.getAttribute(QStringLiteral("f_CURRENTAMOUNT")));
+                double amount = SKGServices::stringToDouble(obj.getAttribute(QLatin1String("f_CURRENTAMOUNT")));
 
                 KColorScheme scheme(QPalette::Normal);
                 QColor negativeC = scheme.foreground(KColorScheme::NegativeText).color().toHsv();
