@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -29,7 +29,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGBudgetPlugin, "metadata.json")
 
-SKGBudgetPlugin::SKGBudgetPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
+SKGBudgetPlugin::SKGBudgetPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -50,16 +52,16 @@ bool SKGBudgetPlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skrooge_budget"), title());
-    setXMLFile(QStringLiteral("skrooge_budget.rc"));
+    setComponentName(QLatin1String("skrooge_budget"), title());
+    setXMLFile(QLatin1String("skrooge_budget.rc"));
 
     // Create yours actions here
     // -----------
     QStringList overlayrun;
-    overlayrun.push_back(QStringLiteral("system-run"));
+    overlayrun.push_back(QLatin1String("system-run"));
     auto act = new QAction(SKGServices::fromTheme(icon(), overlayrun), i18nc("Verb", "Process budget rules"), this);
     connect(act, &QAction::triggered, this, &SKGBudgetPlugin::onProcessRules);
-    registerGlobalAction(QStringLiteral("tool_process_budget_rules"), act);
+    registerGlobalAction(QLatin1String("tool_process_budget_rules"), act);
     return true;
 }
 
@@ -76,7 +78,7 @@ QString SKGBudgetPlugin::title() const
 
 QString SKGBudgetPlugin::icon() const
 {
-    return QStringLiteral("view-calendar-whatsnext");
+    return QLatin1String("view-calendar-whatsnext");
 }
 
 QString SKGBudgetPlugin::toolTip() const
@@ -104,36 +106,36 @@ SKGAdviceList SKGBudgetPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEINFUNC(10)
     SKGAdviceList output;
-    QString month = QDate::currentDate().toString(QStringLiteral("yyyy-MM"));
-    QString year = QDate::currentDate().toString(QStringLiteral("yyyy"));
+    QString month = QDate::currentDate().toString(QLatin1String("yyyy-MM"));
+    QString year = QDate::currentDate().toString(QLatin1String("yyyy"));
 
     // Alarms
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgbudgetplugin_alarm"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgbudgetplugin_alarm"))) {
         SKGObjectBase::SKGListSKGObjectBase budgets;
         // Query is done on v_budget_display because v_budget_display is faster than v_budget
-        SKGError err = m_currentBankDocument->getObjects(QStringLiteral("v_budget_display"), "(f_CURRENTAMOUNT/f_budgeted_modified>0.8 OR (f_CURRENTAMOUNT<0 AND f_budgeted_modified>0)) AND ABS(f_CURRENTAMOUNT-f_budgeted_modified)>" % SKGServices::doubleToString(EPSILON) % " AND f_budgeted<0 AND (t_PERIOD='" % month % "' OR t_PERIOD='" % year % "');", budgets);
+        SKGError err = m_currentBankDocument->getObjects(QLatin1String("v_budget_display"), "(f_CURRENTAMOUNT/f_budgeted_modified>0.8 OR (f_CURRENTAMOUNT<0 AND f_budgeted_modified>0)) AND ABS(f_CURRENTAMOUNT-f_budgeted_modified)>" % SKGServices::doubleToString(EPSILON) % " AND f_budgeted<0 AND (t_PERIOD='" % month % "' OR t_PERIOD='" % year % "');", budgets);
         int nb = budgets.count();
         if (nb != 0) {
             SKGServices::SKGUnitInfo primary = m_currentBankDocument->getPrimaryUnit();
             SKGAdvice::SKGAdviceActionList autoCorrections;
             for (int i = 0; !err && i < nb; ++i) {
                 SKGBudgetObject budget(budgets.at(i));
-                double f_CURRENTAMOUNT = SKGServices::stringToDouble(budget.getAttribute(QStringLiteral("f_CURRENTAMOUNT")));
-                double f_budgeted_modified = SKGServices::stringToDouble(budget.getAttribute(QStringLiteral("f_budgeted_modified")));
+                double f_CURRENTAMOUNT = SKGServices::stringToDouble(budget.getAttribute(QLatin1String("f_CURRENTAMOUNT")));
+                double f_budgeted_modified = SKGServices::stringToDouble(budget.getAttribute(QLatin1String("f_budgeted_modified")));
 
                 SKGAdvice ad;
                 ad.setUUID("skgbudgetplugin_alarm|" % SKGServices::intToString(budget.getID()));
                 ad.setPriority((f_CURRENTAMOUNT < f_budgeted_modified ? 9 : 6));
-                ad.setShortMessage(i18nc("Advice on making the best (short)", "Budget alarm for '%1'", budget.getAttribute(QStringLiteral("t_CATEGORY"))));
+                ad.setShortMessage(i18nc("Advice on making the best (short)", "Budget alarm for '%1'", budget.getAttribute(QLatin1String("t_CATEGORY"))));
                 ad.setLongMessage(i18nc("Advice on making the best (long)", "Take care to your budget.<br> %1.<br>%2 / %3",
-                                        budget.getAttribute(QStringLiteral("t_CATEGORY")),
+                                        budget.getAttribute(QLatin1String("t_CATEGORY")),
                                         m_currentBankDocument->formatMoney(f_CURRENTAMOUNT, primary),
                                         m_currentBankDocument->formatMoney(f_budgeted_modified, primary)));
                 autoCorrections.resize(0);
                 {
                     SKGAdvice::SKGAdviceAction a;
                     a.Title = i18nc("Advice on making the best (action)", "Open transactions corresponding to this budget");
-                    a.IconName = QStringLiteral("quickopen");
+                    a.IconName = QLatin1String("quickopen");
                     a.IsRecommended = false;
                     autoCorrections.push_back(a);
                 }
@@ -143,21 +145,21 @@ SKGAdviceList SKGBudgetPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgbudgetplugin_oldprocessing"))) {
-        QString lastBudgetProcessingDate = m_currentBankDocument->getParameter(QStringLiteral("SKG_LAST_BUDGET_PROCESSING"));
-        if (lastBudgetProcessingDate.isEmpty() ||  SKGServices::stringToTime(lastBudgetProcessingDate).date() < QDate::currentDate().addMonths(-1)) {  // Ignore header
+    if (!iIgnoredAdvice.contains(QLatin1String("skgbudgetplugin_oldprocessing"))) {
+        QString lastBudgetProcessingDate = m_currentBankDocument->getParameter(QLatin1String("SKG_LAST_BUDGET_PROCESSING"));
+        if (lastBudgetProcessingDate.isEmpty() ||  SKGServices::stringToDate(lastBudgetProcessingDate) < QDate::currentDate().addMonths(-1)) {  // Ignore header
             bool exist = false;
-            m_currentBankDocument->existObjects(QStringLiteral("budgetrule"), QLatin1String(""), exist);
+            m_currentBankDocument->existObjects(QLatin1String("budgetrule"), QLatin1String(""), exist);
             if (exist) {
                 SKGAdvice ad;
-                ad.setUUID(QStringLiteral("skgbudgetplugin_oldprocessing"));
+                ad.setUUID(QLatin1String("skgbudgetplugin_oldprocessing"));
                 ad.setPriority(3);
                 ad.setShortMessage(i18nc("Advice on making the best (short)", "Old budget treatment"));
                 ad.setLongMessage(i18nc("Advice on making the best (long)", "The budget has not been treated for at least one month."));
                 SKGAdvice::SKGAdviceActionList autoCorrections;
                 {
                     SKGAdvice::SKGAdviceAction a;
-                    a.Title = QStringLiteral("skg://tool_process_budget_rules");
+                    a.Title = QLatin1String("skg://tool_process_budget_rules");
                     a.IsRecommended = true;
                     autoCorrections.push_back(a);
                 }
@@ -177,7 +179,7 @@ SKGError SKGBudgetPlugin::executeAdviceCorrection(const QString& iAdviceIdentifi
         SKGBudgetObject budget(m_currentBankDocument, SKGServices::stringToInt(id));
         budget.load();
 
-        QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open"));
+        QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("open"));
         if (act != nullptr) {
             act->setData(budget.getUniqueID());
             act->trigger();
