@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -35,22 +35,22 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
 
     ui.kUseScheduledOperation->hide();
 
-    ui.kTopBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-up-double")));
-    ui.kUpBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-up")));
-    ui.kDownBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down")));
-    ui.kBottomBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down-double")));
+    ui.kTopBtn->setIcon(SKGServices::fromTheme(QLatin1String("arrow-up-double")));
+    ui.kUpBtn->setIcon(SKGServices::fromTheme(QLatin1String("arrow-up")));
+    ui.kDownBtn->setIcon(SKGServices::fromTheme(QLatin1String("arrow-down")));
+    ui.kBottomBtn->setIcon(SKGServices::fromTheme(QLatin1String("arrow-down-double")));
 
-    ui.kPeriodLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_period"))));
-    ui.kYearLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("i_year"))));
-    ui.kMonthLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("i_month"))));
-    ui.kAmountLabel->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("f_value"))));
-    ui.kCategoryLabel->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_category"))));
-    ui.kYearCheck->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("i_year"))));
-    ui.kMonthCheck->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("i_month"))));
-    ui.kCategoryCheck->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_category"))));
-    ui.kPeriodLbl2->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_period"))));
-    ui.kAmountLabel2->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("f_value"))));
-    ui.kCategoryTransferCheck->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_category"))));
+    ui.kPeriodLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_period"))));
+    ui.kYearLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("i_year"))));
+    ui.kMonthLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("i_month"))));
+    ui.kAmountLabel->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("f_value"))));
+    ui.kCategoryLabel->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_category"))));
+    ui.kYearCheck->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("i_year"))));
+    ui.kMonthCheck->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("i_month"))));
+    ui.kCategoryCheck->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_category"))));
+    ui.kPeriodLbl2->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_period"))));
+    ui.kAmountLabel2->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("f_value"))));
+    ui.kCategoryTransferCheck->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_category"))));
 
     ui.kYear->setValue(QDate::currentDate().year());
     ui.kYearAutoBase->setValue(QDate::currentDate().year());
@@ -60,57 +60,57 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
     ui.kPeriod->addItem(i18nc("Noun, how to define a budget period", "Individual"));
 
 
-    ui.kView->getShowWidget()->addItem(QStringLiteral("all"), i18nc("Noun, budget items to display", "All"), QLatin1String(""),
+    ui.kView->getShowWidget()->addItem(QLatin1String("all"), i18nc("Noun, budget items to display", "All"), QLatin1String(""),
                                        QLatin1String(""),
-                                       QStringLiteral("current;currentYear;currentMonth;previousYear;previousMonth"),
-                                       QStringLiteral("none"), QLatin1String(""), QLatin1String(""),
-                                       Qt::META + Qt::Key_A);
-    ui.kView->getShowWidget()->addItem(QStringLiteral("none"), i18nc("Noun, budget items to display", "None"), QLatin1String(""),
-                                       QStringLiteral("1=0"),
+                                       QLatin1String("current;currentYear;currentMonth;previousYear;previousMonth"),
+                                       QLatin1String("none"), QLatin1String(""), QLatin1String(""),
+                                       Qt::META | Qt::Key_A);
+    ui.kView->getShowWidget()->addItem(QLatin1String("none"), i18nc("Noun, budget items to display", "None"), QLatin1String(""),
+                                       QLatin1String("1=0"),
                                        QLatin1String(""),  // Check when checked
-                                       QStringLiteral("all;current;currentYear;currentMonth;previousYear;previousMonth"),       // Uncheck when checked
+                                       QLatin1String("all;current;currentYear;currentMonth;previousYear;previousMonth"),       // Uncheck when checked
                                        QLatin1String(""),       // Check when unchecked
-                                       QStringLiteral("all"),    // Uncheck when unchecked
-                                       Qt::META + Qt::Key_0);
+                                       QLatin1String("all"),    // Uncheck when unchecked
+                                       Qt::META | Qt::Key_0);
     ui.kView->getShowWidget()->addSeparator();
-    ui.kView->getShowWidget()->addItem(QStringLiteral("current"), i18nc("Noun, budget items to display", "Current"), QStringLiteral("view-calendar-whatsnext"),
-                                       QStringLiteral("t_PERIOD>=STRFTIME('%Y-%m', date('now', 'localtime')) OR t_PERIOD=STRFTIME('%Y', date('now', 'localtime'))"),
-                                       QStringLiteral("currentMonth"),  // Check when checked
-                                       QStringLiteral("none"),       // Uncheck when checked
+    ui.kView->getShowWidget()->addItem(QLatin1String("current"), i18nc("Noun, budget items to display", "Current"), QLatin1String("view-calendar-whatsnext"),
+                                       QLatin1String("t_PERIOD>=STRFTIME('%Y-%m', date('now', 'localtime')) OR t_PERIOD=STRFTIME('%Y', date('now', 'localtime'))"),
+                                       QLatin1String("currentMonth"),  // Check when checked
+                                       QLatin1String("none"),       // Uncheck when checked
                                        QLatin1String(""),       // Check when unchecked
-                                       QStringLiteral("all"),    // Uncheck when unchecked
-                                       Qt::META + Qt::Key_1);
+                                       QLatin1String("all"),    // Uncheck when unchecked
+                                       Qt::META | Qt::Key_1);
     ui.kView->getShowWidget()->addSeparator();
-    ui.kView->getShowWidget()->addItem(QStringLiteral("currentYear"), i18nc("Noun, budget items to display", "Current year"), QStringLiteral("view-calendar-month"),
-                                       QStringLiteral("t_PERIOD LIKE STRFTIME('%Y', date('now', 'localtime'))||'%'"),
+    ui.kView->getShowWidget()->addItem(QLatin1String("currentYear"), i18nc("Noun, budget items to display", "Current year"), QLatin1String("view-calendar-month"),
+                                       QLatin1String("t_PERIOD LIKE STRFTIME('%Y', date('now', 'localtime'))||'%'"),
                                        QLatin1String(""),
-                                       QStringLiteral("none"),
+                                       QLatin1String("none"),
                                        QLatin1String(""),
-                                       QStringLiteral("all"),
-                                       Qt::META + Qt::Key_3);
-    ui.kView->getShowWidget()->addItem(QStringLiteral("currentMonth"), i18nc("Noun, budget items to display", "Current month"), QStringLiteral("view-calendar-week"),
-                                       QStringLiteral("t_PERIOD=STRFTIME('%Y-%m', date('now', 'localtime'))"),
+                                       QLatin1String("all"),
+                                       Qt::META | Qt::Key_3);
+    ui.kView->getShowWidget()->addItem(QLatin1String("currentMonth"), i18nc("Noun, budget items to display", "Current month"), QLatin1String("view-calendar-week"),
+                                       QLatin1String("t_PERIOD=STRFTIME('%Y-%m', date('now', 'localtime'))"),
                                        QLatin1String(""),
-                                       QStringLiteral("none"),
+                                       QLatin1String("none"),
                                        QLatin1String(""),
-                                       QStringLiteral("all;current"),
-                                       Qt::META + Qt::Key_2);
+                                       QLatin1String("all;current"),
+                                       Qt::META | Qt::Key_2);
     ui.kView->getShowWidget()->addSeparator();
-    ui.kView->getShowWidget()->addItem(QStringLiteral("previousYear"), i18nc("Noun, budget items to display", "Previous year"), QStringLiteral("view-calendar-month"),
-                                       QStringLiteral("t_PERIOD LIKE STRFTIME('%Y', date('now', 'localtime','start of year','-1 day'))||'%'"),
+    ui.kView->getShowWidget()->addItem(QLatin1String("previousYear"), i18nc("Noun, budget items to display", "Previous year"), QLatin1String("view-calendar-month"),
+                                       QLatin1String("t_PERIOD LIKE STRFTIME('%Y', date('now', 'localtime','start of year','-1 day'))||'%'"),
                                        QLatin1String(""),
-                                       QStringLiteral("none"),
+                                       QLatin1String("none"),
                                        QLatin1String(""),
-                                       QStringLiteral("all"),
-                                       Qt::META + Qt::Key_5);
-    ui.kView->getShowWidget()->addItem(QStringLiteral("previousMonth"), i18nc("Noun, budget items to display", "Previous month"), QStringLiteral("view-calendar-week"),
-                                       QStringLiteral("t_PERIOD=STRFTIME('%Y-%m', date('now', 'localtime','start of month','-1 day'))"),
+                                       QLatin1String("all"),
+                                       Qt::META | Qt::Key_5);
+    ui.kView->getShowWidget()->addItem(QLatin1String("previousMonth"), i18nc("Noun, budget items to display", "Previous month"), QLatin1String("view-calendar-week"),
+                                       QLatin1String("t_PERIOD=STRFTIME('%Y-%m', date('now', 'localtime','start of month','-1 day'))"),
                                        QLatin1String(""),
-                                       QStringLiteral("none"),
+                                       QLatin1String("none"),
                                        QLatin1String(""),
-                                       QStringLiteral("all"),
-                                       Qt::META + Qt::Key_4);
-    ui.kView->getShowWidget()->setDefaultState(QStringLiteral("current;currentMonth"));
+                                       QLatin1String("all"),
+                                       Qt::META | Qt::Key_4);
+    ui.kView->getShowWidget()->setDefaultState(QLatin1String("current;currentMonth"));
 
     m_timer.setSingleShot(true);
     connect(&m_timer, &QTimer::timeout, this, &SKGBudgetPluginWidget::refreshInfoZone, Qt::QueuedConnection);
@@ -127,23 +127,23 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
 
     auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
     if (doc != nullptr) {
-        ui.kUnitCmb->addItem(QStringLiteral("%"));
+        ui.kUnitCmb->addItem(QLatin1String("%"));
         ui.kUnitCmb->addItem(doc->getPrimaryUnit().Symbol);
         ui.kUnit->setText(doc->getPrimaryUnit().Symbol);
 
         // Bind transaction view
-        m_objectModel = new SKGObjectModel(doc, QStringLiteral("v_budget_display"), QStringLiteral("1=0"), this, QLatin1String(""), false);
+        m_objectModel = new SKGObjectModel(doc, QLatin1String("v_budget_display"), QLatin1String("1=0"), this, QLatin1String(""), false);
         ui.kView->setModel(m_objectModel);
         ui.kSortButton->setVisible(false);
     }
 
-    connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open")).data(), &QAction::trigger);
+    connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("open")).data(), &QAction::trigger);
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, this, [ = ] {this->onSelectionChanged();});
 
     // Add Standard KDE Icons to buttons to Transactions
-    ui.kModifyBtn->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
-    ui.kAddBtn->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
-    QAction* processAction = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("tool_process_budget_rules"));
+    ui.kModifyBtn->setIcon(SKGServices::fromTheme(QLatin1String("dialog-ok")));
+    ui.kAddBtn->setIcon(SKGServices::fromTheme(QLatin1String("list-add")));
+    QAction* processAction = SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("tool_process_budget_rules"));
     if (processAction != nullptr) {
         ui.kProcessBtn->setIcon(processAction->icon());
         connect(ui.kProcessBtn, &QPushButton::clicked, processAction, &QAction::trigger);
@@ -153,19 +153,19 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.SKGManualSection);
         list.push_back(ui.SKGEditionButtonsSection);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("user-properties")), i18n("Manual"), i18n("Display the edit panel for standard budget"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("user-properties")), i18n("Manual"), i18n("Display the edit panel for standard budget"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.SKGAutoSection);
         list.push_back(ui.SKGEditionButtonsSection);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("games-solve")), i18n("Auto"), i18n("Display the edit panel for automatic budgets"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("games-solve")), i18n("Auto"), i18n("Display the edit panel for automatic budgets"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.SKGRuleSection);
         list.push_back(ui.SKGEditionButtonsSection);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("run-build")), i18n("Rules"), i18n("Display the edit panel for rules"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("run-build")), i18n("Rules"), i18n("Display the edit panel for rules"), list);
     }
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGBudgetPluginWidget::onBtnModeClicked, Qt::QueuedConnection);
     connect(ui.kAddBtn, &QPushButton::clicked, this, &SKGBudgetPluginWidget::onAddClicked);
@@ -185,15 +185,9 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
     connect(ui.kUpBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onUp);
     connect(ui.kDownBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onDown);
     connect(ui.kBottomBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onBottom);
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    connect(ui.kYearAuto, static_cast<void (QSpinBox::*)(const QString&)>(&QSpinBox::valueChanged), this, [ = ](const QString & text) {
-        ui.kRemovePrevious->setText(i18nc("Option", "Remove existing budgets for %1", text));
-    });
-#else
     connect(ui.kYearAuto, &QSpinBox::textChanged, this, [ = ](const QString & text) {
         ui.kRemovePrevious->setText(i18nc("Option", "Remove existing budgets for %1", text));
     });
-#endif
     ui.kYearAuto->setValue(QDate::currentDate().year());
 
     ui.kWidgetSelector->setSelectedMode(0);
@@ -231,17 +225,17 @@ bool SKGBudgetPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 QString SKGBudgetPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
-    if ((m_objectModel != nullptr) && m_objectModel->getRealTable() == QStringLiteral("budget")) {
-        root.setAttribute(QStringLiteral("view"), ui.kView->getState());
-        root.setAttribute(QStringLiteral("viewRule"), m_viewRule);
+    root.setAttribute(QLatin1String("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
+    if ((m_objectModel != nullptr) && m_objectModel->getRealTable() == QLatin1String("budget")) {
+        root.setAttribute(QLatin1String("view"), ui.kView->getState());
+        root.setAttribute(QLatin1String("viewRule"), m_viewRule);
     } else {
-        root.setAttribute(QStringLiteral("view"), m_viewBudget);
-        root.setAttribute(QStringLiteral("viewRule"), ui.kView->getState());
+        root.setAttribute(QLatin1String("view"), m_viewBudget);
+        root.setAttribute(QLatin1String("viewRule"), ui.kView->getState());
     }
 
     return doc.toString();
@@ -250,20 +244,20 @@ QString SKGBudgetPluginWidget::getState()
 void SKGBudgetPluginWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString currentPage = root.attribute(QStringLiteral("currentPage"));
+    QString currentPage = root.attribute(QLatin1String("currentPage"));
     if (currentPage.isEmpty()) {
         currentPage = '0';
     }
 
     ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
 
-    m_viewBudget = root.attribute(QStringLiteral("view"));
-    m_viewRule = root.attribute(QStringLiteral("viewRule"));
-    if ((m_objectModel != nullptr) && m_objectModel->getRealTable() == QStringLiteral("budget")) {
+    m_viewBudget = root.attribute(QLatin1String("view"));
+    m_viewRule = root.attribute(QLatin1String("viewRule"));
+    if ((m_objectModel != nullptr) && m_objectModel->getRealTable() == QLatin1String("budget")) {
         ui.kView->setState(m_viewBudget);
     } else {
         ui.kView->setState(m_viewRule);
@@ -272,7 +266,7 @@ void SKGBudgetPluginWidget::setState(const QString& iState)
 
 QString SKGBudgetPluginWidget::getDefaultStateAttribute()
 {
-    return QStringLiteral("SKGBUDGET_DEFAULT_PARAMETERS");
+    return QLatin1String("SKGBUDGET_DEFAULT_PARAMETERS");
 }
 
 QWidget* SKGBudgetPluginWidget::mainWidget()
@@ -297,15 +291,15 @@ void SKGBudgetPluginWidget::dataModified(const QString& iTableName, int iIdTrans
     Q_UNUSED(iIdTransaction)
 
     // Refresh widgets
-    if (iTableName == QStringLiteral("budget") || iTableName.isEmpty()) {
+    if (iTableName == QLatin1String("budget") || iTableName.isEmpty()) {
         // Refresh info area
         m_timer.start(300);
     }
 
     if (!iLightTransaction) {
-        if (iTableName == QStringLiteral("category") || iTableName.isEmpty()) {
+        if (iTableName == QLatin1String("category") || iTableName.isEmpty()) {
             // Set type category
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kCategoryEdit << ui.kCategoryRule << ui.kCategoryTransfer, getDocument(), QStringLiteral("category"), QStringLiteral("t_fullname"), QLatin1String(""));
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kCategoryEdit << ui.kCategoryRule << ui.kCategoryTransfer, getDocument(), QLatin1String("category"), QLatin1String("t_fullname"), QLatin1String(""));
         }
     }
 }
@@ -317,17 +311,17 @@ void SKGBudgetPluginWidget::onBtnModeClicked(int mode)
         return;
     }
 
-    if (mode == 2 && m_objectModel->getTable() != QStringLiteral("v_budgetrule_display")) {
+    if (mode == 2 && m_objectModel->getTable() != QLatin1String("v_budgetrule_display")) {
         ui.kView->getShowWidget()->setEnabled(false);
         m_viewBudget = ui.kView->getState();
         m_objectModel->setFilter(QLatin1String(""));
-        m_objectModel->setTable(QStringLiteral("v_budgetrule_display"));
+        m_objectModel->setTable(QLatin1String("v_budgetrule_display"));
         ui.kSortButton->setVisible(true);
         ui.kView->setState(m_viewRule);
-    } else if (mode != 2 && m_objectModel->getTable() != QStringLiteral("v_budget_display")) {
+    } else if (mode != 2 && m_objectModel->getTable() != QLatin1String("v_budget_display")) {
         ui.kView->getShowWidget()->setEnabled(true);
         m_viewRule = ui.kView->getState();
-        m_objectModel->setTable(QStringLiteral("v_budget_display"));
+        m_objectModel->setTable(QLatin1String("v_budget_display"));
         ui.kSortButton->setVisible(false);
         ui.kView->setState(m_viewBudget);
     }
@@ -503,10 +497,10 @@ SKGError SKGBudgetPluginWidget::updateBudget(SKGBudgetObject& iBudget, int iMont
     // Is the sign forced ?
     if (ui.kAmountEdit->sign() == 0) {
         // No
-        SKGObjectBase cat2(cat.getDocument(), QStringLiteral("v_category_display"), cat.getID());
+        SKGObjectBase cat2(cat.getDocument(), QLatin1String("v_category_display"), cat.getID());
 
         // Are we able to find to sign with the category ?
-        if (cat2.getAttribute(QStringLiteral("t_TYPEEXPENSE")) == QStringLiteral("-")) {
+        if (cat2.getAttribute(QLatin1String("t_TYPEEXPENSE")) == QLatin1String("-")) {
             val = -val;
         }
     }
@@ -569,12 +563,12 @@ void SKGBudgetPluginWidget::onSelectionChanged()
     int nb = objs.count();
     int mode = ui.kWidgetSelector->getSelectedMode();
     if (nb != 0) {
-        if (m_objectModel->getRealTable() == QStringLiteral("budget")) {
+        if (m_objectModel->getRealTable() == QLatin1String("budget")) {
             SKGBudgetObject budget(objs.at(0));
             ui.kYear->setValue(budget.getYear());
             ui.kMonth->setValue(budget.getMonth());
             ui.kAmountEdit->setValue(budget.getBudgetedAmount());
-            ui.kCategoryEdit->setText(budget.getAttribute(QStringLiteral("t_CATEGORY")));
+            ui.kCategoryEdit->setText(budget.getAttribute(QLatin1String("t_CATEGORY")));
             ui.kPeriod->setCurrentIndex(budget.getMonth() == 0 ? 1 : 2);  // Set yearly or individual
             ui.kIncludingSubCategories->setChecked(budget.isSubCategoriesInclusionEnabled());
 
@@ -588,9 +582,9 @@ void SKGBudgetPluginWidget::onSelectionChanged()
             ui.kMonthCheck->setChecked(rule.isMonthConditionEnabled());
             ui.kMonthRule->setValue(rule.getBudgetMonth());
             ui.kCategoryCheck->setChecked(rule.isCategoryConditionEnabled());
-            ui.kCategoryRule->setText(rule.getAttribute(QStringLiteral("t_CATEGORYCONDITION")));
+            ui.kCategoryRule->setText(rule.getAttribute(QLatin1String("t_CATEGORYCONDITION")));
             ui.kCategoryTransferCheck->setChecked(rule.isCategoryChangeEnabled());
-            ui.kCategoryTransfer->setText(rule.getAttribute(QStringLiteral("t_CATEGORY")));
+            ui.kCategoryTransfer->setText(rule.getAttribute(QLatin1String("t_CATEGORY")));
             ui.kUnitCmb->setCurrentIndex(rule.isAbolute() ? 1 : 0);
             ui.kAmountEdit2->setValue(rule.getQuantity());
             ui.kModeCmb->setCurrentIndex(ui.kModeCmb->findData(static_cast<int>(rule.getTransferMode())));
@@ -672,7 +666,7 @@ void SKGBudgetPluginWidget::onTop()
 
             double order = 1;
             SKGStringListList result;
-            err = getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT min(f_sortorder) from budgetrule"), result);
+            err = getDocument()->executeSelectSqliteOrder(QLatin1String("SELECT min(f_sortorder) from budgetrule"), result);
             if (!err && result.count() == 2) {
                 order = SKGServices::stringToDouble(result.at(1).at(0)) - 1;
             }
@@ -800,7 +794,7 @@ void SKGBudgetPluginWidget::onBottom()
 
             double order = 1;
             SKGStringListList result;
-            err = getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT max(f_sortorder) from budgetrule"), result);
+            err = getDocument()->executeSelectSqliteOrder(QLatin1String("SELECT max(f_sortorder) from budgetrule"), result);
             if (!err && result.count() == 2) {
                 order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
             }
