@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -26,7 +26,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGCalculatorPlugin, "metadata.json")
 
-SKGCalculatorPlugin::SKGCalculatorPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
+SKGCalculatorPlugin::SKGCalculatorPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -47,8 +49,8 @@ bool SKGCalculatorPlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skrooge_calculator"), title());
-    setXMLFile(QStringLiteral("skrooge_calculator.rc"));
+    setComponentName(QLatin1String("skrooge_calculator"), title());
+    setXMLFile(QLatin1String("skrooge_calculator.rc"));
 
     // Create yours actions here
     return true;
@@ -69,20 +71,20 @@ SKGBoardWidget* SKGCalculatorPlugin::getDashboardWidget(int iIndex)
 {
     Q_UNUSED(iIndex)
     auto listForFilter = QStringList()
-                         << QStringLiteral("t_name")
-                         << QStringLiteral("t_number")
-                         << QStringLiteral("t_agency_number")
-                         << QStringLiteral("t_agency_address")
-                         << QStringLiteral("t_comment")
-                         << QStringLiteral("t_bookmarked")
-                         << QStringLiteral("t_TYPENLS")
-                         << QStringLiteral("t_BANK")
-                         << QStringLiteral("t_BANK_NUMBER");
+                         << QLatin1String("t_name")
+                         << QLatin1String("t_number")
+                         << QLatin1String("t_agency_number")
+                         << QLatin1String("t_agency_address")
+                         << QLatin1String("t_comment")
+                         << QLatin1String("t_bookmarked")
+                         << QLatin1String("t_TYPENLS")
+                         << QLatin1String("t_BANK")
+                         << QLatin1String("t_BANK_NUMBER");
 
     return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
-                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/interests.qml")),
-                                  QStringList() << QStringLiteral("v_account_display") << QStringLiteral("interest"),
+                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/interests.qml")),
+                                  QStringList() << QLatin1String("v_account_display") << QLatin1String("interest"),
                                   SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_YEARS,
                                   listForFilter);
 }
@@ -100,7 +102,7 @@ QString SKGCalculatorPlugin::title() const
 
 QString SKGCalculatorPlugin::icon() const
 {
-    return QStringLiteral("accessories-calculator");
+    return QLatin1String("accessories-calculator");
 }
 
 QString SKGCalculatorPlugin::toolTip() const
@@ -130,9 +132,9 @@ SKGAdviceList SKGCalculatorPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGAdviceList output;
 
     // Search investment accounts without interest rate
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgcalculatorplugin_nointerest"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgcalculatorplugin_nointerest"))) {
         SKGObjectBase::SKGListSKGObjectBase accounts;
-        m_currentBankDocument->getObjects(QStringLiteral("account"), QStringLiteral("t_type='I' AND t_close='N' AND NOT EXISTS (SELECT 1 FROM interest WHERE interest.rd_account_id=account.id)"), accounts);
+        m_currentBankDocument->getObjects(QLatin1String("account"), QLatin1String("t_type='I' AND t_close='N' AND NOT EXISTS (SELECT 1 FROM interest WHERE interest.rd_account_id=account.id)"), accounts);
         int nb = accounts.count();
         SKGAdvice::SKGAdviceActionList autoCorrections;
         for (int i = 0; i < nb; ++i) {
@@ -146,7 +148,7 @@ SKGAdviceList SKGCalculatorPlugin::advice(const QStringList& iIgnoredAdvice)
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Link allowing user to open a new tab for defining interests parameters", "Open interest page");
-                a.IconName = QStringLiteral("quickopen");
+                a.IconName = QLatin1String("quickopen");
                 a.IsRecommended = false;
                 autoCorrections.push_back(a);
             }
