@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -38,18 +38,18 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(QWidget* iParent, SKGDocume
 
     ui.setupUi(this);
     ui.kUnitEdit->setDocument(iDocument);
-    ui.kUnitEdit->setWhereClauseCondition(QStringLiteral("t_type IN ('1','2','C')"));
+    ui.kUnitEdit->setWhereClauseCondition(QLatin1String("t_type IN ('1','2','C')"));
 
-    ui.kUpdate->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
-    ui.kAdd->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
+    ui.kUpdate->setIcon(SKGServices::fromTheme(QLatin1String("dialog-ok")));
+    ui.kAdd->setIcon(SKGServices::fromTheme(QLatin1String("list-add")));
 
-    ui.kLoadSummaryTitle->setIcon(SKGServices::fromTheme(QStringLiteral("configure")), KTitleWidget::ImageLeft);
-    ui.kPaymentSummaryTitle->setIcon(SKGServices::fromTheme(QStringLiteral("bookmarks")), KTitleWidget::ImageLeft);
-    ui.kAmortizationTableTitle->setIcon(SKGServices::fromTheme(QStringLiteral("view-pim-calendar")), KTitleWidget::ImageLeft);
+    ui.kLoadSummaryTitle->setIcon(SKGServices::fromTheme(QLatin1String("configure")), KTitleWidget::ImageLeft);
+    ui.kPaymentSummaryTitle->setIcon(SKGServices::fromTheme(QLatin1String("bookmarks")), KTitleWidget::ImageLeft);
+    ui.kAmortizationTableTitle->setIcon(SKGServices::fromTheme(QLatin1String("view-pim-calendar")), KTitleWidget::ImageLeft);
 
-    ui.kInterestResultsTitle->setIcon(SKGServices::fromTheme(QStringLiteral("bookmarks")), KTitleWidget::ImageLeft);
-    ui.kInterestValuesTitle->setIcon(SKGServices::fromTheme(QStringLiteral("configure")), KTitleWidget::ImageLeft);
-    ui.kDefineValueTitle->setIcon(SKGServices::fromTheme(QStringLiteral("configure")), KTitleWidget::ImageLeft);
+    ui.kInterestResultsTitle->setIcon(SKGServices::fromTheme(QLatin1String("bookmarks")), KTitleWidget::ImageLeft);
+    ui.kInterestValuesTitle->setIcon(SKGServices::fromTheme(QLatin1String("configure")), KTitleWidget::ImageLeft);
+    ui.kDefineValueTitle->setIcon(SKGServices::fromTheme(QLatin1String("configure")), KTitleWidget::ImageLeft);
 
     ui.kCreditValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
     ui.kDebitValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
@@ -67,15 +67,15 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(QWidget* iParent, SKGDocume
     SKGWidgetSelector::SKGListQWidget list;
     list.push_back(ui.kInterestFrm);
     list.push_back(ui.kBtnFrm);
-    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("taxes-finances")), i18n("Interest"), i18n("Interests calculator"), list);
-    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("accessories-calculator")), i18n("Amortization Table"), i18n("Loan amortization table calculator"), ui.kAmortizationFrm);
+    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("taxes-finances")), i18n("Interest"), i18n("Interests calculator"), list);
+    ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("accessories-calculator")), i18n("Amortization Table"), i18n("Loan amortization table calculator"), ui.kAmortizationFrm);
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGCalculatorPluginWidget::onBtnModeClicked);
 
     // Bind account creation view
-    m_objectModel = new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_interest"), QLatin1String(""), this, QLatin1String(""), false);
+    m_objectModel = new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("v_interest"), QLatin1String(""), this, QLatin1String(""), false);
     ui.kInterestView->setModel(m_objectModel);
 
-    auto resultModel = new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("interest_result"), QLatin1String(""), this, QLatin1String(""), false);
+    auto resultModel = new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("interest_result"), QLatin1String(""), this, QLatin1String(""), false);
     ui.kInterestResultTable->setModel(resultModel);
 
     connect(ui.kInterestView, &SKGTableView::selectionChangedDelayed, this, &SKGCalculatorPluginWidget::onSelectionChanged);
@@ -133,24 +133,24 @@ bool SKGCalculatorPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 QString SKGCalculatorPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
-    root.setAttribute(QStringLiteral("account"), ui.kDisplayAccountCombo->currentText());
-    root.setAttribute(QStringLiteral("year"), ui.KYearEdit->text());
+    root.setAttribute(QLatin1String("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
+    root.setAttribute(QLatin1String("account"), ui.kDisplayAccountCombo->currentText());
+    root.setAttribute(QLatin1String("year"), ui.KYearEdit->text());
 
-    root.setAttribute(QStringLiteral("amortizationLoan"), ui.kLoanEdit->text());
-    root.setAttribute(QStringLiteral("amortizationUnit"), ui.kUnitEdit->text());
-    root.setAttribute(QStringLiteral("amortizationRate"), SKGServices::doubleToString(ui.kAnnualRateEdit->value()));
-    root.setAttribute(QStringLiteral("amortizationLenght"), SKGServices::intToString(ui.kLenghtEdit->value()));
-    root.setAttribute(QStringLiteral("amortizationInsuranceRate"), SKGServices::doubleToString(ui.kInsuranceRateEdit->value()));
+    root.setAttribute(QLatin1String("amortizationLoan"), ui.kLoanEdit->text());
+    root.setAttribute(QLatin1String("amortizationUnit"), ui.kUnitEdit->text());
+    root.setAttribute(QLatin1String("amortizationRate"), SKGServices::doubleToString(ui.kAnnualRateEdit->value()));
+    root.setAttribute(QLatin1String("amortizationLenght"), SKGServices::intToString(ui.kLenghtEdit->value()));
+    root.setAttribute(QLatin1String("amortizationInsuranceRate"), SKGServices::doubleToString(ui.kInsuranceRateEdit->value()));
 
 
     // Memorize table settings
-    root.setAttribute(QStringLiteral("view"), ui.kInterestView->getState());
-    root.setAttribute(QStringLiteral("viewResult"), ui.kInterestResultTable->getState());
+    root.setAttribute(QLatin1String("view"), ui.kInterestView->getState());
+    root.setAttribute(QLatin1String("viewResult"), ui.kInterestResultTable->getState());
 
     return doc.toString();
 }
@@ -158,18 +158,18 @@ QString SKGCalculatorPluginWidget::getState()
 void SKGCalculatorPluginWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString account = root.attribute(QStringLiteral("account"));
-    QString currentPage = root.attribute(QStringLiteral("currentPage"));
-    QString year = root.attribute(QStringLiteral("year"));
-    QString amortizationLoan = root.attribute(QStringLiteral("amortizationLoan"));
-    QString amortizationUnit = root.attribute(QStringLiteral("amortizationUnit"));
-    QString amortizationRate = root.attribute(QStringLiteral("amortizationRate"));
-    QString amortizationInsuranceRate = root.attribute(QStringLiteral("amortizationInsuranceRate"));
-    QString amortizationLenght = root.attribute(QStringLiteral("amortizationLenght"));
+    QString account = root.attribute(QLatin1String("account"));
+    QString currentPage = root.attribute(QLatin1String("currentPage"));
+    QString year = root.attribute(QLatin1String("year"));
+    QString amortizationLoan = root.attribute(QLatin1String("amortizationLoan"));
+    QString amortizationUnit = root.attribute(QLatin1String("amortizationUnit"));
+    QString amortizationRate = root.attribute(QLatin1String("amortizationRate"));
+    QString amortizationInsuranceRate = root.attribute(QLatin1String("amortizationInsuranceRate"));
+    QString amortizationLenght = root.attribute(QLatin1String("amortizationLenght"));
 
     if (!currentPage.isEmpty()) {
         ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
@@ -207,13 +207,13 @@ void SKGCalculatorPluginWidget::setState(const QString& iState)
     }
 
     // !!! Must be done here after onFilterChanged
-    ui.kInterestView->setState(root.attribute(QStringLiteral("view")));
-    ui.kInterestResultTable->setState(root.attribute(QStringLiteral("viewResult")));
+    ui.kInterestView->setState(root.attribute(QLatin1String("view")));
+    ui.kInterestResultTable->setState(root.attribute(QLatin1String("viewResult")));
 }
 
 QString SKGCalculatorPluginWidget::getDefaultStateAttribute()
 {
-    return QStringLiteral("SKGCALCULATOR_DEFAULT_PARAMETERS");
+    return QLatin1String("SKGCALCULATOR_DEFAULT_PARAMETERS");
 }
 
 void SKGCalculatorPluginWidget::onBtnModeClicked(int mode)
@@ -262,7 +262,7 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
     // Refresh widgets
     QSqlDatabase* db = getDocument()->getMainDatabase();
     setEnabled(db != nullptr);
-    if (db != nullptr && (iTableName == QStringLiteral("interest") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QLatin1String("interest") || iTableName.isEmpty())) {
         // Correction bug 2299394 vvv
         if (ui.kInterestView->isAutoResized()) {
             ui.kInterestView->resizeColumnsToContentsDelayed();
@@ -276,12 +276,12 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
 
     // Refresh interest parameter view
     QString current = ui.kDisplayAccountCombo->currentText();
-    if (db != nullptr && (iTableName == QStringLiteral("v_account_display") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QLatin1String("v_account_display") || iTableName.isEmpty())) {
         // Clear
         ui.kDisplayAccountCombo->clear();
 
         SKGStringListList listAccount;
-        getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT t_ICON, t_name from v_account_display where t_close='N' order by t_name"), listAccount);
+        getDocument()->executeSelectSqliteOrder(QLatin1String("SELECT t_ICON, t_name from v_account_display where t_close='N' order by t_name"), listAccount);
 
         int nbAccounts = listAccount.count();
         if (nbAccounts >= 0) {
@@ -306,14 +306,14 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
     }
 
     // Fill years
-    if (db != nullptr && (iTableName == QStringLiteral("v_operation_display") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QLatin1String("v_operation_display") || iTableName.isEmpty())) {
         disconnect(ui.KYearEdit, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGCalculatorPluginWidget::onFilterChanged);
 
         int lastYear = QDate::currentDate().year();
         int firstYear = lastYear;
 
         QStringList list;
-        getDocument()->getDistinctValues(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEYEAR"), QLatin1String(""), list);
+        getDocument()->getDistinctValues(QLatin1String("v_operation_display"), QLatin1String("d_DATEYEAR"), QLatin1String(""), list);
         if (!list.isEmpty()) {
             firstYear = SKGServices::stringToInt(list.at(0));
         }
@@ -332,7 +332,7 @@ void SKGCalculatorPluginWidget::dataModified(const QString& iTableName, int iIdT
         connect(ui.KYearEdit, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentTextChanged), this, &SKGCalculatorPluginWidget::onFilterChanged);
     }
     // Refresh computation
-    if (db != nullptr && (iTableName == QStringLiteral("interest") || iTableName == QStringLiteral("account") || iTableName.isEmpty())) {
+    if (db != nullptr && (iTableName == QLatin1String("interest") || iTableName == QLatin1String("account") || iTableName.isEmpty())) {
         computeInterest();
     }
     QApplication::restoreOverrideCursor();
