@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -34,8 +34,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGCategoriesPlugin, "metadata.json")
 
-SKGCategoriesPlugin::SKGCategoriesPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
-    : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
+SKGCategoriesPlugin::SKGCategoriesPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -56,32 +57,32 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skrooge_categories"), title());
-    setXMLFile(QStringLiteral("skrooge_categories.rc"));
+    setComponentName(QLatin1String("skrooge_categories"), title());
+    setXMLFile(QLatin1String("skrooge_categories.rc"));
 
     // Import categories
     QStringList overlaycategories;
     overlaycategories.push_back(icon());
 
     QStringList overlaydelete;
-    overlaydelete.push_back(QStringLiteral("edit-delete"));
+    overlaydelete.push_back(QLatin1String("edit-delete"));
 
-    auto contextMenu = new KSelectAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlaycategories), i18nc("Verb", "Import categories"), this);
-    registerGlobalAction(QStringLiteral("import_categories"), contextMenu);
+    auto contextMenu = new KSelectAction(SKGServices::fromTheme(QLatin1String("document-import"), overlaycategories), i18nc("Verb", "Import categories"), this);
+    registerGlobalAction(QLatin1String("import_categories"), contextMenu);
 
-    QAction* actImportStdCat = contextMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlaycategories), i18nc("Verb", "Import standard categories"));
+    QAction* actImportStdCat = contextMenu->addAction(SKGServices::fromTheme(QLatin1String("document-import"), overlaycategories), i18nc("Verb", "Import standard categories"));
     actImportStdCat->setCheckable(false);
     connect(actImportStdCat, &QAction::triggered, this, &SKGCategoriesPlugin::importStandardCategories);
-    registerGlobalAction(QStringLiteral("import_standard_categories"), actImportStdCat);
+    registerGlobalAction(QLatin1String("import_standard_categories"), actImportStdCat);
 
-    const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "skrooge/categories/" % QLocale().name().split(QStringLiteral("_")).at(0), QStandardPaths::LocateDirectory);
+    const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "skrooge/categories/" % QLocale().name().split(QLatin1String("_")).at(0), QStandardPaths::LocateDirectory);
     for (const auto& dir : dirs) {
-        QDirIterator it(dir, QStringList() << QStringLiteral("*.qif"));
+        QDirIterator it(dir, QStringList() << QLatin1String("*.qif"));
         while (it.hasNext()) {
             QString cat = it.next();
 
             QString name = QFileInfo(cat).baseName().replace('_', ' ');
-            QAction* act = contextMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-import"), overlaycategories), i18nc("Verb", "Import categories [%1]", name));
+            QAction* act = contextMenu->addAction(SKGServices::fromTheme(QLatin1String("document-import"), overlaycategories), i18nc("Verb", "Import categories [%1]", name));
             act->setCheckable(false);
             act->setData(cat);
             connect(act, &QAction::triggered, this, &SKGCategoriesPlugin::importCategories);
@@ -91,18 +92,18 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument)
 
     auto deleteUnusedCategoriesAction = new QAction(SKGServices::fromTheme(icon(), overlaydelete), i18nc("Verb", "Delete unused categories"), this);
     connect(deleteUnusedCategoriesAction, &QAction::triggered, this, &SKGCategoriesPlugin::deleteUnusedCategories);
-    registerGlobalAction(QStringLiteral("clean_delete_unused_categories"), deleteUnusedCategoriesAction);
+    registerGlobalAction(QLatin1String("clean_delete_unused_categories"), deleteUnusedCategoriesAction);
 
     // ------------
     auto actTmp = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb", "Open similar categories…"), this);
     actTmp->setData(QString("skg://skrooge_categories_plugin/?title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Similar categories")) %
-                            "&whereClause=" % SKGServices::encodeForUrl(QStringLiteral("id IN (SELECT category.id FROM category, ("
+                            "&whereClause=" % SKGServices::encodeForUrl(QLatin1String("id IN (SELECT category.id FROM category, ("
                                     "SELECT * FROM category C WHERE EXISTS (SELECT 1 FROM category p2 WHERE p2.id<>C.id AND upper(p2.t_fullname)=upper(C.t_fullname) AND p2.t_fullname<>C.t_fullname)) "
                                     "AS C WHERE category.t_fullname=C.t_fullname OR C.t_fullname LIKE category.t_fullname||' > %')"))));
     connect(actTmp, &QAction::triggered, SKGMainPanel::getMainPanel(),  [ = ]() {
         SKGMainPanel::getMainPanel()->SKGMainPanel::openPage();
     });
-    registerGlobalAction(QStringLiteral("view_open_similar_categories"), actTmp);
+    registerGlobalAction(QLatin1String("view_open_similar_categories"), actTmp);
     /*TODO
     WITH RECURSIVE
     cat(t_fullname,id, level) AS (
@@ -143,25 +144,25 @@ SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
     if (iIndex == 0)  {
         return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex),
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_period_table.qml")),
-                                      QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::ALL_PERIODS);
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/categories_period_table.qml")),
+                                      QStringList() << QLatin1String("v_suboperation_consolidated"), SKGSimplePeriodEdit::ALL_PERIODS);
     }
     if (iIndex == 1) {
         return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex) % " - %1",
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_variations.qml")),
-                                      QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS);
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/categories_variations.qml")),
+                                      QStringList() << QLatin1String("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS);
     }
     if (iIndex == 2) {
         return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex) % " - %1",
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/budget_table.qml")),
-                                      QStringList() << QStringLiteral("v_budget"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_MONTHS);
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/budget_table.qml")),
+                                      QStringList() << QLatin1String("v_budget"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_MONTHS);
     }
     return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex) % " - %1",
-                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_variations_issues.qml")),
-                                  QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS);
+                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/categories_variations_issues.qml")),
+                                  QStringList() << QLatin1String("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS);
 }
 
 void SKGCategoriesPlugin::refresh()
@@ -175,7 +176,7 @@ void SKGCategoriesPlugin::refresh()
                 m_docUniqueIdentifier = std::move(doc_id);
 
                 bool exist = false;
-                SKGError err = m_currentBankDocument->existObjects(QStringLiteral("category"), QString(), exist);
+                SKGError err = m_currentBankDocument->existObjects(QLatin1String("category"), QString(), exist);
                 if (!err && !exist) {
                     importStandardCategories();
 
@@ -276,7 +277,7 @@ QString SKGCategoriesPlugin::title() const
 
 QString SKGCategoriesPlugin::icon() const
 {
-    return QStringLiteral("view-categories");
+    return QLatin1String("view-categories");
 }
 
 QString SKGCategoriesPlugin::toolTip() const
@@ -307,19 +308,19 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEINFUNC(10)
     SKGAdviceList output;
     // Check unused categories
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgcategoriesplugin_unused"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgcategoriesplugin_unused"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects(QStringLiteral("v_category_used2"), QStringLiteral("t_ISUSEDCASCADE='N'"), exist);
+        m_currentBankDocument->existObjects(QLatin1String("v_category_used2"), QLatin1String("t_ISUSEDCASCADE='N'"), exist);
         if (exist) {
             SKGAdvice ad;
-            ad.setUUID(QStringLiteral("skgcategoriesplugin_unused"));
+            ad.setUUID(QLatin1String("skgcategoriesplugin_unused"));
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused categories"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing categories that have no transactions."));
             SKGAdvice::SKGAdviceActionList autoCorrections;
             {
                 SKGAdvice::SKGAdviceAction a;
-                a.Title = QStringLiteral("skg://clean_delete_unused_categories");
+                a.Title = QLatin1String("skg://clean_delete_unused_categories");
                 a.IsRecommended = true;
                 autoCorrections.push_back(a);
             }
@@ -329,10 +330,10 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Check transactions not validated
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgmonthlyplugin_maincategoriesvariation"))) {
-        QString month = QDate::currentDate().toString(QStringLiteral("yyyy-MM"));
+    if (!iIgnoredAdvice.contains(QLatin1String("skgmonthlyplugin_maincategoriesvariation"))) {
+        QString month = QDate::currentDate().toString(QLatin1String("yyyy-MM"));
         QDate datepreviousmonth = QDate::currentDate().addDays(-QDate::currentDate().day());
-        QString previousmonth = datepreviousmonth.toString(QStringLiteral("yyyy-MM"));
+        QString previousmonth = datepreviousmonth.toString(QLatin1String("yyyy-MM"));
 
         QStringList listCategories;
         QStringList listVariations = m_currentBankDocument->get5MainCategoriesVariationList(month, previousmonth, true, &listCategories);
@@ -349,7 +350,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Open sub transactions with category containing '%1'", listCategories.at(i));
-                a.IconName = QStringLiteral("quickopen");
+                a.IconName = QLatin1String("quickopen");
                 a.IsRecommended = false;
                 autoCorrections.push_back(a);
             }
@@ -359,19 +360,19 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Check categories with different case
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgcategoriesplugin_case"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgcategoriesplugin_case"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects(QStringLiteral("category"), QStringLiteral("EXISTS (SELECT 1 FROM category p2 WHERE p2.id<>category.id AND upper(p2.t_fullname)=upper(category.t_fullname) AND p2.t_fullname<>category.t_fullname)"), exist);
+        m_currentBankDocument->existObjects(QLatin1String("category"), QLatin1String("EXISTS (SELECT 1 FROM category p2 WHERE p2.id<>category.id AND upper(p2.t_fullname)=upper(category.t_fullname) AND p2.t_fullname<>category.t_fullname)"), exist);
         if (exist) {
             SKGAdvice ad;
-            ad.setUUID(QStringLiteral("skgcategoriesplugin_case"));
+            ad.setUUID(QLatin1String("skgcategoriesplugin_case"));
             ad.setPriority(3);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Some categories seem to be identical"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Some categories seem to be identical but with different syntax. They could be merged."));
             SKGAdvice::SKGAdviceActionList autoCorrections;
             {
                 SKGAdvice::SKGAdviceAction a;
-                a.Title = QStringLiteral("skg://view_open_similar_categories");
+                a.Title = QLatin1String("skg://view_open_similar_categories");
                 a.IsRecommended = false;
                 autoCorrections.push_back(a);
             }
@@ -387,11 +388,11 @@ SKGError SKGCategoriesPlugin::executeAdviceCorrection(const QString& iAdviceIden
     if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgmonthlyplugin_maincategoriesvariation|"))) {
         // Get parameters
         QString category = iAdviceIdentifier.right(iAdviceIdentifier.length() - 41);
-        QString month = QDate::currentDate().toString(QStringLiteral("yyyy-MM"));
+        QString month = QDate::currentDate().toString(QLatin1String("yyyy-MM"));
 
         // Call transaction plugin
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=" % icon() % "&operationTable=v_suboperation_consolidated&title=" %
-                                               SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub transactions with category containing '%1'",  category)) % "&operationWhereClause=" % SKGServices::encodeForUrl("d_DATEMONTH='" % month % "' AND t_REALCATEGORY='" % SKGServices::stringToSqlString(category) % '\''));
+                                               SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub transactions with category containing '%1'",  category)) % "&operationWhereClause=" % SKGServices::encodeForUrl("d_DATEMONTH='" % month % "' AND t_REALCATEGORY='" % SKGServices::stringToSqlString(category) % QLatin1Char('\'')));
         return SKGError();
     }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
@@ -405,7 +406,7 @@ void SKGCategoriesPlugin::deleteUnusedCategories() const
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused categories"), err)
 
         QStringList categoriesUsed;
-        err = m_currentBankDocument->getDistinctValues(QStringLiteral("category"), QStringLiteral("t_fullname"), QStringLiteral("t_fullname in ("
+        err = m_currentBankDocument->getDistinctValues(QLatin1String("category"), QLatin1String("t_fullname"), QLatin1String("t_fullname in ("
                 "SELECT DISTINCT(category.t_fullname) FROM category, suboperation WHERE suboperation.r_category_id=category.id UNION ALL "
                 "SELECT DISTINCT(category.t_fullname) FROM category, budget WHERE budget.rc_category_id=category.id UNION ALL "
                 "SELECT DISTINCT(category.t_fullname) FROM category, budgetrule WHERE budgetrule.rc_category_id=category.id UNION ALL "
@@ -423,9 +424,9 @@ void SKGCategoriesPlugin::deleteUnusedCategories() const
         IFOK(err) {
             QString sql;
             if (!categoriesUsed.isEmpty()) {
-                sql = "DELETE FROM category WHERE t_fullname NOT IN ('" % categoriesUsed.join(QStringLiteral("','")) % "')";
+                sql = "DELETE FROM category WHERE t_fullname NOT IN ('" % categoriesUsed.join(QLatin1String("','")) % "')";
             } else {
-                sql = QStringLiteral("DELETE FROM category");
+                sql = QLatin1String("DELETE FROM category");
             }
             err = m_currentBankDocument->executeSqliteOrder(sql);
         }
