@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGOPERATIONPLUGIN_H
@@ -28,7 +28,7 @@ public:
     /**
      * Default Constructor
      */
-    explicit SKGOperationPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
+    explicit SKGOperationPlugin(QWidget* iWidget, QObject* iParent, const KPluginMetaData& metaData, const QVariantList& iArg);
 
     /**
      * Default Destructor
@@ -148,6 +148,7 @@ private Q_SLOTS:
     void onDuplicate();
     void onCreateTemplate();
     void onSwitchToMarked();
+    void onSwitchToChecked();
     void onOpenOperations();
     void onGroupOperation();
     void onUngroupOperation();
