@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -43,11 +43,11 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
     newSizePolicy.setHorizontalStretch(0);
     newSizePolicy.setVerticalStretch(0);
 
-    if (index.column() == m_listAttributes.indexOf(QStringLiteral("t_category"))) {
+    if (index.column() == m_listAttributes.indexOf(QLatin1String("t_category"))) {
         auto editor = new SKGComboBox(iParent);
         editor->setEditable(true);
         if (m_document != nullptr) {
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << editor, m_document, QStringLiteral("category"), QStringLiteral("t_fullname"), QStringLiteral("t_close='N'"));
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << editor, m_document, QLatin1String("category"), QLatin1String("t_fullname"), QLatin1String("t_close='N'"));
         }
         editor->setSizePolicy(newSizePolicy);
         editor->setSizeAdjustPolicy(QComboBox::AdjustToContents);
@@ -55,11 +55,11 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
 
         return editor;
     }
-    if (index.column() == m_listAttributes.indexOf(QStringLiteral("t_comment"))) {
+    if (index.column() == m_listAttributes.indexOf(QLatin1String("t_comment"))) {
         auto editor = new SKGComboBox(iParent);
         editor->setEditable(true);
         if (m_document != nullptr) {
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << editor, m_document, QStringLiteral("v_operation_all_comment"), QStringLiteral("t_comment"), QLatin1String(""));
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << editor, m_document, QLatin1String("v_operation_all_comment"), QLatin1String("t_comment"), QLatin1String(""));
         }
         editor->setSizePolicy(newSizePolicy);
         editor->setSizeAdjustPolicy(QComboBox::AdjustToContents);
@@ -67,7 +67,7 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
 
         return editor;
     }
-    if (index.column() == m_listAttributes.indexOf(QStringLiteral("f_value"))) {
+    if (index.column() == m_listAttributes.indexOf(QLatin1String("f_value"))) {
         auto editor = new SKGCalculatorEdit(iParent);
         editor->setMode(SKGCalculatorEdit::EXPRESSION);
         QMapIterator<QString, double> i(m_parameters);
@@ -80,18 +80,18 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
 
         return editor;
     }
-    if (index.column() == m_listAttributes.indexOf(QStringLiteral("t_refund"))) {
+    if (index.column() == m_listAttributes.indexOf(QLatin1String("t_refund"))) {
         auto editor = new SKGComboBox(iParent);
         editor->setEditable(true);
         if (m_document != nullptr) {
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << editor, m_document, QStringLiteral("refund"), QStringLiteral("t_name"), QStringLiteral("t_close='N'"));
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << editor, m_document, QLatin1String("refund"), QLatin1String("t_name"), QLatin1String("t_close='N'"));
         }
         editor->setSizePolicy(newSizePolicy);
         editor->setSizeAdjustPolicy(QComboBox::AdjustToContents);
         m_table->setColumnWidth(index.column(), editor->sizeHint().width());
 
         return editor;
-    }  if (index.column() == m_listAttributes.indexOf(QStringLiteral("d_date"))) {
+    }  if (index.column() == m_listAttributes.indexOf(QLatin1String("d_date"))) {
         auto editor = new SKGDateEdit(iParent);
         editor->setSizePolicy(newSizePolicy);
         editor->setSizeAdjustPolicy(QComboBox::AdjustToContents);
@@ -105,15 +105,15 @@ QWidget* SKGSplitTableDelegate::createEditor(QWidget* iParent,
 
 void SKGSplitTableDelegate::setEditorData(QWidget* editor, const QModelIndex& index) const
 {
-    if (index.column() == m_listAttributes.indexOf(QStringLiteral("f_value"))) {
+    if (index.column() == m_listAttributes.indexOf(QLatin1String("f_value"))) {
         auto* calculator = qobject_cast<SKGCalculatorEdit*>(editor);
         if (calculator != nullptr) {
             calculator->setText(index.model()->data(index, Qt::ToolTipRole).toString());
         }
-    } else if (index.column() == m_listAttributes.indexOf(QStringLiteral("d_date"))) {
+    } else if (index.column() == m_listAttributes.indexOf(QLatin1String("d_date"))) {
         auto* date = qobject_cast<SKGDateEdit*>(editor);
         if (date != nullptr) {
-            date->setDate(SKGServices::stringToTime(index.model()->data(index, Qt::ToolTipRole).toString()).date());
+            date->setDate(SKGServices::stringToDate(index.model()->data(index, Qt::ToolTipRole).toString()));
         }
     } else {
         QItemDelegate::setEditorData(editor, index);
@@ -122,7 +122,7 @@ void SKGSplitTableDelegate::setEditorData(QWidget* editor, const QModelIndex& in
 
 void SKGSplitTableDelegate::setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const
 {
-    if (index.column() == m_listAttributes.indexOf(QStringLiteral("f_value"))) {
+    if (index.column() == m_listAttributes.indexOf(QLatin1String("f_value"))) {
         auto* calculator = qobject_cast<SKGCalculatorEdit*>(editor);
         if ((calculator != nullptr) && (model != nullptr)) {
             QString f = calculator->formula();
@@ -136,7 +136,7 @@ void SKGSplitTableDelegate::setModelData(QWidget* editor, QAbstractItemModel* mo
             model->blockSignals(previous);
             model->setData(index, t, Qt::DisplayRole);
         }
-    } else if (index.column() == m_listAttributes.indexOf(QStringLiteral("d_date"))) {
+    } else if (index.column() == m_listAttributes.indexOf(QLatin1String("d_date"))) {
         auto* date = qobject_cast<SKGDateEdit*>(editor);
         if ((date != nullptr) && (model != nullptr)) {
             QString dateDisplay = SKGMainPanel::dateToString(date->date());
