@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -34,31 +34,31 @@ SKGPayeePluginWidget::SKGPayeePluginWidget(QWidget* iParent, SKGDocument* iDocum
     ui.setupUi(this);
 
     // Set show widget
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("all"), i18n("All"), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META + Qt::Key_A);
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("opened"), i18n("Opened"), QStringLiteral("vcs-normal"), QStringLiteral("t_close='N'"), QLatin1String(""), Qt::META + Qt::Key_O);
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("closed"), i18n("Closed"), QStringLiteral("vcs-conflicting"), QStringLiteral("t_close='Y'"), QLatin1String(""), Qt::META + Qt::Key_C);
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("highlighted"), i18n("Highlighted only"), QStringLiteral("bookmarks"), QStringLiteral("t_bookmarked='Y'"), QLatin1String(""), Qt::META + Qt::Key_H);
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("income"), i18n("Income"), QStringLiteral("list-add"), QStringLiteral("f_CURRENTAMOUNT>=0"), QLatin1String(""), Qt::META + Qt::Key_Plus);
-    ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("expenditure"), i18n("Expenditure"), QStringLiteral("list-remove"), QStringLiteral("f_CURRENTAMOUNT<=0"), QLatin1String(""), Qt::META + Qt::Key_Minus);
-    ui.kView->getShowWidget()->setDefaultState(QStringLiteral("all"));
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("all"), i18n("All"), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META | Qt::Key_A);
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("opened"), i18n("Opened"), QLatin1String("vcs-normal"), QLatin1String("t_close='N'"), QLatin1String(""), Qt::META | Qt::Key_O);
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("closed"), i18n("Closed"), QLatin1String("vcs-conflicting"), QLatin1String("t_close='Y'"), QLatin1String(""), Qt::META | Qt::Key_C);
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("highlighted"), i18n("Highlighted only"), QLatin1String("bookmarks"), QLatin1String("t_bookmarked='Y'"), QLatin1String(""), Qt::META | Qt::Key_H);
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("income"), i18n("Income"), QLatin1String("list-add"), QLatin1String("f_CURRENTAMOUNT>=0"), QLatin1String(""), Qt::META | Qt::Key_Plus);
+    ui.kView->getShowWidget()->addGroupedItem(QLatin1String("expenditure"), i18n("Expenditure"), QLatin1String("list-remove"), QLatin1String("f_CURRENTAMOUNT<=0"), QLatin1String(""), Qt::META | Qt::Key_Minus);
+    ui.kView->getShowWidget()->setDefaultState(QLatin1String("all"));
 
 
-    ui.kView->getShowWidget()->setDefaultState(QStringLiteral("all"));
+    ui.kView->getShowWidget()->setDefaultState(QLatin1String("all"));
 
-    ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_name"))));
-    ui.kAddressLabel->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_address"))));
-    ui.kCategoryLabel->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_CATEGORY"))));
+    ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_name"))));
+    ui.kAddressLabel->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_address"))));
+    ui.kCategoryLabel->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_CATEGORY"))));
 
-    ui.kAddButton->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
-    ui.kModifyButton->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
-    ui.kDeleteUnusedButton->setIcon(SKGServices::fromTheme(QStringLiteral("edit-delete")));
+    ui.kAddButton->setIcon(SKGServices::fromTheme(QLatin1String("list-add")));
+    ui.kModifyButton->setIcon(SKGServices::fromTheme(QLatin1String("dialog-ok")));
+    ui.kDeleteUnusedButton->setIcon(SKGServices::fromTheme(QLatin1String("edit-delete")));
 
-    ui.kView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_payee_display"), QStringLiteral("1=0"), this, QLatin1String(""), false));
+    ui.kView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("v_payee_display"), QLatin1String("1=0"), this, QLatin1String(""), false));
     ui.kView->getView()->resizeColumnToContents(0);
 
     connect(getDocument(), &SKGDocument::tableModified, this, &SKGPayeePluginWidget::dataModified, Qt::QueuedConnection);
     connect(ui.kView->getView(), &SKGTreeView::clickEmptyArea, this, &SKGPayeePluginWidget::cleanEditor);
-    connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open")).data(), &QAction::trigger);
+    connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("open")).data(), &QAction::trigger);
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, this, [ = ] {this->onSelectionChanged();});
 
     connect(ui.kAddButton, &QPushButton::clicked, this, &SKGPayeePluginWidget::onAddPayee);
@@ -103,7 +103,7 @@ void SKGPayeePluginWidget::onSelectionChanged()
 
         ui.kNameInput->setText(obj.getName());
         ui.kAddressEdit->setText(obj.getAddress());
-        ui.kCategoryEdit->setText(obj.getAttribute(QStringLiteral("t_CATEGORY")));
+        ui.kCategoryEdit->setText(obj.getAttribute(QLatin1String("t_CATEGORY")));
     } else if (nbSelect > 1) {
         ui.kNameInput->setText(NOUPDATE);
         ui.kAddressEdit->setText(NOUPDATE);
@@ -117,27 +117,27 @@ void SKGPayeePluginWidget::onSelectionChanged()
 QString SKGPayeePluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
-    root.setAttribute(QStringLiteral("view"), ui.kView->getState());
+    root.setAttribute(QLatin1String("view"), ui.kView->getState());
     return doc.toString();
 }
 
 void SKGPayeePluginWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    ui.kView->setFilter(SKGServices::fromTheme(root.attribute(QStringLiteral("title_icon"))), root.attribute(QStringLiteral("title")), root.attribute(QStringLiteral("whereClause")));
-    ui.kView->setState(root.attribute(QStringLiteral("view")));
+    ui.kView->setFilter(SKGServices::fromTheme(root.attribute(QLatin1String("title_icon"))), root.attribute(QLatin1String("title")), root.attribute(QLatin1String("whereClause")));
+    ui.kView->setState(root.attribute(QLatin1String("view")));
 }
 
 QString SKGPayeePluginWidget::getDefaultStateAttribute()
 {
-    return QStringLiteral("SKGPAYEE_DEFAULT_PARAMETERS");
+    return QLatin1String("SKGPAYEE_DEFAULT_PARAMETERS");
 }
 
 QWidget* SKGPayeePluginWidget::mainWidget()
@@ -160,11 +160,11 @@ void SKGPayeePluginWidget::dataModified(const QString& iTableName, int iIdTransa
     Q_UNUSED(iIdTransaction)
 
     if (!iLightTransaction) {
-        if (iTableName == QStringLiteral("payee") || iTableName.isEmpty()) {
+        if (iTableName == QLatin1String("payee") || iTableName.isEmpty()) {
             // Set completions
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kNameInput, getDocument(), QStringLiteral("payee"), QStringLiteral("t_name"), QLatin1String(""), true);
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAddressEdit, getDocument(), QStringLiteral("payee"), QStringLiteral("t_address"), QLatin1String(""), true);
-            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kCategoryEdit, getDocument(), QStringLiteral("category"), QStringLiteral("t_fullname"), QLatin1String(""));
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kNameInput, getDocument(), QLatin1String("payee"), QLatin1String("t_name"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kAddressEdit, getDocument(), QLatin1String("payee"), QLatin1String("t_address"), QLatin1String(""), true);
+            SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << ui.kCategoryEdit, getDocument(), QLatin1String("category"), QLatin1String("t_fullname"), QLatin1String(""));
         }
     }
 }
@@ -312,7 +312,7 @@ bool SKGPayeePluginWidget::isEditor()
 
 void SKGPayeePluginWidget::onDeleteUnused()
 {
-    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_delete_unused_payees"));
+    QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("clean_delete_unused_payees"));
     if (act != nullptr) {
         act->trigger();
     }
