@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -27,8 +27,8 @@ SKGReportBoardWidget::SKGReportBoardWidget(QWidget* iParent, SKGDocumentBank* iD
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
     QStringList overlayopen;
-    overlayopen.push_back(QStringLiteral("quickopen"));
-    auto open = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), this);
+    overlayopen.push_back(QLatin1String("quickopen"));
+    auto open = new QAction(SKGServices::fromTheme(QLatin1String("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), this);
     connect(open, &QAction::triggered, this, &SKGReportBoardWidget::onOpen);
     addAction(open);
 
@@ -47,12 +47,12 @@ SKGReportBoardWidget::~SKGReportBoardWidget()
 
 QString SKGReportBoardWidget::getState()
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
     if (m_graph != nullptr) {
-        root.setAttribute(QStringLiteral("graph"), m_graph->getState());
+        root.setAttribute(QLatin1String("graph"), m_graph->getState());
     }
     return doc.toString();
 }
@@ -61,17 +61,17 @@ void SKGReportBoardWidget::setState(const QString& iState)
 {
     SKGBoardWidget::setState(iState);
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     if (doc.setContent(iState)) {
         QDomElement root = doc.documentElement();
 
-        QString title = root.attribute(QStringLiteral("title"));
+        QString title = root.attribute(QLatin1String("title"));
         if (!title.isEmpty()) {
             setMainTitle(title);
         }
 
 
-        QString graphS = root.attribute(QStringLiteral("graph"));
+        QString graphS = root.attribute(QLatin1String("graph"));
         if (m_graph != nullptr) {
             if (graphS.isEmpty()) {
                 m_graph->setState(iState);
@@ -88,9 +88,9 @@ void SKGReportBoardWidget::dataModified(const QString& iTableName, int iIdTransa
 {
     SKGTRACEINFUNC(10)
     Q_UNUSED(iIdTransaction)
-    if (iTableName == QStringLiteral("operation") || iTableName.isEmpty()) {
+    if (iTableName == QLatin1String("operation") || iTableName.isEmpty()) {
         bool exist = false;
-        getDocument()->existObjects(QStringLiteral("account"), QLatin1String(""), exist);
+        getDocument()->existObjects(QLatin1String("account"), QLatin1String(""), exist);
         if (parentWidget() != nullptr) {
             setVisible(exist);
         }
@@ -99,24 +99,24 @@ void SKGReportBoardWidget::dataModified(const QString& iTableName, int iIdTransa
 
 void SKGReportBoardWidget::onOpen()
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     QString graphS;
     if (doc.setContent(getState())) {
         QDomElement root = doc.documentElement();
-        graphS = root.attribute(QStringLiteral("graph"));
+        graphS = root.attribute(QLatin1String("graph"));
 
-        QDomDocument doc2(QStringLiteral("SKGML"));
+        QDomDocument doc2(QLatin1String("SKGML"));
         if (doc2.setContent(graphS)) {
             QDomElement root2 = doc2.documentElement();
 
-            QString currentPage = root2.attribute(QStringLiteral("currentPage"));
+            QString currentPage = root2.attribute(QLatin1String("currentPage"));
             if (SKGServices::stringToInt(currentPage) < -1) {
-                root2.setAttribute(QStringLiteral("currentPage"), QStringLiteral("-1"));
+                root2.setAttribute(QLatin1String("currentPage"), QLatin1String("-1"));
                 graphS = doc2.toString();
             }
         }
     }
-    SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge report plugin")), -1, graphS);
+    SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QLatin1String("Skrooge report plugin")), -1, graphS);
 }
 
 
