@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -38,8 +38,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGReportPlugin, "metadata.json")
 
-SKGReportPlugin::SKGReportPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
+SKGReportPlugin::SKGReportPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -60,41 +61,41 @@ bool SKGReportPlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skrooge_report"), title());
-    setXMLFile(QStringLiteral("skrooge_report.rc"));
+    setComponentName(QLatin1String("skrooge_report"), title());
+    setXMLFile(QLatin1String("skrooge_report.rc"));
 
     // Menu
     QStringList overlayopen;
-    overlayopen.push_back(QStringLiteral("quickopen"));
-    auto actOpenReport = new QAction(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), this);
+    overlayopen.push_back(QLatin1String("quickopen"));
+    auto actOpenReport = new QAction(SKGServices::fromTheme(QLatin1String("view-statistics"), overlayopen), i18nc("Verb", "Open report…"), this);
     connect(actOpenReport, &QAction::triggered, this, &SKGReportPlugin::onOpenReport);
-    actionCollection()->setDefaultShortcut(actOpenReport, Qt::META + Qt::Key_R);
-    registerGlobalAction(QStringLiteral("open_report"), actOpenReport,
-                         QStringList() << QStringLiteral("operation") << QStringLiteral("suboperation") << QStringLiteral("account") << QStringLiteral("unit") << QStringLiteral("category") << QStringLiteral("refund") << QStringLiteral("payee") << QStringLiteral("rule"), 1, -1, 120);
+    actionCollection()->setDefaultShortcut(actOpenReport, Qt::META | Qt::Key_R);
+    registerGlobalAction(QLatin1String("open_report"), actOpenReport,
+                         QStringList() << QLatin1String("operation") << QLatin1String("suboperation") << QLatin1String("account") << QLatin1String("unit") << QLatin1String("category") << QLatin1String("refund") << QLatin1String("payee") << QLatin1String("rule"), 1, -1, 120);
 
 
     // ---------------
     {
-        auto act = new QAction(SKGServices::fromTheme(QStringLiteral("security-low"), overlayopen), i18nc("Verb", "Open very old transactions…"), this);
+        auto act = new QAction(SKGServices::fromTheme(QLatin1String("security-low"), overlayopen), i18nc("Verb", "Open very old transactions…"), this);
         act->setData(QString("skg://skrooge_operation_plugin/?title_icon=security-low&title=" %
                              SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Very old transactions")) %
-                             "&operationWhereClause=" % SKGServices::encodeForUrl(QStringLiteral("d_date<=(SELECT date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"))));
+                             "&operationWhereClause=" % SKGServices::encodeForUrl(QLatin1String("d_date<=(SELECT date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"))));
         connect(act, &QAction::triggered, SKGMainPanel::getMainPanel(),  [ = ]() {
             SKGMainPanel::getMainPanel()->openPage();
         });
-        registerGlobalAction(QStringLiteral("view_open_very_old_operations"), act);
+        registerGlobalAction(QLatin1String("view_open_very_old_operations"), act);
     }
 
     // ---------------
     {
-        auto act = new QAction(SKGServices::fromTheme(QStringLiteral("security-low"), overlayopen), i18nc("Verb", "Open very far transactions in the future…"), this);
+        auto act = new QAction(SKGServices::fromTheme(QLatin1String("security-low"), overlayopen), i18nc("Verb", "Open very far transactions in the future…"), this);
         act->setData(QString("skg://skrooge_operation_plugin/?title_icon=security-low&title=" %
                              SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Very far transactions in the future")) %
-                             "&operationWhereClause=" % SKGServices::encodeForUrl(QStringLiteral("d_date>=(SELECT date('now', 'localtime', '+50 year'))"))));
+                             "&operationWhereClause=" % SKGServices::encodeForUrl(QLatin1String("d_date>=(SELECT date('now', 'localtime', '+50 year'))"))));
         connect(act, &QAction::triggered, SKGMainPanel::getMainPanel(),  [ = ]() {
             SKGMainPanel::getMainPanel()->openPage();
         });
-        registerGlobalAction(QStringLiteral("view_open_very_far_operations"), act);
+        registerGlobalAction(QLatin1String("view_open_very_far_operations"), act);
     }
     return true;
 }
@@ -103,7 +104,7 @@ int SKGReportPlugin::getNbDashboardWidgets()
 {
     // Count the number of bookmark on reports
     int nb = 0;
-    m_currentBankDocument->getNbObjects(QStringLiteral("node"), QStringLiteral("t_data like '\"Skrooge report plugin\";%' "), nb);
+    m_currentBankDocument->getNbObjects(QLatin1String("node"), QLatin1String("t_data like '\"Skrooge report plugin\";%' "), nb);
     return 2 + nb;
 }
 
@@ -117,9 +118,9 @@ QString SKGReportPlugin::getDashboardWidgetTitle(int iIndex)
         return i18nc("Noun, the title of a section",  "Personal Financial Score");
     }
     SKGObjectBase::SKGListSKGObjectBase objs;
-    m_currentBankDocument->getObjects(QStringLiteral("node"), QStringLiteral("t_data like '\"Skrooge report plugin\";%' ORDER BY t_fullname"), objs);
+    m_currentBankDocument->getObjects(QLatin1String("node"), QLatin1String("t_data like '\"Skrooge report plugin\";%' ORDER BY t_fullname"), objs);
     if (iIndex - 2 < objs.count()) {
-        return  i18nc("Noun, the title of a section", "Report bookmarked named \"%1\"", objs[iIndex - 2].getAttribute(QStringLiteral("t_fullname")));
+        return  i18nc("Noun, the title of a section", "Report bookmarked named \"%1\"", objs[iIndex - 2].getAttribute(QLatin1String("t_fullname")));
     }
 
     return QLatin1String("");
@@ -134,17 +135,17 @@ SKGBoardWidget* SKGReportPlugin::getDashboardWidget(int iIndex)
     if (iIndex == 1)  {
         return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex) % " - %1",
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/personal_finance_score.qml")),
-                                      QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_MONTHS);
+                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/personal_finance_score.qml")),
+                                      QStringList() << QLatin1String("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_MONTHS);
     }
     SKGObjectBase::SKGListSKGObjectBase objs;
-    m_currentBankDocument->getObjects(QStringLiteral("node"), QStringLiteral("t_data like '\"Skrooge report plugin\";%' ORDER BY t_fullname"), objs);
+    m_currentBankDocument->getObjects(QLatin1String("node"), QLatin1String("t_data like '\"Skrooge report plugin\";%' ORDER BY t_fullname"), objs);
     if (iIndex - 2 < objs.count()) {
         auto* report = new SKGReportBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
-        QString state = SKGServices::splitCSVLine(objs.at(iIndex - 2).getAttribute(QStringLiteral("t_data"))).at(2);
-        state = state.replace(QStringLiteral("isToolBarVisible=&amp;quot;Y&amp;quot;"), QStringLiteral("isToolBarVisible=&amp;quot;N&amp;quot;"));
-        state = state.replace(QStringLiteral("show=&quot;&amp;quot;table&amp;quot;;&amp;quot;graph&amp;quot;&quot;"), QStringLiteral("show=&quot;&amp;quot;graph&amp;quot;&quot;"));
-        state = state.replace(QStringLiteral("currentPage=\"0\""), QStringLiteral("currentPage=\"-1\""));
+        QString state = SKGServices::splitCSVLine(objs.at(iIndex - 2).getAttribute(QLatin1String("t_data"))).at(2);
+        state = state.replace(QLatin1String("isToolBarVisible=&amp;quot;Y&amp;quot;"), QLatin1String("isToolBarVisible=&amp;quot;N&amp;quot;"));
+        state = state.replace(QLatin1String("show=&quot;&amp;quot;table&amp;quot;;&amp;quot;graph&amp;quot;&quot;"), QLatin1String("show=&quot;&amp;quot;graph&amp;quot;&quot;"));
+        state = state.replace(QLatin1String("currentPage=\"0\""), QLatin1String("currentPage=\"-1\""));
         report->setState(state);
         return  report;
     }
@@ -178,7 +179,7 @@ QString SKGReportPlugin::title() const
 
 QString SKGReportPlugin::icon() const
 {
-    return QStringLiteral("view-statistics");
+    return QLatin1String("view-statistics");
 }
 
 QString SKGReportPlugin::toolTip() const
@@ -210,8 +211,8 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
     int nb = iSelection.count();
     if (nb > 0) {
         QString table = iSelection.at(0).getRealTable();
-        if (table == QStringLiteral("account")) {
-            oWhereClause = QStringLiteral("rd_account_id in (");
+        if (table == QLatin1String("account")) {
+            oWhereClause = QLatin1String("rd_account_id in (");
             oTitle = i18nc("Noun, a list of items", "Transactions of account ");
 
             for (int i = 0; i < nb; ++i) {
@@ -224,8 +225,8 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
                 oTitle += i18n("'%1'", tmp.getName());
             }
             oWhereClause += ')';
-        } else if (table == QStringLiteral("unit")) {
-            oWhereClause = QStringLiteral("rc_unit_id in (");
+        } else if (table == QLatin1String("unit")) {
+            oWhereClause = QLatin1String("rc_unit_id in (");
             oTitle = i18nc("Noun, a list of items", "Transactions with Unit equal to ");
 
             for (int i = 0; i < nb; ++i) {
@@ -238,8 +239,8 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
                 oTitle += i18n("'%1'", tmp.getName());
             }
             oWhereClause += ')';
-        } else if (table == QStringLiteral("category")) {
-            oWhereClause = QStringLiteral("t_REALCATEGORY in (");
+        } else if (table == QLatin1String("category")) {
+            oWhereClause = QLatin1String("t_REALCATEGORY in (");
             QString wc2;
             oTitle = i18nc("Noun, a list of items", "Transactions with Category equal to ");
 
@@ -247,16 +248,16 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
                 SKGCategoryObject tmp(iSelection.at(i));
                 if (i != 0) {
                     oWhereClause += ',';
-                    wc2 += QStringLiteral(" OR ");
+                    wc2 += QLatin1String(" OR ");
                     oTitle += ',';
                 }
-                oWhereClause += '\'' % SKGServices::stringToSqlString(tmp.getFullName()) % '\'';
+                oWhereClause += '\'' % SKGServices::stringToSqlString(tmp.getFullName()) % QLatin1Char('\'');
                 wc2 += "t_REALCATEGORY like '" % SKGServices::stringToSqlString(tmp.getFullName()) % "%'";
                 oTitle += i18n("'%1'", tmp.getFullName());
             }
             oWhereClause += ") OR " % wc2;
-        } else if (table == QStringLiteral("refund")) {
-            oWhereClause = QStringLiteral("r_refund_id in (");
+        } else if (table == QLatin1String("refund")) {
+            oWhereClause = QLatin1String("r_refund_id in (");
             oTitle = i18nc("Noun, a list of items", "Transactions followed by ");
 
             for (int i = 0; i < nb; ++i) {
@@ -269,8 +270,8 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
                 oTitle += i18n("'%1'", tmp.getName());
             }
             oWhereClause += ')';
-        } else if (table == QStringLiteral("payee")) {
-            oWhereClause = QStringLiteral("r_payee_id in (");
+        } else if (table == QLatin1String("payee")) {
+            oWhereClause = QLatin1String("r_payee_id in (");
             oTitle = i18nc("Noun, a list of items", "Transactions assigned to ");
 
             for (int i = 0; i < nb; ++i) {
@@ -283,8 +284,8 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
                 oTitle += i18n("'%1'", tmp.getName());
             }
             oWhereClause += ')';
-        } else if (table == QStringLiteral("operation")) {
-            oWhereClause = QStringLiteral("i_OPID in (");
+        } else if (table == QLatin1String("operation")) {
+            oWhereClause = QLatin1String("i_OPID in (");
             oTitle = i18nc("Noun, a list of items", "Selected transactions");
 
             for (int i = 0; i < nb; ++i) {
@@ -294,8 +295,8 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
                 oWhereClause += SKGServices::intToString(iSelection.at(i).getID());
             }
             oWhereClause += ')';
-        } else if (table == QStringLiteral("suboperation")) {
-            oWhereClause = QStringLiteral("i_SUBOPID in (");
+        } else if (table == QLatin1String("suboperation")) {
+            oWhereClause = QLatin1String("i_SUBOPID in (");
             oTitle = i18nc("Noun, a list of items", "Selected sub transactions");
 
             for (int i = 0; i < nb; ++i) {
@@ -305,7 +306,7 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
                 oWhereClause += SKGServices::intToString(iSelection.at(i).getID());
             }
             oWhereClause += ')';
-        } else if (table == QStringLiteral("rule")) {
+        } else if (table == QLatin1String("rule")) {
             oTitle = i18nc("Noun, a list of items", "Transactions corresponding to rule ");
 
             for (int i = 0; i < nb; ++i) {
@@ -313,10 +314,10 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
                 QString ruleWc = tmp.getSelectSqlOrder();
                 if (!ruleWc.isEmpty()) {
                     if (!oWhereClause.isEmpty()) {
-                        oWhereClause += QStringLiteral(" OR ");
+                        oWhereClause += QLatin1String(" OR ");
                         oTitle += ',';
                     }
-                    oWhereClause += '(' % ruleWc % ')';
+                    oWhereClause += QLatin1Char('(') % ruleWc % QLatin1Char(')');
                     oTitle += i18n("'%1'", tmp.getSearchDescription());
                 }
             }
@@ -350,34 +351,34 @@ SKGAdviceList SKGReportPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGAdviceList output;
 
     // Very old operation
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgreportplugin_veryold"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgreportplugin_veryold"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects(QStringLiteral("operation"), QStringLiteral("d_date<=(SELECT date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"), exist);
+        m_currentBankDocument->existObjects(QLatin1String("operation"), QLatin1String("d_date<=(SELECT date('now', 'localtime', '-50 year')) AND d_date<>'0000-00-00'"), exist);
         if (exist) {
             SKGAdvice ad;
-            ad.setUUID(QStringLiteral("skgreportplugin_veryold"));
+            ad.setUUID(QLatin1String("skgreportplugin_veryold"));
             ad.setPriority(3);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Some transactions are very old"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "For performances reasons, very old transactions are not taken into account in graph report. Check if these transactions are normal."));
             QStringList autoCorrections;
-            autoCorrections.push_back(QStringLiteral("skg://view_open_very_old_operations"));
+            autoCorrections.push_back(QLatin1String("skg://view_open_very_old_operations"));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
 
     // Very far operation
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgreportplugin_veryfar"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgreportplugin_veryfar"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects(QStringLiteral("operation"), QStringLiteral("d_date>=(SELECT date('now', 'localtime', '+50 year'))"), exist);
+        m_currentBankDocument->existObjects(QLatin1String("operation"), QLatin1String("d_date>=(SELECT date('now', 'localtime', '+50 year'))"), exist);
         if (exist) {
             SKGAdvice ad;
-            ad.setUUID(QStringLiteral("skgreportplugin_veryfar"));
+            ad.setUUID(QLatin1String("skgreportplugin_veryfar"));
             ad.setPriority(3);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Some transactions are very far in the future"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "For performances reasons, transactions very far in the future are not taken into account in graph report. Check if these transactions are normal."));
             QStringList autoCorrections;
-            autoCorrections.push_back(QStringLiteral("skg://view_open_very_far_operations"));
+            autoCorrections.push_back(QLatin1String("skg://view_open_very_far_operations"));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
