@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -20,7 +20,7 @@ void SKGTESTReportPlugin::TestPlugin()
     KLocalizedString::setApplicationDomain("skrooge");
 
     SKGDocumentBank doc;
-    SKGReportPlugin plugin(nullptr, nullptr, QVariantList());
+    SKGReportPlugin plugin(nullptr, nullptr, KPluginMetaData(), QVariantList());
     SKGTESTPLUGIN(plugin, doc);
     QCOMPARE(plugin.isInPagesChooser(), true);
     QCOMPARE(plugin.isEnabled(), true);
