@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -27,8 +27,8 @@
 
 SKGScheduledBoardWidget::SKGScheduledBoardWidget(QWidget* iParent, SKGDocument* iDocument)
     : SKGHtmlBoardWidget(iParent, iDocument, i18nc("Noun, the title of a section", "Scheduled transactions"),
-                         QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/scheduled_operations.qml")),
-                         QStringList() << QStringLiteral("v_recurrentoperation_display"))
+                         QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/scheduled_operations.qml")),
+                         QStringList() << QLatin1String("v_recurrentoperation_display"))
 {
     SKGTRACEINFUNC(10)
     m_daysmax = new SKGComboBox(this);
@@ -41,7 +41,7 @@ SKGScheduledBoardWidget::SKGScheduledBoardWidget(QWidget* iParent, SKGDocument*
 
     // Add widget in menu
     auto daysmaxWidget = new QWidgetAction(this);
-    daysmaxWidget->setObjectName(QStringLiteral("daysmaxWidget"));
+    daysmaxWidget->setObjectName(QLatin1String("daysmaxWidget"));
     daysmaxWidget->setDefaultWidget(m_daysmax);
 
     addAction(daysmaxWidget);
@@ -58,23 +58,23 @@ SKGScheduledBoardWidget::~SKGScheduledBoardWidget()
 
 QString SKGScheduledBoardWidget::getState()
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("daysmax"), (m_daysmax != nullptr ? m_daysmax->currentData().toString() : QStringLiteral("30")));
+    root.setAttribute(QLatin1String("daysmax"), (m_daysmax != nullptr ? m_daysmax->currentData().toString() : QLatin1String("30")));
     return doc.toString();
 }
 
 void SKGScheduledBoardWidget::setState(const QString& iState)
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString daysmax = root.attribute(QStringLiteral("daysmax"));
+    QString daysmax = root.attribute(QLatin1String("daysmax"));
     if (daysmax.isEmpty()) {
-        daysmax = QStringLiteral("30");
+        daysmax = QLatin1String("30");
     }
     if (m_daysmax != nullptr && !daysmax.isEmpty()) {
         m_daysmax->setCurrentIndex(m_daysmax->findData(daysmax));
@@ -83,6 +83,6 @@ void SKGScheduledBoardWidget::setState(const QString& iState)
 
 void SKGScheduledBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    m_Report->addParameter(QStringLiteral("scheduled_operation_days_max"), m_daysmax->currentData());
+    m_Report->addParameter(QLatin1String("scheduled_operation_days_max"), m_daysmax->currentData());
     SKGHtmlBoardWidget::dataModified(iTableName, iIdTransaction);
 }
