@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -33,8 +33,11 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGScheduledPlugin, "metadata.json")
 
-SKGScheduledPlugin::SKGScheduledPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr), m_counterAdvice(0), m_assignScheduleMenu(nullptr)
+SKGScheduledPlugin::SKGScheduledPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
+    , m_counterAdvice(0)
+    , m_assignScheduleMenu(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -55,28 +58,32 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skrooge_scheduled"), title());
-    setXMLFile(QStringLiteral("skrooge_scheduled.rc"));
+    setComponentName(QLatin1String("skrooge_scheduled"), title());
+    setXMLFile(QLatin1String("skrooge_scheduled.rc"));
 
     QStringList listOperation;
-    listOperation << QStringLiteral("operation");
+    listOperation << QLatin1String("operation");
 
     // Create yours actions here
     auto actScheduleOperation = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb, create a scheduled transaction", "Schedule"), this);
     connect(actScheduleOperation, &QAction::triggered, this, &SKGScheduledPlugin::onScheduleOperation);
-    actionCollection()->setDefaultShortcut(actScheduleOperation, Qt::CTRL + Qt::Key_I);
-    registerGlobalAction(QStringLiteral("schedule_operation"), actScheduleOperation, QStringList() << QStringLiteral("operation"), 1, -1, 410);
+    actionCollection()->setDefaultShortcut(actScheduleOperation, Qt::CTRL | Qt::Key_I);
+    registerGlobalAction(QLatin1String("schedule_operation"), actScheduleOperation, QStringList() << QLatin1String("operation"), 1, -1, 410);
 
-    auto actSkipScheduledOperation = new QAction(SKGServices::fromTheme(QStringLiteral("nextuntranslated")), i18nc("Verb, skip scheduled transactions", "Skip"), this);
+    auto actSkipScheduledOperation = new QAction(SKGServices::fromTheme(QLatin1String("nextuntranslated")), i18nc("Verb, skip scheduled transactions", "Skip"), this);
     connect(actSkipScheduledOperation, &QAction::triggered, this, &SKGScheduledPlugin::onSkipScheduledOperations);
-    registerGlobalAction(QStringLiteral("skip_scheduled_operations"), actSkipScheduledOperation, QStringList() << QStringLiteral("recurrentoperation"), 1, -1, 410);
+    registerGlobalAction(QLatin1String("skip_scheduled_operations"), actSkipScheduledOperation, QStringList() << QLatin1String("recurrentoperation"), 1, -1, 410);
 
-    auto actAssignScheduleAction = new KToolBarPopupAction(SKGServices::fromTheme(QStringLiteral("edit-guides")), i18nc("Verb, action to assign a schedule", "Assign schedule"), this);
-    m_assignScheduleMenu = actAssignScheduleAction->menu();
+    auto actAssignScheduleAction = new KToolBarPopupAction(SKGServices::fromTheme(QLatin1String("edit-guides")), i18nc("Verb, action to assign a schedule", "Assign schedule"), this);
+    m_assignScheduleMenu = actAssignScheduleAction->popupMenu();
     connect(m_assignScheduleMenu, &QMenu::aboutToShow, this, &SKGScheduledPlugin::onShowAssignScheduleMenu);
+#ifdef SKG_QT6
+
+#else
     actAssignScheduleAction->setStickyMenu(false);
+#endif
     actAssignScheduleAction->setData(1);
-    registerGlobalAction(QStringLiteral("edit_assign_schedule"), actAssignScheduleAction, listOperation, 1, -1, 412);
+    registerGlobalAction(QLatin1String("edit_assign_schedule"), actAssignScheduleAction, listOperation, 1, -1, 412);
 
     return true;
 }
@@ -91,7 +98,7 @@ void SKGScheduledPlugin::onShowAssignScheduleMenu()
         // Search templates
         SKGStringListList listTmp;
         m_currentBankDocument->executeSelectSqliteOrder(
-            QStringLiteral("SELECT t_displayname, id, i_nb_times FROM v_recurrentoperation_displayname ORDER BY i_nb_times DESC, t_displayname"),
+            QLatin1String("SELECT t_displayname, id, i_nb_times FROM v_recurrentoperation_displayname ORDER BY i_nb_times DESC, t_displayname"),
             listTmp);
 
         // Get assigned schedules of selected transactions
@@ -117,7 +124,7 @@ void SKGScheduledPlugin::onShowAssignScheduleMenu()
             auto act = new QWidgetAction(menu);
             auto menuItem = new SKGMenuitem;
             menuItem->setText(text);
-            menuItem->setIcon(SKGServices::fromTheme(QStringLiteral("edit-guides")));
+            menuItem->setIcon(SKGServices::fromTheme(QLatin1String("edit-guides")));
             if (!isActive) {
                 menuItem->setColor(fontDisabledScheduleColor);
             }
@@ -201,7 +208,7 @@ void SKGScheduledPlugin::refresh()
     // Automatic insert
     if ((m_currentBankDocument != nullptr) && m_currentBankDocument->getMainDatabase() != nullptr) {
         QString doc_id = m_currentBankDocument->getUniqueIdentifier();
-        if (m_docUniqueIdentifier != doc_id && m_currentBankDocument->getParameter(QStringLiteral("SKG_DB_BANK_VERSION")) >= QStringLiteral("0.5")) {
+        if (m_docUniqueIdentifier != doc_id && m_currentBankDocument->getParameter(QLatin1String("SKG_DB_BANK_VERSION")) >= QLatin1String("0.5")) {
             m_docUniqueIdentifier = std::move(doc_id);
 
             SKGError err;
@@ -282,7 +289,7 @@ QString SKGScheduledPlugin::title() const
 
 QString SKGScheduledPlugin::icon() const
 {
-    return QStringLiteral("chronometer");
+    return QLatin1String("chronometer");
 }
 
 QString SKGScheduledPlugin::toolTip() const
@@ -315,7 +322,7 @@ SKGError SKGScheduledPlugin::savePreferences() const
         if (skgscheduled_settings::convert_to_from_template()) {
             const auto newTemplateMode = skgscheduled_settings::create_template();
             SKGObjectBase::SKGListSKGObjectBase recurrents;
-            err = m_currentBankDocument->getObjects(QStringLiteral("v_recurrentoperation"), QStringLiteral("(select count(1) from operation where operation.id=rd_operation_id and t_template='%1')=1").arg(newTemplateMode ? "N" : "Y"), recurrents);
+            err = m_currentBankDocument->getObjects(QLatin1String("v_recurrentoperation"), QLatin1String("(select count(1) from operation where operation.id=rd_operation_id and t_template='%1')=1").arg(newTemplateMode ? "N" : "Y"), recurrents);
             int nb = recurrents.count();
             if (nb != 0) {
                 SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Conversion schedule"), err, nb)
@@ -372,7 +379,7 @@ SKGError SKGScheduledPlugin::scheduleOperation(const SKGOperationObject& iOperat
     IFOKDO(err, recOp.save())
     if (!isTemplate && skgscheduled_settings::create_template()) {
         IFOKDO(err, recOp.load())
-        IFOKDO(err, operationObjOrig.setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(recOp.getID())))
+        IFOKDO(err, operationObjOrig.setAttribute(QLatin1String("r_recurrentoperation_id"), SKGServices::intToString(recOp.getID())))
         IFOKDO(err, operationObjOrig.save())
     }
 
@@ -472,7 +479,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
     output.reserve(20);
 
     // Recurrent transaction with the last inserted transaction having a different amount
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgscheduledplugin_notuptodate"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgscheduledplugin_notuptodate"))) {
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT r.id, r.rd_operation_id, r.f_CURRENTAMOUNT, r2.f_CURRENTAMOUNT FROM v_recurrentoperation_display r INNER JOIN (SELECT MAX(d_date), f_CURRENTAMOUNT, r_recurrentoperation_id FROM v_operation_display GROUP BY r_recurrentoperation_id) r2 WHERE r2.r_recurrentoperation_id=r.id AND ABS(r.f_CURRENTAMOUNT-r2.f_CURRENTAMOUNT)>" % SKGServices::doubleToString(EPSILON), result);
         int nb = result.count();
@@ -488,7 +495,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
             QString name = recu.getDisplayName();
 
             SKGAdvice ad;
-            ad.setUUID("skgscheduledplugin_notuptodate|" % idOper % ';' % amountLastOperation);
+            ad.setUUID("skgscheduledplugin_notuptodate|" % idOper % QLatin1Char(';') % amountLastOperation);
             ad.setPriority(4);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled transaction '%1' not uptodate", name));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled transaction '%1' does not have the amount of the last inserted transaction (%2)", name, amountLastOperation));
@@ -496,7 +503,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
             {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Update the next scheduled transaction amount (%1)", amountLastOperation);
-                a.IconName = QStringLiteral("system-run");
+                a.IconName = QLatin1String("system-run");
                 a.IsRecommended = true;
                 autoCorrections.push_back(a);
             }
@@ -506,9 +513,9 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Recurrent transaction with the last inserted transaction having a different date
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgscheduledplugin_newdate"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgscheduledplugin_newdate"))) {
         SKGStringListList result;
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT r.id, r.d_date, "
+        m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT r.id, r.d_date, "
                 "date(r2.d_date, '+'||((CASE r.t_period_unit WHEN 'W' THEN 7  ELSE 1 END)*r.i_period_increment)||' '||(CASE r.t_period_unit WHEN 'M' THEN 'month' WHEN 'Y' THEN 'year' ELSE 'day' END)) "
                 "FROM v_recurrentoperation_display r "
                 "INNER JOIN (SELECT MAX(d_date) as d_date, r_recurrentoperation_id FROM v_operation_display GROUP BY r_recurrentoperation_id) r2 "
@@ -521,12 +528,12 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
             int idRecu = SKGServices::stringToInt(line.at(0));
             const QString& currentDate = line.at(1);
             const QString& newDate = line.at(2);
-            if (SKGServices::stringToTime(newDate).date() > QDate::currentDate() && SKGServices::stringToTime(newDate).date() != SKGServices::stringToTime(currentDate).date()) {
+            if (SKGServices::stringToDate(newDate) > QDate::currentDate() && SKGServices::stringToDate(newDate) != SKGServices::stringToDate(currentDate)) {
                 SKGRecurrentOperationObject recu(m_currentBankDocument, idRecu);
                 QString name = recu.getDisplayName();
 
                 SKGAdvice ad;
-                ad.setUUID("skgscheduledplugin_newdate|" % line.at(0) % ';' % newDate);
+                ad.setUUID("skgscheduledplugin_newdate|" % line.at(0) % QLatin1Char(';') % newDate);
                 ad.setPriority(4);
                 ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled transaction '%1' not uptodate", name));
                 ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled transaction '%1' does not have the date aligned with the last inserted transaction (%2)", name, currentDate));
@@ -534,7 +541,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
                 {
                     SKGAdvice::SKGAdviceAction a;
                     a.Title = i18nc("Advice on making the best (action)", "Update the next scheduled transaction date (%1)", newDate);
-                    a.IconName = QStringLiteral("system-run");
+                    a.IconName = QLatin1String("system-run");
                     a.IsRecommended = true;
                     autoCorrections.push_back(a);
                 }
@@ -545,10 +552,10 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Possible recurrent transactions
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgscheduledplugin_possibleschedule"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgscheduledplugin_possibleschedule"))) {
         SKGStringListList result;
 
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1 WHERE op1.id||'#'||op1.f_QUANTITY IN (SELECT op1.id||'#'||op2.f_QUANTITY FROM operation op1, v_operation_tmp1 op2 "
+        m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT op1.id, op1.t_displayname FROM v_operation_displayname op1 WHERE op1.id||'#'||op1.f_QUANTITY IN (SELECT op1.id||'#'||op2.f_QUANTITY FROM operation op1, v_operation_tmp1 op2 "
                 "WHERE op1.rd_account_id=op2.rd_account_id AND op1.r_payee_id=op2.r_payee_id AND op1.rc_unit_id=op2.rc_unit_id "
                 "AND op1.r_recurrentoperation_id=0 AND op1.d_date<>'0000-00-00' AND op1.d_date=date(op2.d_date, '+1 month') "
                 "AND op1.d_date>(SELECT date('now', 'localtime','-2 month')) AND op2.d_date>(SELECT date('now', 'localtime','-3 month'))) "
@@ -640,7 +647,7 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
         {
             SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Update scheduled transaction"), err)
             SKGRecurrentOperationObject rop(m_currentBankDocument, id);
-            IFOKDO(err, rop.setDate(SKGServices::stringToTime(newDate).date()))
+            IFOKDO(err, rop.setDate(SKGServices::stringToDate(newDate)))
             IFOKDO(err, rop.save())
 
             // Send message
