@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -33,8 +33,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGSearchPlugin, "metadata.json")
 
-SKGSearchPlugin::SKGSearchPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
+SKGSearchPlugin::SKGSearchPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -64,8 +65,8 @@ SKGBoardWidget* SKGSearchPlugin::getDashboardWidget(int iIndex)
     Q_UNUSED(iIndex)
     return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
-                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/alarm.qml")),
-                                  QStringList() << QStringLiteral("operation") << QStringLiteral("rule"));
+                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/alarm.qml")),
+                                  QStringList() << QLatin1String("operation") << QLatin1String("rule"));
 }
 
 bool SKGSearchPlugin::setupActions(SKGDocument* iDocument)
@@ -77,48 +78,48 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skrooge_search"), title());
-    setXMLFile(QStringLiteral("skrooge_search.rc"));
+    setComponentName(QLatin1String("skrooge_search"), title());
+    setXMLFile(QLatin1String("skrooge_search.rc"));
 
     // Create yours actions here
     // Execute on all operation
-    auto actExecuteAll = new QAction(SKGServices::fromTheme(QStringLiteral("system-run")), i18nc("Verb, action to execute", "Execute on all transactions"), this);
+    auto actExecuteAll = new QAction(SKGServices::fromTheme(QLatin1String("system-run")), i18nc("Verb, action to execute", "Execute on all transactions"), this);
     connect(actExecuteAll, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::ALL); });
-    registerGlobalAction(QStringLiteral("execute_all"), actExecuteAll, QStringList() << QStringLiteral("rule"), 1, -1, 501);
+    registerGlobalAction(QLatin1String("execute_all"), actExecuteAll, QStringList() << QLatin1String("rule"), 1, -1, 501);
 
     // Execute on not checked
     {
         QStringList overlaycsv;
-        overlaycsv.push_back(QStringLiteral("document-import"));
-        auto actExecuteImported = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on not checked transactions"), this);
+        overlaycsv.push_back(QLatin1String("document-import"));
+        auto actExecuteImported = new QAction(SKGServices::fromTheme(QLatin1String("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on not checked transactions"), this);
         connect(actExecuteImported, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::NOTCHECKED); });
-        registerGlobalAction(QStringLiteral("execute_notchecked"), actExecuteImported, QStringList() << QStringLiteral("rule"), 1, -1, 502);
+        registerGlobalAction(QLatin1String("execute_notchecked"), actExecuteImported, QStringList() << QLatin1String("rule"), 1, -1, 502);
     }
 
     // Execute on imported transaction
     {
         QStringList overlaycsv;
-        overlaycsv.push_back(QStringLiteral("document-import"));
-        auto actExecuteImported = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on imported transactions"), this);
+        overlaycsv.push_back(QLatin1String("document-import"));
+        auto actExecuteImported = new QAction(SKGServices::fromTheme(QLatin1String("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on imported transactions"), this);
         connect(actExecuteImported, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::IMPORTED); });
-        registerGlobalAction(QStringLiteral("execute_imported"), actExecuteImported, QStringList() << QStringLiteral("rule"), 1, -1, 502);
+        registerGlobalAction(QLatin1String("execute_imported"), actExecuteImported, QStringList() << QLatin1String("rule"), 1, -1, 502);
     }
 
     // Execute on not validated
     {
         QStringList overlaycsv;
-        overlaycsv.push_back(QStringLiteral("dialog-ok"));
-        auto actExecuteNotValidated = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on not validated transactions"), this);
+        overlaycsv.push_back(QLatin1String("dialog-ok"));
+        auto actExecuteNotValidated = new QAction(SKGServices::fromTheme(QLatin1String("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on not validated transactions"), this);
         connect(actExecuteNotValidated, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::IMPORTEDNOTVALIDATE); });
-        registerGlobalAction(QStringLiteral("execute_not_validated"), actExecuteNotValidated, QStringList() << QStringLiteral("rule"), 1, -1, 503);
+        registerGlobalAction(QLatin1String("execute_not_validated"), actExecuteNotValidated, QStringList() << QLatin1String("rule"), 1, -1, 503);
     }
 
     // Search
-    QAction* actSearch = actionCollection()->addAction(KStandardAction::Find, QStringLiteral("edit_find"), this, SLOT(find()));
-    registerGlobalAction(QStringLiteral("edit_find"), actSearch);  // Global
+    QAction* actSearch = actionCollection()->addAction(KStandardAction::Find, QLatin1String("edit_find"), this, SLOT(find()));
+    registerGlobalAction(QLatin1String("edit_find"), actSearch);  // Global
     auto actSearch2 = new QAction(actSearch->icon(), actSearch->text(), this);
     connect(actSearch2, &QAction::triggered, this, &SKGSearchPlugin::find);
-    registerGlobalAction(QStringLiteral("edit_find_ctx"), actSearch2, QStringList() << QStringLiteral("account") << QStringLiteral("category") << QStringLiteral("refund") << QStringLiteral("payee") << QStringLiteral("operation") << QStringLiteral("suboperation"), 1, -1, 130);   // For contextual menus
+    registerGlobalAction(QLatin1String("edit_find_ctx"), actSearch2, QStringList() << QLatin1String("account") << QLatin1String("category") << QLatin1String("refund") << QLatin1String("payee") << QLatin1String("operation") << QLatin1String("suboperation"), 1, -1, 130);   // For contextual menus
 
     return true;
 }
@@ -141,7 +142,7 @@ void SKGSearchPlugin::raiseAlarms()
 {
     if (m_currentBankDocument != nullptr) {
         SKGObjectBase::SKGListSKGObjectBase rules;
-        SKGError err = m_currentBankDocument->getObjects(QStringLiteral("v_rule"), QStringLiteral("t_action_type='A' ORDER BY i_ORDER"), rules);
+        SKGError err = m_currentBankDocument->getObjects(QLatin1String("v_rule"), QLatin1String("t_action_type='A' ORDER BY i_ORDER"), rules);
         int nb = rules.count();
         if (!err && (nb != 0)) {
             for (int i = 0; !err && i < nb; ++i) {
@@ -196,97 +197,97 @@ void SKGSearchPlugin::find()
         int nb = selection.count();
         if (nb > 0) {
             QString table = selection.at(0).getRealTable();
-            if (table == QStringLiteral("account")) {
-                QDomDocument doc(QStringLiteral("SKGML"));
-                QDomElement element = doc.createElement(QStringLiteral("element"));
+            if (table == QLatin1String("account")) {
+                QDomDocument doc(QLatin1String("SKGML"));
+                QDomElement element = doc.createElement(QLatin1String("element"));
                 doc.appendChild(element);
                 for (int i = 0; i < nb; ++i) {
-                    QDomElement elementLine = doc.createElement(QStringLiteral("element"));
+                    QDomElement elementLine = doc.createElement(QLatin1String("element"));
                     element.appendChild(elementLine);
 
-                    QDomElement elementElement = doc.createElement(QStringLiteral("element"));
+                    QDomElement elementElement = doc.createElement(QLatin1String("element"));
                     elementLine.appendChild(elementElement);
 
-                    elementElement.setAttribute(QStringLiteral("attribute"), QStringLiteral("t_ACCOUNT"));
-                    elementElement.setAttribute(QStringLiteral("operator"), QStringLiteral("#ATT#='#V1S#'"));
-                    elementElement.setAttribute(QStringLiteral("value"), selection.at(i).getAttribute(QStringLiteral("t_name")));
+                    elementElement.setAttribute(QLatin1String("attribute"), QLatin1String("t_ACCOUNT"));
+                    elementElement.setAttribute(QLatin1String("operator"), QLatin1String("#ATT#='#V1S#'"));
+                    elementElement.setAttribute(QLatin1String("value"), selection.at(i).getAttribute(QLatin1String("t_name")));
                 }
                 xmlsearchcondition = doc.toString();
-            } else if (table == QStringLiteral("category")) {
-                QDomDocument doc(QStringLiteral("SKGML"));
-                QDomElement element = doc.createElement(QStringLiteral("element"));
+            } else if (table == QLatin1String("category")) {
+                QDomDocument doc(QLatin1String("SKGML"));
+                QDomElement element = doc.createElement(QLatin1String("element"));
                 doc.appendChild(element);
                 for (int i = 0; i < nb; ++i) {
-                    QDomElement elementLine = doc.createElement(QStringLiteral("element"));
+                    QDomElement elementLine = doc.createElement(QLatin1String("element"));
                     element.appendChild(elementLine);
 
-                    QDomElement elementElement = doc.createElement(QStringLiteral("element"));
+                    QDomElement elementElement = doc.createElement(QLatin1String("element"));
                     elementLine.appendChild(elementElement);
 
-                    elementElement.setAttribute(QStringLiteral("attribute"), QStringLiteral("t_REALCATEGORY"));
-                    elementElement.setAttribute(QStringLiteral("operator"), QStringLiteral("#ATT#='#V1S#'"));
+                    elementElement.setAttribute(QLatin1String("attribute"), QLatin1String("t_REALCATEGORY"));
+                    elementElement.setAttribute(QLatin1String("operator"), QLatin1String("#ATT#='#V1S#'"));
                     SKGCategoryObject cat(selection.at(i));
-                    elementElement.setAttribute(QStringLiteral("value"), cat.getFullName());
+                    elementElement.setAttribute(QLatin1String("value"), cat.getFullName());
                 }
                 xmlsearchcondition = doc.toString();
-            } else if (table == QStringLiteral("refund")) {
-                QDomDocument doc(QStringLiteral("SKGML"));
-                QDomElement element = doc.createElement(QStringLiteral("element"));
+            } else if (table == QLatin1String("refund")) {
+                QDomDocument doc(QLatin1String("SKGML"));
+                QDomElement element = doc.createElement(QLatin1String("element"));
                 doc.appendChild(element);
                 for (int i = 0; i < nb; ++i) {
-                    QDomElement elementLine = doc.createElement(QStringLiteral("element"));
+                    QDomElement elementLine = doc.createElement(QLatin1String("element"));
                     element.appendChild(elementLine);
 
-                    QDomElement elementElement = doc.createElement(QStringLiteral("element"));
+                    QDomElement elementElement = doc.createElement(QLatin1String("element"));
                     elementLine.appendChild(elementElement);
 
-                    elementElement.setAttribute(QStringLiteral("attribute"), QStringLiteral("t_REALREFUND"));
-                    elementElement.setAttribute(QStringLiteral("operator"), QStringLiteral("#ATT#='#V1S#'"));
-                    elementElement.setAttribute(QStringLiteral("value"), selection.at(i).getAttribute(QStringLiteral("t_name")));
+                    elementElement.setAttribute(QLatin1String("attribute"), QLatin1String("t_REALREFUND"));
+                    elementElement.setAttribute(QLatin1String("operator"), QLatin1String("#ATT#='#V1S#'"));
+                    elementElement.setAttribute(QLatin1String("value"), selection.at(i).getAttribute(QLatin1String("t_name")));
                 }
                 xmlsearchcondition = doc.toString();
-            } else if (table == QStringLiteral("payee")) {
-                QDomDocument doc(QStringLiteral("SKGML"));
-                QDomElement element = doc.createElement(QStringLiteral("element"));
+            } else if (table == QLatin1String("payee")) {
+                QDomDocument doc(QLatin1String("SKGML"));
+                QDomElement element = doc.createElement(QLatin1String("element"));
                 doc.appendChild(element);
                 for (int i = 0; i < nb; ++i) {
-                    QDomElement elementLine = doc.createElement(QStringLiteral("element"));
+                    QDomElement elementLine = doc.createElement(QLatin1String("element"));
                     element.appendChild(elementLine);
 
-                    QDomElement elementElement = doc.createElement(QStringLiteral("element"));
+                    QDomElement elementElement = doc.createElement(QLatin1String("element"));
                     elementLine.appendChild(elementElement);
 
-                    elementElement.setAttribute(QStringLiteral("attribute"), QStringLiteral("t_PAYEE"));
-                    elementElement.setAttribute(QStringLiteral("operator"), QStringLiteral("#ATT#='#V1S#'"));
-                    elementElement.setAttribute(QStringLiteral("value"), selection.at(i).getAttribute(QStringLiteral("t_name")));
+                    elementElement.setAttribute(QLatin1String("attribute"), QLatin1String("t_PAYEE"));
+                    elementElement.setAttribute(QLatin1String("operator"), QLatin1String("#ATT#='#V1S#'"));
+                    elementElement.setAttribute(QLatin1String("value"), selection.at(i).getAttribute(QLatin1String("t_name")));
                 }
                 xmlsearchcondition = doc.toString();
-            } else if (table == QStringLiteral("operation") || table == QStringLiteral("suboperation")) {
+            } else if (table == QLatin1String("operation") || table == QLatin1String("suboperation")) {
                 QStringList attributeForQuery;
-                attributeForQuery << QStringLiteral("d_date") << QStringLiteral("t_number") << QStringLiteral("t_mode") << QStringLiteral("t_PAYEE") << QStringLiteral("t_comment") << QStringLiteral("t_REALCATEGORY") << QStringLiteral("t_status") << QStringLiteral("t_bookmarked") << QStringLiteral("t_imported") << QStringLiteral("t_ACCOUNT") << QStringLiteral("f_REALCURRENTAMOUNT") << QStringLiteral("t_REALREFUND");
+                attributeForQuery << QLatin1String("d_date") << QLatin1String("t_number") << QLatin1String("t_mode") << QLatin1String("t_PAYEE") << QLatin1String("t_comment") << QLatin1String("t_REALCATEGORY") << QLatin1String("t_status") << QLatin1String("t_bookmarked") << QLatin1String("t_imported") << QLatin1String("t_ACCOUNT") << QLatin1String("f_REALCURRENTAMOUNT") << QLatin1String("t_REALREFUND");
 
-                QDomDocument doc(QStringLiteral("SKGML"));
-                QDomElement element = doc.createElement(QStringLiteral("element"));
+                QDomDocument doc(QLatin1String("SKGML"));
+                QDomElement element = doc.createElement(QLatin1String("element"));
                 doc.appendChild(element);
                 for (int i = 0; i < nb; ++i) {
-                    QDomElement elementLine = doc.createElement(QStringLiteral("element"));
+                    QDomElement elementLine = doc.createElement(QLatin1String("element"));
                     element.appendChild(elementLine);
 
                     for (int j = 0; j < attributeForQuery.count(); ++j) {
                         const QString& att = attributeForQuery.at(j);
-                        QString attRead = (att == QStringLiteral("t_REALCATEGORY") ? QStringLiteral("t_CATEGORY") : (att == QStringLiteral("f_REALCURRENTAMOUNT") ? QStringLiteral("f_CURRENTAMOUNT") : (att == QStringLiteral("t_REALREFUND") ? QStringLiteral("t_REFUND") : att)));
+                        QString attRead = (att == QLatin1String("t_REALCATEGORY") ? QLatin1String("t_CATEGORY") : (att == QLatin1String("f_REALCURRENTAMOUNT") ? QLatin1String("f_CURRENTAMOUNT") : (att == QLatin1String("t_REALREFUND") ? QLatin1String("t_REFUND") : att)));
 
-                        SKGObjectBase op(selection.at(i).getDocument(), QStringLiteral("v_operation_display_all"), selection.at(i).getID());
+                        SKGObjectBase op(selection.at(i).getDocument(), QLatin1String("v_operation_display_all"), selection.at(i).getID());
                         op.load();
 
                         QString val = op.getAttribute(attRead);
                         if (!val.isEmpty()) {
-                            QDomElement elementElement = doc.createElement(QStringLiteral("element"));
+                            QDomElement elementElement = doc.createElement(QLatin1String("element"));
                             elementLine.appendChild(elementElement);
 
-                            elementElement.setAttribute(QStringLiteral("attribute"), att);
-                            elementElement.setAttribute(QStringLiteral("operator"), att.startsWith(QLatin1String("f_")) || att.startsWith(QLatin1String("i_")) ? QStringLiteral("#ATT#=#V1#") : QStringLiteral("#ATT#='#V1S#'"));
-                            elementElement.setAttribute(QStringLiteral("value"), val);
+                            elementElement.setAttribute(QLatin1String("attribute"), att);
+                            elementElement.setAttribute(QLatin1String("operator"), att.startsWith(QLatin1String("f_")) || att.startsWith(QLatin1String("i_")) ? QLatin1String("#ATT#=#V1#") : QLatin1String("#ATT#='#V1S#'"));
+                            elementElement.setAttribute(QLatin1String("value"), val);
                         }
                     }
                 }
@@ -325,7 +326,7 @@ QString SKGSearchPlugin::title() const
 
 QString SKGSearchPlugin::icon() const
 {
-    return QStringLiteral("edit-find");
+    return QLatin1String("edit-find");
 }
 
 QString SKGSearchPlugin::toolTip() const
@@ -357,9 +358,9 @@ SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGAdviceList output;
 
     // Alarms
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgsearchplugin_alarm"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgsearchplugin_alarm"))) {
         SKGObjectBase::SKGListSKGObjectBase rules;
-        SKGError err = m_currentBankDocument->getObjects(QStringLiteral("v_rule"), QStringLiteral("t_action_type='A' ORDER BY i_ORDER"), rules);
+        SKGError err = m_currentBankDocument->getObjects(QLatin1String("v_rule"), QLatin1String("t_action_type='A' ORDER BY i_ORDER"), rules);
         int nb = rules.count();
         if (nb != 0) {
             SKGServices::SKGUnitInfo primary = m_currentBankDocument->getPrimaryUnit();
@@ -390,7 +391,7 @@ SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
                         {
                             SKGAdvice::SKGAdviceAction a;
                             a.Title = i18nc("Advice on making the best (action)", "Open transactions corresponding to this alarm");
-                            a.IconName = QStringLiteral("quickopen");
+                            a.IconName = QLatin1String("quickopen");
                             a.IsRecommended = false;
                             autoCorrections.push_back(a);
                         }
