@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGSEARCHPLUGIN_H
@@ -31,7 +31,7 @@ public:
     /**
      * Default Constructor
      */
-    explicit SKGSearchPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg);
+    explicit SKGSearchPlugin(QWidget* iWidget, QObject* iParent, const KPluginMetaData& metaData, const QVariantList& iArg);
 
     /**
      * Default Destructor
