@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -36,87 +36,87 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(QWidget* iParent, SKGDocument* iDoc
     ui.kAlarmMessage->setToolTip(msg);
     ui.kAlarmMessage->setStatusTip(msg);
 
-    ui.kView->getShowWidget()->addItem(QStringLiteral("search"), i18nc("Noun, a search", "Search"), QStringLiteral("edit-find"), QStringLiteral("t_action_type='S'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META + Qt::Key_S);
-    ui.kView->getShowWidget()->addItem(QStringLiteral("update"), i18nc("Noun, a modification", "Update"), QStringLiteral("view-refresh"), QStringLiteral("t_action_type='U'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META + Qt::Key_U);
-    ui.kView->getShowWidget()->addItem(QStringLiteral("alarm"), i18nc("Noun, an alarm", "Alarm"), QStringLiteral("dialog-warning"), QStringLiteral("t_action_type='A'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META + Qt::Key_A);
-    ui.kView->getShowWidget()->addItem(QStringLiteral("template"), i18nc("Noun, a modification by applying a template", "Template"), QStringLiteral("edit-guides"), QStringLiteral("t_action_type='T'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META + Qt::Key_T);
+    ui.kView->getShowWidget()->addItem(QLatin1String("search"), i18nc("Noun, a search", "Search"), QLatin1String("edit-find"), QLatin1String("t_action_type='S'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META | Qt::Key_S);
+    ui.kView->getShowWidget()->addItem(QLatin1String("update"), i18nc("Noun, a modification", "Update"), QLatin1String("view-refresh"), QLatin1String("t_action_type='U'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META | Qt::Key_U);
+    ui.kView->getShowWidget()->addItem(QLatin1String("alarm"), i18nc("Noun, an alarm", "Alarm"), QLatin1String("dialog-warning"), QLatin1String("t_action_type='A'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META | Qt::Key_A);
+    ui.kView->getShowWidget()->addItem(QLatin1String("template"), i18nc("Noun, a modification by applying a template", "Template"), QLatin1String("edit-guides"), QLatin1String("t_action_type='T'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META | Qt::Key_T);
     ui.kView->getShowWidget()->addSeparator();
-    ui.kView->getShowWidget()->addItem(QStringLiteral("highlighted"), i18nc("Adjective, an highlighted item", "Highlighted"), QStringLiteral("bookmarks"), QStringLiteral("t_bookmarked='Y'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META + Qt::Key_H);
-    ui.kView->getShowWidget()->setDefaultState(QStringLiteral("search;update;alarm;template;highlighted"));
+    ui.kView->getShowWidget()->addItem(QLatin1String("highlighted"), i18nc("Adjective, an highlighted item", "Highlighted"), QLatin1String("bookmarks"), QLatin1String("t_bookmarked='Y'"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META | Qt::Key_H);
+    ui.kView->getShowWidget()->setDefaultState(QLatin1String("search;update;alarm;template;highlighted"));
 
     // Add Standard KDE Icons to buttons
-    ui.kUpdate->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
-    ui.kAdd->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
-    ui.kSearch->setIcon(SKGServices::fromTheme(QStringLiteral("edit-find")));
+    ui.kUpdate->setIcon(SKGServices::fromTheme(QLatin1String("dialog-ok")));
+    ui.kAdd->setIcon(SKGServices::fromTheme(QLatin1String("list-add")));
+    ui.kSearch->setIcon(SKGServices::fromTheme(QLatin1String("edit-find")));
     QStringList overlayopen;
-    overlayopen.push_back(QStringLiteral("quickopen"));
-    ui.kOpenReport->setIcon(SKGServices::fromTheme(QStringLiteral("view-statistics"), overlayopen));
+    overlayopen.push_back(QLatin1String("quickopen"));
+    ui.kOpenReport->setIcon(SKGServices::fromTheme(QLatin1String("view-statistics"), overlayopen));
 
-    ui.kTopBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-up-double")));
-    ui.kUpBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-up")));
-    ui.kDownBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down")));
-    ui.kBottomBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down-double")));
+    ui.kTopBtn->setIcon(SKGServices::fromTheme(QLatin1String("arrow-up-double")));
+    ui.kUpBtn->setIcon(SKGServices::fromTheme(QLatin1String("arrow-up")));
+    ui.kDownBtn->setIcon(SKGServices::fromTheme(QLatin1String("arrow-down")));
+    ui.kBottomBtn->setIcon(SKGServices::fromTheme(QLatin1String("arrow-down-double")));
 
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("edit-find")), i18n("Search"), i18n("Display the edit panel for searches"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("edit-find")), i18n("Search"), i18n("Display the edit panel for searches"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
         list.push_back(ui.kActionGrp);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("view-refresh")), i18n("Update"), i18n("Display the edit panel for updates"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("view-refresh")), i18n("Update"), i18n("Display the edit panel for updates"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
         list.push_back(ui.kAlarmFrm);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("dialog-warning")), i18n("Alarm"), i18n("Display the edit panel for alarm"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("dialog-warning")), i18n("Alarm"), i18n("Display the edit panel for alarm"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
         list.push_back(ui.kTemplateFrm);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("edit-guides")), i18n("Template"), i18n("Display the edit panel for updates by templates"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("edit-guides")), i18n("Template"), i18n("Display the edit panel for updates by templates"), list);
     }
 
     QStringList attributeForQuery;
     attributeForQuery.reserve(40);
-    attributeForQuery << QStringLiteral("d_DATEOP") << QStringLiteral("t_number") << QStringLiteral("t_mode") << QStringLiteral("t_PAYEE") << QStringLiteral("t_comment") << QStringLiteral("t_REALCOMMENT") << QStringLiteral("t_REALCATEGORY") << QStringLiteral("t_status") << QStringLiteral("t_bookmarked") << QStringLiteral("t_imported") << QStringLiteral("t_TRANSFER") << QStringLiteral("t_UNIT") << QStringLiteral("t_ACCOUNT") << QStringLiteral("t_BANK") << QStringLiteral("t_TOACCOUNT") << QStringLiteral("f_REALCURRENTAMOUNT") << QStringLiteral("t_REALREFUND") << QStringLiteral("f_BALANCE") << QStringLiteral("i_NBSUBOPERATIONS");
+    attributeForQuery << QLatin1String("d_DATEOP") << QLatin1String("t_number") << QLatin1String("t_mode") << QLatin1String("t_PAYEE") << QLatin1String("t_comment") << QLatin1String("t_REALCOMMENT") << QLatin1String("t_REALCATEGORY") << QLatin1String("t_status") << QLatin1String("t_bookmarked") << QLatin1String("t_imported") << QLatin1String("t_TRANSFER") << QLatin1String("t_UNIT") << QLatin1String("t_ACCOUNT") << QLatin1String("t_BANK") << QLatin1String("t_TOACCOUNT") << QLatin1String("f_REALCURRENTAMOUNT") << QLatin1String("t_REALREFUND") << QLatin1String("f_BALANCE") << QLatin1String("i_NBSUBOPERATIONS");
     QStringList attributeForUpdate;
     attributeForUpdate.reserve(40);
-    attributeForUpdate << QStringLiteral("d_DATEOP") << QStringLiteral("t_number") << QStringLiteral("t_mode") << QStringLiteral("t_PAYEE") << QStringLiteral("t_comment") << QStringLiteral("t_status") << QStringLiteral("t_bookmarked") << QStringLiteral("t_imported") << QStringLiteral("t_REALCOMMENT") << QStringLiteral("t_REALCATEGORY") << QStringLiteral("t_ACCOUNT") << QStringLiteral("t_REALREFUND") << QStringLiteral("t_UNIT");
+    attributeForUpdate << QLatin1String("d_DATEOP") << QLatin1String("t_number") << QLatin1String("t_mode") << QLatin1String("t_PAYEE") << QLatin1String("t_comment") << QLatin1String("t_status") << QLatin1String("t_bookmarked") << QLatin1String("t_imported") << QLatin1String("t_REALCOMMENT") << QLatin1String("t_REALCATEGORY") << QLatin1String("t_ACCOUNT") << QLatin1String("t_REALREFUND") << QLatin1String("t_UNIT");
     // WARNING: trigger must be modified if this list is modifier
 
     // Adding properties
     QStringList properties;
-    iDocument->getDistinctValues(QStringLiteral("parameters"), QStringLiteral("t_name"), QStringLiteral("(t_uuid_parent like '%-operation' OR t_uuid_parent like '%-suboperation') AND t_name NOT LIKE 'SKG_%'"), properties);
+    iDocument->getDistinctValues(QLatin1String("parameters"), QLatin1String("t_name"), QLatin1String("(t_uuid_parent like '%-operation' OR t_uuid_parent like '%-suboperation') AND t_name NOT LIKE 'SKG_%'"), properties);
     int nb = properties.count();
     for (int i = 0; i < nb; ++i) {
         attributeForQuery.push_back("p_" % properties.at(i));
         attributeForUpdate.push_back("p_" % properties.at(i));
     }
 
-    ui.kQueryCreator->setParameters(iDocument, QStringLiteral("v_suboperation_consolidated"), attributeForQuery);
-    ui.kActionCreator->setParameters(iDocument, QStringLiteral("v_suboperation_consolidated"), attributeForUpdate, true);
+    ui.kQueryCreator->setParameters(iDocument, QLatin1String("v_suboperation_consolidated"), attributeForQuery);
+    ui.kActionCreator->setParameters(iDocument, QLatin1String("v_suboperation_consolidated"), attributeForUpdate, true);
 
     // Bind transaction view
-    ui.kView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_rule_display"), QStringLiteral("1=1 ORDER BY f_sortorder"), this, QLatin1String(""), false));
+    ui.kView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("v_rule_display"), QLatin1String("1=1 ORDER BY f_sortorder"), this, QLatin1String(""), false));
     ui.kView->getView()->sortByColumn(0, Qt::AscendingOrder);
 
     // Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel() != nullptr) {
         auto menu = new QMenu(this);
-        menu->setIcon(SKGServices::fromTheme(QStringLiteral("system-run")));
-        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("execute_all")));
-        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("execute_imported")));
-        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("execute_not_validated")));
-        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("execute_notchecked")));
+        menu->setIcon(SKGServices::fromTheme(QLatin1String("system-run")));
+        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("execute_all")));
+        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("execute_imported")));
+        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("execute_not_validated")));
+        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("execute_notchecked")));
 
         ui.kApply->setIcon(menu->icon());
         ui.kApply->setMenu(menu);
@@ -126,7 +126,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(QWidget* iParent, SKGDocument* iDoc
     ui.kWidgetSelector->setSelectedMode(0);
 
     connect(ui.kView->getView(), &SKGTreeView::clickEmptyArea, this, &SKGSearchPluginWidget::cleanEditor);
-    connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open")).data(), &QAction::trigger);
+    connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("open")).data(), &QAction::trigger);
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, this, [ = ] {this->onSelectionChanged();});
     connect(ui.kQueryCreator, &SKGQueryCreator::search, this, &SKGSearchPluginWidget::onOpen);
 
@@ -173,23 +173,23 @@ bool SKGSearchPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 QString SKGSearchPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
-    root.setAttribute(QStringLiteral("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
-    root.setAttribute(QStringLiteral("view"), ui.kView->getState());
+    root.setAttribute(QLatin1String("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
+    root.setAttribute(QLatin1String("view"), ui.kView->getState());
     return doc.toString();
 }
 
 void SKGSearchPluginWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString currentPage = root.attribute(QStringLiteral("currentPage"));
-    QString xmlsearchcondition = root.attribute(QStringLiteral("xmlsearchcondition"));
+    QString currentPage = root.attribute(QLatin1String("currentPage"));
+    QString xmlsearchcondition = root.attribute(QLatin1String("xmlsearchcondition"));
 
     if (currentPage.isEmpty()) {
         currentPage = '0';
@@ -197,12 +197,12 @@ void SKGSearchPluginWidget::setState(const QString& iState)
 
     ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
     ui.kQueryCreator->setXMLCondition(xmlsearchcondition);
-    ui.kView->setState(root.attribute(QStringLiteral("view")));
+    ui.kView->setState(root.attribute(QLatin1String("view")));
 }
 
 QString SKGSearchPluginWidget::getDefaultStateAttribute()
 {
-    return QStringLiteral("SKGSEARCH_DEFAULT_PARAMETERS");
+    return QLatin1String("SKGSEARCH_DEFAULT_PARAMETERS");
 }
 
 QWidget* SKGSearchPluginWidget::mainWidget()
@@ -231,14 +231,14 @@ void SKGSearchPluginWidget::dataModified(const QString& iTableName, int iIdTrans
     Q_UNUSED(iIdTransaction)
 
     // Refresh account list
-    if (iTableName == QStringLiteral("unit") || iTableName.isEmpty()) {
+    if (iTableName == QLatin1String("unit") || iTableName.isEmpty()) {
         ui.kAlarmUnit->setText(qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit().Symbol);
     }
 
-    if (iTableName == QStringLiteral("operation") || iTableName.isEmpty()) {
+    if (iTableName == QLatin1String("operation") || iTableName.isEmpty()) {
         // Fill combo boxes
         SKGStringListList result;
-        getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT id, t_displayname FROM v_operation_displayname WHERE t_template='Y' ORDER BY t_displayname"), result);
+        getDocument()->executeSelectSqliteOrder(QLatin1String("SELECT id, t_displayname FROM v_operation_displayname WHERE t_template='Y' ORDER BY t_displayname"), result);
         int nb2 = result.count();
         for (int i = 1; i < nb2; ++i) {  // Ignore header
             const QStringList& r = result.at(i);
@@ -357,23 +357,23 @@ void SKGSearchPluginWidget::onSelectionChanged()
             ui.kActionCreator->setXMLCondition(rule.getXMLActionDefinition());
         } else if (index == 2) {
             // Set alarm mode
-            QDomDocument doc(QStringLiteral("SKGML"));
+            QDomDocument doc(QLatin1String("SKGML"));
             doc.setContent(rule.getXMLActionDefinition());
 
             QDomElement element = doc.documentElement();
             QDomElement elementLine = element.firstChild().toElement();
             QDomElement elementElement = elementLine.firstChild().toElement();
-            ui.kAlarmAmount->setValue(SKGServices::stringToDouble(elementElement.attribute(QStringLiteral("value"))));
-            ui.kAlarmMessage->setText(elementElement.attribute(QStringLiteral("value2")));
+            ui.kAlarmAmount->setValue(SKGServices::stringToDouble(elementElement.attribute(QLatin1String("value"))));
+            ui.kAlarmMessage->setText(elementElement.attribute(QLatin1String("value2")));
         } else if (index == 3) {
             // Set template mode
-            QDomDocument doc(QStringLiteral("SKGML"));
+            QDomDocument doc(QLatin1String("SKGML"));
             doc.setContent(rule.getXMLActionDefinition());
 
             QDomElement element = doc.documentElement();
             QDomElement elementLine = element.firstChild().toElement();
             QDomElement elementElement = elementLine.firstChild().toElement();
-            ui.kTemplate->setCurrentIndex(ui.kTemplate->findData(elementElement.attribute(QStringLiteral("value"))));
+            ui.kTemplate->setCurrentIndex(ui.kTemplate->findData(elementElement.attribute(QLatin1String("value"))));
         }
     }
 
@@ -397,7 +397,7 @@ void SKGSearchPluginWidget::onTop()
 
             double order = 1;
             SKGStringListList result;
-            err = getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT min(f_sortorder) from rule"), result);
+            err = getDocument()->executeSelectSqliteOrder(QLatin1String("SELECT min(f_sortorder) from rule"), result);
             if (!err && result.count() == 2) {
                 order = SKGServices::stringToDouble(result.at(1).at(0)) - 1;
             }
@@ -525,7 +525,7 @@ void SKGSearchPluginWidget::onBottom()
 
             double order = 1;
             SKGStringListList result;
-            err = getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT max(f_sortorder) from rule"), result);
+            err = getDocument()->executeSelectSqliteOrder(QLatin1String("SELECT max(f_sortorder) from rule"), result);
             if (!err && result.count() == 2) {
                 order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
             }
@@ -555,29 +555,29 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule, OpenMode iMode)
     _SKGTRACEINFUNC(10)
 
     // Build where clause and title
-    QString wc = "i_SUBOPID in (SELECT i_SUBOPID FROM v_operation_prop WHERE " % iRule.getSelectSqlOrder() % ')';
+    QString wc = "i_SUBOPID in (SELECT i_SUBOPID FROM v_operation_prop WHERE " % iRule.getSelectSqlOrder() % QLatin1Char(')');
     QString title = i18nc("Noun, a list of items", "Sub transactions corresponding to rule '%1'",  iRule.getSearchDescription());
 
     // Call transaction plugin
-    QDomDocument doc(QStringLiteral("SKGML"));
-    doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(iMode == TABLE ? QStringLiteral("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS") : QStringLiteral("SKGREPORT_DEFAULT_PARAMETERS")));
+    QDomDocument doc(QLatin1String("SKGML"));
+    doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(iMode == TABLE ? QLatin1String("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS") : QLatin1String("SKGREPORT_DEFAULT_PARAMETERS")));
     QDomElement root = doc.documentElement();
     if (root.isNull()) {
-        root = doc.createElement(QStringLiteral("parameters"));
+        root = doc.createElement(QLatin1String("parameters"));
         doc.appendChild(root);
     }
 
-    root.setAttribute(QStringLiteral("operationWhereClause"), wc);
-    root.setAttribute(QStringLiteral("title"), title);
-    root.setAttribute(QStringLiteral("title_icon"), QStringLiteral("edit-find"));
+    root.setAttribute(QLatin1String("operationWhereClause"), wc);
+    root.setAttribute(QLatin1String("title"), title);
+    root.setAttribute(QLatin1String("title_icon"), QLatin1String("edit-find"));
 
     if (iMode == TABLE) {
-        root.setAttribute(QStringLiteral("operationTable"), QStringLiteral("v_suboperation_consolidated"));
-        root.setAttribute(QStringLiteral("currentPage"), QStringLiteral("-1"));
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge operation plugin")), -1, doc.toString(), i18nc("Noun, a list of items", "Sub transactions"));
+        root.setAttribute(QLatin1String("operationTable"), QLatin1String("v_suboperation_consolidated"));
+        root.setAttribute(QLatin1String("currentPage"), QLatin1String("-1"));
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QLatin1String("Skrooge operation plugin")), -1, doc.toString(), i18nc("Noun, a list of items", "Sub transactions"));
     } else {
-        root.setAttribute(QStringLiteral("period"), QStringLiteral("0"));
-        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge report plugin")), -1, doc.toString());
+        root.setAttribute(QLatin1String("period"), QLatin1String("0"));
+        SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(QLatin1String("Skrooge report plugin")), -1, doc.toString());
     }
 }
 
@@ -639,39 +639,39 @@ QString SKGSearchPluginWidget::getXMLActionDefinition()
         output = ui.kActionCreator->getXMLCondition();
     } else if (ui.kWidgetSelector->getSelectedMode() == 2) {
         // Mode alarm
-        QDomDocument doc(QStringLiteral("SKGML"));
-        QDomElement element = doc.createElement(QStringLiteral("element"));
+        QDomDocument doc(QLatin1String("SKGML"));
+        QDomElement element = doc.createElement(QLatin1String("element"));
         doc.appendChild(element);
 
-        QDomElement elementLine = doc.createElement(QStringLiteral("element"));
+        QDomElement elementLine = doc.createElement(QLatin1String("element"));
         element.appendChild(elementLine);
 
-        QDomElement elementElement = doc.createElement(QStringLiteral("element"));
+        QDomElement elementElement = doc.createElement(QLatin1String("element"));
         elementLine.appendChild(elementElement);
 
-        elementElement.setAttribute(QStringLiteral("attribute"), QStringLiteral("f_REALCURRENTAMOUNT"));
-        elementElement.setAttribute(QStringLiteral("operator"), QStringLiteral("ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'"));
-        elementElement.setAttribute(QStringLiteral("operator2"), QStringLiteral(">="));
-        elementElement.setAttribute(QStringLiteral("value"), SKGServices::doubleToString(ui.kAlarmAmount->value()));
-        elementElement.setAttribute(QStringLiteral("value2"), ui.kAlarmMessage->text());
+        elementElement.setAttribute(QLatin1String("attribute"), QLatin1String("f_REALCURRENTAMOUNT"));
+        elementElement.setAttribute(QLatin1String("operator"), QLatin1String("ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'"));
+        elementElement.setAttribute(QLatin1String("operator2"), QLatin1String(">="));
+        elementElement.setAttribute(QLatin1String("value"), SKGServices::doubleToString(ui.kAlarmAmount->value()));
+        elementElement.setAttribute(QLatin1String("value2"), ui.kAlarmMessage->text());
 
         output = doc.toString();
     } else if (ui.kWidgetSelector->getSelectedMode() == 3) {
         // Mode template
-        QDomDocument doc(QStringLiteral("SKGML"));
-        QDomElement element = doc.createElement(QStringLiteral("element"));
+        QDomDocument doc(QLatin1String("SKGML"));
+        QDomElement element = doc.createElement(QLatin1String("element"));
         doc.appendChild(element);
 
-        QDomElement elementLine = doc.createElement(QStringLiteral("element"));
+        QDomElement elementLine = doc.createElement(QLatin1String("element"));
         element.appendChild(elementLine);
 
-        QDomElement elementElement = doc.createElement(QStringLiteral("element"));
+        QDomElement elementElement = doc.createElement(QLatin1String("element"));
         elementLine.appendChild(elementElement);
 
-        elementElement.setAttribute(QStringLiteral("attribute"), QStringLiteral("id"));
-        elementElement.setAttribute(QStringLiteral("operator"), QStringLiteral("APPLYTEMPLATE(#V1#)"));
-        elementElement.setAttribute(QStringLiteral("value"), ui.kTemplate->itemData(ui.kTemplate->currentIndex()).toString());
-        elementElement.setAttribute(QStringLiteral("value2"), ui.kTemplate->currentText());
+        elementElement.setAttribute(QLatin1String("attribute"), QLatin1String("id"));
+        elementElement.setAttribute(QLatin1String("operator"), QLatin1String("APPLYTEMPLATE(#V1#)"));
+        elementElement.setAttribute(QLatin1String("value"), ui.kTemplate->itemData(ui.kTemplate->currentIndex()).toString());
+        elementElement.setAttribute(QLatin1String("value2"), ui.kTemplate->currentText());
 
         output = doc.toString();
     }
