@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -25,7 +25,9 @@
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGTrackerPlugin, "metadata.json")
 
-SKGTrackerPlugin::SKGTrackerPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
+SKGTrackerPlugin::SKGTrackerPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -47,8 +49,8 @@ bool SKGTrackerPlugin::setupActions(SKGDocument* iDocument)
 
     m_currentBankDocument = iDocument;
 
-    setComponentName(QStringLiteral("skrooge_tracker"), title());
-    setXMLFile(QStringLiteral("skrooge_tracker.rc"));
+    setComponentName(QLatin1String("skrooge_tracker"), title());
+    setXMLFile(QLatin1String("skrooge_tracker.rc"));
 
     // Create yours actions here
     return true;
@@ -72,7 +74,7 @@ QString SKGTrackerPlugin::title() const
 
 QString SKGTrackerPlugin::icon() const
 {
-    return QStringLiteral("crosshairs");
+    return QLatin1String("crosshairs");
 }
 
 QString SKGTrackerPlugin::toolTip() const
@@ -102,9 +104,9 @@ SKGAdviceList SKGTrackerPlugin::advice(const QStringList& iIgnoredAdvice)
     SKGTRACEINFUNC(10)
     SKGAdviceList output;
     // Search old trackers
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgtrackerplugin_old"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgtrackerplugin_old"))) {
         SKGStringListList result;
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name  FROM v_refund_display WHERE t_close='N' AND julianday('now', 'localtime')-julianday(d_LASTDATE)>300 ORDER BY julianday('now', 'localtime')-julianday(d_LASTDATE) DESC;"), result);
+        m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT t_name  FROM v_refund_display WHERE t_close='N' AND julianday('now', 'localtime')-julianday(d_LASTDATE)>300 ORDER BY julianday('now', 'localtime')-julianday(d_LASTDATE) DESC;"), result);
         int nb = result.count();
         output.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
