@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -27,7 +27,7 @@ SKGUnitBoardWidget::SKGUnitBoardWidget(QWidget* iParent, SKGDocument* iDocument)
     // Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    m_menuFavorite = new QAction(SKGServices::fromTheme(QStringLiteral("bookmarks")), i18nc("Display only favorite accounts", "Highlighted only"), this);
+    m_menuFavorite = new QAction(SKGServices::fromTheme(QLatin1String("bookmarks")), i18nc("Display only favorite accounts", "Highlighted only"), this);
     m_menuFavorite->setCheckable(true);
     m_menuFavorite->setChecked(false);
     connect(m_menuFavorite, &QAction::triggered, this, [ = ]() {
@@ -104,16 +104,16 @@ SKGUnitBoardWidget::~SKGUnitBoardWidget()
 
 QString SKGUnitBoardWidget::getState()
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
-    root.setAttribute(QStringLiteral("m_menuCurrencies"), (m_menuCurrencies != nullptr) && m_menuCurrencies->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("m_menuObjects"), (m_menuObjects != nullptr) && m_menuObjects->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuIndexes"), (m_menuIndexes != nullptr) && m_menuIndexes->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuShares"), (m_menuShares != nullptr) && m_menuShares->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuSharesOwnedOnly"), (m_menuSharesOwnedOnly != nullptr) && m_menuSharesOwnedOnly->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuFavorite"), (m_menuFavorite != nullptr) && m_menuFavorite->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QLatin1String("m_menuCurrencies"), (m_menuCurrencies != nullptr) && m_menuCurrencies->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("m_menuObjects"), (m_menuObjects != nullptr) && m_menuObjects->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuIndexes"), (m_menuIndexes != nullptr) && m_menuIndexes->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuShares"), (m_menuShares != nullptr) && m_menuShares->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuSharesOwnedOnly"), (m_menuSharesOwnedOnly != nullptr) && m_menuSharesOwnedOnly->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("menuFavorite"), (m_menuFavorite != nullptr) && m_menuFavorite->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
     return doc.toString();
 }
 
@@ -121,27 +121,27 @@ void SKGUnitBoardWidget::setState(const QString& iState)
 {
     SKGBoardWidget::setState(iState);
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     if (m_menuCurrencies != nullptr) {
-        m_menuCurrencies->setChecked(root.attribute(QStringLiteral("m_menuCurrencies")) == QStringLiteral("Y"));
+        m_menuCurrencies->setChecked(root.attribute(QLatin1String("m_menuCurrencies")) == QLatin1String("Y"));
     }
     if (m_menuObjects != nullptr) {
-        m_menuObjects->setChecked(root.attribute(QStringLiteral("m_menuObjects")) == QStringLiteral("Y"));
+        m_menuObjects->setChecked(root.attribute(QLatin1String("m_menuObjects")) == QLatin1String("Y"));
     }
     if (m_menuIndexes != nullptr) {
-        m_menuIndexes->setChecked(root.attribute(QStringLiteral("menuIndexes")) != QStringLiteral("N"));
+        m_menuIndexes->setChecked(root.attribute(QLatin1String("menuIndexes")) != QLatin1String("N"));
     }
     if (m_menuShares != nullptr) {
-        m_menuShares->setChecked(root.attribute(QStringLiteral("menuShares")) != QStringLiteral("N"));
+        m_menuShares->setChecked(root.attribute(QLatin1String("menuShares")) != QLatin1String("N"));
     }
     if (m_menuSharesOwnedOnly != nullptr) {
-        m_menuSharesOwnedOnly->setChecked(root.attribute(QStringLiteral("menuSharesOwnedOnly")) != QStringLiteral("N"));
+        m_menuSharesOwnedOnly->setChecked(root.attribute(QLatin1String("menuSharesOwnedOnly")) != QLatin1String("N"));
     }
     if (m_menuFavorite != nullptr) {
-        m_menuFavorite->setChecked(root.attribute(QStringLiteral("menuFavorite")) == QStringLiteral("Y"));
+        m_menuFavorite->setChecked(root.attribute(QLatin1String("menuFavorite")) == QLatin1String("Y"));
     }
 
     dataModified(QLatin1String(""), 0);
@@ -152,7 +152,7 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
     SKGTRACEINFUNC(10)
     Q_UNUSED(iIdTransaction)
 
-    if (iTableName == QStringLiteral("v_unit_display") || iTableName.isEmpty()) {
+    if (iTableName == QLatin1String("v_unit_display") || iTableName.isEmpty()) {
         auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
         if (doc != nullptr) {
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
@@ -167,51 +167,51 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                 }
 
                 if (m_menuIndexes->isChecked()) {
-                    wc = QStringLiteral("t_type='I'");
+                    wc = QLatin1String("t_type='I'");
                 }
                 if (m_menuShares->isChecked()) {
                     if (!wc.isEmpty()) {
-                        wc += QStringLiteral(" OR ");
+                        wc += QLatin1String(" OR ");
                     }
                     if (m_menuSharesOwnedOnly->isChecked()) {
-                        wc += QStringLiteral("(t_type='S' AND f_QUANTITYOWNED>0)");
+                        wc += QLatin1String("(t_type='S' AND f_QUANTITYOWNED>0)");
                     } else {
-                        wc += QStringLiteral("t_type='S'");
+                        wc += QLatin1String("t_type='S'");
                     }
                 }
                 if (m_menuCurrencies->isChecked()) {
                     if (!wc.isEmpty()) {
-                        wc += QStringLiteral(" OR ");
+                        wc += QLatin1String(" OR ");
                     }
-                    wc += QStringLiteral("t_type IN ('1','2','C')");
+                    wc += QLatin1String("t_type IN ('1','2','C')");
                 }
                 if (m_menuObjects->isChecked()) {
                     if (!wc.isEmpty()) {
-                        wc += QStringLiteral(" OR ");
+                        wc += QLatin1String(" OR ");
                     }
-                    wc += QStringLiteral("t_type='O'");
+                    wc += QLatin1String("t_type='O'");
                 }
             }
 
             if (wc.isEmpty()) {
-                wc = QStringLiteral("1=0");
+                wc = QLatin1String("1=0");
             } else if ((m_menuFavorite != nullptr) && m_menuFavorite->isChecked()) {
-                wc = "t_bookmarked='Y' AND (" % wc % ')';
+                wc = "t_bookmarked='Y' AND (" % wc % QLatin1Char(')');
             }
 
             SKGObjectBase::SKGListSKGObjectBase objs;
-            SKGError err = getDocument()->getObjects(QStringLiteral("v_unit_display"), wc % " ORDER BY t_type DESC, t_name ASC", objs);
+            SKGError err = getDocument()->getObjects(QLatin1String("v_unit_display"), wc % " ORDER BY t_type DESC, t_name ASC", objs);
             IFOK(err) {
                 KColorScheme scheme(QPalette::Normal, KColorScheme::Window);
                 auto color = scheme.foreground(KColorScheme::NormalText).color().name().right(6);
-                QString html = QStringLiteral("<html><head><style>a {color: #") + color + ";}</style></head><body>";
+                QString html = QLatin1String("<html><head><style>a {color: #") + color + ";}</style></head><body>";
                 int nb = objs.count();
                 if (nb != 0) {
-                    html += QStringLiteral("<table>");
+                    html += QLatin1String("<table>");
                     QString lastTitle;
                     for (int i = 0; i < nb; ++i) {
                         SKGUnitObject obj(objs.at(i));
-                        QString type = obj.getAttribute(QStringLiteral("t_TYPENLS"));
+                        QString type = obj.getAttribute(QLatin1String("t_TYPENLS"));
                         if (lastTitle != type) {
                             lastTitle = type;
                             html += "<tr><td><b>" % SKGServices::stringToHtml(lastTitle) % "</b></td></tr>";
@@ -222,24 +222,24 @@ void SKGUnitBoardWidget::dataModified(const QString& iTableName, int iIdTransact
                         if (obj.getType() == SKGUnitObject::INDEX) {
                             primary.Symbol = ' ';
                         }
-                        html += doc->formatMoney(SKGServices::stringToDouble(obj.getAttribute(QStringLiteral("f_CURRENTAMOUNT"))), primary);
-                        html += QStringLiteral("</td><td>(");
+                        html += doc->formatMoney(SKGServices::stringToDouble(obj.getAttribute(QLatin1String("f_CURRENTAMOUNT"))), primary);
+                        html += QLatin1String("</td><td>(");
                         double amountOneYearBefore = obj.getAmount(QDate::currentDate().addYears(-1));
                         double val = 100.0 * (obj.getAmount() - amountOneYearBefore) / amountOneYearBefore;
                         html += doc->formatPercentage(val);
-                        html += QStringLiteral(")</td></tr>");
+                        html += QLatin1String(")</td></tr>");
                     }
-                    html += QStringLiteral("</table>");
+                    html += QLatin1String("</table>");
                 } else {
                     html += i18nc("Message about not having any financial Share or financial index in the document", R"(No share or index defined<br>on the <a href="%1">"Units"</a> page.)", "skg://Skrooge_unit_plugin");
                 }
-                html += QStringLiteral("</body></html>");
+                html += QLatin1String("</body></html>");
                 m_label->setText(html);
             }
 
             // No widget if no account
             bool exist = false;
-            getDocument()->existObjects(QStringLiteral("account"), QLatin1String(""), exist);
+            getDocument()->existObjects(QLatin1String("account"), QLatin1String(""), exist);
             if (parentWidget() != nullptr) {
                 setVisible(exist);
             }
