@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -13,7 +13,7 @@
 #include <kaboutdata.h>
 #include <kactioncollection.h>
 #include <kpluginfactory.h>
-#include <kservicetypetrader.h>
+#include <kpluginmetadata.h>
 
 #include <qaction.h>
 #include <qinputdialog.h>
@@ -28,15 +28,16 @@
 #include "skgunit_settings.h"
 #include "skgunitboardwidget.h"
 #include "skgunitpluginwidget.h"
-#include "skgunitvalueobject.h"
+#include <utility>
 
 /**
  * This plugin factory.
  */
 K_PLUGIN_CLASS_WITH_JSON(SKGUnitPlugin, "metadata.json")
 
-SKGUnitPlugin::SKGUnitPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
-    : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
+SKGUnitPlugin::SKGUnitPlugin(QWidget *iWidget, QObject *iParent, const KPluginMetaData & /*metaData*/, const QVariantList & /*iArg*/)
+    : SKGInterfacePlugin(iParent)
+    , m_currentBankDocument(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -57,19 +58,19 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument)
         return false;
     }
 
-    setComponentName(QStringLiteral("skrooge_unit"), title());
-    setXMLFile(QStringLiteral("skrooge_unit.rc"));
+    setComponentName(QLatin1String("skrooge_unit"), title());
+    setXMLFile(QLatin1String("skrooge_unit.rc"));
 
     // Menu
-    auto actSplitShare = new QAction(SKGServices::fromTheme(QStringLiteral("format-text-strikethrough")), i18nc("Verb", "Split share…"), this);
+    auto actSplitShare = new QAction(SKGServices::fromTheme(QLatin1String("format-text-strikethrough")), i18nc("Verb", "Split share…"), this);
     connect(actSplitShare, &QAction::triggered, this, &SKGUnitPlugin::onSplitShare);
-    actionCollection()->setDefaultShortcut(actSplitShare, Qt::ALT + Qt::Key_Slash);
-    registerGlobalAction(QStringLiteral("edit_split_stock"), actSplitShare, QStringList() << QStringLiteral("unit"), 1, 1, 310);  // TODO(Stephane MANKOWSKI): must be a share
+    actionCollection()->setDefaultShortcut(actSplitShare, Qt::ALT | Qt::Key_Slash);
+    registerGlobalAction(QLatin1String("edit_split_stock"), actSplitShare, QStringList() << QLatin1String("unit"), 1, 1, 310);  // TODO(Stephane MANKOWSKI): must be a share
 
     // -----------
     auto act = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb", "Delete unused units"), this);
     connect(act, &QAction::triggered, this, &SKGUnitPlugin::deleteUnusedUnits);
-    registerGlobalAction(QStringLiteral("clean_delete_unused_units"), act);
+    registerGlobalAction(QLatin1String("clean_delete_unused_units"), act);
     return true;
 }
 
@@ -92,18 +93,18 @@ SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
         return new SKGUnitBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
     }
 
-    auto listForFilter = QStringList() << QStringLiteral("t_name")
-                         << QStringLiteral("t_symbol")
-                         << QStringLiteral("t_country")
-                         << QStringLiteral("t_type")
-                         << QStringLiteral("t_internet_code")
-                         << QStringLiteral("t_source")
-                         << QStringLiteral("t_bookmarked");
+    auto listForFilter = QStringList() << QLatin1String("t_name")
+                         << QLatin1String("t_symbol")
+                         << QLatin1String("t_country")
+                         << QLatin1String("t_type")
+                         << QLatin1String("t_internet_code")
+                         << QLatin1String("t_source")
+                         << QLatin1String("t_bookmarked");
 
     return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
-                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/portfolio.qml")),
-                                  QStringList() << QStringLiteral("v_operation_display"),
+                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("skrooge/html/default/portfolio.qml")),
+                                  QStringList() << QLatin1String("v_operation_display"),
                                   SKGSimplePeriodEdit::NONE,
                                   listForFilter);
 }
@@ -118,7 +119,7 @@ void SKGUnitPlugin::refresh()
             m_docUniqueIdentifier = std::move(doc_id);
             // Check if current unit is existing
             bool exist = false;
-            SKGError err = m_currentBankDocument->existObjects(QStringLiteral("unit"), QLatin1String(""), exist);
+            SKGError err = m_currentBankDocument->existObjects(QLatin1String("unit"), QLatin1String(""), exist);
             IFOK(err) {
                 if (!exist) {
                     SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Create default unit"), err)
@@ -135,11 +136,11 @@ void SKGUnitPlugin::refresh()
                     }
                 } else if (skgunit_settings::download_on_open()) {
                     // Check frequency
-                    QString lastAutomaticDownload = m_currentBankDocument->getParameter(QStringLiteral("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD"));
+                    QString lastAutomaticDownload = m_currentBankDocument->getParameter(QLatin1String("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD"));
                     if (lastAutomaticDownload.isEmpty()) {
-                        lastAutomaticDownload = QStringLiteral("1970-01-01");
+                        lastAutomaticDownload = QLatin1String("1970-01-01");
                     }
-                    QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, QStringLiteral("yyyy-MM-dd"));
+                    QDate lastAutomaticDownloadDate = QDate::fromString(lastAutomaticDownload, QLatin1String("yyyy-MM-dd"));
                     if ((lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 1 && skgunit_settings::download_frequency() == 0) ||
                         (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 7 && skgunit_settings::download_frequency() == 1) ||
                         (lastAutomaticDownloadDate.daysTo(QDate::currentDate()) >= 30 && skgunit_settings::download_frequency() == 2))
@@ -147,7 +148,7 @@ void SKGUnitPlugin::refresh()
                     {
                         // Download all units
                         SKGObjectBase::SKGListSKGObjectBase selection;
-                        err = m_currentBankDocument->getObjects(QStringLiteral("unit"), QLatin1String(""), selection);
+                        err = m_currentBankDocument->getObjects(QLatin1String("unit"), QLatin1String(""), selection);
                         int nb = selection.count();
                         SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Automatic download of units"), err, nb)
                         for (int i = 0; !err && i < nb; ++i) {
@@ -161,7 +162,7 @@ void SKGUnitPlugin::refresh()
                         }
 
                         // Memorize the last download date
-                        IFOKDO(err, m_currentBankDocument->setParameter(QStringLiteral("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD"), QDate::currentDate().toString(QStringLiteral("yyyy-MM-dd"))))
+                        IFOKDO(err, m_currentBankDocument->setParameter(QLatin1String("SKG_LAST_UNIT_AUTOMATIC_DOWNLOAD"), QDate::currentDate().toString(QLatin1String("yyyy-MM-dd"))))
                     }
                 }
             }
@@ -174,7 +175,7 @@ void SKGUnitPlugin::refresh()
 
 QStringList SKGUnitPlugin::subPlugins() const
 {
-    return QStringList() << QStringLiteral("skrooge/source");
+    return QStringList() << QLatin1String("skrooge_source");
 }
 
 SKGTabPage* SKGUnitPlugin::getWidget()
@@ -191,15 +192,10 @@ QWidget* SKGUnitPlugin::getPreferenceWidget()
 
     // Get sources from.desktop file
     QStringList sources;
-    const auto list2 = KServiceTypeTrader::self()->query(QStringLiteral("skrooge/source"));
+    const auto list2 = SKGServices::findDataPlugins(QLatin1String("skrooge_source"));
     for (const auto& service : list2) {
-#ifdef SKG_KF_5102
-        auto name = service->property(QStringLiteral("X-KDE-PluginInfo-Name"), QMetaType::QString).toString();
-        auto keyAPI = service->property(QStringLiteral("X-SKROOGE-keyAPI"), QMetaType::Bool).toBool();
-#else
-        auto name = service->property(QStringLiteral("X-KDE-PluginInfo-Name"), QVariant::String).toString();
-        auto keyAPI = service->property(QStringLiteral("X-SKROOGE-keyAPI"), QVariant::Bool).toBool();
-#endif
+        auto name = service.pluginId().remove(QLatin1String("org.kde.skrooge-source-")).toLower();
+        auto keyAPI = service.value(QLatin1String("X-SKROOGE-keyAPI"), false);
         if (!sources.contains(name) && keyAPI) {
             sources.push_back(name);
         }
@@ -224,7 +220,7 @@ QWidget* SKGUnitPlugin::getPreferenceWidget()
         {
             SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Save API keys"), err)
             auto keys = lwidgets->keys();
-            for (const auto& k : qAsConst(keys)) {
+            for (const auto& k : std::as_const(keys)) {
                 m_currentBankDocument->setParameter("KEYAPI_" + k, lwidgets->value(k)->text());
             }
         }
@@ -247,7 +243,7 @@ QString SKGUnitPlugin::title() const
 
 QString SKGUnitPlugin::icon() const
 {
-    return QStringLiteral("taxes-finances");
+    return QLatin1String("taxes-finances");
 }
 
 QString SKGUnitPlugin::toolTip() const
@@ -318,11 +314,11 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Get all currencies
     SKGStringListList result;
-    m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT (SELECT count(1) FROM operation WHERE operation.rc_unit_id=unit.id), unit.t_name FROM unit WHERE t_type='C' GROUP BY t_name ORDER BY count(1) DESC"), result);
+    m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT (SELECT count(1) FROM operation WHERE operation.rc_unit_id=unit.id), unit.t_name FROM unit WHERE t_type='C' GROUP BY t_name ORDER BY count(1) DESC"), result);
     int nb = result.count();
 
     // Check primary unit
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_primaryunit"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgunitplugin_primaryunit"))) {
         if (m_currentBankDocument->getPrimaryUnit().Name.isEmpty() && nb > 1) {
             // Get unit
             QString unit = result.at(1).at(1);
@@ -355,7 +351,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Check secondary unit
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_secondaryunit"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgunitplugin_secondaryunit"))) {
         if (m_currentBankDocument->getSecondaryUnit().Name.isEmpty() && nb > 1) {
             // Get unit
             QString unit = result.at(1).at(1);
@@ -386,8 +382,8 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Shares not downloaded
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_notdownloaded"))) {
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name, t_internet_code from unit WHERE t_internet_code<>'' AND (julianday('now', 'localtime')-(SELECT MAX(julianday(d_date)) FROM unitvalue WHERE rd_unit_id=unit.id ))>30 OR NOT EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)"), result);
+    if (!iIgnoredAdvice.contains(QLatin1String("skgunitplugin_notdownloaded"))) {
+        m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT t_name, t_internet_code from unit WHERE t_internet_code<>'' AND (julianday('now', 'localtime')-(SELECT MAX(julianday(d_date)) FROM unitvalue WHERE rd_unit_id=unit.id ))>30 OR NOT EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)"), result);
         nb = result.count();
         SKGAdvice::SKGAdviceActionList autoCorrections;
         autoCorrections.reserve(nb);
@@ -413,7 +409,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             if (!internet_code.isEmpty()) {
                 SKGAdvice::SKGAdviceAction a;
                 a.Title = i18nc("Advice on making the best (action)", "Download '%1'", unit);
-                a.IconName = QStringLiteral("download");
+                a.IconName = QLatin1String("download");
                 a.IsRecommended = true;
                 autoCorrections.push_back(a);
             }
@@ -423,25 +419,25 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Check unused units
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_unused"))) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgunitplugin_unused"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects(QStringLiteral("unit"), QStringLiteral("t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)"), exist);
+        m_currentBankDocument->existObjects(QLatin1String("unit"), QLatin1String("t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)"), exist);
         if (exist) {
             SKGAdvice ad;
-            ad.setUUID(QStringLiteral("skgunitplugin_unused"));
+            ad.setUUID(QLatin1String("skgunitplugin_unused"));
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused units"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing units for which no transaction is registered."));
             QStringList autoCorrections;
-            autoCorrections.push_back(QStringLiteral("skg://clean_delete_unused_units"));
+            autoCorrections.push_back(QLatin1String("skg://clean_delete_unused_units"));
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
 
     // Check unit too complex
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_amountnotdefined"))) {
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name FROM v_unit WHERE t_type IN ('2','C') AND f_CURRENTAMOUNT=1"), result);
+    if (!iIgnoredAdvice.contains(QLatin1String("skgunitplugin_amountnotdefined"))) {
+        m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT t_name FROM v_unit WHERE t_type IN ('2','C') AND f_CURRENTAMOUNT=1"), result);
         nb = result.count();
         SKGAdvice::SKGAdviceActionList autoCorrections;
         autoCorrections.reserve(nb);
@@ -469,8 +465,8 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Check unit too complex
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_toocomplex"))) {
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT A.t_name FROM unit A, unit B, unit C, unit D WHERE A.rd_unit_id=B.id AND B.rd_unit_id=C.id AND C.rd_unit_id=D.id"), result);
+    if (!iIgnoredAdvice.contains(QLatin1String("skgunitplugin_toocomplex"))) {
+        m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT A.t_name FROM unit A, unit B, unit C, unit D WHERE A.rd_unit_id=B.id AND B.rd_unit_id=C.id AND C.rd_unit_id=D.id"), result);
         nb = result.count();
         SKGAdvice::SKGAdviceActionList autoCorrections;
         autoCorrections.reserve(nb);
@@ -480,7 +476,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
             const QString& unit = line.at(0);
 
             SKGAdvice ad;
-            ad.setUUID(QStringLiteral("skgunitplugin_toocomplex"));
+            ad.setUUID(QLatin1String("skgunitplugin_toocomplex"));
             ad.setPriority(9);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "The definition of the unit '%1' is too complex", unit));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "'%1' is defined relatively to another unit defined relatively to a third one. This is too complex and not supported by Skrooge.", unit));
@@ -498,8 +494,8 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // Unit with very old values
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_veryold"))) {
-        m_currentBankDocument->executeSelectSqliteOrder(QStringLiteral("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=(SELECT date('now', 'localtime', '-50 year')))"), result);
+    if (!iIgnoredAdvice.contains(QLatin1String("skgunitplugin_veryold"))) {
+        m_currentBankDocument->executeSelectSqliteOrder(QLatin1String("SELECT t_name from unit WHERE (SELECT COUNT(*) FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id)>1 AND EXISTS (SELECT 1 FROM unitvalue WHERE unitvalue.rd_unit_id=unit.id AND unitvalue.d_date<=(SELECT date('now', 'localtime', '-50 year')))"), result);
         nb = result.count();
         SKGAdvice::SKGAdviceActionList autoCorrections;
         autoCorrections.reserve(nb);
@@ -527,9 +523,9 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     // No decimal settings
-    if (!iIgnoredAdvice.contains(QStringLiteral("skgunitplugin_decimalsymbol")) && QLocale().decimalPoint().isNull()) {
+    if (!iIgnoredAdvice.contains(QLatin1String("skgunitplugin_decimalsymbol")) && QLocale().decimalPoint().isNull()) {
         SKGAdvice ad;
-        ad.setUUID(QStringLiteral("skgunitplugin_decimalsymbol"));
+        ad.setUUID(QLatin1String("skgunitplugin_decimalsymbol"));
         ad.setPriority(9);
         ad.setShortMessage(i18nc("Advice on making the best (short)", "No decimal symbol defined"));
         ad.setLongMessage(i18nc("Advice on making the best (long)", "In KDE localization settings, there is no decimal symbol defined for currencies. This could be confusing."));
@@ -537,7 +533,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         {
             SKGAdvice::SKGAdviceAction a;
             a.Title = i18nc("Advice on making the best (action)", "Edit KDE settings");
-            a.IconName = QStringLiteral("configure");
+            a.IconName = QLatin1String("configure");
             a.IsRecommended = false;
             autoCorrections.push_back(a);
         }
@@ -552,7 +548,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
 {
     if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_primaryunit|"))) {
         if (iSolution == 1) {
-            SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
+            SKGMainPanel::getMainPanel()->openPage(QLatin1String("skg://skrooge_unit_plugin"));
         } else {
             // Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 26);
@@ -584,7 +580,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
     }
     if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_secondaryunit|"))) {
         if (iSolution == 1) {
-            SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
+            SKGMainPanel::getMainPanel()->openPage(QLatin1String("skg://skrooge_unit_plugin"));
         } else {
             // Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
@@ -616,7 +612,7 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
     }
     if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_notdownloaded|"))) {
         if (iSolution == 0) {
-            SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
+            SKGMainPanel::getMainPanel()->openPage(QLatin1String("skg://skrooge_unit_plugin"));
         } else {
             // Get parameters
             QString unit = iAdviceIdentifier.right(iAdviceIdentifier.length() - 28);
@@ -637,11 +633,11 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
             iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_toocomplex")) ||
             iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_amountnotdefined|")))
        ) {
-        SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
+        SKGMainPanel::getMainPanel()->openPage(QLatin1String("skg://skrooge_unit_plugin"));
         return SKGError();
     }
     if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_decimalsymbol"))) {
-        QProcess::execute(QStringLiteral("kcmshell5"), QStringList() << QStringLiteral("formats"));
+        QProcess::execute(QLatin1String("kcmshell5"), QStringList() << QLatin1String("formats"));
         return SKGError();
     }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
@@ -655,7 +651,7 @@ void SKGUnitPlugin::deleteUnusedUnits() const
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused units"), err)
 
         // Modification of payee object
-        QString sql = QStringLiteral("DELETE FROM unit WHERE t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)");
+        QString sql = QLatin1String("DELETE FROM unit WHERE t_type NOT IN ('I', '1', '2') AND NOT EXISTS (SELECT 1 FROM operation WHERE operation.rc_unit_id=unit.id) AND NOT EXISTS (SELECT 1 FROM unit as unit2 WHERE unit2.rd_unit_id=unit.id)");
         err = m_currentBankDocument->executeSqliteOrder(sql);
     }
 
