@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -11,10 +11,15 @@
 #include "skgunitpluginwidget.h"
 
 #include <klocalizedstring.h>
+#ifndef SKG_QT6
 #include <krun.h>
+#endif
 #include <kzip.h>
-
+#ifdef SKG_QT6
+#include <KNSWidgets/Dialog>
+#else
 #include <kns3/qtquickdialogwrapper.h>
+#endif
 #include <qdir.h>
 #include <qdom.h>
 #include <qevent.h>
@@ -47,110 +52,110 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     connect(m_unitValueGraphCmb, static_cast<void (SKGComboBox::*)(int)>(&SKGComboBox::currentIndexChanged), this, &SKGUnitPluginWidget::onSelectionChanged);
     ui.kGraph->graph()->addToolbarWidget(m_unitValueGraphCmb);
 
-    ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_name"))));
-    ui.kDecimalLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("i_nbdecimal"))));
-    ui.kCountyLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_country"))));
-    ui.kSymbolLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_symbol"))));
-    ui.kTypeLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_type"))));
-    ui.kInternetLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_internet_code"))));
-    ui.kDateLabel->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("d_date"))));
-    ui.kAmountLabel->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("f_value"))));
-    ui.kUnitLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_UNIT"))));
-    ui.kUnitLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_UNIT"))));
-    ui.kDownloadSourceLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_source"))));
+    ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_name"))));
+    ui.kDecimalLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("i_nbdecimal"))));
+    ui.kCountyLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_country"))));
+    ui.kSymbolLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_symbol"))));
+    ui.kTypeLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_type"))));
+    ui.kInternetLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_internet_code"))));
+    ui.kDateLabel->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("d_date"))));
+    ui.kAmountLabel->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("f_value"))));
+    ui.kUnitLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_UNIT"))));
+    ui.kUnitLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_UNIT"))));
+    ui.kDownloadSourceLbl->setText(i18n("%1:", iDocument->getDisplay(QLatin1String("t_source"))));
 
-    ui.kUnitTableViewEdition->getShowWidget()->addItem(QStringLiteral("all"), i18nc("Noun, items to display", "All"), QLatin1String(""),
+    ui.kUnitTableViewEdition->getShowWidget()->addItem(QLatin1String("all"), i18nc("Noun, items to display", "All"), QLatin1String(""),
             QLatin1String(""),
-            QStringLiteral("currency;share;index;object"),  // Check when checked
-            QStringLiteral("highlighted"),  // Uncheck when checked
+            QLatin1String("currency;share;index;object"),  // Check when checked
+            QLatin1String("highlighted"),  // Uncheck when checked
             QLatin1String(""), QLatin1String(""),
-            Qt::META + Qt::Key_A);
-    ui.kUnitTableViewEdition->getShowWidget()->addItem(QStringLiteral("highlighted"), i18n("Highlighted only"), QStringLiteral("bookmarks"), QStringLiteral("t_bookmarked='Y'"), QLatin1String(""), QStringLiteral("all;currency;share;index;object"), QStringLiteral("all"), QLatin1String(""), Qt::META + Qt::Key_H);
+            Qt::META | Qt::Key_A);
+    ui.kUnitTableViewEdition->getShowWidget()->addItem(QLatin1String("highlighted"), i18n("Highlighted only"), QLatin1String("bookmarks"), QLatin1String("t_bookmarked='Y'"), QLatin1String(""), QLatin1String("all;currency;share;index;object"), QLatin1String("all"), QLatin1String(""), Qt::META | Qt::Key_H);
     ui.kUnitTableViewEdition->getShowWidget()->addSeparator();
-    ui.kUnitTableViewEdition->getShowWidget()->addItem(QStringLiteral("currency"), i18nc("Noun, a country's currency", "Currency"), QLatin1String(""),
-            QStringLiteral("t_type IN ('1','2','C')"),
+    ui.kUnitTableViewEdition->getShowWidget()->addItem(QLatin1String("currency"), i18nc("Noun, a country's currency", "Currency"), QLatin1String(""),
+            QLatin1String("t_type IN ('1','2','C')"),
             QLatin1String(""),  // Check when checked
-            QStringLiteral("highlighted"),       // Uncheck when checked
+            QLatin1String("highlighted"),       // Uncheck when checked
             QLatin1String(""),       // Check when unchecked
-            QStringLiteral("all"), Qt::META + Qt::Key_C);     // Uncheck when unchecked
-    ui.kUnitTableViewEdition->getShowWidget()->addItem(QStringLiteral("share"), i18nc("Noun, a financial share, as in a stock market", "Share"), QLatin1String(""),
-            QStringLiteral("t_type='S'"),
+            QLatin1String("all"), Qt::META | Qt::Key_C);     // Uncheck when unchecked
+    ui.kUnitTableViewEdition->getShowWidget()->addItem(QLatin1String("share"), i18nc("Noun, a financial share, as in a stock market", "Share"), QLatin1String(""),
+            QLatin1String("t_type='S'"),
             QLatin1String(""),
-            QStringLiteral("highlighted"),
+            QLatin1String("highlighted"),
             QLatin1String(""),
-            QStringLiteral("all"), Qt::META + Qt::Key_S);
-    ui.kUnitTableViewEdition->getShowWidget()->addItem(QStringLiteral("index"), i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40…", "Index"), QLatin1String(""),
-            QStringLiteral("t_type='I'"),
+            QLatin1String("all"), Qt::META | Qt::Key_S);
+    ui.kUnitTableViewEdition->getShowWidget()->addItem(QLatin1String("index"), i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40…", "Index"), QLatin1String(""),
+            QLatin1String("t_type='I'"),
             QLatin1String(""),
-            QStringLiteral("highlighted"),
+            QLatin1String("highlighted"),
             QLatin1String(""),
-            QStringLiteral("all;current"), Qt::META + Qt::Key_I);
-    ui.kUnitTableViewEdition->getShowWidget()->addItem(QStringLiteral("object"), i18nc("Noun, a physical object like a house or a car", "Object"), QLatin1String(""),
-            QStringLiteral("t_type='O'"),
+            QLatin1String("all;current"), Qt::META | Qt::Key_I);
+    ui.kUnitTableViewEdition->getShowWidget()->addItem(QLatin1String("object"), i18nc("Noun, a physical object like a house or a car", "Object"), QLatin1String(""),
+            QLatin1String("t_type='O'"),
             QLatin1String(""),
-            QStringLiteral("highlighted"),
+            QLatin1String("highlighted"),
             QLatin1String(""),
-            QStringLiteral("all"), Qt::META + Qt::Key_O);
+            QLatin1String("all"), Qt::META | Qt::Key_O);
 
-    ui.kUnitTableViewEdition->getShowWidget()->setDefaultState(QStringLiteral("all;currency;share;index;object"));
+    ui.kUnitTableViewEdition->getShowWidget()->setDefaultState(QLatin1String("all;currency;share;index;object"));
 
-    ui.kGraph->getShowWidget()->setState(QStringLiteral("\"graph\""));
+    ui.kGraph->getShowWidget()->setState(QLatin1String("\"graph\""));
     ui.kGraph->setFilterVisibility(false);
 
     ui.kUnitCreatorUnit->setDocument(iDocument);
-    ui.kUnitCreatorUnit->setWhereClauseCondition(QStringLiteral("t_type IN ('1','2','C')"));
+    ui.kUnitCreatorUnit->setWhereClauseCondition(QLatin1String("t_type IN ('1','2','C')"));
 
     // Add Standard KDE Icons to buttons to Accounts
-    ui.kUnitAdd->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
-    ui.kUnitUpdate->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
-    ui.kUnitValueDownload->setIcon(SKGServices::fromTheme(QStringLiteral("download")));
-    ui.kDeleteSource->setIcon(SKGServices::fromTheme(QStringLiteral("edit-delete")));
-    ui.kGetNewHotStuff->setIcon(SKGServices::fromTheme(QStringLiteral("get-hot-new-stuff")));
+    ui.kUnitAdd->setIcon(SKGServices::fromTheme(QLatin1String("list-add")));
+    ui.kUnitUpdate->setIcon(SKGServices::fromTheme(QLatin1String("dialog-ok")));
+    ui.kUnitValueDownload->setIcon(SKGServices::fromTheme(QLatin1String("download")));
+    ui.kDeleteSource->setIcon(SKGServices::fromTheme(QLatin1String("edit-delete")));
+    ui.kGetNewHotStuff->setIcon(SKGServices::fromTheme(QLatin1String("get-hot-new-stuff")));
 
-    auto newValidator = new QRegularExpressionValidator(QRegularExpression(QStringLiteral("^[\\w\\s]+$")), this);
+    auto newValidator = new QRegularExpressionValidator(QRegularExpression(QLatin1String("^[\\w\\s]+$")), this);
     ui.kDownloadSource->setValidator(newValidator);
 
     QStringList overlays;
-    overlays.push_back(QStringLiteral("list-add"));
-    m_upload = new QAction(SKGServices::fromTheme(QStringLiteral("get-hot-new-stuff"), overlays), i18n("Upload"), this);
+    overlays.push_back(QLatin1String("list-add"));
+    m_upload = new QAction(SKGServices::fromTheme(QLatin1String("get-hot-new-stuff"), overlays), i18n("Upload"), this);
     connect(m_upload, &QAction::triggered, this, &SKGUnitPluginWidget::onPutNewHotStuff);
 
     auto menu = new QMenu(this);
     menu->addAction(m_upload);
     ui.kGetNewHotStuff->setMenu(menu);
 
-    ui.kUnitOpen->setIcon(SKGServices::fromTheme(QStringLiteral("quickopen")));
+    ui.kUnitOpen->setIcon(SKGServices::fromTheme(QLatin1String("quickopen")));
     connect(ui.kUnitOpen, &QPushButton::clicked, this, &SKGUnitPluginWidget::onOpenURL);
 
-    auto downloadLastAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download last value only"), this);
+    auto downloadLastAction = new QAction(SKGServices::fromTheme(QLatin1String("download")), i18n("download last value only"), this);
     downloadLastAction->setData(static_cast<int>(SKGUnitObject::LAST));
     connect(downloadLastAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    auto downloadLastMonthlyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download monthly values since last known value"), this);
+    auto downloadLastMonthlyAction = new QAction(SKGServices::fromTheme(QLatin1String("download")), i18n("download monthly values since last known value"), this);
     downloadLastMonthlyAction->setData(static_cast<int>(SKGUnitObject::LAST_MONTHLY));
     connect(downloadLastMonthlyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    auto downloadLastWeeklyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download weekly values since last known value"), this);
+    auto downloadLastWeeklyAction = new QAction(SKGServices::fromTheme(QLatin1String("download")), i18n("download weekly values since last known value"), this);
     downloadLastWeeklyAction->setData(static_cast<int>(SKGUnitObject::LAST_WEEKLY));
     connect(downloadLastWeeklyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    auto downloadLastDailyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download daily values since last known value"), this);
+    auto downloadLastDailyAction = new QAction(SKGServices::fromTheme(QLatin1String("download")), i18n("download daily values since last known value"), this);
     downloadLastDailyAction->setData(static_cast<int>(SKGUnitObject::LAST_DAILY));
     connect(downloadLastDailyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    auto downloadMonthlyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download all monthly values"), this);
+    auto downloadMonthlyAction = new QAction(SKGServices::fromTheme(QLatin1String("download")), i18n("download all monthly values"), this);
     downloadMonthlyAction->setData(static_cast<int>(SKGUnitObject::ALL_MONTHLY));
     connect(downloadMonthlyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    auto downloadWeeklyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download all weekly values"), this);
+    auto downloadWeeklyAction = new QAction(SKGServices::fromTheme(QLatin1String("download")), i18n("download all weekly values"), this);
     downloadWeeklyAction->setData(static_cast<int>(SKGUnitObject::ALL_WEEKLY));
     connect(downloadWeeklyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    auto downloadDailyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download all daily values"), this);
+    auto downloadDailyAction = new QAction(SKGServices::fromTheme(QLatin1String("download")), i18n("download all daily values"), this);
     downloadDailyAction->setData(static_cast<int>(SKGUnitObject::ALL_DAILY));
     connect(downloadDailyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    auto simplifyAction = new QAction(SKGServices::fromTheme(QStringLiteral("edit-delete")), i18n("simplify values"), this);
+    auto simplifyAction = new QAction(SKGServices::fromTheme(QLatin1String("edit-delete")), i18n("simplify values"), this);
     connect(simplifyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onSimplify);
 
 
@@ -170,19 +175,19 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kStandardFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("dialog-ok")), i18n("Standard"), i18n("Display the edit panel for standard units"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("dialog-ok")), i18n("Standard"), i18n("Display the edit panel for standard units"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kManualFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("user-properties")), i18n("Manual / Share"), i18n("Display the edit panel for manual units"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("user-properties")), i18n("Manual / Share"), i18n("Display the edit panel for manual units"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kValuesFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("taxes-finances")), i18n("Values"), i18n("Display the edit panel for values of units"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme(QLatin1String("taxes-finances")), i18n("Values"), i18n("Display the edit panel for values of units"), list);
     }
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGUnitPluginWidget::onUnitCreatorModified);
 
@@ -194,8 +199,8 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40…", "Index"), static_cast<int>(SKGUnitObject::INDEX));
     ui.kTypeCreatorUnit->addItem(i18nc("Noun, a physical object like a house or a car", "Object"), static_cast<int>(SKGUnitObject::OBJECT));
     bool primaryUnit, secondaryUnit;
-    iDocument->existObjects(QStringLiteral("unit"), QStringLiteral("t_type='1'"), primaryUnit);
-    iDocument->existObjects(QStringLiteral("unit"), QStringLiteral("t_type='2'"), secondaryUnit);
+    iDocument->existObjects(QLatin1String("unit"), QLatin1String("t_type='1'"), primaryUnit);
+    iDocument->existObjects(QLatin1String("unit"), QLatin1String("t_type='2'"), secondaryUnit);
     if (primaryUnit) {
         if (secondaryUnit) {
             ui.kTypeCreatorUnit->setCurrentIndex(2);
@@ -208,16 +213,16 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
 
     // Bind unit creation view
     {
-        ui.kUnitTableViewEdition->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_unit_display"), QLatin1String(""), this, QLatin1String(""), false));
+        ui.kUnitTableViewEdition->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("v_unit_display"), QLatin1String(""), this, QLatin1String(""), false));
 
         connect(ui.kUnitTableViewEdition->getView(), &SKGTreeView::clickEmptyArea, this, &SKGUnitPluginWidget::cleanEditor);
-        connect(ui.kUnitTableViewEdition->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open")).data(), &QAction::trigger);
+        connect(ui.kUnitTableViewEdition->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QLatin1String("open")).data(), &QAction::trigger);
         connect(ui.kUnitTableViewEdition->getView(), &SKGTreeView::selectionChangedDelayed, this, [ = ] {this->onSelectionChanged();});
     }
 
     // Bind unit creation view
     {
-        auto objectModel2 = new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_unitvalue_display"), QStringLiteral("1=0"), this, QLatin1String(""), false);
+        auto objectModel2 = new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QLatin1String("v_unitvalue_display"), QLatin1String("1=0"), this, QLatin1String(""), false);
         ui.kUnitValueTableViewEdition->setModel(objectModel2);
         connect(ui.kUnitValueTableViewEdition, &SKGTableView::selectionChangedDelayed, this, &SKGUnitPluginWidget::onSelectionValueChanged);
     }
@@ -309,7 +314,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
         ui.kCountryCreatorUnit->setText(unit.getCountry());
         ui.kTypeCreatorUnit->setCurrentIndex(ui.kTypeCreatorUnit->findData(static_cast<int>(unit.getType())));
         ui.kInternetCreatorUnit->setText(unit.getInternetCode());
-        ui.kUnitCreatorUnit->setText(unit.getAttribute(QStringLiteral("t_UNIT")));
+        ui.kUnitCreatorUnit->setText(unit.getAttribute(QLatin1String("t_UNIT")));
         ui.kNbDecimal->setValue(unit.getNumberDecimal());
         ui.kDownloadSource->setText(unit.getDownloadSource());
     } else if (nbSelect > 1) {
@@ -338,9 +343,9 @@ void SKGUnitPluginWidget::onSelectionChanged()
 
     // Draw plot
     SKGStringListList table;
-    getDocument()->getConsolidatedView(QStringLiteral("v_unitvalue_display"), QStringLiteral("d_date"), QStringLiteral("t_UNIT"),
-                                       m_unitValueGraphCmb->currentIndex() == 0 ? QStringLiteral("f_quantity") : QStringLiteral("f_AMOUNTOWNED"),
-                                       QStringLiteral("TOTAL"), wc % " AND d_date>(SELECT date('now', 'localtime', '-50 year')) AND d_date<(SELECT date('now', 'localtime', '+50 year'))", table, QLatin1String(""));
+    getDocument()->getConsolidatedView(QLatin1String("v_unitvalue_display"), QLatin1String("d_date"), QLatin1String("t_UNIT"),
+                                       m_unitValueGraphCmb->currentIndex() == 0 ? QLatin1String("f_quantity") : QLatin1String("f_AMOUNTOWNED"),
+                                       QLatin1String("TOTAL"), wc % " AND d_date>(SELECT date('now', 'localtime', '-50 year')) AND d_date<(SELECT date('now', 'localtime', '+50 year'))", table, QLatin1String(""));
 
     SKGServices::SKGUnitInfo primaryUnit = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
     SKGServices::SKGUnitInfo secondaryUnit = qobject_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
@@ -389,9 +394,9 @@ void SKGUnitPluginWidget::onSelectionValueChanged()
                 unitValue.getUnit(unit);
 
                 ui.kDateEdit->setDate(unitValue.getDate());
-                ui.kAmountEdit->setText(SKGServices::toCurrencyString(SKGServices::stringToDouble(unitValue.getAttribute(QStringLiteral("f_quantity"))),
+                ui.kAmountEdit->setText(SKGServices::toCurrencyString(SKGServices::stringToDouble(unitValue.getAttribute(QLatin1String("f_quantity"))),
                                         QLatin1String(""),
-                                        SKGServices::stringToInt(unit.getAttribute(QStringLiteral("i_nbdecimal")))));
+                                        SKGServices::stringToInt(unit.getAttribute(QLatin1String("i_nbdecimal")))));
             }
         } else {
             ui.kDateEdit->setDate(QDate::currentDate());
@@ -695,20 +700,20 @@ int SKGUnitPluginWidget::getNbSelectedObjects()
 QString SKGUnitPluginWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("splitter1State"), QString(ui.kMainSplitter->saveState().toHex()));
-    root.setAttribute(QStringLiteral("splitter2State"), QString(ui.kValuesSplitter->saveState().toHex()));
+    root.setAttribute(QLatin1String("splitter1State"), QString(ui.kMainSplitter->saveState().toHex()));
+    root.setAttribute(QLatin1String("splitter2State"), QString(ui.kValuesSplitter->saveState().toHex()));
 
     // Memorize table settings
-    root.setAttribute(QStringLiteral("unitview"), ui.kUnitTableViewEdition->getState());
-    root.setAttribute(QStringLiteral("unitvalueview"), ui.kUnitValueTableViewEdition->getState());
-    root.setAttribute(QStringLiteral("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
-    root.setAttribute(QStringLiteral("obsolete"), ui.kObsolete->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("graphSettings"), ui.kGraph->getState());
-    root.setAttribute(QStringLiteral("unitvaluegraphmode"), m_unitValueGraphCmb->currentIndex());
+    root.setAttribute(QLatin1String("unitview"), ui.kUnitTableViewEdition->getState());
+    root.setAttribute(QLatin1String("unitvalueview"), ui.kUnitValueTableViewEdition->getState());
+    root.setAttribute(QLatin1String("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
+    root.setAttribute(QLatin1String("obsolete"), ui.kObsolete->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("graphSettings"), ui.kGraph->getState());
+    root.setAttribute(QLatin1String("unitvaluegraphmode"), m_unitValueGraphCmb->currentIndex());
 
     return doc.toString();
 }
@@ -716,15 +721,15 @@ QString SKGUnitPluginWidget::getState()
 void SKGUnitPluginWidget::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString splitter1State = root.attribute(QStringLiteral("splitter1State"));
-    QString splitter2State = root.attribute(QStringLiteral("splitter2State"));
-    QString currentPage = root.attribute(QStringLiteral("currentPage"));
-    QString obsolete = root.attribute(QStringLiteral("obsolete"));
-    QString unitvaluegraphmode = root.attribute(QStringLiteral("unitvaluegraphmode"));
+    QString splitter1State = root.attribute(QLatin1String("splitter1State"));
+    QString splitter2State = root.attribute(QLatin1String("splitter2State"));
+    QString currentPage = root.attribute(QLatin1String("currentPage"));
+    QString obsolete = root.attribute(QLatin1String("obsolete"));
+    QString unitvaluegraphmode = root.attribute(QLatin1String("unitvaluegraphmode"));
 
 
     if (currentPage.isEmpty()) {
@@ -738,11 +743,11 @@ void SKGUnitPluginWidget::setState(const QString& iState)
         ui.kValuesSplitter->restoreState(QByteArray::fromHex(splitter2State.toLatin1()));
     }
     ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
-    ui.kObsolete->setChecked(obsolete == QStringLiteral("Y"));
+    ui.kObsolete->setChecked(obsolete == QLatin1String("Y"));
 
-    ui.kUnitTableViewEdition->setState(root.attribute(QStringLiteral("unitview")));
-    ui.kUnitValueTableViewEdition->setState(root.attribute(QStringLiteral("unitvalueview")));
-    ui.kGraph->setState(root.attribute(QStringLiteral("graphSettings")));
+    ui.kUnitTableViewEdition->setState(root.attribute(QLatin1String("unitview")));
+    ui.kUnitValueTableViewEdition->setState(root.attribute(QLatin1String("unitvalueview")));
+    ui.kGraph->setState(root.attribute(QLatin1String("graphSettings")));
     ui.kGraph->setGraphType(SKGTableWithGraph::LINE);
     if (!unitvaluegraphmode.isEmpty()) {
         m_unitValueGraphCmb->setCurrentIndex(SKGServices::stringToInt(unitvaluegraphmode));
@@ -751,7 +756,7 @@ void SKGUnitPluginWidget::setState(const QString& iState)
 
 QString SKGUnitPluginWidget::getDefaultStateAttribute()
 {
-    return QStringLiteral("SKGUNIT_DEFAULT_PARAMETERS");
+    return QLatin1String("SKGUNIT_DEFAULT_PARAMETERS");
 }
 
 void SKGUnitPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
@@ -759,7 +764,7 @@ void SKGUnitPluginWidget::dataModified(const QString& iTableName, int iIdTransac
     SKGTRACEINFUNC(10)
     Q_UNUSED(iIdTransaction)
 
-    if (iTableName == QStringLiteral("unitvalue") || iTableName.isEmpty()) {
+    if (iTableName == QLatin1String("unitvalue") || iTableName.isEmpty()) {
         // Correction bug 2299394 vvv
         if (ui.kUnitValueTableViewEdition->isAutoResized()) {
             ui.kUnitValueTableViewEdition->resizeColumnsToContentsDelayed();
@@ -873,9 +878,12 @@ void SKGUnitPluginWidget::onSourceChanged()
 
 void SKGUnitPluginWidget::onGetNewHotStuff()
 {
-    QPointer<KNS3::QtQuickDialogWrapper> dialog = new KNS3::QtQuickDialogWrapper(QStringLiteral("skrooge_unit.knsrc"), this);
+#ifdef SKG_QT6
+    QPointer<KNSWidgets::Dialog> dialog = new KNSWidgets::Dialog(QLatin1String("skrooge_unit.knsrc"), this);
+#else
+    QPointer<KNS3::QtQuickDialogWrapper> dialog = new KNS3::QtQuickDialogWrapper(QLatin1String("skrooge_unit.knsrc"), this);
+#endif
     dialog->exec();
-
     fillSourceList();
 }
 
@@ -884,7 +892,7 @@ void SKGUnitPluginWidget::onPutNewHotStuff()
     QString source = ui.kDownloadSource->text().trimmed();
 
     // Create zip file
-    QString sourceFileName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("skrooge/quotes/") % source % ".txt";
+    QString sourceFileName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QLatin1String("skrooge/quotes/") % source % ".txt";
     QString zipFileName = QDir::tempPath() % "/" % source % ".zip";
     KZip zip(zipFileName);
     if (zip.open(QIODevice::WriteOnly)) {
