@@ -1,8 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #***************************************************************************
-#* SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
-#* SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+#* SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+#* SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
 #* SPDX-License-Identifier: GPL-3.0-or-later
 #***************************************************************************
 
@@ -22,7 +22,16 @@ tempDir='/data'
 
 class Releasor(object):
     def __init__(self, args):
-        self.ubuntuVersions=['jammy', 'noble', 'oracular']
+        self.versionstotreat = [
+            {
+                "v": "5",
+                "ubuntuVersions": ['noble', 'oracular']
+            },
+            {
+                "v": "6",
+                "ubuntuVersions": ['oracular']
+            }
+        ]
         self.workdingDir=os.path.join(tempDir, 'skrooge-release_' + args.version)
         print("# Working directory :" + self.workdingDir)    
         if args.version.endswith(".0") or args.stable:
@@ -117,7 +126,7 @@ class Releasor(object):
             buildPath = os.path.join(p, 'build')
             os.mkdir(buildPath)
             os.chdir(buildPath) 
-            cmd = ['cmake', '..', '-DCMAKE_INSTALL_PREFIX=`kf5-config --prefix`', '-DQT_PLUGIN_INSTALL_DIR=`kf5-config --qt-plugins`']
+            cmd = ['cmake', '..', '-DCMAKE_INSTALL_PREFIX=/usr', '-DQT_PLUGIN_INSTALL_DIR=/usr/lib/x86_64-linux-gnu/qt6/plugins', '-DQT_MAJOR_VERSION=6']
             self.logfile.write('### '+' '.join(cmd)+'\n')
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
             if rc == 0:    
@@ -150,65 +159,85 @@ class Releasor(object):
                 cmd = ['sha256sum', filename+'.sig']
                 self.logfile.write('### '+' '.join(cmd)+'\n')                
                 rc = subprocess.call(cmd)  
-            print("Thank you.\nRegards.\n"   )      
-    def modify(self, args):
+            print("Thank you.\nRegards.\n"   )
+
+    def buildDebian(self, args):
         print('# Get dsc')
-        os.chdir(self.workdingDir)  
-        cmd = ['apt', 'source', 'skrooge']
-        self.logfile.write('### '+' '.join(cmd)+'\n')                
-        rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
-        if rc == 0:
-            previousPackage = [os.path.join(self.workdingDir, o) for o in os.listdir(self.workdingDir) if os.path.isdir(os.path.join(self.workdingDir, o)) and o.startswith('skrooge-')][0]
-            print('#   previousPackage='+previousPackage)
-            
-            os.chdir(previousPackage)  
-            if os.path.exists('debian'):
-                shutil.rmtree('debian')
-            cmd = ['tar', '-xvf', os.path.join(toolPath, 'skrooge-release-debian.tar.gz')]
-            self.logfile.write('### '+' '.join(cmd)+'\n')                
+        for v in self.versionstotreat:
+            os.chdir(self.workdingDir)
+            cmd = ['apt', 'source', 'skrooge']
+            self.logfile.write('### '+' '.join(cmd)+'\n')
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
             if rc == 0:
-                cmd = ['uupdate', '-u', 'skrooge-'+args.version+'.tar.xz']
-                self.logfile.write('### '+' '.join(cmd)+'\n')                
+                previousPackage = [os.path.join(self.workdingDir, o) for o in os.listdir(self.workdingDir) if os.path.isdir(os.path.join(self.workdingDir, o)) and o.startswith('skrooge-') and not o.endswith('.orig')][0]
+                print('#   previousPackage='+previousPackage)
+                os.chdir(previousPackage)
+                if os.path.exists('debian'):
+                    shutil.rmtree('debian')
+                cmd = ['tar', '-xvf', os.path.join(toolPath, 'skrooge-release-debian-kf'+v["v"]+'.tar.gz')]
+                self.logfile.write('### '+' '.join(cmd)+'\n')
                 rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
+                if rc == 0:
+                    cmd = ['uupdate', '-u', 'skrooge-'+args.version+'.tar.xz']
+                    self.logfile.write('### '+' '.join(cmd)+'\n')
+                    rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
                 if rc == 0:
                     # Read the changelog
                     os.chdir('../skrooge-'+args.version)
+                    if os.path.exists('debian'):
+                        shutil.rmtree('debian')
+                    cmd = ['tar', '-xvf', os.path.join(toolPath, 'skrooge-release-debian-kf'+v["v"]+'.tar.gz')]
+                    self.logfile.write('### '+' '.join(cmd)+'\n')
+                    rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
                     with open(os.path.join(self.workdingDir, 'skrooge-'+args.version+'/CHANGELOG'), 'r') as fileChangelog:
                         fileChangelog.readline() # To pass the first line
                         changelogContent = ''
                         done = False
                         for line in fileChangelog:
                             if line.strip() == '' and done == False:
-                                changelogContent += ' -- Stephane MANKOWSKI (Perso) <stephane@mankowski.fr>  {}\n'.format(datetime.datetime.now().strftime('%a, %d %b %Y %H:%M:%S +0100'))
+                                changelogContent += ' -- Stéphane MANKOWSKI <stephane@mankowski.fr>  {}\n'.format(datetime.datetime.now().strftime('%a, %d %b %Y %H:%M:%S +0100'))
                                 done = True
                             if not line.startswith(' -- '):
-                                changelogContent += line  
-                        
+                                changelogContent += line
+
                         #
                         for ppa in self.ppatotreat:
-                            for i in range(len(self.ubuntuVersions)):
-                                print('#   {}/{}: {} - {}'.format(i+1, len(self.ubuntuVersions), self.ubuntuVersions[i], ppa))
+                            for i in range(len(v["ubuntuVersions"])):
+                                print('#   {}/{}: {} - {}-kf{}'.format(i+1, len(v["ubuntuVersions"]), v["ubuntuVersions"][i], ppa, v["v"]))
                                 f = open(os.path.join(self.workdingDir, 'skrooge-'+args.version+'/debian/control'), 'r')
                                 cf = f.read()
                                 f.close()
-                                
-                                #print('#   make changes for '+self.ubuntuVersions[i])
+
+                                #print('#   make changes for '+v["ubuntuVersions"][i])
                                 #f = open(os.path.join(self.workdingDir, 'skrooge-'+args.version+'/debian/control'), 'w')
                                 #f.write(cf.replace('libqjson-dev, \n', '').replace('libqjson0, ', ''))
-                                #f.close()                                 
-                                    
+                                #f.close()
+
                                 with open(os.path.join(self.workdingDir, 'skrooge-'+args.version+'/debian/changelog'), 'w') as fileDebianChangelog:
-                                    fileDebianChangelog.write('skrooge ('+args.version+'-0ubuntu1~'+ppa+str(i+1)+') '+self.ubuntuVersions[i]+'; urgency=medium\n')
+                                    fileDebianChangelog.write('skrooge ('+args.version+'-0ubuntu'+v["v"]+'~'+ppa+str(i+1)+') '+v["ubuntuVersions"][i]+'; urgency=medium\n')
                                     fileDebianChangelog.write(changelogContent+'\n')
-                                    
+
                                     cmd = ['debuild', '-S', '-sa']
-                                    self.logfile.write('### '+' '.join(cmd)+'\n')                
-                                    rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
+                                    self.logfile.write('### '+' '.join(cmd)+'\n')
+                                    rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
                                     if rc!=0:
                                         break
                             if rc!=0:
-                                break                                    
+                                break
+
+                        os.chdir(self.workdingDir)
+                        print('#   Cleaning')
+                        shutil.rmtree('skrooge-'+args.version+'.orig')
+                        print('#     1- skrooge-'+args.version+'.orig')
+                        shutil.rmtree('skrooge-'+args.version)
+                        print('#     2- skrooge-'+args.version)
+                        if os.path.exists(previousPackage):
+                            shutil.rmtree(previousPackage)
+                            print('#     3- '+previousPackage)
+                        t = previousPackage.replace(os.path.basename(previousPackage), os.path.basename(previousPackage).replace('-', '_'))
+                        if os.path.exists(t+'.orig.tar.xz'):
+                            os.remove(t+'.orig.tar.xz')
+                            print('#     4- '+t+'.orig.tar.xz')
         print('#   '+("DONE" if rc == 0 else "FAILED"))
         return rc      
     
@@ -218,17 +247,18 @@ class Releasor(object):
         if not args.publish:
             print('#   Publication ignored')
         os.chdir(self.workdingDir)  
-        for ppa in self.ppatotreat:
-            for i in range(len(self.ubuntuVersions)):
-                print('#   {}/{}: {} {}'.format(i+1, len(self.ubuntuVersions), self.ubuntuVersions[i], ppa))
-                cmd = ['dput', '-f', 'ppa:s-mankowski/'+ppa+'-kf5', 'skrooge_'+args.version+'-0ubuntu1~'+ppa+str(i+1)+'_source.changes']
-                if not args.publish:
-                    print('#     '+' '.join(cmd)+'\n')
-                else:
-                    self.logfile.write('### '+' '.join(cmd)+'\n')                
-                    rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
-                    if rc!=0:
-                        break
+        for v in self.versionstotreat:
+            for ppa in self.ppatotreat:
+                for i in range(len(v["ubuntuVersions"])):
+                    print('#   {}/{}: {} {}'.format(i+1, len(v["ubuntuVersions"]), v["ubuntuVersions"][i], ppa))
+                    cmd = ['dput', '-f', 'ppa:s-mankowski/'+ppa+'-kf'+v["v"], 'skrooge_'+args.version+'-0ubuntu'+v["v"]+'~'+ppa+str(i+1)+'_source.changes']
+                    if not args.publish:
+                        print('#     '+' '.join(cmd)+'\n')
+                    else:
+                        self.logfile.write('### '+' '.join(cmd)+'\n')
+                        rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
+                        if rc!=0:
+                            break
         print('#   '+("DONE" if rc == 0 else "FAILED"))
         return rc     
     
@@ -355,9 +385,9 @@ def main():
     rc=r.prepareWorkingDirectory(args)
     if(rc == 0 and not (args.appimage or args.snap)): rc=r.makeTarFile(args)
     if(rc == 0 and not (args.appimage or args.snap)): rc=r.updateTarFile(args)
-    if(rc == 0 and not (args.appimage or args.snap)): rc=r.modify(args)
+    if(rc == 0 and not (args.appimage or args.snap)): rc=r.buildDebian(args)
     if(rc == 0 and args.appimage): rc=r.buildAppImage(args)
-    if(rc == 0 and args.snap): rc=r.buildSnap(args)   
+    if(rc == 0 and args.snap): rc=r.buildSnap(args)
     if(rc == 0 and not (args.appimage or args.snap)): rc=r.publishLaunchpad(args)
     if(rc == 0 and not (args.snap)): rc=r.publishKDE(args)
     print("#####################")
