@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -23,6 +23,7 @@
 #include "skgmainpanel.h"
 #include "skgruleobject.h"
 #include "skgservices.h"
+#include <utility>
 
 SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document, const QString& attribute, bool iModeUpdate, const QStringList& iListAtt)
     : QWidget(iParent), m_updateMode(iModeUpdate), m_kValue1(nullptr), m_kValue2(nullptr), m_kAttributes(nullptr)
@@ -38,9 +39,9 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     auto horizontalLayout = new QHBoxLayout(this);
     horizontalLayout->setSpacing(2);
     horizontalLayout->setContentsMargins(0, 0, 0, 0);
-    horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
+    horizontalLayout->setObjectName(QLatin1String("horizontalLayout"));
     m_kOperator = new SKGComboBox(this);
-    m_kOperator->setObjectName(QStringLiteral("kOperator"));
+    m_kOperator->setObjectName(QLatin1String("kOperator"));
     m_kOperator->setSizeAdjustPolicy(KComboBox::AdjustToContentsOnFirstShow);
     QSizePolicy newSizePolicy2(QSizePolicy::Fixed, QSizePolicy::Fixed);
     newSizePolicy2.setHorizontalStretch(0);
@@ -53,7 +54,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     if (nbAtt != 0) {
         m_kAttributes = new SKGComboBox(this);
         if (m_kAttributes != nullptr) {
-            m_kAttributes->setObjectName(QStringLiteral("kAttributes"));
+            m_kAttributes->setObjectName(QLatin1String("kAttributes"));
             m_kAttributes->setMinimumSize(QSize(100, 0));
             m_kAttributes->setEditable(false);
             QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -64,7 +65,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
 
             horizontalLayout->addWidget(m_kAttributes);
 
-            for (const auto& att : qAsConst(iListAtt)) {
+            for (const auto& att : std::as_const(iListAtt)) {
                 if (document != nullptr) {
                     m_kAttributes->addItem(document->getIcon(att), document->getDisplay(att), att);
                 }
@@ -74,7 +75,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     if (attType == SKGServices::TEXT) {
         auto cmbVal1 = new SKGComboBox(this);
         if (cmbVal1 != nullptr) {
-            cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
+            cmbVal1->setObjectName(QLatin1String("cmbVal1"));
             cmbVal1->setMinimumSize(QSize(100, 0));
             cmbVal1->setEditable(true);
             QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -89,7 +90,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
         }
         auto cmbVal2 = new SKGComboBox(this);
         if (cmbVal2 != nullptr) {
-            cmbVal2->setObjectName(QStringLiteral("cmbVal2"));
+            cmbVal2->setObjectName(QLatin1String("cmbVal2"));
             cmbVal2->setMinimumSize(QSize(100, 0));
             cmbVal2->setEditable(true);
             QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -104,41 +105,41 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
         }
 
         if (document != nullptr) {
-            QString realTable = QStringLiteral("operation");
+            QString realTable = QLatin1String("operation");
             QString realAtt = attribute;
             QString realCond = QLatin1String("");
-            if (attribute == QStringLiteral("t_REALCATEGORY")) {
-                realTable = QStringLiteral("category");
-                realAtt = QStringLiteral("t_fullname");
-            } else if (attribute == QStringLiteral("t_BANK")) {
-                realTable = QStringLiteral("bank");
-                realAtt = QStringLiteral("t_name");
-            } else if (attribute == QStringLiteral("t_ACCOUNT") || attribute == QStringLiteral("t_TOACCOUNT")) {
-                realTable = QStringLiteral("account");
-                realAtt = QStringLiteral("t_name");
-            } else if (attribute == QStringLiteral("t_UNIT")) {
-                realTable = QStringLiteral("unit");
-                realAtt = QStringLiteral("t_name");
-            } else if (attribute == QStringLiteral("t_REALCOMMENT")) {
-                realTable = QStringLiteral("suboperation");
-                realAtt = QStringLiteral("t_comment");
-            } else if (attribute == QStringLiteral("t_REALREFUND")) {
-                realTable = QStringLiteral("refund");
-                realAtt = QStringLiteral("t_name");
-            } else if (attribute == QStringLiteral("t_PAYEE")) {
-                realTable = QStringLiteral("payee");
-                realAtt = QStringLiteral("t_name");
+            if (attribute == QLatin1String("t_REALCATEGORY")) {
+                realTable = QLatin1String("category");
+                realAtt = QLatin1String("t_fullname");
+            } else if (attribute == QLatin1String("t_BANK")) {
+                realTable = QLatin1String("bank");
+                realAtt = QLatin1String("t_name");
+            } else if (attribute == QLatin1String("t_ACCOUNT") || attribute == QLatin1String("t_TOACCOUNT")) {
+                realTable = QLatin1String("account");
+                realAtt = QLatin1String("t_name");
+            } else if (attribute == QLatin1String("t_UNIT")) {
+                realTable = QLatin1String("unit");
+                realAtt = QLatin1String("t_name");
+            } else if (attribute == QLatin1String("t_REALCOMMENT")) {
+                realTable = QLatin1String("suboperation");
+                realAtt = QLatin1String("t_comment");
+            } else if (attribute == QLatin1String("t_REALREFUND")) {
+                realTable = QLatin1String("refund");
+                realAtt = QLatin1String("t_name");
+            } else if (attribute == QLatin1String("t_PAYEE")) {
+                realTable = QLatin1String("payee");
+                realAtt = QLatin1String("t_name");
             } else if (attribute.startsWith(QLatin1String("p_"))) {
-                realTable = QStringLiteral("parameters");
-                realAtt = QStringLiteral("t_value");
-                realCond = "t_name='" % attribute.right(attribute.length() - 2) % '\'';
+                realTable = QLatin1String("parameters");
+                realAtt = QLatin1String("t_value");
+                realCond = "t_name='" % attribute.right(attribute.length() - 2) % QLatin1Char('\'');
             }
             SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << cmbVal1 << cmbVal2, document, realTable, realAtt, realCond);
         }
     } else  if (attType == SKGServices::INTEGER || attType == SKGServices::FLOAT) {
         auto cmbVal1 = new SKGCalculatorEdit(this);
         if (cmbVal1 != nullptr) {
-            cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
+            cmbVal1->setObjectName(QLatin1String("cmbVal1"));
             cmbVal1->setMode(SKGCalculatorEdit::EXPRESSION);
             cmbVal1->setMinimumSize(QSize(100, 0));
 
@@ -147,7 +148,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
         }
         auto cmbVal2 = new SKGCalculatorEdit(this);
         if (cmbVal2 != nullptr) {
-            cmbVal2->setObjectName(QStringLiteral("cmbVal2"));
+            cmbVal2->setObjectName(QLatin1String("cmbVal2"));
             cmbVal2->setMode(SKGCalculatorEdit::EXPRESSION);
             cmbVal2->setMinimumSize(QSize(100, 0));
 
@@ -158,7 +159,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
         if (iModeUpdate) {
             auto cmbVal1 = new SKGComboBox(this);
             if (cmbVal1 != nullptr) {
-                cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
+                cmbVal1->setObjectName(QLatin1String("cmbVal1"));
                 cmbVal1->setMinimumSize(QSize(100, 0));
                 cmbVal1->setEditable(true);
                 QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -174,7 +175,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
 
             auto cmbVal2 = new SKGComboBox(this);
             if (cmbVal2 != nullptr) {
-                cmbVal2->setObjectName(QStringLiteral("cmbVal2"));
+                cmbVal2->setObjectName(QLatin1String("cmbVal2"));
                 cmbVal2->setMinimumSize(QSize(100, 0));
                 cmbVal2->setEditable(false);
                 QSizePolicy newSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -182,15 +183,15 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
                 newSizePolicy.setVerticalStretch(0);
                 newSizePolicy.setHeightForWidth(cmbVal2->sizePolicy().hasHeightForWidth());
                 cmbVal2->setSizePolicy(newSizePolicy);
-                cmbVal2->addItems(QStringList() << QStringLiteral("YYYYMMDD") << QStringLiteral("MMDDYYYY") << QStringLiteral("DDMMYYYY")
-                                  << QStringLiteral("MM-DD-YY") << QStringLiteral("DD-MM-YY") << QStringLiteral("MM-DD-YYYY") << QStringLiteral("DD-MM-YYYY") << QStringLiteral("YYYY-MM-DD"));
+                cmbVal2->addItems(QStringList() << QLatin1String("YYYYMMDD") << QLatin1String("MMDDYYYY") << QLatin1String("DDMMYYYY")
+                                  << QLatin1String("MM-DD-YY") << QLatin1String("DD-MM-YY") << QLatin1String("MM-DD-YYYY") << QLatin1String("DD-MM-YYYY") << QLatin1String("YYYY-MM-DD"));
                 horizontalLayout->addWidget(cmbVal2);
                 m_kValue2 = cmbVal2;
             }
         } else {
             auto cmbVal1 = new SKGDateEdit(this);
             if (cmbVal1 != nullptr) {
-                cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
+                cmbVal1->setObjectName(QLatin1String("cmbVal1"));
                 cmbVal1->setMinimumSize(QSize(100, 0));
 
                 horizontalLayout->addWidget(cmbVal1);
@@ -199,7 +200,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
 
             auto cmbVal2 = new SKGDateEdit(this);
             if (cmbVal2 != nullptr) {
-                cmbVal2->setObjectName(QStringLiteral("cmbVal2"));
+                cmbVal2->setObjectName(QLatin1String("cmbVal2"));
                 cmbVal2->setMinimumSize(QSize(100, 0));
 
                 horizontalLayout->addWidget(cmbVal2);
@@ -209,7 +210,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     } else  if (attType == SKGServices::BOOL || attType == SKGServices::TRISTATE) {
         auto cmbVal1 = new QCheckBox(this);
         if (cmbVal1 != nullptr) {
-            cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
+            cmbVal1->setObjectName(QLatin1String("cmbVal1"));
             cmbVal1->setMinimumSize(QSize(100, 0));
             cmbVal1->setTristate(attType == SKGServices::TRISTATE);
 
@@ -237,7 +238,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
 
     QStringList listOps = SKGRuleObject::getListOfOperators(attType, m_updateMode ? SKGRuleObject::UPDATE : SKGRuleObject::SEARCH);
     int nb = listOps.count();
-    if (iModeUpdate && attribute == QStringLiteral("t_REALCATEGORY") && nb > 1) {
+    if (iModeUpdate && attribute == QLatin1String("t_REALCATEGORY") && nb > 1) {
         nb = 1;    // TODO(Stephane MANKOWSKI): unblock t_REALCATEGORY
     }
     for (int i = 0; i < nb; ++i) {
@@ -291,13 +292,13 @@ void SKGPredicatCreator::onOperatorChanged()
         m_kOperator->setToolTip(SKGRuleObject::getToolTipForOperator(req));
     }
     if (m_kValue1 != nullptr) {
-        m_kValue1->setVisible(req.contains(QStringLiteral("#V1S#")) || req.contains(QStringLiteral("#V1#")));
+        m_kValue1->setVisible(req.contains(QLatin1String("#V1S#")) || req.contains(QLatin1String("#V1#")));
     }
     if (m_kValue2 != nullptr) {
-        m_kValue2->setVisible(req.contains(QStringLiteral("#V2S#")) || req.contains(QStringLiteral("#V2#")) || req.contains(QStringLiteral("#DF#")));
+        m_kValue2->setVisible(req.contains(QLatin1String("#V2S#")) || req.contains(QLatin1String("#V2#")) || req.contains(QLatin1String("#DF#")));
     }
     if (m_kAttributes != nullptr) {
-        m_kAttributes->setVisible(req.contains(QStringLiteral("#ATT2#")));
+        m_kAttributes->setVisible(req.contains(QLatin1String("#ATT2#")));
     }
 }
 
@@ -308,13 +309,13 @@ QString SKGPredicatCreator::text()
 
 QString SKGPredicatCreator::getTextFromXml(const QString& iXML)
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iXML);
     QDomElement root = doc.documentElement();
-    QString output = SKGRuleObject::getDisplayForOperator(root.attribute(QStringLiteral("operator")),
-                     root.attribute(QStringLiteral("value")),
-                     root.attribute(QStringLiteral("value2")),
-                     root.attribute(QStringLiteral("att2s")));
+    QString output = SKGRuleObject::getDisplayForOperator(root.attribute(QLatin1String("operator")),
+                     root.attribute(QLatin1String("value")),
+                     root.attribute(QLatin1String("value2")),
+                     root.attribute(QLatin1String("att2s")));
     return output;
 }
 
@@ -324,28 +325,28 @@ QString SKGPredicatCreator::xmlDescription()
     if (m_kOperator != nullptr) {
         QString op = m_kOperator->itemData(m_kOperator->currentIndex()).toString();
         if (!op.isEmpty()) {
-            QDomDocument doc(QStringLiteral("SKGML"));
-            QDomElement root = doc.createElement(QStringLiteral("element"));
+            QDomDocument doc(QLatin1String("SKGML"));
+            QDomElement root = doc.createElement(QLatin1String("element"));
             doc.appendChild(root);
 
             // Condition
-            root.setAttribute(QStringLiteral("operator"), op);
+            root.setAttribute(QLatin1String("operator"), op);
             if ((m_kValue1 != nullptr) && m_kValue1->isVisible()) {
                 auto* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
                 if (cmbVal1 != nullptr) {
-                    root.setAttribute(QStringLiteral("value"), SKGServices::dateToSqlString(cmbVal1->date()));
+                    root.setAttribute(QLatin1String("value"), SKGServices::dateToSqlString(cmbVal1->date()));
                 } else {
                     auto* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
                     if (cmbVal12 != nullptr) {
-                        root.setAttribute(QStringLiteral("value"), cmbVal12->text());
+                        root.setAttribute(QLatin1String("value"), cmbVal12->text());
                     } else {
                         auto* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
                         if (cmbVal13 != nullptr) {
-                            root.setAttribute(QStringLiteral("value"), cmbVal13->checkState() == Qt::Checked ? QStringLiteral("Y") : cmbVal13->checkState() == Qt::Unchecked ? QStringLiteral("N") : QStringLiteral("P"));
+                            root.setAttribute(QLatin1String("value"), cmbVal13->checkState() == Qt::Checked ? QLatin1String("Y") : cmbVal13->checkState() == Qt::Unchecked ? QLatin1String("N") : QLatin1String("P"));
                         } else {
                             auto* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
                             if (cmbVal14 != nullptr) {
-                                root.setAttribute(QStringLiteral("value"), cmbVal14->text());
+                                root.setAttribute(QLatin1String("value"), cmbVal14->text());
                             }
                         }
                     }
@@ -354,23 +355,23 @@ QString SKGPredicatCreator::xmlDescription()
             if ((m_kValue2 != nullptr) && m_kValue2->isVisible()) {
                 auto* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
                 if (cmbVal2 != nullptr) {
-                    root.setAttribute(QStringLiteral("value2"), SKGServices::dateToSqlString(cmbVal2->date()));
+                    root.setAttribute(QLatin1String("value2"), SKGServices::dateToSqlString(cmbVal2->date()));
                 } else {
                     auto* cmbVal21 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
                     if (cmbVal21 != nullptr) {
-                        root.setAttribute(QStringLiteral("value2"), cmbVal21->text());
+                        root.setAttribute(QLatin1String("value2"), cmbVal21->text());
                     } else {
                         auto* cmbVal22 = qobject_cast<SKGComboBox*> (m_kValue2);
                         if (cmbVal22 != nullptr) {
-                            root.setAttribute(QStringLiteral("value2"), cmbVal22->text());
+                            root.setAttribute(QLatin1String("value2"), cmbVal22->text());
                         }
                     }
                 }
             }
 
             if ((m_kAttributes != nullptr) && m_kAttributes->isVisible()) {
-                root.setAttribute(QStringLiteral("att2"), m_kAttributes->itemData(m_kAttributes->currentIndex()).toString());
-                root.setAttribute(QStringLiteral("att2s"), m_kAttributes->text());
+                root.setAttribute(QLatin1String("att2"), m_kAttributes->itemData(m_kAttributes->currentIndex()).toString());
+                root.setAttribute(QLatin1String("att2s"), m_kAttributes->text());
             }
 
             output = doc.toString();
@@ -381,28 +382,28 @@ QString SKGPredicatCreator::xmlDescription()
 
 void SKGPredicatCreator::setXmlDescription(const QString& iXML)
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iXML);
     QDomElement root = doc.documentElement();
 
     // Condition
     if (m_kOperator != nullptr) {
-        m_kOperator->setCurrentIndex(m_kOperator->findData(root.attribute(QStringLiteral("operator"))));
+        m_kOperator->setCurrentIndex(m_kOperator->findData(root.attribute(QLatin1String("operator"))));
         auto* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
         if (cmbVal1 != nullptr) {
-            cmbVal1->setDate(SKGServices::stringToTime(root.attribute(QStringLiteral("value"))).date());
+            cmbVal1->setDate(SKGServices::stringToDate(root.attribute(QLatin1String("value"))));
         } else {
             auto* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
             if (cmbVal12 != nullptr) {
-                cmbVal12->setText(root.attribute(QStringLiteral("value")));
+                cmbVal12->setText(root.attribute(QLatin1String("value")));
             } else {
                 auto* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
                 if (cmbVal13 != nullptr) {
-                    cmbVal13->setCheckState(root.attribute(QStringLiteral("value")) == QStringLiteral("Y") ? Qt::Checked : root.attribute(QStringLiteral("value")) == QStringLiteral("P") ? Qt::PartiallyChecked : Qt::Unchecked);
+                    cmbVal13->setCheckState(root.attribute(QLatin1String("value")) == QLatin1String("Y") ? Qt::Checked : root.attribute(QLatin1String("value")) == QLatin1String("P") ? Qt::PartiallyChecked : Qt::Unchecked);
                 } else {
                     auto* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
                     if (cmbVal14 != nullptr) {
-                        cmbVal14->setText(root.attribute(QStringLiteral("value")));
+                        cmbVal14->setText(root.attribute(QLatin1String("value")));
                     }
                 }
             }
@@ -410,21 +411,21 @@ void SKGPredicatCreator::setXmlDescription(const QString& iXML)
 
         auto* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
         if (cmbVal2 != nullptr) {
-            cmbVal2->setDate(SKGServices::stringToTime(root.attribute(QStringLiteral("value2"))).date());
+            cmbVal2->setDate(SKGServices::stringToDate(root.attribute(QLatin1String("value2"))));
         } else {
             auto* cmbVal22 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
             if (cmbVal22 != nullptr) {
-                cmbVal22->setText(root.attribute(QStringLiteral("value2")));
+                cmbVal22->setText(root.attribute(QLatin1String("value2")));
             } else {
                 auto* cmbVal23 = qobject_cast<SKGComboBox*> (m_kValue2);
                 if (cmbVal23 != nullptr) {
-                    cmbVal23->setText(root.attribute(QStringLiteral("value2")));
+                    cmbVal23->setText(root.attribute(QLatin1String("value2")));
                 }
             }
         }
 
         if (m_kAttributes != nullptr) {
-            m_kAttributes->setCurrentIndex(m_kAttributes->findData(root.attribute(QStringLiteral("att2"))));
+            m_kAttributes->setCurrentIndex(m_kAttributes->findData(root.attribute(QLatin1String("att2"))));
         }
     }
 
