@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -19,6 +19,7 @@
 #include "skgquerydelegate.h"
 #include "skgruleobject.h"
 #include "skgservices.h"
+#include <utility>
 
 #define ADDOPERATOR(title, op) \
     { \
@@ -37,8 +38,8 @@ SKGQueryCreator::SKGQueryCreator(QWidget* iParent)
     ui.kList->setWordWrap(false);
     ui.kList->horizontalHeader()->setSectionsMovable(true);
 
-    ui.kToolHelp->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-information")));
-    ui.kCheckMode->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down")));
+    ui.kToolHelp->setIcon(SKGServices::fromTheme(QLatin1String("dialog-information")));
+    ui.kCheckMode->setIcon(SKGServices::fromTheme(QLatin1String("arrow-down")));
     ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in advanced mode"));
 
     connect(ui.kFilterEdit, &QLineEdit::textChanged, this, &SKGQueryCreator::onTextFilterChanged);
@@ -96,13 +97,13 @@ void SKGQueryCreator::setAdvancedSearchMode(bool iAdvancedMode) const
         ui.kToolHelp->hide();
         ui.kFrmAdvanced->show();
         ui.kFilterEdit->hide();
-        ui.kCheckMode->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-up")));
+        ui.kCheckMode->setIcon(SKGServices::fromTheme(QLatin1String("arrow-up")));
         ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in simple mode"));
     } else {
         ui.kToolHelp->show();
         ui.kFrmAdvanced->hide();
         ui.kFilterEdit->show();
-        ui.kCheckMode->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down")));
+        ui.kCheckMode->setIcon(SKGServices::fromTheme(QLatin1String("arrow-down")));
         ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in advanced mode"));
     }
 }
@@ -140,7 +141,7 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
         SKGServices::SKGAttributesList attributes;
         m_document->getAttributesDescription(m_table, attributes);
         listAtts.reserve(nb + attributes.count());
-        for (const auto& att : qAsConst(attributes)) {
+        for (const auto& att : std::as_const(attributes)) {
             if (iListAttribute.isEmpty() || iListAttribute.contains(att.name)) {
                 listAtts.push_back(att);
             }
@@ -167,12 +168,12 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
             helpMenu = new QMenu(this);
             {
                 QAction* act = helpMenu->addAction(i18nc("Operator contains", "or"));
-                act->setData(QStringLiteral(" +"));
+                act->setData(QLatin1String(" +"));
                 connect(act, &QAction::triggered, this, &SKGQueryCreator::onAddText);
             }
             {
                 QAction* act = helpMenu->addAction(i18nc("Operator contains", "but not"));
-                act->setData(QStringLiteral(" -"));
+                act->setData(QLatin1String(" -"));
                 connect(act, &QAction::triggered, this, &SKGQueryCreator::onAddText);
             }
             helpMenu->addSeparator();
@@ -195,15 +196,15 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
             helpMenu->addSeparator();
             {
                 QAction* act = helpMenu->addAction(i18nc("Operator contains", "Contains"));
-                act->setData(QStringLiteral(":"));
+                act->setData(QLatin1String(":"));
                 connect(act, &QAction::triggered, this, &SKGQueryCreator::onAddText);
             }
-            ADDOPERATOR(QStringLiteral("="), QStringLiteral("="))
-            ADDOPERATOR(i18nc("Noun", "Regular expression"), QStringLiteral("#"))
-            ADDOPERATOR(QStringLiteral(">"), QStringLiteral(">"))
-            ADDOPERATOR(QStringLiteral("<"), QStringLiteral("<"))
-            ADDOPERATOR(QStringLiteral(">="), QStringLiteral(">="))
-            ADDOPERATOR(QStringLiteral("<="), QStringLiteral("<="))
+            ADDOPERATOR(QLatin1String("="), QLatin1String("="))
+            ADDOPERATOR(i18nc("Noun", "Regular expression"), QLatin1String("#"))
+            ADDOPERATOR(QLatin1String(">"), QLatin1String(">"))
+            ADDOPERATOR(QLatin1String("<"), QLatin1String("<"))
+            ADDOPERATOR(QLatin1String(">="), QLatin1String(">="))
+            ADDOPERATOR(QLatin1String("<="), QLatin1String("<="))
             ui.kToolHelp->setMenu(helpMenu);
         }
 
@@ -262,7 +263,7 @@ void SKGQueryCreator::clearContents()
 
 void SKGQueryCreator::setXMLCondition(const QString& iXML)
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iXML);
     QDomElement root = doc.documentElement();
 
@@ -270,7 +271,7 @@ void SKGQueryCreator::setXMLCondition(const QString& iXML)
     ui.kList->setRowCount(0);
     ui.kList->setColumnCount(0);
 
-    if (root.tagName() == QStringLiteral("element")) {
+    if (root.tagName() == QLatin1String("element")) {
         // Mode advanced
         setAdvancedSearchMode(true);
         int row = -1;
@@ -286,17 +287,17 @@ void SKGQueryCreator::setXMLCondition(const QString& iXML)
                 while (!n.isNull()) {
                     QDomElement element = n.toElement();
                     if (!element.isNull()) {
-                        QString attribute = element.attribute(QStringLiteral("attribute"));
+                        QString attribute = element.attribute(QLatin1String("attribute"));
                         int idx = getIndexQueryColumn(attribute, row);
                         if (idx >= 0) {
-                            QDomDocument doc2(QStringLiteral("SKGML"));
-                            QDomElement root2 = doc2.createElement(QStringLiteral("element"));
+                            QDomDocument doc2(QLatin1String("SKGML"));
+                            QDomElement root2 = doc2.createElement(QLatin1String("element"));
                             doc2.appendChild(root2);
-                            root2.setAttribute(QStringLiteral("operator"), element.attribute(QStringLiteral("operator")));
-                            root2.setAttribute(QStringLiteral("value"), element.attribute(QStringLiteral("value")));
-                            root2.setAttribute(QStringLiteral("value2"), element.attribute(QStringLiteral("value2")));
-                            root2.setAttribute(QStringLiteral("att2"), element.attribute(QStringLiteral("att2")));
-                            root2.setAttribute(QStringLiteral("att2s"), element.attribute(QStringLiteral("att2s")));
+                            root2.setAttribute(QLatin1String("operator"), element.attribute(QLatin1String("operator")));
+                            root2.setAttribute(QLatin1String("value"), element.attribute(QLatin1String("value")));
+                            root2.setAttribute(QLatin1String("value2"), element.attribute(QLatin1String("value2")));
+                            root2.setAttribute(QLatin1String("att2"), element.attribute(QLatin1String("att2")));
+                            root2.setAttribute(QLatin1String("att2s"), element.attribute(QLatin1String("att2s")));
                             QTableWidgetItem* it = ui.kList->item(row, idx);
                             if (it != nullptr) {
                                 QString xml = doc2.toString();
@@ -316,7 +317,7 @@ void SKGQueryCreator::setXMLCondition(const QString& iXML)
     } else  {
         // Mode simple
         setAdvancedSearchMode(false);
-        ui.kFilterEdit->setText(root.attribute(QStringLiteral("query")));
+        ui.kFilterEdit->setText(root.attribute(QLatin1String("query")));
     }
 }
 
@@ -327,20 +328,20 @@ QString SKGQueryCreator::getXMLCondition()
         // Mode advanced
         QHeaderView* hHeader = ui.kList->horizontalHeader();
         if (hHeader != nullptr) {
-            QDomDocument doc(QStringLiteral("SKGML"));
-            QDomElement element = doc.createElement(QStringLiteral("element"));
+            QDomDocument doc(QLatin1String("SKGML"));
+            QDomElement element = doc.createElement(QLatin1String("element"));
             doc.appendChild(element);
 
-            element.appendChild(doc.createComment(QStringLiteral("OR")));
+            element.appendChild(doc.createComment(QLatin1String("OR")));
 
             bool empty = true;
             int nbRow = ui.kList->rowCount();
             int nbCol = hHeader->count();
             for (int j = 0; j < nbRow; ++j) {
-                QDomElement elementLine = doc.createElement(QStringLiteral("element"));
+                QDomElement elementLine = doc.createElement(QLatin1String("element"));
                 element.appendChild(elementLine);
 
-                elementLine.appendChild(doc.createComment(QStringLiteral("AND")));
+                elementLine.appendChild(doc.createComment(QLatin1String("AND")));
 
                 bool atLeastOne = false;
                 for (int i = 0; i < nbCol; ++i) {
@@ -349,29 +350,29 @@ QString SKGQueryCreator::getXMLCondition()
                     if (it != nullptr) {
                         QString co = it->data(Qt::UserRole).toString();
                         if (!co.isEmpty()) {
-                            QDomElement elementElement = doc.createElement(QStringLiteral("element"));
+                            QDomElement elementElement = doc.createElement(QLatin1String("element"));
                             elementLine.appendChild(elementElement);
 
                             QTableWidgetItem* it_h = ui.kList->horizontalHeaderItem(iRealPos);
                             QString attname = it_h->data(Qt::UserRole).toString();
 
-                            QDomDocument doc2(QStringLiteral("SKGML"));
+                            QDomDocument doc2(QLatin1String("SKGML"));
                             doc2.setContent(co);
                             QDomElement root2 = doc2.documentElement();
 
-                            elementElement.setAttribute(QStringLiteral("attribute"), attname);
-                            elementElement.setAttribute(QStringLiteral("operator"), root2.attribute(QStringLiteral("operator")));
-                            if (root2.hasAttribute(QStringLiteral("value"))) {
-                                elementElement.setAttribute(QStringLiteral("value"), root2.attribute(QStringLiteral("value")));
+                            elementElement.setAttribute(QLatin1String("attribute"), attname);
+                            elementElement.setAttribute(QLatin1String("operator"), root2.attribute(QLatin1String("operator")));
+                            if (root2.hasAttribute(QLatin1String("value"))) {
+                                elementElement.setAttribute(QLatin1String("value"), root2.attribute(QLatin1String("value")));
                             }
-                            if (root2.hasAttribute(QStringLiteral("value2"))) {
-                                elementElement.setAttribute(QStringLiteral("value2"), root2.attribute(QStringLiteral("value2")));
+                            if (root2.hasAttribute(QLatin1String("value2"))) {
+                                elementElement.setAttribute(QLatin1String("value2"), root2.attribute(QLatin1String("value2")));
                             }
-                            if (root2.hasAttribute(QStringLiteral("att2"))) {
-                                elementElement.setAttribute(QStringLiteral("att2"), root2.attribute(QStringLiteral("att2")));
+                            if (root2.hasAttribute(QLatin1String("att2"))) {
+                                elementElement.setAttribute(QLatin1String("att2"), root2.attribute(QLatin1String("att2")));
                             }
-                            if (root2.hasAttribute(QStringLiteral("att2s"))) {
-                                elementElement.setAttribute(QStringLiteral("att2s"), root2.attribute(QStringLiteral("att2s")));
+                            if (root2.hasAttribute(QLatin1String("att2s"))) {
+                                elementElement.setAttribute(QLatin1String("att2s"), root2.attribute(QLatin1String("att2s")));
                             }
 
                             atLeastOne = true;
@@ -390,10 +391,10 @@ QString SKGQueryCreator::getXMLCondition()
         }
     } else {
         // Mode simple
-        QDomDocument doc(QStringLiteral("SKGML"));
-        QDomElement element = doc.createElement(QStringLiteral("simple"));
-        element.setAttribute(QStringLiteral("query"), ui.kFilterEdit->text());
-        element.setAttribute(QStringLiteral("sql"), SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(ui.kFilterEdit->text()), m_attributes, m_document));
+        QDomDocument doc(QLatin1String("SKGML"));
+        QDomElement element = doc.createElement(QLatin1String("simple"));
+        element.setAttribute(QLatin1String("query"), ui.kFilterEdit->text());
+        element.setAttribute(QLatin1String("sql"), SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(ui.kFilterEdit->text()), m_attributes, m_document));
         doc.appendChild(element);
         output = doc.toString();
     }
@@ -477,7 +478,7 @@ void SKGQueryCreator::addNewLine()
 
         // Add a delete icon
         if (!m_updateMode) {
-            ui.kList->setVerticalHeaderItem(row, new QTableWidgetItem(SKGServices::fromTheme(QStringLiteral("edit-delete")), QLatin1String("")));
+            ui.kList->setVerticalHeaderItem(row, new QTableWidgetItem(SKGServices::fromTheme(QLatin1String("edit-delete")), QLatin1String("")));
         }
 
         for (int i = 0; i < nbCol; ++i) {
