@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -16,7 +16,7 @@
 #include "skgmainpanel.h"
 #include "skgunitvalueobject.h"
 
-SKGUnitComboBox::SKGUnitComboBox(QWidget* iParent): SKGComboBox(iParent), m_document(nullptr), m_fillWhereClause(QStringLiteral("t_type!='I'"))
+SKGUnitComboBox::SKGUnitComboBox(QWidget* iParent): SKGComboBox(iParent), m_document(nullptr), m_fillWhereClause(QLatin1String("t_type!='I'"))
 {
 }
 
@@ -76,7 +76,7 @@ void SKGUnitComboBox::refershList()
 {
     // Fill comboboxes
     if (m_document != nullptr) {
-        SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << this, m_document, QStringLiteral("unit"), QStringLiteral("ifnull(t_symbol,t_name)"), m_fillWhereClause);
+        SKGMainPanel::fillWithDistinctValue(QList<QWidget*>() << this, m_document, QLatin1String("unit"), QLatin1String("ifnull(t_symbol,t_name)"), m_fillWhereClause);
         SKGServices::SKGUnitInfo primary = m_document->getPrimaryUnit();
         if (!primary.Symbol.isEmpty()) {
             this->setCurrentIndex(this->findText(primary.Symbol));
@@ -92,7 +92,7 @@ void SKGUnitComboBox::dataModified(const QString& iTableName, int iIdTransaction
     if (m_document != nullptr) {
         QSqlDatabase* db = m_document->getMainDatabase();
         setEnabled(db != nullptr);
-        if (db != nullptr && (iTableName == QStringLiteral("unit") || iTableName.isEmpty())) {
+        if (db != nullptr && (iTableName == QLatin1String("unit") || iTableName.isEmpty())) {
             refershList();
         }
     }
