@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -43,27 +43,27 @@ QWidget* SKGPredicatCreatorDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGPredicatCreatorDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGPredicatCreator");
+    return QLatin1String("SKGPredicatCreator");
 }
 
 QString SKGPredicatCreatorDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGPredicatCreatorDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("skrooge.png"));
+    return SKGServices::fromTheme(QLatin1String("skrooge.png"));
 }
 
 QString SKGPredicatCreatorDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A predicat creator");
+    return QLatin1String("A predicat creator");
 }
 
 QString SKGPredicatCreatorDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A predicat creator");
+    return QLatin1String("A predicat creator");
 }
 
 bool SKGPredicatCreatorDesignerPlugin::isContainer() const
@@ -73,20 +73,20 @@ bool SKGPredicatCreatorDesignerPlugin::isContainer() const
 
 QString SKGPredicatCreatorDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGPredicatCreator\" name=\"SKGPredicatCreator\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>100</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGPredicatCreator\" name=\"SKGPredicatCreator\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>100</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGPredicatCreatorDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgpredicatcreator.h");
+    return QLatin1String("skgpredicatcreator.h");
 }
 
