@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -43,27 +43,27 @@ QWidget* SKGQueryCreatorDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGQueryCreatorDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGQueryCreator");
+    return QLatin1String("SKGQueryCreator");
 }
 
 QString SKGQueryCreatorDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGQueryCreatorDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("skrooge.png"));
+    return SKGServices::fromTheme(QLatin1String("skrooge.png"));
 }
 
 QString SKGQueryCreatorDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A query creator");
+    return QLatin1String("A query creator");
 }
 
 QString SKGQueryCreatorDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A query creator");
+    return QLatin1String("A query creator");
 }
 
 bool SKGQueryCreatorDesignerPlugin::isContainer() const
@@ -73,20 +73,20 @@ bool SKGQueryCreatorDesignerPlugin::isContainer() const
 
 QString SKGQueryCreatorDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGQueryCreator\" name=\"SKGQueryCreator\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>100</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGQueryCreator\" name=\"SKGQueryCreator\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>100</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGQueryCreatorDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgquerycreator.h");
+    return QLatin1String("skgquerycreator.h");
 }
 
