@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -44,27 +44,27 @@ QWidget* SKGUnitComboBoxDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGUnitComboBoxDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGUnitComboBox");
+    return QLatin1String("SKGUnitComboBox");
 }
 
 QString SKGUnitComboBoxDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGUnitComboBoxDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("skrooge.png"));
+    return SKGServices::fromTheme(QLatin1String("skrooge.png"));
 }
 
 QString SKGUnitComboBoxDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A unit combo box");
+    return QLatin1String("A unit combo box");
 }
 
 QString SKGUnitComboBoxDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A unit combo box");
+    return QLatin1String("A unit combo box");
 }
 
 bool SKGUnitComboBoxDesignerPlugin::isContainer() const
@@ -74,20 +74,20 @@ bool SKGUnitComboBoxDesignerPlugin::isContainer() const
 
 QString SKGUnitComboBoxDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGUnitComboBox\" name=\"SKGUnitComboBox\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>100</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGUnitComboBox\" name=\"SKGUnitComboBox\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>100</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGUnitComboBoxDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgunitcombobox.h");
+    return QLatin1String("skgunitcombobox.h");
 }
 
