@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -28,7 +28,7 @@ int factorial(int n)
 
 SKGAccountObject::SKGAccountObject() : SKGAccountObject(nullptr, 0) {}
 
-SKGAccountObject::SKGAccountObject(SKGDocument* iDocument, int iID) : SKGNamedObject(iDocument, QStringLiteral("v_account"), iID) {}
+SKGAccountObject::SKGAccountObject(SKGDocument* iDocument, int iID) : SKGNamedObject(iDocument, QLatin1String("v_account"), iID) {}
 
 SKGAccountObject::~SKGAccountObject() = default;
 
@@ -36,21 +36,21 @@ SKGAccountObject::SKGAccountObject(const SKGAccountObject& iObject)
     = default;
 
 SKGAccountObject::SKGAccountObject(const SKGNamedObject& iObject)
-    : SKGNamedObject(iObject.getDocument(), QStringLiteral("v_account"), iObject.getID())
+    : SKGNamedObject(iObject.getDocument(), QLatin1String("v_account"), iObject.getID())
 {
-    if (iObject.getRealTable() == QStringLiteral("account")) {
+    if (iObject.getRealTable() == QLatin1String("account")) {
         copyFrom(iObject);
     } else {
-        *this = SKGNamedObject(iObject.getDocument(), QStringLiteral("v_account"), iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), QLatin1String("v_account"), iObject.getID());
     }
 }
 
 SKGAccountObject::SKGAccountObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable() == QStringLiteral("account")) {
+    if (iObject.getRealTable() == QLatin1String("account")) {
         copyFrom(iObject);
     } else {
-        *this = SKGNamedObject(iObject.getDocument(), QStringLiteral("v_account"), iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), QLatin1String("v_account"), iObject.getID());
     }
 }
 
@@ -78,14 +78,14 @@ SKGError SKGAccountObject::setInitialBalance(double iBalance, const SKGUnitObjec
         IFOK(err) {
             SKGOperationObject initialBalanceOp;
             err = addOperation(initialBalanceOp, true);
-            IFOKDO(err, initialBalanceOp.setAttribute(QStringLiteral("d_date"), QStringLiteral("0000-00-00")))
+            IFOKDO(err, initialBalanceOp.setAttribute(QLatin1String("d_date"), QLatin1String("0000-00-00")))
             IFOKDO(err, initialBalanceOp.setUnit(iUnit))
             IFOKDO(err, initialBalanceOp.setStatus(SKGOperationObject::CHECKED))
             IFOKDO(err, initialBalanceOp.save())
 
             SKGSubOperationObject initialBalanceSubOp;
             IFOKDO(err, initialBalanceOp.addSubOperation(initialBalanceSubOp))
-            IFOKDO(err, initialBalanceSubOp.setAttribute(QStringLiteral("d_date"), QStringLiteral("0000-00-00")))
+            IFOKDO(err, initialBalanceSubOp.setAttribute(QLatin1String("d_date"), QLatin1String("0000-00-00")))
             IFOKDO(err, initialBalanceSubOp.setQuantity(iBalance))
             IFOKDO(err, initialBalanceSubOp.save())
         }
@@ -118,23 +118,23 @@ SKGError SKGAccountObject::getInitialBalance(double& oBalance, SKGUnitObject& oU
 
 SKGError SKGAccountObject::setBank(const SKGBankObject& iBank)
 {
-    return setAttribute(QStringLiteral("rd_bank_id"), SKGServices::intToString(iBank.getID()));
+    return setAttribute(QLatin1String("rd_bank_id"), SKGServices::intToString(iBank.getID()));
 }
 
 SKGError SKGAccountObject::getBank(SKGBankObject& oBank) const
 {
-    SKGError err = getDocument()->getObject(QStringLiteral("v_bank"), "id=" % getAttribute(QStringLiteral("rd_bank_id")), oBank);
+    SKGError err = getDocument()->getObject(QLatin1String("v_bank"), "id=" % getAttribute(QLatin1String("rd_bank_id")), oBank);
     return err;
 }
 
 SKGError SKGAccountObject::setLinkedAccount(const SKGAccountObject& iAccount)
 {
-    return setAttribute(QStringLiteral("r_account_id"), SKGServices::intToString(iAccount.getID()));
+    return setAttribute(QLatin1String("r_account_id"), SKGServices::intToString(iAccount.getID()));
 }
 
 SKGError SKGAccountObject::getLinkedAccount(SKGAccountObject& oAccount) const
 {
-    SKGError err = getDocument()->getObject(QStringLiteral("v_account"), "id=" % getAttribute(QStringLiteral("r_account_id")), oAccount);
+    SKGError err = getDocument()->getObject(QLatin1String("v_account"), "id=" % getAttribute(QLatin1String("r_account_id")), oAccount);
     return err;
 }
 
@@ -142,7 +142,7 @@ SKGError SKGAccountObject::getLinkedByAccounts(SKGListSKGObjectBase& oAccounts)
 {
     SKGError err;
     if (getDocument() != nullptr) {
-        err = getDocument()->getObjects(QStringLiteral("v_account"),
+        err = getDocument()->getObjects(QLatin1String("v_account"),
                                         "r_account_id=" % SKGServices::intToString(getID()),
                                         oAccounts);
     }
@@ -151,49 +151,49 @@ SKGError SKGAccountObject::getLinkedByAccounts(SKGListSKGObjectBase& oAccounts)
 
 SKGError SKGAccountObject::setNumber(const QString& iNumber)
 {
-    return setAttribute(QStringLiteral("t_number"), iNumber);
+    return setAttribute(QLatin1String("t_number"), iNumber);
 }
 
 QString SKGAccountObject::getNumber() const
 {
-    return getAttribute(QStringLiteral("t_number"));
+    return getAttribute(QLatin1String("t_number"));
 }
 
 SKGError SKGAccountObject::setComment(const QString& iComment)
 {
-    return setAttribute(QStringLiteral("t_comment"), iComment);
+    return setAttribute(QLatin1String("t_comment"), iComment);
 }
 
 QString SKGAccountObject::getComment() const
 {
-    return getAttribute(QStringLiteral("t_comment"));
+    return getAttribute(QLatin1String("t_comment"));
 }
 
 SKGError SKGAccountObject::setAgencyNumber(const QString& iNumber)
 {
-    return setAttribute(QStringLiteral("t_agency_number"), iNumber);
+    return setAttribute(QLatin1String("t_agency_number"), iNumber);
 }
 
 QString SKGAccountObject::getAgencyNumber() const
 {
-    return getAttribute(QStringLiteral("t_agency_number"));
+    return getAttribute(QLatin1String("t_agency_number"));
 }
 
 SKGError SKGAccountObject::setAgencyAddress(const QString& iAddress)
 {
-    return setAttribute(QStringLiteral("t_agency_address"), iAddress);
+    return setAttribute(QLatin1String("t_agency_address"), iAddress);
 }
 
 QString SKGAccountObject::getAgencyAddress() const
 {
-    return getAttribute(QStringLiteral("t_agency_address"));
+    return getAttribute(QLatin1String("t_agency_address"));
 }
 
 SKGError SKGAccountObject::addOperation(SKGOperationObject& oOperation, bool iForce)
 {
     SKGError err;
     if (getID() == 0) {
-        err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGAccountObject::addOperation")));
+        err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGAccountObject::addOperation")));
     } else {
         oOperation = SKGOperationObject(getDocument());
         err = oOperation.setParentAccount(*this, iForce);
@@ -205,7 +205,7 @@ int SKGAccountObject::getNbOperation() const
 {
     int nb = 0;
     if (getDocument() != nullptr) {
-        getDocument()->getNbObjects(QStringLiteral("operation"), "rd_account_id=" % SKGServices::intToString(getID()), nb);
+        getDocument()->getNbObjects(QLatin1String("operation"), "rd_account_id=" % SKGServices::intToString(getID()), nb);
     }
     return nb;
 }
@@ -214,7 +214,7 @@ SKGError SKGAccountObject::getOperations(SKGListSKGObjectBase& oOperations) cons
 {
     SKGError err;
     if (getDocument() != nullptr) {
-        err = getDocument()->getObjects(QStringLiteral("v_operation"),
+        err = getDocument()->getObjects(QLatin1String("v_operation"),
                                         "rd_account_id=" % SKGServices::intToString(getID()),
                                         oOperations);
     }
@@ -223,7 +223,7 @@ SKGError SKGAccountObject::getOperations(SKGListSKGObjectBase& oOperations) cons
 
 double SKGAccountObject::getCurrentAmount() const
 {
-    return SKGServices::stringToDouble(getAttributeFromView(QStringLiteral("v_account_amount"), QStringLiteral("f_CURRENTAMOUNT")));
+    return SKGServices::stringToDouble(getAttributeFromView(QLatin1String("v_account_amount"), QLatin1String("f_CURRENTAMOUNT")));
 }
 
 double SKGAccountObject::getAmount(QDate iDate, bool iOnlyCurrencies) const
@@ -234,7 +234,7 @@ double SKGAccountObject::getAmount(QDate iDate, bool iOnlyCurrencies) const
         // Search result in cache
         QString ids = SKGServices::intToString(getID());
         QString dates = SKGServices::dateToSqlString(iDate);
-        QString key = "getamount-" % ids % '-' % dates;
+        QString key = "getamount-" % ids % QLatin1Char('-') % dates;
         QString val = getDocument()->getCachedValue(key);
         if (val.isEmpty()) {
             SKGStringListList listTmp;
@@ -273,63 +273,63 @@ double SKGAccountObject::getAmount(QDate iDate, bool iOnlyCurrencies) const
 
 SKGError SKGAccountObject::setType(SKGAccountObject::AccountType iType)
 {
-    return setAttribute(QStringLiteral("t_type"), (iType == CURRENT ? QStringLiteral("C") :
-                        (iType == CREDITCARD ? QStringLiteral("D") :
-                         (iType == ASSETS ? QStringLiteral("A") :
-                          (iType == INVESTMENT ? QStringLiteral("I") :
-                           (iType == WALLET ? QStringLiteral("W") :
-                            (iType == PENSION ? QStringLiteral("P") :
-                             (iType == LOAN ? QStringLiteral("L") :
-                              (iType == SAVING ? QStringLiteral("S") :
-                               QStringLiteral("O"))))))))));
+    return setAttribute(QLatin1String("t_type"), (iType == CURRENT ? QLatin1String("C") :
+                        (iType == CREDITCARD ? QLatin1String("D") :
+                         (iType == ASSETS ? QLatin1String("A") :
+                          (iType == INVESTMENT ? QLatin1String("I") :
+                           (iType == WALLET ? QLatin1String("W") :
+                            (iType == PENSION ? QLatin1String("P") :
+                             (iType == LOAN ? QLatin1String("L") :
+                              (iType == SAVING ? QLatin1String("S") :
+                               QLatin1String("O"))))))))));
 }
 
 SKGAccountObject::AccountType SKGAccountObject::getType() const
 {
-    QString typeString = getAttribute(QStringLiteral("t_type"));
-    return (typeString == QStringLiteral("C") ? CURRENT :
-            (typeString == QStringLiteral("D") ? CREDITCARD :
-             (typeString == QStringLiteral("A") ? ASSETS :
-              (typeString == QStringLiteral("I") ? INVESTMENT :
-               (typeString == QStringLiteral("W") ? WALLET :
-                (typeString == QStringLiteral("P") ? PENSION :
-                 (typeString == QStringLiteral("L") ? LOAN :
-                  (typeString == QStringLiteral("S") ? SAVING : OTHER))))))));
+    QString typeString = getAttribute(QLatin1String("t_type"));
+    return (typeString == QLatin1String("C") ? CURRENT :
+            (typeString == QLatin1String("D") ? CREDITCARD :
+             (typeString == QLatin1String("A") ? ASSETS :
+              (typeString == QLatin1String("I") ? INVESTMENT :
+               (typeString == QLatin1String("W") ? WALLET :
+                (typeString == QLatin1String("P") ? PENSION :
+                 (typeString == QLatin1String("L") ? LOAN :
+                  (typeString == QLatin1String("S") ? SAVING : OTHER))))))));
 }
 
 SKGError SKGAccountObject::setClosed(bool iClosed)
 {
-    return setAttribute(QStringLiteral("t_close"), iClosed ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_close"), iClosed ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGAccountObject::isClosed() const
 {
-    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_close")) == QLatin1String("Y"));
 }
 
 SKGError SKGAccountObject::bookmark(bool iBookmark)
 {
-    return setAttribute(QStringLiteral("t_bookmarked"), iBookmark ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_bookmarked"), iBookmark ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGAccountObject::isBookmarked() const
 {
-    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_bookmarked")) == QLatin1String("Y"));
 }
 
 SKGError SKGAccountObject::maxLimitAmountEnabled(bool iEnabled)
 {
-    return setAttribute(QStringLiteral("t_maxamount_enabled"), iEnabled ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_maxamount_enabled"), iEnabled ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGAccountObject::isMaxLimitAmountEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_maxamount_enabled")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_maxamount_enabled")) == QLatin1String("Y"));
 }
 
 SKGError SKGAccountObject::setMaxLimitAmount(double iAmount)
 {
-    SKGError err = setAttribute(QStringLiteral("f_maxamount"), SKGServices::doubleToString(iAmount));
+    SKGError err = setAttribute(QLatin1String("f_maxamount"), SKGServices::doubleToString(iAmount));
     if (!err && getMinLimitAmount() > iAmount) {
         err = setMinLimitAmount(iAmount);
     }
@@ -338,22 +338,22 @@ SKGError SKGAccountObject::setMaxLimitAmount(double iAmount)
 
 double SKGAccountObject::getMaxLimitAmount() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_maxamount")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_maxamount")));
 }
 
 SKGError SKGAccountObject::minLimitAmountEnabled(bool iEnabled)
 {
-    return setAttribute(QStringLiteral("t_minamount_enabled"), iEnabled ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_minamount_enabled"), iEnabled ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGAccountObject::isMinLimitAmountEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_minamount_enabled")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_minamount_enabled")) == QLatin1String("Y"));
 }
 
 SKGError SKGAccountObject::setMinLimitAmount(double iAmount)
 {
-    SKGError err = setAttribute(QStringLiteral("f_minamount"), SKGServices::doubleToString(iAmount));
+    SKGError err = setAttribute(QLatin1String("f_minamount"), SKGServices::doubleToString(iAmount));
     if (!err && getMaxLimitAmount() < iAmount) {
         err = setMaxLimitAmount(iAmount);
     }
@@ -362,27 +362,27 @@ SKGError SKGAccountObject::setMinLimitAmount(double iAmount)
 
 double SKGAccountObject::getMinLimitAmount() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_minamount")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_minamount")));
 }
 
 SKGError SKGAccountObject::setReconciliationDate(QDate iDate)
 {
-    return setAttribute(QStringLiteral("d_reconciliationdate"), SKGServices::dateToSqlString(iDate));
+    return setAttribute(QLatin1String("d_reconciliationdate"), SKGServices::dateToSqlString(iDate));
 }
 
 QDate SKGAccountObject::getReconciliationDate() const
 {
-    return SKGServices::stringToTime(getAttribute(QStringLiteral("d_reconciliationdate"))).date();
+    return SKGServices::stringToDate(getAttribute(QLatin1String("d_reconciliationdate")));
 }
 
 SKGError SKGAccountObject::setReconciliationBalance(double iAmount)
 {
-    return setAttribute(QStringLiteral("f_reconciliationbalance"), SKGServices::doubleToString(iAmount));
+    return setAttribute(QLatin1String("f_reconciliationbalance"), SKGServices::doubleToString(iAmount));
 }
 
 double SKGAccountObject::getReconciliationBalance() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_reconciliationbalance")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_reconciliationbalance")));
 }
 
 SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
@@ -400,7 +400,7 @@ SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
         } else {
             // No ==> we get the preferred unit
             SKGObjectBase::SKGListSKGObjectBase units;
-            err = getDocument()->getObjects(QStringLiteral("v_unit"),
+            err = getDocument()->getObjects(QLatin1String("v_unit"),
                                             "t_type IN ('1', '2', 'C') AND EXISTS(SELECT 1 FROM operation WHERE rc_unit_id=v_unit.id AND rd_account_id=" % SKGServices::intToString(getID()) % ") ORDER BY t_type", units);
             int nb = units.count();
             if (nb != 0) {
@@ -415,7 +415,7 @@ SKGError SKGAccountObject::addInterest(SKGInterestObject& oInterest)
 {
     SKGError err;
     if (getID() == 0) {
-        err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGAccountObject::addInterest")));
+        err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGAccountObject::addInterest")));
     } else {
         oInterest = SKGInterestObject(qobject_cast<SKGDocumentBank*>(getDocument()));
         err = oInterest.setAccount(*this);
@@ -425,7 +425,7 @@ SKGError SKGAccountObject::addInterest(SKGInterestObject& oInterest)
 
 SKGError SKGAccountObject::getInterests(SKGListSKGObjectBase& oInterestList) const
 {
-    SKGError err = getDocument()->getObjects(QStringLiteral("v_interest"),
+    SKGError err = getDocument()->getObjects(QLatin1String("v_interest"),
                    "rd_account_id=" % SKGServices::intToString(getID()),
                    oInterestList);
     return err;
@@ -435,7 +435,7 @@ SKGError SKGAccountObject::getInterest(QDate iDate, SKGInterestObject& oInterest
 {
     QString ids = SKGServices::intToString(getID());
     QString dates = SKGServices::dateToSqlString(iDate);
-    SKGError err = SKGObjectBase::getDocument()->getObject(QStringLiteral("v_interest"),
+    SKGError err = SKGObjectBase::getDocument()->getObject(QLatin1String("v_interest"),
                    "rd_account_id=" % ids % " AND d_date<='" % dates %
                    "' AND  ABS(strftime('%s','" % dates %
                    "')-strftime('%s',d_date))=(SELECT MIN(ABS(strftime('%s','" % dates %
@@ -444,9 +444,9 @@ SKGError SKGAccountObject::getInterest(QDate iDate, SKGInterestObject& oInterest
                    oInterest);
 
     // If not found then get first
-    IFKO(err) err = SKGObjectBase::getDocument()->getObject(QStringLiteral("v_interest"),
+    IFKO(err) err = SKGObjectBase::getDocument()->getObject(QLatin1String("v_interest"),
                     "rd_account_id=" % SKGServices::intToString(getID()) % " AND d_date=(SELECT MIN(d_date) FROM interest WHERE rd_account_id=" %
-                    SKGServices::intToString(getID()) % ')',
+                    SKGServices::intToString(getID()) % QLatin1Char(')'),
                     oInterest);
     return err;
 }
@@ -469,7 +469,7 @@ SKGError SKGAccountObject::getInterestItems(SKGAccountObject::SKGInterestItemLis
 
     // Add transactions
     SKGObjectBase::SKGListSKGObjectBase items;
-    err = getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) %
+    err = getDocument()->getObjects(QLatin1String("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) %
                                     " AND t_template='N' AND t_TYPEUNIT IN ('1', '2', 'C')"
                                     " AND d_date>='" % SKGServices::dateToSqlString(initialDate) % "' "
                                     " AND d_date<='" % SKGServices::dateToSqlString(lastDate) % "' ORDER BY d_date", items);
@@ -493,7 +493,7 @@ SKGError SKGAccountObject::getInterestItems(SKGAccountObject::SKGInterestItemLis
 
     // Add interest
     IFOK(err) {
-        err = getDocument()->getObjects(QStringLiteral("v_interest"), "rd_account_id=" % SKGServices::intToString(getID()) %
+        err = getDocument()->getObjects(QLatin1String("v_interest"), "rd_account_id=" % SKGServices::intToString(getID()) %
                                         " AND d_date>='" % SKGServices::dateToSqlString(initialDate) % "' "
                                         " AND d_date<='" % SKGServices::dateToSqlString(lastDate) % "' ORDER BY d_date", items);
 
@@ -507,7 +507,7 @@ SKGError SKGAccountObject::getInterestItems(SKGAccountObject::SKGInterestItemLis
             itemI.date = ob.getDate();
             itemI.valueDate = itemI.date;
             itemI.rate = ob.getRate();
-            itemI.base = SKGServices::stringToInt(ob.getAttribute(QStringLiteral("t_base")));
+            itemI.base = SKGServices::stringToInt(ob.getAttribute(QLatin1String("t_base")));
             itemI.coef = 0;
             itemI.annualInterest = 0;
             itemI.accruedInterest = 0;
@@ -554,9 +554,9 @@ SKGError SKGAccountObject::getInterestItems(SKGAccountObject::SKGInterestItemLis
             err = computeInterestItems(oInterestList, oInterests, y);
         } else {
             // Drop temporary table
-            IFOKDO(err, getDocument()->executeSqliteOrder(QStringLiteral("DROP TABLE IF EXISTS interest_result")))
+            IFOKDO(err, getDocument()->executeSqliteOrder(QLatin1String("DROP TABLE IF EXISTS interest_result")))
             // Create fake table
-            IFOKDO(err, getDocument()->executeSqliteOrder(QStringLiteral("CREATE TEMP TABLE interest_result(a)")))
+            IFOKDO(err, getDocument()->executeSqliteOrder(QLatin1String("CREATE TEMP TABLE interest_result(a)")))
         }
     }
     return err;
@@ -589,7 +589,7 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
     for (int i = 0; !err && i < nb; ++i) {
         SKGInterestItem tmp = ioInterestList.at(i);
         SKGObjectBase object = tmp.object;
-        if (object.getRealTable() == QStringLiteral("operation")) {
+        if (object.getRealTable() == QLatin1String("operation")) {
             // Get transactions
             SKGOperationObject op(object);
 
@@ -599,7 +599,7 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
             // Get value date computation mode
             SKGInterestObject::ValueDateMode valueMode = SKGInterestObject::FIFTEEN;
             SKGInterestObject::InterestMode baseMode = SKGInterestObject::FIFTEEN24;
-            if (currentInterest.object.getRealTable() == QStringLiteral("interest")) {
+            if (currentInterest.object.getRealTable() == QLatin1String("interest")) {
                 SKGInterestObject interestObj(currentInterest.object);
                 valueMode = (tmp.amount >= 0 ? interestObj.getIncomeValueDateMode() : interestObj.getExpenditueValueDateMode());
                 baseMode = interestObj.getInterestComputationMode();
@@ -608,7 +608,7 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
             }
 
             // Compute value date
-            if (object.getRealTable() == QStringLiteral("operation")) {
+            if (object.getRealTable() == QLatin1String("operation")) {
                 if (valueMode == SKGInterestObject::FIFTEEN) {
                     if (tmp.amount >= 0) {
                         if (tmp.date.day() <= 15) {
@@ -648,7 +648,7 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
             // Compute annual interest
             tmp.annualInterest = tmp.amount * tmp.coef * tmp.rate / 100;
 
-        } else if (object.getRealTable() == QStringLiteral("interest")) {
+        } else if (object.getRealTable() == QLatin1String("interest")) {
             // Compute coef
             if (tmp.base == 365) {
                 QDate last(tmp.date.year(), 12, 31);
@@ -686,18 +686,18 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
     // Create temporary table
     IFOK(err) {
         QStringList sqlOrders;
-        sqlOrders << QStringLiteral("DROP TABLE IF EXISTS interest_result")
-                  << QStringLiteral("CREATE TEMP TABLE interest_result("
-                                    "id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,"
-                                    "d_date DATE NOT NULL,"
-                                    "d_valuedate DATE NOT NULL,"
-                                    "t_comment TEXT NOT NULL DEFAULT '',"
-                                    "f_currentamount FLOAT NOT NULL DEFAULT 0,"
-                                    "f_coef FLOAT NOT NULL DEFAULT 0,"
-                                    "f_rate FLOAT NOT NULL DEFAULT 0,"
-                                    "f_annual_interest FLOAT NOT NULL DEFAULT 0,"
-                                    "f_accrued_interest FLOAT NOT NULL DEFAULT 0"
-                                    ")");
+        sqlOrders << QLatin1String("DROP TABLE IF EXISTS interest_result")
+                  << QLatin1String("CREATE TEMP TABLE interest_result("
+                                   "id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,"
+                                   "d_date DATE NOT NULL,"
+                                   "d_valuedate DATE NOT NULL,"
+                                   "t_comment TEXT NOT NULL DEFAULT '',"
+                                   "f_currentamount FLOAT NOT NULL DEFAULT 0,"
+                                   "f_coef FLOAT NOT NULL DEFAULT 0,"
+                                   "f_rate FLOAT NOT NULL DEFAULT 0,"
+                                   "f_annual_interest FLOAT NOT NULL DEFAULT 0,"
+                                   "f_accrued_interest FLOAT NOT NULL DEFAULT 0"
+                                   ")");
         err = getDocument()->executeSqliteOrders(sqlOrders);
 
         // Fill table
@@ -709,12 +709,12 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
                 "INSERT INTO interest_result (d_date,d_valuedate,t_comment,f_currentamount,f_coef,f_rate,f_annual_interest,f_accrued_interest) "
                 " VALUES ('" % SKGServices::dateToSqlString(interest.date) %
                 "','" % SKGServices::dateToSqlString(interest.valueDate) %
-                "','" % SKGServices::stringToSqlString(object.getRealTable() == QStringLiteral("operation") ? i18nc("Noun", "Relative to transaction '%1'", SKGOperationObject(object).getDisplayName()) : i18nc("Noun", "Rate change")) %
+                "','" % SKGServices::stringToSqlString(object.getRealTable() == QLatin1String("operation") ? i18nc("Noun", "Relative to transaction '%1'", SKGOperationObject(object).getDisplayName()) : i18nc("Noun", "Rate change")) %
                 "'," % SKGServices::doubleToString(interest.amount) %
-                ',' % SKGServices::doubleToString(interest.coef) %
-                ',' % SKGServices::doubleToString(interest.rate) %
-                ',' % SKGServices::doubleToString(interest.annualInterest) %
-                ',' % SKGServices::doubleToString(interest.accruedInterest) %
+                QLatin1Char(',') % SKGServices::doubleToString(interest.coef) %
+                QLatin1Char(',') % SKGServices::doubleToString(interest.rate) %
+                QLatin1Char(',') % SKGServices::doubleToString(interest.annualInterest) %
+                QLatin1Char(',') % SKGServices::doubleToString(interest.accruedInterest) %
                 ")";
 
             err = getDocument()->executeSqliteOrder(sqlinsert);
@@ -732,7 +732,7 @@ SKGError SKGAccountObject::transferDeferredOperations(const SKGAccountObject& iT
     if (doc != nullptr) {
         // Get marked transactions
         SKGObjectBase::SKGListSKGObjectBase transactions;
-        IFOKDO(err, getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='P'", transactions))
+        IFOKDO(err, getDocument()->getObjects(QLatin1String("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='P'", transactions))
         int nb = transactions.count();
         if (nb != 0) {
             SKGOperationObject mergedOperations;
@@ -799,16 +799,16 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
         if (getUnit(unitAccount).isSucceeded()) {
             if (!unitAccount.getSymbol().isEmpty()) {
                 unit1.Symbol = unitAccount.getSymbol();
-                unit1.Value = SKGServices::stringToDouble(unitAccount.getAttribute(QStringLiteral("f_CURRENTAMOUNT")));
+                unit1.Value = SKGServices::stringToDouble(unitAccount.getAttribute(QLatin1String("f_CURRENTAMOUNT")));
             }
         }
-        SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, unit1, false) << SKGENDL;
+        SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, unit1, false) << Qt::endl;
 
         // Get balance of checked transactions
         QString balanceString;
         getDocument()->executeSingleSelectSqliteOrder("SELECT f_CHECKED from v_account_display WHERE id=" % SKGServices::intToString(getID()), balanceString);
         double balance = SKGServices::stringToDouble(balanceString);
-        SKGTRACEL(5) << "balance=" << doc->formatMoney(balance, unit1, false) << SKGENDL;
+        SKGTRACEL(5) << "balance=" << doc->formatMoney(balance, unit1, false) << Qt::endl;
 
 
         QString zero = doc->formatMoney(0, unit1, false);
@@ -817,11 +817,11 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
         if (sdiff == zero || sdiff == negativezero) {
             // This is an empty soluce
             output.push_back(QVector<SKGOperationObject>());
-            SKGTRACEL(5) << "empty solution found !!!" << SKGENDL;
+            SKGTRACEL(5) << "empty solution found !!!" << Qt::endl;
         } else {
             // Get all imported transaction
             SKGObjectBase::SKGListSKGObjectBase transactions;
-            getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status!='Y' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", transactions);
+            getDocument()->getObjects(QLatin1String("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status!='Y' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", transactions);
             int nb = transactions.count();
 
             if (!iSearchAllPossibleReconciliation) {
@@ -836,7 +836,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                 }
                 QString sdiff = doc->formatMoney(amount + balance - iTargetBalance * unit1.Value, unit1, false);
                 if (sdiff == zero || sdiff == negativezero) {
-                    SKGTRACEL(5) << "all transactions are a solution !!!" << SKGENDL;
+                    SKGTRACEL(5) << "all transactions are a solution !!!" << Qt::endl;
                     output.push_back(list);
                     return output;
                 }
@@ -844,9 +844,9 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
 
             // Search
             int nbmax = 500;
-            SKGTRACEL(5) << "Nb transactions:" << nb << SKGENDL;
+            SKGTRACEL(5) << "Nb transactions:" << nb << Qt::endl;
             if (nb > nbmax) {
-                SKGTRACEL(5) << "Too many transactions (" << nb << ") ==> Reducing the size of the computation" << SKGENDL;
+                SKGTRACEL(5) << "Too many transactions (" << nb << ") ==> Reducing the size of the computation" << Qt::endl;
                 for (int i = 0; i < nb - nbmax; ++i) {
                     SKGOperationObject op(transactions.at(0));
                     auto amount = op.getCurrentAmount();
@@ -867,7 +867,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
     output.reserve(5);
     auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
     if (doc != nullptr) {
-        SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, iUnit, false) << SKGENDL;
+        SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, iUnit, false) << Qt::endl;
 
         // Comparison
         QString zero = doc->formatMoney(0, iUnit, false);
@@ -879,10 +879,10 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
             // Get all transactions of the next date
             QVector<SKGOperationObject> nextOperations;
             nextOperations.reserve(iOperations.count());
-            QString date = iOperations.at(0).getAttribute(QStringLiteral("d_date"));
+            QString date = iOperations.at(0).getAttribute(QLatin1String("d_date"));
             for (int i = 0; i < nb; ++i) {
                 SKGOperationObject op(iOperations.at(i));
-                if (op.getAttribute(QStringLiteral("d_date")) == date) {
+                if (op.getAttribute(QLatin1String("d_date")) == date) {
                     nextOperations.push_back(op);
                 } else {
                     break;
@@ -891,7 +891,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
 
             // Get all combination of transactions
             int nbNext = nextOperations.count();
-            SKGTRACEL(5) << date << ":" << nbNext << " transactions found" << SKGENDL;
+            SKGTRACEL(5) << date << ":" << nbNext << " transactions found" << Qt::endl;
             std::vector<int> v(nbNext);
             for (int i = 0; i < nbNext; ++i) {
                 v[i] = i;
@@ -900,7 +900,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
             double nextBalance = iBalance;
             int index = 0;
             if (nbNext > 7) {
-                SKGTRACEL(5) << "Too many combination: " << factorial(nbNext) << " ==> limited to 5040" << SKGENDL;
+                SKGTRACEL(5) << "Too many combination: " << factorial(nbNext) << " ==> limited to 5040" << Qt::endl;
                 nbNext = 7;
             }
             nb = factorial(nbNext);
@@ -930,7 +930,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                 // Test the combination
                 double diff = iBalance - iTargetBalance * iUnit.Value;
                 double previousDiff = diff;
-                SKGTRACEL(5) << "Check combination " << (index + 1) << "/" << nb << ": Diff=" << doc->formatMoney(diff, iUnit, false) << SKGENDL;
+                SKGTRACEL(5) << "Check combination " << (index + 1) << "/" << nb << ": Diff=" << doc->formatMoney(diff, iUnit, false) << Qt::endl;
 
                 // Try to find an immediate soluce
                 int nbop = combi.count();
@@ -941,18 +941,18 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                         nextBalance += amount;
                     }
                     QString sdiff = doc->formatMoney(diff, iUnit, false);
-                    SKGTRACEL(5) << (j + 1) << "/" << nbop << ": Amount=" << amount << " / New diff=" << sdiff << SKGENDL;
+                    SKGTRACEL(5) << (j + 1) << "/" << nbop << ": Amount=" << amount << " / New diff=" << sdiff << Qt::endl;
                     if (sdiff == zero || sdiff == negativezero) {
                         // This is a soluce
                         auto s = combi.mid(0, j + 1);
                         if (output.contains(s)) {
-                            SKGTRACEL(5) << "found but already existing !!!" << SKGENDL;
+                            SKGTRACEL(5) << "found but already existing !!!" << Qt::endl;
                         } else {
                             output.push_back(s);
-                            SKGTRACEL(5) << "found !!!" << SKGENDL;
+                            SKGTRACEL(5) << "found !!!" << Qt::endl;
                             if (j == nbop - 1 || iSearchAllPossibleReconciliation) {
                                 // No need to test all combinations
-                                SKGTRACEL(5) << "No need to test all combinations" << SKGENDL;
+                                SKGTRACEL(5) << "No need to test all combinations" << Qt::endl;
                                 stopTests = true;
                             }
                         }
@@ -961,7 +961,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
 
                 // Check if tests of all combinations can be cancelled
                 if ((previousDiff > 0 && previousDiff + sumOperationsNegatives > 0) || (previousDiff < 0 && previousDiff + sumOperationPositives < 0)) {
-                    SKGTRACEL(5) << "No need to test all combinations due to signs of transactions and diffs" << SKGENDL;
+                    SKGTRACEL(5) << "No need to test all combinations due to signs of transactions and diffs" << Qt::endl;
                     stopTests = true;
                 }
 
@@ -980,9 +980,9 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
         }
     }
 
-    SKGTRACEL(5) << output.count() << " soluces found" << SKGENDL;
+    SKGTRACEL(5) << output.count() << " soluces found" << Qt::endl;
     if (!output.isEmpty()) {
-        SKGTRACEL(5) << "Size of the first soluce: " << output.at(0).count() << SKGENDL;
+        SKGTRACEL(5) << "Size of the first soluce: " << output.at(0).count() << Qt::endl;
     }
     return output;
 }
@@ -1013,7 +1013,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         }
 
         // Check all
-        SKGTRACEL(5) << length << " transactions marked" << SKGENDL;
+        SKGTRACEL(5) << length << " transactions marked" << Qt::endl;
         for (int i = 0; i < length; ++i) {
             SKGOperationObject op(soluce.at(i));
             err = op.setStatus(SKGOperationObject::MARKED);
