@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -18,7 +18,7 @@
 SKGBankObject::SKGBankObject(): SKGBankObject(nullptr)
 {}
 
-SKGBankObject::SKGBankObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QStringLiteral("v_bank"), iID)
+SKGBankObject::SKGBankObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QLatin1String("v_bank"), iID)
 {}
 
 SKGBankObject::~SKGBankObject()
@@ -29,19 +29,19 @@ SKGBankObject::SKGBankObject(const SKGBankObject& iObject)
 
 SKGBankObject::SKGBankObject(const SKGNamedObject& iObject)
 {
-    if (iObject.getRealTable() == QStringLiteral("bank")) {
+    if (iObject.getRealTable() == QLatin1String("bank")) {
         copyFrom(iObject);
     } else {
-        *this = SKGNamedObject(iObject.getDocument(), QStringLiteral("v_bank"), iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), QLatin1String("v_bank"), iObject.getID());
     }
 }
 
 SKGBankObject::SKGBankObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable() == QStringLiteral("bank")) {
+    if (iObject.getRealTable() == QLatin1String("bank")) {
         copyFrom(iObject);
     } else {
-        *this = SKGNamedObject(iObject.getDocument(), QStringLiteral("v_bank"), iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), QLatin1String("v_bank"), iObject.getID());
     }
 }
 
@@ -61,17 +61,17 @@ SKGError SKGBankObject::addAccount(SKGAccountObject& oAccount)
 {
     SKGError err;
     if (getID() == 0) {
-        err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGBankObject::addAccount")));
+        err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGBankObject::addAccount")));
     } else {
         oAccount = SKGAccountObject(qobject_cast<SKGDocumentBank*>(getDocument()));
-        err = oAccount.setAttribute(QStringLiteral("rd_bank_id"), SKGServices::intToString(getID()));
+        err = oAccount.setAttribute(QLatin1String("rd_bank_id"), SKGServices::intToString(getID()));
     }
     return err;
 }
 
 SKGError SKGBankObject::getAccounts(SKGListSKGObjectBase& oAccountList) const
 {
-    SKGError err = getDocument()->getObjects(QStringLiteral("v_account"),
+    SKGError err = getDocument()->getObjects(QLatin1String("v_account"),
                    "rd_bank_id=" % SKGServices::intToString(getID()),
                    oAccountList);
     return err;
@@ -79,26 +79,26 @@ SKGError SKGBankObject::getAccounts(SKGListSKGObjectBase& oAccountList) const
 
 SKGError SKGBankObject::setNumber(const QString& iNumber)
 {
-    return setAttribute(QStringLiteral("t_bank_number"), iNumber);
+    return setAttribute(QLatin1String("t_bank_number"), iNumber);
 }
 
 QString SKGBankObject::getNumber() const
 {
-    return getAttribute(QStringLiteral("t_bank_number"));
+    return getAttribute(QLatin1String("t_bank_number"));
 }
 
 SKGError SKGBankObject::setIcon(const QString& iIcon)
 {
-    return setAttribute(QStringLiteral("t_icon"), iIcon);
+    return setAttribute(QLatin1String("t_icon"), iIcon);
 }
 
 QString SKGBankObject::getIcon() const
 {
-    return getAttribute(QStringLiteral("t_icon"));
+    return getAttribute(QLatin1String("t_icon"));
 }
 
 double SKGBankObject::getCurrentAmount() const
 {
-    return SKGServices::stringToDouble(getAttributeFromView(QStringLiteral("v_bank_amount"), QStringLiteral("f_CURRENTAMOUNT")));
+    return SKGServices::stringToDouble(getAttributeFromView(QLatin1String("v_bank_amount"), QLatin1String("f_CURRENTAMOUNT")));
 }
 
