@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -23,7 +23,7 @@ SKGBudgetObject::SKGBudgetObject() : SKGBudgetObject(nullptr)
 {}
 
 SKGBudgetObject::SKGBudgetObject(SKGDocument* iDocument, int iID)
-    : SKGObjectBase(iDocument, QStringLiteral("v_budget"), iID)
+    : SKGObjectBase(iDocument, QLatin1String("v_budget"), iID)
 {}
 
 SKGBudgetObject::~SKGBudgetObject()
@@ -34,10 +34,10 @@ SKGBudgetObject::SKGBudgetObject(const SKGBudgetObject& iObject)
 
 SKGBudgetObject::SKGBudgetObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable() == QStringLiteral("budget")) {
+    if (iObject.getRealTable() == QLatin1String("budget")) {
         copyFrom(iObject);
     } else {
-        *this = SKGObjectBase(iObject.getDocument(), QStringLiteral("v_budget"), iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), QLatin1String("v_budget"), iObject.getID());
     }
 }
 
@@ -52,12 +52,12 @@ QString SKGBudgetObject::getWhereclauseId() const
     // Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();
     if (output.isEmpty()) {
-        QString y = getAttribute(QStringLiteral("i_year"));
+        QString y = getAttribute(QLatin1String("i_year"));
         if (!y.isEmpty()) {
             output = "i_year=" % y;
         }
 
-        QString m = getAttribute(QStringLiteral("i_month"));
+        QString m = getAttribute(QLatin1String("i_month"));
         if (!m.isEmpty()) {
             if (!output.isEmpty()) {
                 output = output % " AND ";
@@ -65,86 +65,86 @@ QString SKGBudgetObject::getWhereclauseId() const
             output = output % "i_month=" % m;
         }
 
-        QString r = getAttribute(QStringLiteral("rc_category_id"));
+        QString r = getAttribute(QLatin1String("rc_category_id"));
         if (!output.isEmpty()) {
             output = output % " AND ";
         }
-        output = output % "rc_category_id=" % (r.isEmpty() ? QStringLiteral("0") : std::move(r));
+        output = output % "rc_category_id=" % (r.isEmpty() ? QLatin1String("0") : std::move(r));
     }
     return output;
 }
 
 SKGError SKGBudgetObject::setBudgetedAmount(double iAmount)
 {
-    SKGError err = setAttribute(QStringLiteral("f_budgeted"), SKGServices::doubleToString(iAmount));
-    IFOKDO(err, setAttribute(QStringLiteral("f_budgeted_modified"), SKGServices::doubleToString(iAmount)))
-    IFOKDO(err, setAttribute(QStringLiteral("t_modification_reasons"), QLatin1String("")))
+    SKGError err = setAttribute(QLatin1String("f_budgeted"), SKGServices::doubleToString(iAmount));
+    IFOKDO(err, setAttribute(QLatin1String("f_budgeted_modified"), SKGServices::doubleToString(iAmount)))
+    IFOKDO(err, setAttribute(QLatin1String("t_modification_reasons"), QLatin1String("")))
     return err;
 }
 
 double SKGBudgetObject::getBudgetedAmount() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_budgeted")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_budgeted")));
 }
 
 double SKGBudgetObject::getBudgetedModifiedAmount() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_budgeted_modified")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_budgeted_modified")));
 }
 
 QString SKGBudgetObject::getModificationReasons() const
 {
-    return getAttribute(QStringLiteral("t_modification_reasons"));
+    return getAttribute(QLatin1String("t_modification_reasons"));
 }
 
 double SKGBudgetObject::getDelta() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_DELTABEFORETRANSFER")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_DELTABEFORETRANSFER")));
 }
 
 SKGError SKGBudgetObject::setYear(int iYear)
 {
-    return setAttribute(QStringLiteral("i_year"), SKGServices::intToString(iYear));
+    return setAttribute(QLatin1String("i_year"), SKGServices::intToString(iYear));
 }
 
 int SKGBudgetObject::getYear() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_year")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_year")));
 }
 
 SKGError SKGBudgetObject::setMonth(int iMonth)
 {
-    return setAttribute(QStringLiteral("i_month"), SKGServices::intToString(iMonth));
+    return setAttribute(QLatin1String("i_month"), SKGServices::intToString(iMonth));
 }
 
 int SKGBudgetObject::getMonth() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_month")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_month")));
 }
 
 SKGError SKGBudgetObject::setCategory(const SKGCategoryObject& iCategory)
 {
-    return setAttribute(QStringLiteral("rc_category_id"), SKGServices::intToString(iCategory.getID()));
+    return setAttribute(QLatin1String("rc_category_id"), SKGServices::intToString(iCategory.getID()));
 }
 
 SKGError SKGBudgetObject::getCategory(SKGCategoryObject& oCategory) const
 {
-    return getDocument()->getObject(QStringLiteral("v_category"), "id=" % getAttribute(QStringLiteral("rc_category_id")), oCategory);
+    return getDocument()->getObject(QLatin1String("v_category"), "id=" % getAttribute(QLatin1String("rc_category_id")), oCategory);
 }
 
 SKGError SKGBudgetObject::enableSubCategoriesInclusion(bool iEnable)
 {
-    return setAttribute(QStringLiteral("t_including_subcategories"), iEnable ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_including_subcategories"), iEnable ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGBudgetObject::isSubCategoriesInclusionEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_including_subcategories")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_including_subcategories")) == QLatin1String("Y"));
 }
 
 SKGError SKGBudgetObject::removeCategory()
 {
-    return setAttribute(QStringLiteral("rc_category_id"), QStringLiteral("0"));
+    return setAttribute(QLatin1String("rc_category_id"), QLatin1String("0"));
 }
 
 SKGError SKGBudgetObject::process()
@@ -154,15 +154,15 @@ SKGError SKGBudgetObject::process()
     // Main values
     int m = getMonth();
     int y = getYear();
-    double transferred = SKGServices::stringToDouble(getAttribute(QStringLiteral("f_transferred")));
+    double transferred = SKGServices::stringToDouble(getAttribute(QLatin1String("f_transferred")));
 
     // Get budgets rules ordered
     SKGObjectBase::SKGListSKGObjectBase budgetsRules;
     QString sql = "(t_year_condition='N' OR i_year=" % SKGServices::intToString(y) % ") AND "
                   "(t_month_condition='N' OR i_month=" % SKGServices::intToString(m) % ") AND "
-                  "(t_category_condition='N' OR rc_category_id=" % getAttribute(QStringLiteral("rc_category_id")) % ") "
+                  "(t_category_condition='N' OR rc_category_id=" % getAttribute(QLatin1String("rc_category_id")) % ") "
                   "ORDER BY i_ORDER ASC";
-    err = getDocument()->getObjects(QStringLiteral("v_budgetrule"), sql, budgetsRules);
+    err = getDocument()->getObjects(QLatin1String("v_budgetrule"), sql, budgetsRules);
 
     int nb = budgetsRules.count();
     if (!err && (nb != 0)) {
@@ -218,17 +218,17 @@ SKGError SKGBudgetObject::process()
                         if (impactedBudget.exist()) {
                             err = impactedBudget.load();
                             QString newBudget = SKGServices::doubleToString(impactedBudget.getBudgetedModifiedAmount() - value);
-                            IFOKDO(err, impactedBudget.setAttribute(QStringLiteral("f_budgeted_modified"), newBudget))
-                            QString reasons = impactedBudget.getAttribute(QStringLiteral("t_modification_reasons"));
+                            IFOKDO(err, impactedBudget.setAttribute(QLatin1String("f_budgeted_modified"), newBudget))
+                            QString reasons = impactedBudget.getAttribute(QLatin1String("t_modification_reasons"));
                             if (!reasons.isEmpty()) {
                                 reasons += '\n';
                             }
                             reasons += i18nc("Message", "Transfer of %1 from '%2' to '%3' due to the rule '%4'", value, getDisplayName(), impactedBudget.getDisplayName(), rule.getDisplayName());
-                            IFOKDO(err, impactedBudget.setAttribute(QStringLiteral("t_modification_reasons"), reasons))
+                            IFOKDO(err, impactedBudget.setAttribute(QLatin1String("t_modification_reasons"), reasons))
                             IFOKDO(err, impactedBudget.save())
 
                             transferred += value;
-                            IFOKDO(err, setAttribute(QStringLiteral("f_transferred"), SKGServices::doubleToString(transferred)))
+                            IFOKDO(err, setAttribute(QLatin1String("f_transferred"), SKGServices::doubleToString(transferred)))
                             IFOKDO(err, save())
                         } else {
                             getDocument()->sendMessage(i18nc("", "Impossible to apply the rule '%1' for budget '%2' because the impacted budget does not exist", rule.getDisplayName(), this->getDisplayName()), SKGDocument::Warning);
@@ -304,7 +304,7 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
 
                 if (!catName.isEmpty() && (countPercent > 85 || count == 1)) {
                     SKGCategoryObject cat;
-                    err = iDocument->getObject(QStringLiteral("v_category"), "t_fullname = '" % SKGServices::stringToSqlString(catName) % '\'', cat);
+                    err = iDocument->getObject(QLatin1String("v_category"), "t_fullname = '" % SKGServices::stringToSqlString(catName) % QLatin1Char('\''), cat);
                     for (int m = fistMonth; !err && m <= (count == 1 ? fistMonth : 12); ++m) {
                         SKGBudgetObject budget(iDocument);
                         err = budget.setBudgetedAmount(amount);
@@ -321,7 +321,7 @@ SKGError SKGBudgetObject::createAutomaticBudget(SKGDocumentBank* iDocument, int
             }
 
             // Analyze
-            IFOKDO(err, iDocument->executeSqliteOrder(QStringLiteral("ANALYZE")))
+            IFOKDO(err, iDocument->executeSqliteOrder(QLatin1String("ANALYZE")))
             ++step;
             IFOKDO(err, iDocument->stepForward(step))
 
@@ -340,7 +340,7 @@ SKGError SKGBudgetObject::balanceBudget(SKGDocumentBank* iDocument, int iYear, i
 
         // Monthly balancing
         if (!err && iMonth != -1) {
-            for (int m = (iMonth == 0 ? 1 : qAsConst(iMonth)); !err && m <= (iMonth == 0 ? 12 : iMonth); ++m) {
+            for (int m = (iMonth == 0 ? 1 : std::as_const(iMonth)); !err && m <= (iMonth == 0 ? 12 : iMonth); ++m) {
                 SKGStringListList listTmp;
                 err = iDocument->executeSelectSqliteOrder("SELECT TOTAL(f_budgeted) FROM budget WHERE i_year=" % SKGServices::intToString(iYear) % " AND i_month=" % SKGServices::intToString(m) % " AND rc_category_id<>0", listTmp);
                 if (!err && listTmp.count() == 2) {
