@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -23,7 +23,7 @@ SKGBudgetRuleObject::SKGBudgetRuleObject()
 {}
 
 SKGBudgetRuleObject::SKGBudgetRuleObject(SKGDocument* iDocument, int iID)
-    : SKGObjectBase(iDocument, QStringLiteral("v_budgetrule"), iID)
+    : SKGObjectBase(iDocument, QLatin1String("v_budgetrule"), iID)
 {}
 
 SKGBudgetRuleObject::~SKGBudgetRuleObject()
@@ -34,10 +34,10 @@ SKGBudgetRuleObject::SKGBudgetRuleObject(const SKGBudgetRuleObject& iObject)
 
 SKGBudgetRuleObject::SKGBudgetRuleObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable() == QStringLiteral("budgetrule")) {
+    if (iObject.getRealTable() == QLatin1String("budgetrule")) {
         copyFrom(iObject);
     } else {
-        *this = SKGObjectBase(iObject.getDocument(), QStringLiteral("v_budgetrule"), iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), QLatin1String("v_budgetrule"), iObject.getID());
     }
 }
 
@@ -49,121 +49,121 @@ SKGBudgetRuleObject& SKGBudgetRuleObject::operator= (const SKGObjectBase& iObjec
 
 SKGError SKGBudgetRuleObject::enableYearCondition(bool iEnable)
 {
-    return setAttribute(QStringLiteral("t_year_condition"), iEnable ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_year_condition"), iEnable ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGBudgetRuleObject::isYearConditionEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_year_condition")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_year_condition")) == QLatin1String("Y"));
 }
 
 SKGError SKGBudgetRuleObject::enableMonthCondition(bool iEnable)
 {
-    return setAttribute(QStringLiteral("t_month_condition"), iEnable ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_month_condition"), iEnable ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGBudgetRuleObject::isMonthConditionEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_month_condition")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_month_condition")) == QLatin1String("Y"));
 }
 
 SKGError SKGBudgetRuleObject::enableCategoryCondition(bool iEnable)
 {
-    return setAttribute(QStringLiteral("t_category_condition"), iEnable ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_category_condition"), iEnable ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGBudgetRuleObject::isCategoryConditionEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_category_condition")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_category_condition")) == QLatin1String("Y"));
 }
 
 SKGError SKGBudgetRuleObject::setBudgetYear(int iYear)
 {
-    return setAttribute(QStringLiteral("i_year"), SKGServices::intToString(iYear));
+    return setAttribute(QLatin1String("i_year"), SKGServices::intToString(iYear));
 }
 
 int SKGBudgetRuleObject::getBudgetYear() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_year")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_year")));
 }
 
 SKGError SKGBudgetRuleObject::setBudgetMonth(int iMonth)
 {
-    return setAttribute(QStringLiteral("i_month"), SKGServices::intToString(iMonth));
+    return setAttribute(QLatin1String("i_month"), SKGServices::intToString(iMonth));
 }
 
 int SKGBudgetRuleObject::getBudgetMonth() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_month")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_month")));
 }
 
 SKGError SKGBudgetRuleObject::setBudgetCategory(const SKGCategoryObject& iCategory)
 {
-    return setAttribute(QStringLiteral("rc_category_id"), SKGServices::intToString(iCategory.getID()));
+    return setAttribute(QLatin1String("rc_category_id"), SKGServices::intToString(iCategory.getID()));
 }
 
 SKGError SKGBudgetRuleObject::getBudgetCategory(SKGCategoryObject& oCategory) const
 {
-    return getDocument()->getObject(QStringLiteral("v_category"), "id=" % getAttribute(QStringLiteral("rc_category_id")), oCategory);
+    return getDocument()->getObject(QLatin1String("v_category"), "id=" % getAttribute(QLatin1String("rc_category_id")), oCategory);
 }
 
 SKGError SKGBudgetRuleObject::removeBudgetCategory()
 {
-    return setAttribute(QStringLiteral("rc_category_id"), QStringLiteral("0"));
+    return setAttribute(QLatin1String("rc_category_id"), QLatin1String("0"));
 }
 
 SKGError SKGBudgetRuleObject::setCondition(SKGBudgetRuleObject::Condition iCondition)
 {
-    return setAttribute(QStringLiteral("i_condition"), SKGServices::intToString(static_cast<int>(iCondition)));
+    return setAttribute(QLatin1String("i_condition"), SKGServices::intToString(static_cast<int>(iCondition)));
 }
 
 SKGBudgetRuleObject::Condition SKGBudgetRuleObject::getCondition() const
 {
-    return static_cast<SKGBudgetRuleObject::Condition>(SKGServices::stringToInt(getAttribute(QStringLiteral("i_condition"))));
+    return static_cast<SKGBudgetRuleObject::Condition>(SKGServices::stringToInt(getAttribute(QLatin1String("i_condition"))));
 }
 
 SKGError SKGBudgetRuleObject::setQuantity(double iQuantity, bool iAbsolute)
 {
-    SKGError err = setAttribute(QStringLiteral("f_quantity"), SKGServices::doubleToString(iQuantity));
-    IFOKDO(err, setAttribute(QStringLiteral("t_absolute"), iAbsolute ? QStringLiteral("Y") : QStringLiteral("N")))
+    SKGError err = setAttribute(QLatin1String("f_quantity"), SKGServices::doubleToString(iQuantity));
+    IFOKDO(err, setAttribute(QLatin1String("t_absolute"), iAbsolute ? QLatin1String("Y") : QLatin1String("N")))
     return err;
 }
 
 double SKGBudgetRuleObject::getQuantity() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_quantity")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_quantity")));
 }
 
 bool SKGBudgetRuleObject::isAbolute() const
 {
-    return getAttribute(QStringLiteral("t_absolute")) != QStringLiteral("N");
+    return getAttribute(QLatin1String("t_absolute")) != QLatin1String("N");
 }
 
 SKGError SKGBudgetRuleObject::enableCategoryChange(bool iEnable)
 {
-    return setAttribute(QStringLiteral("t_category_target"), iEnable ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_category_target"), iEnable ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGBudgetRuleObject::isCategoryChangeEnabled() const
 {
-    return getAttribute(QStringLiteral("t_category_target")) == QStringLiteral("Y");
+    return getAttribute(QLatin1String("t_category_target")) == QLatin1String("Y");
 }
 
 SKGError SKGBudgetRuleObject::setTransfer(SKGBudgetRuleObject::Mode iMode, const SKGCategoryObject& iCategory)
 {
-    SKGError err = setAttribute(QStringLiteral("t_rule"), iMode == NEXT ? QStringLiteral("N") : iMode == CURRENT ? QStringLiteral("C") : QStringLiteral("Y"));
-    IFOKDO(err, setAttribute(QStringLiteral("rc_category_id_target"), SKGServices::intToString(iCategory.getID())))
+    SKGError err = setAttribute(QLatin1String("t_rule"), iMode == NEXT ? QLatin1String("N") : iMode == CURRENT ? QLatin1String("C") : QLatin1String("Y"));
+    IFOKDO(err, setAttribute(QLatin1String("rc_category_id_target"), SKGServices::intToString(iCategory.getID())))
     return err;
 }
 
 SKGBudgetRuleObject::Mode SKGBudgetRuleObject::getTransferMode() const
 {
-    return (getAttribute(QStringLiteral("t_rule")) == QStringLiteral("N") ? NEXT : (getAttribute(QStringLiteral("t_rule")) == QStringLiteral("C") ? CURRENT : YEAR));
+    return (getAttribute(QLatin1String("t_rule")) == QLatin1String("N") ? NEXT : (getAttribute(QLatin1String("t_rule")) == QLatin1String("C") ? CURRENT : YEAR));
 }
 
 SKGError SKGBudgetRuleObject::getTransferCategory(SKGCategoryObject& oCategory) const
 {
-    return getDocument()->getObject(QStringLiteral("v_category"), "id=" % getAttribute(QStringLiteral("rc_category_id_target")), oCategory);
+    return getDocument()->getObject(QLatin1String("v_category"), "id=" % getAttribute(QLatin1String("rc_category_id_target")), oCategory);
 }
 
 SKGError SKGBudgetRuleObject::processAllRules(SKGDocumentBank* iDocument)
@@ -172,12 +172,12 @@ SKGError SKGBudgetRuleObject::processAllRules(SKGDocumentBank* iDocument)
     SKGTRACEINFUNCRC(10, err)
     if (iDocument != nullptr) {
         // Initialize
-        err = iDocument->executeSqliteOrder(QStringLiteral("UPDATE budget SET f_budgeted_modified=f_budgeted  WHERE f_budgeted_modified!=f_budgeted"));
-        IFOKDO(err, iDocument->executeSqliteOrder(QStringLiteral("UPDATE budget SET f_transferred=0  WHERE f_transferred!=0")))
+        err = iDocument->executeSqliteOrder(QLatin1String("UPDATE budget SET f_budgeted_modified=f_budgeted  WHERE f_budgeted_modified!=f_budgeted"));
+        IFOKDO(err, iDocument->executeSqliteOrder(QLatin1String("UPDATE budget SET f_transferred=0  WHERE f_transferred!=0")))
 
         // Get budgets ordered by date
         SKGObjectBase::SKGListSKGObjectBase budgets;
-        IFOKDO(err, iDocument->getObjects(QStringLiteral("vm_budget_tmp"), QStringLiteral("length(t_RULES)>0 "
+        IFOKDO(err, iDocument->getObjects(QLatin1String("vm_budget_tmp"), QLatin1String("length(t_RULES)>0 "
                                           "AND (t_PERIOD<=STRFTIME('%Y-%m', date('now', 'localtime')) OR t_PERIOD=STRFTIME('%Y', date('now', 'localtime'))) "
                                           "ORDER BY t_PERIOD, id"), budgets));
         int nb = budgets.count();
@@ -191,7 +191,7 @@ SKGError SKGBudgetRuleObject::processAllRules(SKGDocumentBank* iDocument)
                 IFOKDO(err, iDocument->stepForward(i + 1))
             }
 
-            IFOKDO(err, iDocument->setParameter(QStringLiteral("SKG_LAST_BUDGET_PROCESSING"), QDate::currentDate().toString(QStringLiteral("yyyy-MM-dd"))))
+            IFOKDO(err, iDocument->setParameter(QLatin1String("SKG_LAST_BUDGET_PROCESSING"), QDate::currentDate().toString(QLatin1String("yyyy-MM-dd"))))
 
             SKGENDTRANSACTION(iDocument,  err)
         }
@@ -207,17 +207,17 @@ SKGError SKGBudgetRuleObject::setOrder(double iOrder)
     if (order == -1) {
         order = 1;
         SKGStringListList result;
-        err = getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT max(f_sortorder) from budgetrule"), result);
+        err = getDocument()->executeSelectSqliteOrder(QLatin1String("SELECT max(f_sortorder) from budgetrule"), result);
         if (!err && result.count() == 2) {
             order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
         }
     }
-    IFOKDO(err, setAttribute(QStringLiteral("f_sortorder"), SKGServices::doubleToString(order)))
+    IFOKDO(err, setAttribute(QLatin1String("f_sortorder"), SKGServices::doubleToString(order)))
     return err;
 }
 
 double SKGBudgetRuleObject::getOrder() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_sortorder")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_sortorder")));
 }
 
