@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -19,7 +19,7 @@
 SKGCategoryObject::SKGCategoryObject() : SKGCategoryObject(nullptr)
 {}
 
-SKGCategoryObject::SKGCategoryObject(SKGDocument* iDocument, int iID) : SKGNamedObject(iDocument, QStringLiteral("v_category"), iID)
+SKGCategoryObject::SKGCategoryObject(SKGDocument* iDocument, int iID) : SKGNamedObject(iDocument, QLatin1String("v_category"), iID)
 {}
 
 SKGCategoryObject::~SKGCategoryObject()
@@ -30,10 +30,10 @@ SKGCategoryObject::SKGCategoryObject(const SKGCategoryObject& iObject) = default
 SKGCategoryObject::SKGCategoryObject(const SKGObjectBase& iObject)
 
 {
-    if (iObject.getRealTable() == QStringLiteral("category")) {
+    if (iObject.getRealTable() == QLatin1String("category")) {
         copyFrom(iObject);
     } else {
-        *this = SKGNamedObject(iObject.getDocument(), QStringLiteral("v_category"), iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), QLatin1String("v_category"), iObject.getID());
     }
 }
 
@@ -65,15 +65,15 @@ QString SKGCategoryObject::getWhereclauseId() const
     // Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();  // clazy:exclude=skipped-base-method
     if (output.isEmpty()) {
-        if (!(getAttribute(QStringLiteral("t_name")).isEmpty())) {
-            output = "t_name='" % SKGServices::stringToSqlString(getAttribute(QStringLiteral("t_name"))) % '\'';
+        if (!(getAttribute(QLatin1String("t_name")).isEmpty())) {
+            output = "t_name='" % SKGServices::stringToSqlString(getAttribute(QLatin1String("t_name"))) % QLatin1Char('\'');
         }
-        QString rd_category_id = getAttribute(QStringLiteral("rd_category_id"));
+        QString rd_category_id = getAttribute(QLatin1String("rd_category_id"));
         if (!output.isEmpty()) {
-            output += QStringLiteral(" AND ");
+            output += QLatin1String(" AND ");
         }
         if (rd_category_id.isEmpty()) {
-            output += QStringLiteral("(rd_category_id=0 OR rd_category_id IS NULL OR rd_category_id='')");
+            output += QLatin1String("(rd_category_id=0 OR rd_category_id IS NULL OR rd_category_id='')");
         } else {
             output += "rd_category_id=" % rd_category_id;
         }
@@ -83,7 +83,7 @@ QString SKGCategoryObject::getWhereclauseId() const
 
 QString SKGCategoryObject::getFullName() const
 {
-    return getAttribute(QStringLiteral("t_fullname"));
+    return getAttribute(QLatin1String("t_fullname"));
 }
 
 SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
@@ -100,7 +100,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
         oCategory = SKGCategoryObject(nullptr, 0);
     } else if (iDocument != nullptr) {
         if (!iRenameIfAlreadyExist) {
-            iDocument->getObject(QStringLiteral("v_category"), "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oCategory);
+            iDocument->getObject(QLatin1String("v_category"), "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % QLatin1Char('\''), oCategory);
         } else {
             oCategory.resetID();
         }
@@ -117,7 +117,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
                     int index = 1;
                     while (!err && oCategory.exist()) {
                         index++;
-                        err = oCategory.setName(iFullPath % " (" % SKGServices::intToString(index) % ')');
+                        err = oCategory.setName(iFullPath % " (" % SKGServices::intToString(index) % QLatin1Char(')'));
                     }
                 }
 
@@ -142,7 +142,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
                     if (!err && iRenameIfAlreadyExist) {
                         int index = 2;
                         while (!err && oCategory.exist()) {
-                            err = oCategory.setName(second % " (" % SKGServices::intToString(index) % ')');
+                            err = oCategory.setName(second % " (" % SKGServices::intToString(index) % QLatin1Char(')'));
                             ++index;
                         }
                     }
@@ -166,10 +166,10 @@ SKGError SKGCategoryObject::addCategory(SKGCategoryObject& oCategory)
     SKGError err;
     SKGTRACEINFUNCRC(10, err)
     if (getID() == 0) {
-        err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGCategoryObject::addCategory")));
+        err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGCategoryObject::addCategory")));
     } else {
         oCategory = SKGCategoryObject(qobject_cast<SKGDocumentBank*>(getDocument()));
-        err = oCategory.setAttribute(QStringLiteral("rd_category_id"), SKGServices::intToString(getID()));
+        err = oCategory.setAttribute(QLatin1String("rd_category_id"), SKGServices::intToString(getID()));
     }
     return err;
 }
@@ -179,7 +179,7 @@ SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory
     SKGError err;
     SKGTRACEINFUNCRC(10, err)
     if (iCategory.getID() == 0) {
-        err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGCategoryObject::setParentCategory")));
+        err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGCategoryObject::setParentCategory")));
     } else {
         // Check if it is a loop
         SKGCategoryObject current = iCategory;
@@ -193,22 +193,22 @@ SKGError SKGCategoryObject::setParentCategory(const SKGCategoryObject& iCategory
             }
         } while (!err && current.getID() != 0);
 
-        IFOKDO(err, setAttribute(QStringLiteral("rd_category_id"), SKGServices::intToString(iCategory.getID())))
+        IFOKDO(err, setAttribute(QLatin1String("rd_category_id"), SKGServices::intToString(iCategory.getID())))
     }
     return err;
 }
 
 SKGError SKGCategoryObject::removeParentCategory()
 {
-    return setAttribute(QStringLiteral("rd_category_id"), QStringLiteral("0"));
+    return setAttribute(QLatin1String("rd_category_id"), QLatin1String("0"));
 }
 
 SKGError SKGCategoryObject::getParentCategory(SKGCategoryObject& oCategory) const
 {
     SKGError err;
-    QString parent_id = getAttribute(QStringLiteral("rd_category_id"));
-    if (!parent_id.isEmpty() && parent_id != QStringLiteral("0")) {
-        err = getDocument()->getObject(QStringLiteral("v_category"), "id=" % parent_id, oCategory);
+    QString parent_id = getAttribute(QLatin1String("rd_category_id"));
+    if (!parent_id.isEmpty() && parent_id != QLatin1String("0")) {
+        err = getDocument()->getObject(QLatin1String("v_category"), "id=" % parent_id, oCategory);
     }
     return err;
 }
@@ -233,24 +233,24 @@ SKGError SKGCategoryObject::getRootCategory(SKGCategoryObject& oCategory) const
 
 SKGError SKGCategoryObject::getCategories(SKGListSKGObjectBase& oCategoryList) const
 {
-    return getDocument()->getObjects(QStringLiteral("v_category"),
+    return getDocument()->getObjects(QLatin1String("v_category"),
                                      "rd_category_id=" % SKGServices::intToString(getID()),
                                      oCategoryList);
 }
 
 double SKGCategoryObject::getCurrentAmount() const
 {
-    QString v = getAttribute(QStringLiteral("f_SUMCURRENTAMOUNT"));
+    QString v = getAttribute(QLatin1String("f_SUMCURRENTAMOUNT"));
     if (v.isEmpty()) {
-        SKGNamedObject cat(getDocument(), QStringLiteral("v_category_display"), getID());
-        v = cat.getAttribute(QStringLiteral("f_SUMCURRENTAMOUNT"));
+        SKGNamedObject cat(getDocument(), QLatin1String("v_category_display"), getID());
+        v = cat.getAttribute(QLatin1String("f_SUMCURRENTAMOUNT"));
     }
     return SKGServices::stringToDouble(v);
 }
 
 SKGError SKGCategoryObject::getSubOperations(SKGListSKGObjectBase& oSubOperations) const
 {
-    SKGError err = getDocument()->getObjects(QStringLiteral("v_suboperation"),
+    SKGError err = getDocument()->getObjects(QLatin1String("v_suboperation"),
                    "r_category_id=" % SKGServices::intToString(getID()),
                    oSubOperations);
     return err;
@@ -258,22 +258,22 @@ SKGError SKGCategoryObject::getSubOperations(SKGListSKGObjectBase& oSubOperation
 
 SKGError SKGCategoryObject::bookmark(bool iBookmark)
 {
-    return setAttribute(QStringLiteral("t_bookmarked"), iBookmark ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_bookmarked"), iBookmark ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGCategoryObject::isBookmarked() const
 {
-    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_bookmarked")) == QLatin1String("Y"));
 }
 
 SKGError SKGCategoryObject::setClosed(bool iClosed)
 {
-    return setAttribute(QStringLiteral("t_close"), iClosed ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_close"), iClosed ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGCategoryObject::isClosed() const
 {
-    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_close")) == QLatin1String("Y"));
 }
 
 SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
