@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -11,13 +11,13 @@
 #include "skgimportexportmanager.h"
 
 #include <klocalizedstring.h>
-#include <kservicetypetrader.h>
+#include <kpluginfactory.h>
 
 #include <qcryptographichash.h>
 #include <qfileinfo.h>
 #include <qregularexpression.h>
 #include <qtemporaryfile.h>
-#include <qtextcodec.h>
+
 #include <qstandardpaths.h>
 
 #include <algorithm>
@@ -41,7 +41,7 @@ SKGImportExportManager::SKGImportExportManager(SKGDocumentBank* iDocument,
     setAutomaticValidation(true);
     setAutomaticApplyRules(false);
     m_since_last_import = true;
-    m_codec = QStringLiteral("UTF-8");
+    m_codec = QLatin1String("UTF-8");
 }
 
 SKGImportExportManager::~SKGImportExportManager()
@@ -113,7 +113,7 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         if (items.count() == 2) {
             bankname = items.at(1);
 
-            QStringList items2 = name.split('-');
+            QStringList items2 = name.split(QLatin1Char('-'));
             if (items2.count() == 2) {
                 name = items2.at(0);
                 number = items2.at(1);
@@ -130,7 +130,7 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
             name.replace('_', ' ');
             name.replace('-', ' ');
             nameComplete = name;
-            auto match = QRegularExpression(QStringLiteral("(\\d{6,})")).match(name);
+            auto match = QRegularExpression(QLatin1String("(\\d{6,})")).match(name);
             if (match.hasMatch()) {
                 number = match.captured(1);
                 if (name != number) {
@@ -140,7 +140,7 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         }
 
         // Searching if an account exist
-        QString whereClause = "t_name='" % SKGServices::stringToSqlString(name) % '\'';
+        QString whereClause = "t_name='" % SKGServices::stringToSqlString(name) % QLatin1Char('\'');
         whereClause += " OR t_number='" % SKGServices::stringToSqlString(name) % "'";
         whereClause += " OR t_agency_number||t_number='" % SKGServices::stringToSqlString(name) % "'";
         whereClause += " OR t_BANK_NUMBER||t_agency_number||t_number='" % SKGServices::stringToSqlString(name) % "'";
@@ -153,16 +153,16 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         }
         whereClause += " OR EXISTS(SELECT 1 FROM parameters WHERE t_uuid_parent=v_account.id||'-account' AND t_name='alias' AND t_value= '" % SKGServices::stringToSqlString(name) % "')";
 
-        const auto words = nameComplete.split(' ');
+        const auto words = nameComplete.split(QLatin1Char(' '));
         for (const auto& val : words) {
-            whereClause += " OR t_number='" % SKGServices::stringToSqlString(val) % '\'';
+            whereClause += " OR t_number='" % SKGServices::stringToSqlString(val) % QLatin1Char('\'');
         }
 
         // Avoid to take account with another import ongoing
-        whereClause = '(' % whereClause % ") AND NOT EXISTS(SELECT 1 FROM operation WHERE operation.rd_account_id=v_account.id AND operation.t_imported='T')";
+        whereClause = QLatin1Char('(') % whereClause % ") AND NOT EXISTS(SELECT 1 FROM operation WHERE operation.rd_account_id=v_account.id AND operation.t_imported='T')";
 
         SKGObjectBase::SKGListSKGObjectBase listAccount;
-        err = m_document->getObjects(QStringLiteral("v_account"), whereClause % " ORDER BY t_type ASC", listAccount);
+        err = m_document->getObjects(QLatin1String("v_account"), whereClause % " ORDER BY t_type ASC", listAccount);
         IFOK(err) {
             if (!listAccount.isEmpty()) {
                 // Yes ! Only one account found
@@ -231,7 +231,7 @@ SKGError SKGImportExportManager::getDefaultUnit(SKGUnitObject& oUnit, const QDat
         }
 
         // Do we have to found the best unit for a date ?
-        QString wc = QStringLiteral("t_type IN ('1', '2', 'C')");
+        QString wc = QLatin1String("t_type IN ('1', '2', 'C')");
         if (iDate != nullptr) {
             // Yes
             wc += " AND (d_MINDATE<'" % SKGServices::dateToSqlString(*iDate) % "' OR d_MINDATE IS NULL)";
@@ -239,7 +239,7 @@ SKGError SKGImportExportManager::getDefaultUnit(SKGUnitObject& oUnit, const QDat
 
         // Check if a unit exist
         SKGObjectBase::SKGListSKGObjectBase listUnits;
-        err = m_document->getObjects(QStringLiteral("v_unit"), wc % " ORDER BY ABS(f_CURRENTAMOUNT-1) ASC", listUnits);
+        err = m_document->getObjects(QLatin1String("v_unit"), wc % " ORDER BY ABS(f_CURRENTAMOUNT-1) ASC", listUnits);
         IFOK(err) {
             if (listUnits.isEmpty()) {
                 SKGUnitObject unit(m_document);
@@ -316,24 +316,24 @@ QList<QPair<SKGAccountObject, double> > SKGImportExportManager::getAccountsToChe
 SKGError SKGImportExportManager::finalizeImportation()
 {
     SKGError err;
-    if (!getImportParameters().contains(QStringLiteral("donotfinalize"))) {
+    if (!getImportParameters().contains(QLatin1String("donotfinalize"))) {
         SKGTRACEINFUNCRC(2, err)
         if (m_document != nullptr) {
             // Count the number of transactions imported but already existing
-            QString wc = "v_operation.t_imported='T' AND exists (SELECT 1 from v_operation op2 WHERE op2.t_imported!='T' AND op2.rd_account_id=v_operation.rd_account_id AND op2.t_import_id=v_operation.t_import_id AND ABS(op2.f_CURRENTAMOUNT-v_operation.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % ')';
+            QString wc = "v_operation.t_imported='T' AND exists (SELECT 1 from v_operation op2 WHERE op2.t_imported!='T' AND op2.rd_account_id=v_operation.rd_account_id AND op2.t_import_id=v_operation.t_import_id AND ABS(op2.f_CURRENTAMOUNT-v_operation.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % QLatin1Char(')');
             SKGObjectBase::SKGListSKGObjectBase objects;
-            err = m_document->getObjects(QStringLiteral("v_operation"), wc, objects);
+            err = m_document->getObjects(QLatin1String("v_operation"), wc, objects);
             int nbOperations = objects.count();
             if (!err && (nbOperations != 0)) {
                 err = m_document->sendMessage(i18np("One transaction not imported because it already exists", "%1 transactions not imported because they already exist", nbOperations), SKGDocument::Warning);
 
-                SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BY IMPORT_ID ###" << SKGENDL;
+                SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BY IMPORT_ID ###" << Qt::endl;
                 for (int i = 0; i < nbOperations; ++i) {
-                    SKGTRACEL(1) << objects.at(i).getDisplayName() << " " << objects.at(i).getAttribute(QStringLiteral("t_import_id")) << SKGENDL;
+                    SKGTRACEL(1) << objects.at(i).getDisplayName() << " " << objects.at(i).getAttribute(QLatin1String("t_import_id")) << Qt::endl;
                 }
 
                 // Remove transactions imported for nothing
-                IFOKDO(err, m_document->executeSqliteOrder("DELETE from operation WHERE id IN (SELECT id from v_operation WHERE " % wc % ')'))
+                IFOKDO(err, m_document->executeSqliteOrder("DELETE from operation WHERE id IN (SELECT id from v_operation WHERE " % wc % QLatin1Char(')')))
             }
 
             // Delete transactions before the last import
@@ -341,16 +341,16 @@ SKGError SKGImportExportManager::finalizeImportation()
                 SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-since last date", err)
 
                 // Count the number of transactions before the last import
-                QString wc2 = QStringLiteral("operation.t_imported='T' AND "
-                                             "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND date(o.d_date,'-4 day')>operation.d_date)");
-                err = m_document->getObjects(QStringLiteral("operation"), wc2, objects);
+                QString wc2 = QLatin1String("operation.t_imported='T' AND "
+                                            "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND date(o.d_date,'-4 day')>operation.d_date)");
+                err = m_document->getObjects(QLatin1String("operation"), wc2, objects);
                 int nbOperations2 = objects.count();
                 if (!err && (nbOperations2 != 0)) {
                     err = m_document->sendMessage(i18np("One transaction was not imported because it was dated before the last imported one, you can uncheck the option to avoid this.", "%1 transactions were not imported because they were dated before the last imported one, you can uncheck the option to avoid this.", nbOperations2), SKGDocument::Warning);
 
-                    SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BECAUSE AFTER THE LAST ONE ###" << SKGENDL;
+                    SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BECAUSE AFTER THE LAST ONE ###" << Qt::endl;
                     for (int i = 0; i < nbOperations2; ++i) {
-                        SKGTRACEL(1) << objects.at(i).getDisplayName() << SKGENDL;
+                        SKGTRACEL(1) << objects.at(i).getDisplayName() << Qt::endl;
                     }
 
                     // Remove transactions imported for nothing
@@ -359,14 +359,14 @@ SKGError SKGImportExportManager::finalizeImportation()
             }
 
             // For performances
-            IFOKDO(err, m_document->executeSqliteOrder(QStringLiteral("ANALYZE")))
+            IFOKDO(err, m_document->executeSqliteOrder(QLatin1String("ANALYZE")))
 
             // Apply rules
             if (!err && m_automaticApplyRulesOfImportedOperation) {
                 SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-apply rules", err)
                 // Get rules
                 SKGObjectBase::SKGListSKGObjectBase rules;
-                IFOKDO(err, m_document->getObjects(QStringLiteral("v_rule"), QStringLiteral("1=1 ORDER BY f_sortorder"), rules))
+                IFOKDO(err, m_document->getObjects(QLatin1String("v_rule"), QLatin1String("1=1 ORDER BY f_sortorder"), rules))
 
                 int nbRules = rules.count();
                 IFOKDO(err, m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Finalize import"), nbRules))
@@ -386,10 +386,10 @@ SKGError SKGImportExportManager::finalizeImportation()
             IFOK(err) {
                 SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-change imported status", err)
                 int nbopimported = 0;
-                err = m_document->getNbObjects(QStringLiteral("operation"), QStringLiteral("t_imported='T'"), nbopimported);
+                err = m_document->getNbObjects(QLatin1String("operation"), QLatin1String("t_imported='T'"), nbopimported);
                 IFOKDO(err, m_document->sendMessage(i18np("%1 transaction imported", "%1 transactions imported", nbopimported), SKGDocument::Positive))
-                IFOKDO(err, m_document->executeSqliteOrder(QStringLiteral("UPDATE operation SET t_imported='") %
-                        (m_automaticValidationOfImportedOperation ? QStringLiteral("Y") : QStringLiteral("P")) %
+                IFOKDO(err, m_document->executeSqliteOrder(QLatin1String("UPDATE operation SET t_imported='") %
+                        (m_automaticValidationOfImportedOperation ? QLatin1String("Y") : QLatin1String("P")) %
                         "' WHERE t_imported='T'"));
             }
 
@@ -399,8 +399,8 @@ SKGError SKGImportExportManager::finalizeImportation()
                 // Get the account to check
                 auto act = m_AccountToCheck.at(i).first;
                 auto targetBalance = m_AccountToCheck.at(i).second;
-                err = act.setAttribute(QStringLiteral("f_importbalance"), SKGServices::doubleToString(targetBalance));
-                IFOKDO(err, act.setAttribute(QStringLiteral("d_importdate"), SKGServices::dateToSqlString(QDate::currentDate())))
+                err = act.setAttribute(QLatin1String("f_importbalance"), SKGServices::doubleToString(targetBalance));
+                IFOKDO(err, act.setAttribute(QLatin1String("d_importdate"), SKGServices::dateToSqlString(QDate::currentDate())))
                 IFOKDO(err, act.save())
 
                 auto soluces = act.getPossibleReconciliations(targetBalance, false);
@@ -447,7 +447,7 @@ void SKGImportExportManager::setImportParameters(const QMap< QString, QString >&
 void SKGImportExportManager::loadPlugins()
 {
     if (m_plugins.isEmpty()) {
-        const auto plugins = KPluginMetaData::findPlugins(QStringLiteral("skrooge/import"));
+        const auto plugins = KPluginMetaData::findPlugins(QLatin1String("skrooge_import"));
         int nb = plugins.count();
         for (int i = 0; i < nb; ++i) {
             const auto factory = KPluginFactory::loadFactory(plugins.at(i));
@@ -515,14 +515,14 @@ QString SKGImportExportManager::getImportMimeTypeFilter(bool iIncludingAll)
 
     QString output;
     if (iIncludingAll) {
-        output = regexps.join(QStringLiteral(" ")) % '|' % i18nc("A file format", "All supported formats");
+        output = regexps.join(QLatin1String(" ")) % QLatin1Char('|') % i18nc("A file format", "All supported formats");
     }
     nb = descriptions.count();
     for (int i = 0; i < nb; ++i) {
         if (!output.isEmpty()) {
             output += '\n';
         }
-        output += tmp[descriptions.at(i)] % '|' % descriptions.at(i);
+        output += tmp[descriptions.at(i)] % QLatin1Char('|') % descriptions.at(i);
     }
 
     return output;
@@ -555,14 +555,14 @@ QString SKGImportExportManager::getExportMimeTypeFilter(bool iIncludingAll)
 
     QString output;
     if (iIncludingAll) {
-        output = regexps.join(QStringLiteral(" ")) % '|' % i18nc("A file format", "All supported formats");
+        output = regexps.join(QLatin1String(" ")) % QLatin1Char('|') % i18nc("A file format", "All supported formats");
     }
     nb = descriptions.count();
     for (int i = 0; i < nb; ++i) {
         if (!output.isEmpty()) {
             output += '\n';
         }
-        output += tmp[descriptions.at(i)] % '|' % descriptions.at(i);
+        output += tmp[descriptions.at(i)] % QLatin1Char('|') % descriptions.at(i);
     }
 
     return output;
@@ -610,7 +610,7 @@ SKGError SKGImportExportManager::importFile()
     if (m_document != nullptr) {
         SKGBEGINPROGRESSTRANSACTION(*m_document, i18nc("Noun, name of the user action", "Import with codec %1", m_codec), err, 3)
 
-        err = m_document->executeSqliteOrder(QStringLiteral("ANALYZE"));
+        err = m_document->executeSqliteOrder(QLatin1String("ANALYZE"));
 
         IFOKDO(err, m_document->stepForward(1))
 
@@ -622,7 +622,7 @@ SKGError SKGImportExportManager::importFile()
                 // Import
                 fileTreated = true;
                 m_AccountToCheck.clear();
-                SKGTRACEL(2) << "Input filename=" << m_fileName.toDisplayString() << SKGENDL;
+                SKGTRACEL(2) << "Input filename=" << m_fileName.toDisplayString() << Qt::endl;
                 err = pluginInterface->importFile();
             }
 
@@ -644,7 +644,7 @@ SKGError SKGImportExportManager::exportFile()
     SKGError err;
     SKGTRACEINFUNCRC(2, err)
     if (m_document != nullptr) {
-        err = m_document->executeSqliteOrder(QStringLiteral("ANALYZE"));
+        err = m_document->executeSqliteOrder(QLatin1String("ANALYZE"));
         IFOK(err) {
             // Search plugins
             bool fileTreated = false;
@@ -652,7 +652,7 @@ SKGError SKGImportExportManager::exportFile()
             if (pluginInterface != nullptr) {
                 // Import
                 fileTreated = true;
-                SKGTRACEL(2) << "Input filename=" << m_fileName.toDisplayString() << SKGENDL;
+                SKGTRACEL(2) << "Input filename=" << m_fileName.toDisplayString() << Qt::endl;
                 err = pluginInterface->exportFile();
                 IFOKDO(err, SKGServices::upload(QUrl::fromLocalFile(getLocalFileName(false)), m_fileName))
             }
@@ -677,7 +677,7 @@ SKGError SKGImportExportManager::cleanBankImport()
         IFOK(err) {
             // Step 1 Clean transactions without mode and with comment with double space
             SKGObjectBase::SKGListSKGObjectBase transactions;
-            IFOKDO(err, m_document->getObjects(QStringLiteral("operation"), QStringLiteral("t_imported!='N' and t_mode='' and t_comment like '%  %'"), transactions))
+            IFOKDO(err, m_document->getObjects(QLatin1String("operation"), QLatin1String("t_imported!='N' and t_mode='' and t_comment like '%  %'"), transactions))
 
             int nb = transactions.count();
             for (int i = 0; !err && i < nb ; ++i) {
@@ -686,7 +686,7 @@ SKGError SKGImportExportManager::cleanBankImport()
                 // Comment is like this: <TYPE>  <INFO>
                 // Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
                 QString comment = op.getComment();
-                auto match = QRegularExpression(QStringLiteral("(.+) {2,}(.+)")).match(comment);
+                auto match = QRegularExpression(QLatin1String("(.+) {2,}(.+)")).match(comment);
                 if (match.hasMatch()) {
                     // Get parameters
                     QString mode = match.captured(1);
@@ -703,7 +703,7 @@ SKGError SKGImportExportManager::cleanBankImport()
             IFOKDO(err, m_document->stepForward(1))
 
             // Step 2 Clean transactions without mode and with comment
-            IFOKDO(err, m_document->getObjects(QStringLiteral("operation"), QStringLiteral("t_imported!='N' and t_mode='' and t_comment!=''"), transactions))
+            IFOKDO(err, m_document->getObjects(QLatin1String("operation"), QLatin1String("t_imported!='N' and t_mode='' and t_comment!=''"), transactions))
 
             nb = transactions.count();
             for (int i = 0; !err && i < nb ; ++i) {
@@ -712,7 +712,7 @@ SKGError SKGImportExportManager::cleanBankImport()
                 // Comment is like this: <TYPE> <INFO>
                 // Example: RETRAIT DAB 14-05-16607-482390
                 QString comment = op.getComment();
-                auto match = QRegularExpression(QStringLiteral("(\\S+) +(.+)")).match(comment);
+                auto match = QRegularExpression(QLatin1String("(\\S+) +(.+)")).match(comment);
                 if (match.hasMatch()) {
                     // Get parameters
                     QString mode = match.captured(1);
@@ -729,7 +729,7 @@ SKGError SKGImportExportManager::cleanBankImport()
             IFOKDO(err, m_document->stepForward(2))
 
             // Step 3 Clean cheque without number
-            IFOKDO(err, m_document->getObjects(QStringLiteral("operation"), QStringLiteral("t_imported!='N' and t_number='' and lower(t_mode)='cheque'"), transactions))
+            IFOKDO(err, m_document->getObjects(QLatin1String("operation"), QLatin1String("t_imported!='N' and t_number='' and lower(t_mode)='cheque'"), transactions))
 
             nb = transactions.count();
             for (int i = 0; !err && i < nb ; ++i) {
@@ -738,7 +738,7 @@ SKGError SKGImportExportManager::cleanBankImport()
                 // Comment is like this: <TYPE>  <INFO>
                 // Example: RETRAIT DAB             20/01/08 11H44 013330 LCL GAILLAC 000497
                 QString comment = op.getComment();
-                auto match = QRegularExpression(QStringLiteral("(\\d+)")).match(comment);
+                auto match = QRegularExpression(QLatin1String("(\\d+)")).match(comment);
                 if (match.hasMatch()) {
                     // Get parameters
                     auto number = match.captured(1);
@@ -765,7 +765,7 @@ SKGError SKGImportExportManager::anonymize(const QString& iKey)
     SKGTRACEINFUNCRC(2, err)
     if (m_document != nullptr) {
         if (m_document->isFileModified()) {
-            err = SKGError(ERR_ABORT, i18nc("An information message",  "The document must be saved to be anonymized."), QStringLiteral("skg://file_save"));
+            err = SKGError(ERR_ABORT, i18nc("An information message",  "The document must be saved to be anonymized."), QLatin1String("skg://file_save"));
         } else {
             {
                 // Remove password
@@ -775,25 +775,25 @@ SKGError SKGImportExportManager::anonymize(const QString& iKey)
                 QStringList sqlOrders;
                 if (iKey.isEmpty()) {
                     // Not reversible
-                    sqlOrders << QStringLiteral("UPDATE bank SET t_bank_number='', t_name='bank_'||id")
-                              << QStringLiteral("UPDATE account SET t_number='', t_agency_number='', t_agency_address='', t_comment='', t_name='account_'||id")
-                              << QStringLiteral("UPDATE category SET t_name='category_'||id")
-                              << QStringLiteral("UPDATE payee SET t_address='', t_name='payee_'||id")
-                              << QStringLiteral("UPDATE refund SET t_comment='', t_name='tracker_'||id")
-                              << QStringLiteral("UPDATE operation SET t_comment=''")
-                              << QStringLiteral("UPDATE suboperation SET t_comment='', f_value=f_value%1234.56")
-                              << QStringLiteral("DELETE FROM parameters WHERE t_name NOT LIKE 'SKG_%' OR t_name='SKG_PASSWORD'");
+                    sqlOrders << QLatin1String("UPDATE bank SET t_bank_number='', t_name='bank_'||id")
+                              << QLatin1String("UPDATE account SET t_number='', t_agency_number='', t_agency_address='', t_comment='', t_name='account_'||id")
+                              << QLatin1String("UPDATE category SET t_name='category_'||id")
+                              << QLatin1String("UPDATE payee SET t_address='', t_name='payee_'||id")
+                              << QLatin1String("UPDATE refund SET t_comment='', t_name='tracker_'||id")
+                              << QLatin1String("UPDATE operation SET t_comment=''")
+                              << QLatin1String("UPDATE suboperation SET t_comment='', f_value=f_value%1234.56")
+                              << QLatin1String("DELETE FROM parameters WHERE t_name NOT LIKE 'SKG_%' OR t_name='SKG_PASSWORD'");
                 } else {
                     // Reversible
-                    sqlOrders << QStringLiteral("UPDATE bank SET t_bank_number=XOR(t_bank_number,'") + SKGServices::stringToSqlString(iKey) + "'), t_name=XOR(t_name,'" + SKGServices::stringToSqlString(iKey) + "')"
-                              << QStringLiteral("UPDATE account SET t_number=XOR(t_number,'") + SKGServices::stringToSqlString(iKey) + "'), t_agency_number=XOR(t_agency_number,'" + SKGServices::stringToSqlString(iKey) + "'), t_agency_address=XOR(t_agency_address,'" + SKGServices::stringToSqlString(iKey) + "'), t_comment=XOR(t_comment,'" + SKGServices::stringToSqlString(iKey) + "'), t_name=XOR(t_name,'" + SKGServices::stringToSqlString(iKey) + "')"
-                              << QStringLiteral("UPDATE category SET t_name=XOR(t_name,'") + SKGServices::stringToSqlString(iKey) + "')"
-                              << QStringLiteral("UPDATE payee SET t_address=XOR(t_address,'") + SKGServices::stringToSqlString(iKey) + "'), t_name=XOR(t_name,'" + SKGServices::stringToSqlString(iKey) + "')"
-                              << QStringLiteral("UPDATE refund SET t_comment=XOR(t_comment,'") + SKGServices::stringToSqlString(iKey) + "'), t_name=XOR(t_name,'" + SKGServices::stringToSqlString(iKey) + "')"
-                              << QStringLiteral("UPDATE operation SET t_comment=XOR(t_comment,'") + SKGServices::stringToSqlString(iKey) + "')"
-                              << QStringLiteral("UPDATE suboperation SET t_comment=XOR(t_comment,'") + SKGServices::stringToSqlString(iKey) + "'), f_value=XORD(f_value,'" + SKGServices::stringToSqlString(iKey) + "')"
-                              << QStringLiteral("UPDATE parameters SET t_name=XOR(t_name,'") + SKGServices::stringToSqlString(iKey) + "'), t_value=XOR(t_value,'" + SKGServices::stringToSqlString(iKey) + "'), b_blob=XOR(b_blob,'" + SKGServices::stringToSqlString(iKey) + "') WHERE t_name NOT LIKE 'SKG_%'"
-                              << QStringLiteral("DELETE FROM parameters WHERE t_name='SKG_PASSWORD'");
+                    sqlOrders << QLatin1String("UPDATE bank SET t_bank_number=XOR(t_bank_number,'") + SKGServices::stringToSqlString(iKey) + "'), t_name=XOR(t_name,'" + SKGServices::stringToSqlString(iKey) + "')"
+                              << QLatin1String("UPDATE account SET t_number=XOR(t_number,'") + SKGServices::stringToSqlString(iKey) + "'), t_agency_number=XOR(t_agency_number,'" + SKGServices::stringToSqlString(iKey) + "'), t_agency_address=XOR(t_agency_address,'" + SKGServices::stringToSqlString(iKey) + "'), t_comment=XOR(t_comment,'" + SKGServices::stringToSqlString(iKey) + "'), t_name=XOR(t_name,'" + SKGServices::stringToSqlString(iKey) + "')"
+                              << QLatin1String("UPDATE category SET t_name=XOR(t_name,'") + SKGServices::stringToSqlString(iKey) + "')"
+                              << QLatin1String("UPDATE payee SET t_address=XOR(t_address,'") + SKGServices::stringToSqlString(iKey) + "'), t_name=XOR(t_name,'" + SKGServices::stringToSqlString(iKey) + "')"
+                              << QLatin1String("UPDATE refund SET t_comment=XOR(t_comment,'") + SKGServices::stringToSqlString(iKey) + "'), t_name=XOR(t_name,'" + SKGServices::stringToSqlString(iKey) + "')"
+                              << QLatin1String("UPDATE operation SET t_comment=XOR(t_comment,'") + SKGServices::stringToSqlString(iKey) + "')"
+                              << QLatin1String("UPDATE suboperation SET t_comment=XOR(t_comment,'") + SKGServices::stringToSqlString(iKey) + "'), f_value=XORD(f_value,'" + SKGServices::stringToSqlString(iKey) + "')"
+                              << QLatin1String("UPDATE parameters SET t_name=XOR(t_name,'") + SKGServices::stringToSqlString(iKey) + "'), t_value=XOR(t_value,'" + SKGServices::stringToSqlString(iKey) + "'), b_blob=XOR(b_blob,'" + SKGServices::stringToSqlString(iKey) + "') WHERE t_name NOT LIKE 'SKG_%'"
+                              << QLatin1String("DELETE FROM parameters WHERE t_name='SKG_PASSWORD'");
                 }
 
                 int nb = sqlOrders.count();
@@ -814,7 +814,7 @@ SKGError SKGImportExportManager::anonymize(const QString& iKey)
             IFOKDO(err, m_document->removeAllTransactions())
 
             // Save new file
-            QString newName = m_document->getCurrentFileName().replace(QStringLiteral(".skg"), QStringLiteral("-anonymized.skg"));
+            QString newName = m_document->getCurrentFileName().replace(QLatin1String(".skg"), QLatin1String("-anonymized.skg"));
             if (newName == m_document->getCurrentFileName()) {
                 newName = m_document->getCurrentFileName() % "-anonymized.skg";
             }
@@ -835,7 +835,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
     if (m_document != nullptr) {
         err = m_document->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Find and group transfers"), 3);
         IFOK(err) {
-            IFOKDO(err, m_document->executeSqliteOrder(QStringLiteral("ANALYZE")))
+            IFOKDO(err, m_document->executeSqliteOrder(QLatin1String("ANALYZE")))
             // Look for transactions with
             //  Same units
             //  Same dates
@@ -850,7 +850,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
                            "WHERE s.rd_operation_id=A.ID) AS quantity1, (SELECT TOTAL(s.f_value) FROM suboperation s "
                            "WHERE s.rd_operation_id=B.ID) AS quantity2 FROM operation  A, operation B "
                            "WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND A.i_group_id=0 AND B.i_group_id=0" %
-                           (iAdditionnalCondition.isEmpty() ? QString() : QStringLiteral(" AND ") % iAdditionnalCondition) % ") "
+                           (iAdditionnalCondition.isEmpty() ? QString() : QLatin1String(" AND ") % iAdditionnalCondition) % ") "
                            "WHERE ABS(quantity1+quantity2)<1e-5 AND quantity1!=0",
                            listTmp));
                 // Step 1 done
@@ -864,7 +864,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
                 IFOKDO(err, m_document->executeSelectSqliteOrder(
                            "SELECT A.id, B.id FROM v_operation A, operation B, parameters P "
                            "WHERE +P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_CURRENTAMOUNT+CAST(P.t_value AS REAL))<" % SKGServices::doubleToString(EPSILON) % " AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0" %
-                           (iAdditionnalCondition.isEmpty() ? QString() : QStringLiteral(" AND ") % iAdditionnalCondition),
+                           (iAdditionnalCondition.isEmpty() ? QString() : QLatin1String(" AND ") % iAdditionnalCondition),
                            listTmp2));
 
                 // Step 2 done
@@ -903,37 +903,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
 
 SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged, bool iOnCurrentlyImport)
 {
-    return findAndGroupTransfers(oNbOperationsMerged, iOnCurrentlyImport ? QStringLiteral("A.t_imported='T' AND B.t_imported='T'") : QLatin1String(""));
-}
-
-SKGError SKGImportExportManager::getXMLDocument(QDomElement& oDocument)
-{
-    SKGError err;
-    SKGTRACEINFUNCRC(2, err)
-
-    // Open file
-    QFile file(getLocalFileName());
-    if (!file.open(QIODevice::ReadOnly)) {
-        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", getFileName().toDisplayString()));
-    } else {
-        QDomDocument doc;
-
-        // Set the file without uncompression
-        QString errorMsg;
-        int errorLine = 0;
-        int errorCol = 0;
-        bool contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
-        file.close();
-
-        if (!contentOK) {
-            err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg)).addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", getFileName().toDisplayString()));
-        } else {
-            // Get root
-            oDocument = doc.documentElement();
-        }
-    }
-
-    return err;
+    return findAndGroupTransfers(oNbOperationsMerged, iOnCurrentlyImport ? QLatin1String("A.t_imported='T' AND B.t_imported='T'") : QLatin1String(""));
 }
 
 SKGError SKGImportExportManager::importItems(QDomElement& docElem)
@@ -942,7 +912,7 @@ SKGError SKGImportExportManager::importItems(QDomElement& docElem)
     if (docElem.isNull()) {
         return err;
     }
-    auto type = docElem.tagName().remove(QStringLiteral("list_"));
+    auto type = docElem.tagName().remove(QLatin1String("list_"));
     QDomNodeList items = docElem.elementsByTagName(type);
     int nb = items.count();
     if (nb > 0) {
@@ -994,7 +964,7 @@ SKGError SKGImportExportManager::importItems(QDomElement& docElem)
                 auto name = att.nodeName();
                 if (name != "id" && name != "r_recurrentoperation_id") {
                     auto val = att.nodeValue();
-                    if (name.startsWith(QStringLiteral("rd_")) || name.startsWith(QStringLiteral("rc_")) || name.startsWith(QStringLiteral("r_"))) {
+                    if (name.startsWith(QLatin1String("rd_")) || name.startsWith(QLatin1String("rc_")) || name.startsWith(QLatin1String("r_"))) {
                         auto tmp = name.split("_");
                         if (m_mapIdObject.contains(tmp[1] + "-" + val)) {
                             val = SKGServices::intToString(m_mapIdObject[tmp[1] + "-" + val].getID());
@@ -1017,7 +987,7 @@ SKGError SKGImportExportManager::importItems(QDomElement& docElem)
             } else {
                 IFOKDO(err, obj->save(true, true))
             }
-            m_mapIdObject[type + "-" + item.attribute(QStringLiteral("id"))] = *obj;
+            m_mapIdObject[type + "-" + item.attribute(QLatin1String("id"))] = *obj;
 
             delete obj;
 
