@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGIMPORTEXPORTMANAGER_H
@@ -276,14 +276,6 @@ public:
      */
     QList<QPair<SKGAccountObject, double>> getAccountsToCheck();
 
-    /**
-     * Get the document as an XML object
-     * @param oDocument The output XML document.
-     * @return an object managing the error.
-     *   @see SKGError
-     */
-    SKGError getXMLDocument(QDomElement& oDocument);
-
     /**
      * Import a XML document
      * @param docElem The document to import.
