@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -11,6 +11,7 @@
 #include "skgoperationobject.h"
 
 #include <klocalizedstring.h>
+#include <utility>
 
 #include "skgaccountobject.h"
 #include "skgdocument.h"
@@ -24,7 +25,7 @@
 SKGOperationObject::SKGOperationObject() : SKGOperationObject(nullptr)
 {}
 
-SKGOperationObject::SKGOperationObject(SKGDocument* iDocument, int iID) : SKGObjectBase(iDocument, QStringLiteral("v_operation"), iID)
+SKGOperationObject::SKGOperationObject(SKGDocument* iDocument, int iID) : SKGObjectBase(iDocument, QLatin1String("v_operation"), iID)
 {}
 
 SKGOperationObject::~SKGOperationObject()
@@ -35,10 +36,10 @@ SKGOperationObject::SKGOperationObject(const SKGOperationObject& iObject)
 
 SKGOperationObject::SKGOperationObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable() == QStringLiteral("operation")) {
+    if (iObject.getRealTable() == QLatin1String("operation")) {
         copyFrom(iObject);
     } else {
-        *this = SKGObjectBase(iObject.getDocument(), QStringLiteral("v_operation"), iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), QLatin1String("v_operation"), iObject.getID());
     }
 }
 
@@ -72,7 +73,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, QDate iDa
     IFOKDO(err, oOperation.bookmark(false))
     IFOKDO(err, oOperation.setNumber(QLatin1String("")))
     IFOKDO(err, oOperation.setGroupOperation(oOperation))
-    IFOKDO(err, oOperation.setAttribute(QStringLiteral("d_createdate"), SKGServices::dateToSqlString(QDateTime::currentDateTime())))
+    IFOKDO(err, oOperation.setAttribute(QLatin1String("d_createdate"), SKGServices::dateToSqlString(QDateTime::currentDateTime())))
     IFOKDO(err, oOperation.save(false, false))
 
     // Duplicate subop
@@ -136,7 +137,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, QDate iDa
 SKGError SKGOperationObject::getParentAccount(SKGAccountObject& oAccount) const
 {
     SKGObjectBase objTmp;
-    SKGError err = getDocument()->getObject(QStringLiteral("v_account"), "id=" % getAttribute(QStringLiteral("rd_account_id")), objTmp);
+    SKGError err = getDocument()->getObject(QLatin1String("v_account"), "id=" % getAttribute(QLatin1String("rd_account_id")), objTmp);
     oAccount = objTmp;
     return err;
 }
@@ -144,16 +145,16 @@ SKGError SKGOperationObject::getParentAccount(SKGAccountObject& oAccount) const
 SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount, bool iForce)
 {
     SKGError err;
-    QString currentAccount = getAttribute(QStringLiteral("rd_account_id"));
+    QString currentAccount = getAttribute(QLatin1String("rd_account_id"));
     QString newAccount = SKGServices::intToString(iAccount.getID());
-    if (newAccount == QStringLiteral("0")) {
-        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGOperationObject::setParentAccount")));
+    if (newAccount == QLatin1String("0")) {
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGOperationObject::setParentAccount")));
     } else {
         if (newAccount != currentAccount) {
             if (iAccount.isClosed() && !iForce) {
                 err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add a transaction in a closed account"));
             } else {
-                err = setAttribute(QStringLiteral("rd_account_id"), newAccount);
+                err = setAttribute(QLatin1String("rd_account_id"), newAccount);
             }
         }
     }
@@ -162,52 +163,52 @@ SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount,
 
 SKGError SKGOperationObject::setMode(const QString& iMode)
 {
-    return setAttribute(QStringLiteral("t_mode"), iMode);
+    return setAttribute(QLatin1String("t_mode"), iMode);
 }
 
 QString SKGOperationObject::getMode() const
 {
-    return getAttribute(QStringLiteral("t_mode"));
+    return getAttribute(QLatin1String("t_mode"));
 }
 
 SKGError SKGOperationObject::setPayee(const SKGPayeeObject& iPayee)
 {
-    return setAttribute(QStringLiteral("r_payee_id"), SKGServices::intToString(iPayee.getID()));
+    return setAttribute(QLatin1String("r_payee_id"), SKGServices::intToString(iPayee.getID()));
 }
 
 SKGError SKGOperationObject::getPayee(SKGPayeeObject& oPayee) const
 {
-    SKGError err = getDocument()->getObject(QStringLiteral("v_payee"), "id=" % SKGServices::intToString(SKGServices::stringToInt(getAttribute(QStringLiteral("r_payee_id")))), oPayee);
+    SKGError err = getDocument()->getObject(QLatin1String("v_payee"), "id=" % SKGServices::intToString(SKGServices::stringToInt(getAttribute(QLatin1String("r_payee_id")))), oPayee);
     return err;
 }
 
 SKGError SKGOperationObject::setComment(const QString& iComment)
 {
-    return setAttribute(QStringLiteral("t_comment"), iComment);
+    return setAttribute(QLatin1String("t_comment"), iComment);
 }
 
 QString SKGOperationObject::getComment() const
 {
-    return getAttribute(QStringLiteral("t_comment"));
+    return getAttribute(QLatin1String("t_comment"));
 }
 
 SKGError SKGOperationObject::setNumber(const QString& iNumber)
 {
-    return setAttribute(QStringLiteral("t_number"), iNumber);
+    return setAttribute(QLatin1String("t_number"), iNumber);
 }
 
 QString SKGOperationObject::getNumber() const
 {
-    return getAttribute(QStringLiteral("t_number"));
+    return getAttribute(QLatin1String("t_number"));
 }
 
 SKGOperationObject::OperationStatus SKGOperationObject::getStatus() const
 {
-    QString t_status = getAttribute(QStringLiteral("t_status"));
-    if (t_status == QStringLiteral("Y")) {
+    QString t_status = getAttribute(QLatin1String("t_status"));
+    if (t_status == QLatin1String("Y")) {
         return SKGOperationObject::CHECKED;
     }
-    if (t_status == QStringLiteral("P")) {
+    if (t_status == QLatin1String("P")) {
         return SKGOperationObject::MARKED;
     }
     return SKGOperationObject::NONE;
@@ -215,7 +216,7 @@ SKGOperationObject::OperationStatus SKGOperationObject::getStatus() const
 
 SKGError SKGOperationObject::setStatus(SKGOperationObject::OperationStatus iStatus)
 {
-    return setAttribute(QStringLiteral("t_status"), (iStatus == SKGOperationObject::CHECKED ? QStringLiteral("Y") : (iStatus == SKGOperationObject::MARKED ? QStringLiteral("P") : QStringLiteral("N"))));
+    return setAttribute(QLatin1String("t_status"), (iStatus == SKGOperationObject::CHECKED ? QLatin1String("Y") : (iStatus == SKGOperationObject::MARKED ? QLatin1String("P") : QLatin1String("N"))));
 }
 
 SKGError SKGOperationObject::setDate(QDate iDate, bool iRefreshSubOperations)
@@ -243,30 +244,30 @@ SKGError SKGOperationObject::setDate(QDate iDate, bool iRefreshSubOperations)
             }
         }
     }
-    IFOKDO(err, setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(iDate)))
+    IFOKDO(err, setAttribute(QLatin1String("d_date"), SKGServices::dateToSqlString(iDate)))
     return err;
 }
 
 QDate SKGOperationObject::getDate() const
 {
-    return SKGServices::stringToTime(getAttribute(QStringLiteral("d_date"))).date();
+    return SKGServices::stringToDate(getAttribute(QLatin1String("d_date")));
 }
 
 SKGError SKGOperationObject::getUnit(SKGUnitObject& oUnit) const
 {
-    SKGError err = (getDocument() == nullptr ? SKGError(ERR_POINTER, i18nc("Error message", "Transaction impossible because the document is missing")) : getDocument()->getObject(QStringLiteral("v_unit"), "id=" % getAttribute(QStringLiteral("rc_unit_id")), oUnit));
-    // SKGError err = getDocument()->getObject(QStringLiteral("v_unit"), "id=" % getAttribute(QStringLiteral("rc_unit_id")), oUnit);
+    SKGError err = (getDocument() == nullptr ? SKGError(ERR_POINTER, i18nc("Error message", "Transaction impossible because the document is missing")) : getDocument()->getObject(QLatin1String("v_unit"), "id=" % getAttribute(QLatin1String("rc_unit_id")), oUnit));
+    // SKGError err = getDocument()->getObject(QLatin1String("v_unit"), "id=" % getAttribute(QLatin1String("rc_unit_id")), oUnit);
     return err;
 }
 
 SKGError SKGOperationObject::setUnit(const SKGUnitObject& iUnit)
 {
-    return setAttribute(QStringLiteral("rc_unit_id"), SKGServices::intToString(iUnit.getID()));
+    return setAttribute(QLatin1String("rc_unit_id"), SKGServices::intToString(iUnit.getID()));
 }
 
 bool SKGOperationObject::isInGroup() const
 {
-    return (getAttribute(QStringLiteral("i_group_id")) != QStringLiteral("0"));
+    return (getAttribute(QLatin1String("i_group_id")) != QLatin1String("0"));
 }
 
 bool SKGOperationObject::isTransfer(SKGOperationObject& oOperation) const
@@ -277,24 +278,24 @@ bool SKGOperationObject::isTransfer(SKGOperationObject& oOperation) const
     if (ops.count() == 2) {
         oOperation = (*this == SKGOperationObject(ops.at(0)) ? ops.at(1) : ops.at(0));
     }
-    return (getAttribute(QStringLiteral("t_TRANSFER")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_TRANSFER")) == QLatin1String("Y"));
 }
 
 SKGError SKGOperationObject::getGroupedOperations(SKGListSKGObjectBase& oGroupedOperations) const
 {
     SKGError err;
-    QString gpId1 = getAttribute(QStringLiteral("i_group_id"));
-    if (gpId1 == QStringLiteral("0") || gpId1.isEmpty()) {
+    QString gpId1 = getAttribute(QLatin1String("i_group_id"));
+    if (gpId1 == QLatin1String("0") || gpId1.isEmpty()) {
         oGroupedOperations.clear();
     } else {
-        err = getDocument()->getObjects(QStringLiteral("v_operation"), "i_group_id=" % gpId1, oGroupedOperations);
+        err = getDocument()->getObjects(QLatin1String("v_operation"), "i_group_id=" % gpId1, oGroupedOperations);
     }
     return err;
 }
 
 SKGError SKGOperationObject::getGroupOperation(SKGOperationObject& oOperation) const
 {
-    SKGError err = getDocument()->getObject(QStringLiteral("v_operation"), "id=" % getAttribute(QStringLiteral("i_group_id")), oOperation);
+    SKGError err = getDocument()->getObject(QLatin1String("v_operation"), "id=" % getAttribute(QLatin1String("i_group_id")), oOperation);
     return err;
 }
 
@@ -306,15 +307,15 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
     // Is it a remove group ?
     if (iOperation == *this) {
         // Yes
-        err = setAttribute(QStringLiteral("i_group_id"), QStringLiteral("0"));
+        err = setAttribute(QLatin1String("i_group_id"), QLatin1String("0"));
     } else {
         // Get previous groups
-        QString group1 = getAttribute(QStringLiteral("i_group_id"));
-        QString group2 = iOperation.getAttribute(QStringLiteral("i_group_id"));
+        QString group1 = getAttribute(QLatin1String("i_group_id"));
+        QString group2 = iOperation.getAttribute(QLatin1String("i_group_id"));
 
         // Create a new group
         SKGStringListList result;
-        err = getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT max(i_group_id) from operation"), result);
+        err = getDocument()->executeSelectSqliteOrder(QLatin1String("SELECT max(i_group_id) from operation"), result);
         IFOK(err) {
             // Compute new group id
             QString newIdGroup('1');
@@ -324,18 +325,18 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
 
             // Set group id
             SKGOperationObject op1 = SKGOperationObject(iOperation.getDocument(), iOperation.getID());
-            err = op1.setAttribute(QStringLiteral("i_group_id"), newIdGroup);
+            err = op1.setAttribute(QLatin1String("i_group_id"), newIdGroup);
             IFOKDO(err, op1.save(true, false))
 
-            IFOKDO(err, setAttribute(QStringLiteral("i_group_id"), newIdGroup))
+            IFOKDO(err, setAttribute(QLatin1String("i_group_id"), newIdGroup))
 
             // Update all objects of group2
-            if (!err && !group1.isEmpty() && group1 != QStringLiteral("0")) {
+            if (!err && !group1.isEmpty() && group1 != QLatin1String("0")) {
                 err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group1);
             }
 
             // Update all objects of group2
-            if (!err && !group2.isEmpty() && group2 != QStringLiteral("0")) {
+            if (!err && !group2.isEmpty() && group2 != QLatin1String("0")) {
                 err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group2);
             }
         }
@@ -346,58 +347,58 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
 
 SKGError SKGOperationObject::bookmark(bool iBookmark)
 {
-    return setAttribute(QStringLiteral("t_bookmarked"), iBookmark ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_bookmarked"), iBookmark ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGOperationObject::isBookmarked() const
 {
-    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_bookmarked")) == QLatin1String("Y"));
 }
 
 SKGError SKGOperationObject::setImported(bool iImported)
 {
-    return setAttribute(QStringLiteral("t_imported"), iImported ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_imported"), iImported ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGOperationObject::isImported() const
 {
-    return (getAttribute(QStringLiteral("t_imported")) != QStringLiteral("N"));
+    return (getAttribute(QLatin1String("t_imported")) != QLatin1String("N"));
 }
 
 SKGError SKGOperationObject::setImportID(const QString& iImportID)
 {
-    SKGError err = setAttribute(QStringLiteral("t_import_id"), iImportID);
+    SKGError err = setAttribute(QLatin1String("t_import_id"), iImportID);
     if (!err && !iImportID.isEmpty()) {
-        err = setAttribute(QStringLiteral("t_imported"), QStringLiteral("T"));
+        err = setAttribute(QLatin1String("t_imported"), QLatin1String("T"));
     }
     return err;
 }
 
 QString SKGOperationObject::getImportID() const
 {
-    return getAttribute(QStringLiteral("t_import_id"));
+    return getAttribute(QLatin1String("t_import_id"));
 }
 
 SKGError SKGOperationObject::setTemplate(bool iTemplate)
 {
-    return setAttribute(QStringLiteral("t_template"), iTemplate ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_template"), iTemplate ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGOperationObject::isTemplate() const
 {
-    return (getAttribute(QStringLiteral("t_template")) != QStringLiteral("N"));
+    return (getAttribute(QLatin1String("t_template")) != QLatin1String("N"));
 }
 
 int SKGOperationObject::getNbSubOperations() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_NBSUBOPERATIONS")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_NBSUBOPERATIONS")));
 }
 
 SKGError SKGOperationObject::addSubOperation(SKGSubOperationObject& oSubOperation)
 {
     SKGError err;
     if (getID() == 0) {
-        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGOperationObject::addSubOperation")));
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGOperationObject::addSubOperation")));
     } else {
         oSubOperation = SKGSubOperationObject(getDocument());
         err = oSubOperation.setParentOperation(*this);
@@ -410,9 +411,9 @@ SKGError SKGOperationObject::getSubOperations(SKGListSKGObjectBase& oSubOperatio
 {
     SKGError err;
     if (getID() == 0) {
-        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGOperationObject::getSubOperations")));
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGOperationObject::getSubOperations")));
     } else {
-        err = getDocument()->getObjects(QStringLiteral("v_suboperation"),
+        err = getDocument()->getObjects(QLatin1String("v_suboperation"),
                                         "rd_operation_id=" % SKGServices::intToString(getID()) % " ORDER BY i_order", oSubOperations);
     }
     return err;
@@ -420,7 +421,7 @@ SKGError SKGOperationObject::getSubOperations(SKGListSKGObjectBase& oSubOperatio
 
 double SKGOperationObject::getCurrentAmount() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_CURRENTAMOUNT")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_CURRENTAMOUNT")));
 }
 
 double SKGOperationObject::getBalance() const
@@ -428,8 +429,8 @@ double SKGOperationObject::getBalance() const
     double output = 0.0;
     SKGStringListList result;
     SKGError err = getDocument()->executeSelectSqliteOrder("SELECT TOTAL(f_CURRENTAMOUNT) FROM v_operation WHERE t_template='N' AND "
-                   "rd_account_id=" % getAttribute(QStringLiteral("rd_account_id")) % " AND (d_date<'" % getAttribute(QStringLiteral("d_date")) % "' OR "
-                   "(d_date='" % getAttribute(QStringLiteral("d_date")) % "' AND id<=" % SKGServices::intToString(getID()) % "))", result);
+                   "rd_account_id=" % getAttribute(QLatin1String("rd_account_id")) % " AND (d_date<'" % getAttribute(QLatin1String("d_date")) % "' OR "
+                   "(d_date='" % getAttribute(QLatin1String("d_date")) % "' AND id<=" % SKGServices::intToString(getID()) % "))", result);
     IFOK(err) {
         output = SKGServices::stringToDouble(result.at(1).at(0));
     }
@@ -440,11 +441,11 @@ double SKGOperationObject::getBalance() const
 double SKGOperationObject::getAmount(QDate iDate) const
 {
     // Get quantity
-    double quantity = SKGServices::stringToDouble(getAttribute(QStringLiteral("f_QUANTITY")));
+    double quantity = SKGServices::stringToDouble(getAttribute(QLatin1String("f_QUANTITY")));
 
     // Is the unit value already in cache ?
     double coef = 1;
-    QString val = getDocument()->getCachedValue("unitvalue-" % getAttribute(QStringLiteral("rc_unit_id")));
+    QString val = getDocument()->getCachedValue("unitvalue-" % getAttribute(QLatin1String("rc_unit_id")));
     if (!val.isEmpty()) {
         // Yes
         coef = SKGServices::stringToDouble(val);
@@ -463,7 +464,7 @@ SKGError SKGOperationObject::addRecurrentOperation(SKGRecurrentOperationObject&
 {
     SKGError err;
     if (getID() == 0) {
-        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGOperationObject::addRecurrentOperation")));
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGOperationObject::addRecurrentOperation")));
     } else {
         oRecurrentOperation = SKGRecurrentOperationObject(getDocument());
         err = oRecurrentOperation.setParentOperation(*this);
@@ -476,9 +477,9 @@ SKGError SKGOperationObject::getRecurrentOperations(SKGListSKGObjectBase& oRecur
 {
     SKGError err;
     if (getID() == 0) {
-        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGOperationObject::getRecurrentOperation")));
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QLatin1String("SKGOperationObject::getRecurrentOperation")));
     } else {
-        err = getDocument()->getObjects(QStringLiteral("v_recurrentoperation"),
+        err = getDocument()->getObjects(QLatin1String("v_recurrentoperation"),
                                         "rd_operation_id=" % SKGServices::intToString(getID()), oRecurrentOperation);
     }
     return err;
@@ -486,7 +487,7 @@ SKGError SKGOperationObject::getRecurrentOperations(SKGListSKGObjectBase& oRecur
 
 int SKGOperationObject::getRecurrentOperation() const
 {
-    const auto recurrentId = SKGServices::stringToInt(getAttribute(QStringLiteral("r_recurrentoperation_id")));
+    const auto recurrentId = SKGServices::stringToInt(getAttribute(QLatin1String("r_recurrentoperation_id")));
     if (recurrentId != 0) {
         return recurrentId;
     } else {
@@ -530,7 +531,7 @@ SKGError SKGOperationObject::setRecurrentOperation(int recurrentId)
                     IFOKDO(err, oldRop.setDate(lastObj.getDate()))
                     IFOKDO(err, oldRop.setDate(oldRop.getNextDate()))
                     IFOKDO(err, oldRop.save())
-                    IFOKDO(err, lastObj.setAttribute(QStringLiteral("r_recurrentoperation_id"), QString("0")))
+                    IFOKDO(err, lastObj.setAttribute(QLatin1String("r_recurrentoperation_id"), QString("0")))
                     IFOKDO(err, lastObj.save())
                 } else {
                     IFOKDO(err, oldRop.remove(true, true))
@@ -538,7 +539,7 @@ SKGError SKGOperationObject::setRecurrentOperation(int recurrentId)
             }
         }
 
-        IFOKDO(err, setAttribute(QStringLiteral("r_recurrentoperation_id"), QString("0")))
+        IFOKDO(err, setAttribute(QLatin1String("r_recurrentoperation_id"), QString("0")))
         IFOKDO(err, save())
     }
 
@@ -564,27 +565,27 @@ SKGError SKGOperationObject::setRecurrentOperation(int recurrentId)
             IFOK(err) {
                 if (!newRopParent.isTemplate()) {
                     // Set old parent op as recurrent
-                    IFOKDO(err, newRopParent.setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(recurrentId)))
+                    IFOKDO(err, newRopParent.setAttribute(QLatin1String("r_recurrentoperation_id"), SKGServices::intToString(recurrentId)))
                     IFOKDO(err, newRopParent.save())
 
                     // Set this transaction as reference
                     IFOKDO(err, newRop.setParentOperation(*this))
                 } else {
                     // Set this op as recurrent
-                    IFOKDO(err, setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(recurrentId)))
+                    IFOKDO(err, setAttribute(QLatin1String("r_recurrentoperation_id"), SKGServices::intToString(recurrentId)))
                     IFOKDO(err, save())
                 }
 
                 IFOKDO(err, newRop.setDate(currentDate))
             }
         } else {
-            IFOKDO(err, setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(recurrentId)))
+            IFOKDO(err, setAttribute(QLatin1String("r_recurrentoperation_id"), SKGServices::intToString(recurrentId)))
             IFOKDO(err, save())
         }
         // 492287 vvvv
         IFOKDO(err, newRop.setDate(newRop.getNextDate()))
-        IFOKDO(err, newRop.save())     
-        // 492287 ^^^^   
+        IFOKDO(err, newRop.save())
+        // 492287 ^^^^
     }
 
     return err;
@@ -595,7 +596,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     // Merge operation
     SKGError err = setDate(iDeletedOne.getDate());
     IFOKDO(err, setImportID(iDeletedOne.getImportID()))
-    IFOKDO(err, setAttribute(QStringLiteral("t_imported"), iDeletedOne.getAttribute(QStringLiteral("t_imported"))))
+    IFOKDO(err, setAttribute(QLatin1String("t_imported"), iDeletedOne.getAttribute(QLatin1String("t_imported"))))
     if (!err && getComment().isEmpty()) {
         err = setComment(iDeletedOne.getComment());
     }
@@ -644,7 +645,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
             IFOKDO(err, so1.save())
         } else {
             // Keep ratio
-            for (const auto& sopbase : qAsConst(subOps1)) {
+            for (const auto& sopbase : std::as_const(subOps1)) {
                 SKGSubOperationObject sop(sopbase);
                 IFOKDO(err, sop.setQuantity(targettAmount * sop.getQuantity() / currentAmount))
                 IFOKDO(err, sop.save())
@@ -657,8 +658,8 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     }
 
     // transfers properties
-    IFOKDO(err, getDocument()->executeSqliteOrder(QStringLiteral("DELETE FROM parameters WHERE t_uuid_parent='") % getUniqueID() % QStringLiteral("' AND t_name IN (SELECT t_name FROM parameters WHERE t_uuid_parent='") % iDeletedOne.getUniqueID() % QStringLiteral("')")))
-    IFOKDO(err, getDocument()->executeSqliteOrder(QStringLiteral("UPDATE parameters SET t_uuid_parent='") % getUniqueID() % QStringLiteral("' WHERE t_uuid_parent='") % iDeletedOne.getUniqueID() % QStringLiteral("'")))
+    IFOKDO(err, getDocument()->executeSqliteOrder(QLatin1String("DELETE FROM parameters WHERE t_uuid_parent='") % getUniqueID() % QLatin1String("' AND t_name IN (SELECT t_name FROM parameters WHERE t_uuid_parent='") % iDeletedOne.getUniqueID() % QLatin1String("')")))
+    IFOKDO(err, getDocument()->executeSqliteOrder(QLatin1String("UPDATE parameters SET t_uuid_parent='") % getUniqueID() % QLatin1String("' WHERE t_uuid_parent='") % iDeletedOne.getUniqueID() % QLatin1String("'")))
 
     // Delete useless operation
     IFOKDO(err, iDeletedOne.remove(false, true))
