@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -20,7 +20,7 @@
 SKGPayeeObject::SKGPayeeObject(): SKGPayeeObject(nullptr)
 {}
 
-SKGPayeeObject::SKGPayeeObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QStringLiteral("v_payee"), iID)
+SKGPayeeObject::SKGPayeeObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QLatin1String("v_payee"), iID)
 {}
 
 SKGPayeeObject::~SKGPayeeObject()
@@ -31,10 +31,10 @@ SKGPayeeObject::SKGPayeeObject(const SKGPayeeObject& iObject) = default;
 SKGPayeeObject::SKGPayeeObject(const SKGObjectBase& iObject)
 
 {
-    if (iObject.getRealTable() == QStringLiteral("payee")) {
+    if (iObject.getRealTable() == QLatin1String("payee")) {
         copyFrom(iObject);
     } else {
-        *this = SKGNamedObject(iObject.getDocument(), QStringLiteral("v_payee"), iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), QLatin1String("v_payee"), iObject.getID());
     }
 }
 
@@ -62,7 +62,7 @@ SKGError SKGPayeeObject::createPayee(SKGDocumentBank* iDocument,
     if (iName.isEmpty()) {
         oPayee = SKGPayeeObject(nullptr, 0);
     } else if (iDocument != nullptr) {
-        iDocument->getObject(QStringLiteral("v_payee"), "t_name='" % SKGServices::stringToSqlString(iName) % '\'', oPayee);
+        iDocument->getObject(QLatin1String("v_payee"), "t_name='" % SKGServices::stringToSqlString(iName) % QLatin1Char('\''), oPayee);
         if (oPayee.getID() == 0) {
             // No, we have to create it
             oPayee = SKGPayeeObject(iDocument);
@@ -80,7 +80,7 @@ SKGError SKGPayeeObject::createPayee(SKGDocumentBank* iDocument,
 
 SKGError SKGPayeeObject::getOperations(SKGListSKGObjectBase& oOperations) const
 {
-    SKGError err = getDocument()->getObjects(QStringLiteral("v_operation"),
+    SKGError err = getDocument()->getObjects(QLatin1String("v_operation"),
                    "r_payee_id=" % SKGServices::intToString(getID()),
                    oOperations);
     return err;
@@ -88,43 +88,43 @@ SKGError SKGPayeeObject::getOperations(SKGListSKGObjectBase& oOperations) const
 
 SKGError SKGPayeeObject::setAddress(const QString& iAddress)
 {
-    return setAttribute(QStringLiteral("t_address"), iAddress);
+    return setAttribute(QLatin1String("t_address"), iAddress);
 }
 
 QString SKGPayeeObject::getAddress() const
 {
-    return getAttribute(QStringLiteral("t_address"));
+    return getAttribute(QLatin1String("t_address"));
 }
 
 SKGError SKGPayeeObject::setClosed(bool iClosed)
 {
-    return setAttribute(QStringLiteral("t_close"), iClosed ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_close"), iClosed ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGPayeeObject::isClosed() const
 {
-    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_close")) == QLatin1String("Y"));
 }
 
 SKGError SKGPayeeObject::bookmark(bool iBookmark)
 {
-    return setAttribute(QStringLiteral("t_bookmarked"), iBookmark ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_bookmarked"), iBookmark ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGPayeeObject::isBookmarked() const
 {
-    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_bookmarked")) == QLatin1String("Y"));
 }
 
 SKGError SKGPayeeObject::getCategory(SKGCategoryObject& oCategory) const
 {
-    SKGError err = getDocument()->getObject(QStringLiteral("v_category"), "id=" % getAttribute(QStringLiteral("r_category_id")), oCategory);
+    SKGError err = getDocument()->getObject(QLatin1String("v_category"), "id=" % getAttribute(QLatin1String("r_category_id")), oCategory);
     return err;
 }
 
 SKGError SKGPayeeObject::setCategory(const SKGCategoryObject& iCategory)
 {
-    return setAttribute(QStringLiteral("r_category_id"), SKGServices::intToString(iCategory.getID()));
+    return setAttribute(QLatin1String("r_category_id"), SKGServices::intToString(iCategory.getID()));
 }
 
 SKGError SKGPayeeObject::merge(const SKGPayeeObject& iPayee)
