@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -21,7 +21,7 @@
 SKGRecurrentOperationObject::SKGRecurrentOperationObject(): SKGRecurrentOperationObject(nullptr)
 {}
 
-SKGRecurrentOperationObject::SKGRecurrentOperationObject(SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, QStringLiteral("v_recurrentoperation"), iID)
+SKGRecurrentOperationObject::SKGRecurrentOperationObject(SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, QLatin1String("v_recurrentoperation"), iID)
 {}
 
 SKGRecurrentOperationObject::~SKGRecurrentOperationObject()
@@ -31,10 +31,10 @@ SKGRecurrentOperationObject::SKGRecurrentOperationObject(const SKGRecurrentOpera
 
 SKGRecurrentOperationObject::SKGRecurrentOperationObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable() == QStringLiteral("recurrentoperation")) {
+    if (iObject.getRealTable() == QLatin1String("recurrentoperation")) {
         copyFrom(iObject);
     } else {
-        *this = SKGObjectBase(iObject.getDocument(), QStringLiteral("v_recurrentoperation"), iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), QLatin1String("v_recurrentoperation"), iObject.getID());
     }
 }
 
@@ -53,14 +53,14 @@ SKGRecurrentOperationObject& SKGRecurrentOperationObject::operator= (const SKGRe
 SKGError SKGRecurrentOperationObject::getParentOperation(SKGOperationObject& oOperation) const
 {
     SKGObjectBase objTmp;
-    SKGError err = getDocument()->getObject(QStringLiteral("v_operation"), "id=" % getAttribute(QStringLiteral("rd_operation_id")), objTmp);
+    SKGError err = getDocument()->getObject(QLatin1String("v_operation"), "id=" % getAttribute(QLatin1String("rd_operation_id")), objTmp);
     oOperation = objTmp;
     return err;
 }
 
 SKGError SKGRecurrentOperationObject::setParentOperation(const SKGOperationObject& iOperation)
 {
-    return setAttribute(QStringLiteral("rd_operation_id"), SKGServices::intToString(iOperation.getID()));
+    return setAttribute(QLatin1String("rd_operation_id"), SKGServices::intToString(iOperation.getID()));
 }
 
 SKGError SKGRecurrentOperationObject::setTemplate(bool iTemplate)
@@ -82,7 +82,7 @@ SKGError SKGRecurrentOperationObject::setTemplate(bool iTemplate)
         IFOKDO(err, setParentOperation(parentOp))
         IFOKDO(err, save())
 
-        IFOKDO(err, operationObjOrig.setAttribute(QStringLiteral("r_recurrentoperation_id"), SKGServices::intToString(getID())))
+        IFOKDO(err, operationObjOrig.setAttribute(QLatin1String("r_recurrentoperation_id"), SKGServices::intToString(getID())))
         IFOKDO(err, operationObjOrig.save())
     } else {
         // Convert to non-template
@@ -93,7 +93,7 @@ SKGError SKGRecurrentOperationObject::setTemplate(bool iTemplate)
                 SKGOperationObject lastObj(transactions.last());
                 IFOKDO(err, setParentOperation(lastObj))
                 IFOKDO(err, save())
-                IFOKDO(err, lastObj.setAttribute(QStringLiteral("r_recurrentoperation_id"), QString()))
+                IFOKDO(err, lastObj.setAttribute(QLatin1String("r_recurrentoperation_id"), QString()))
                 IFOKDO(err, lastObj.save())
 
                 SKGObjectBase::SKGListSKGObjectBase goupops;
@@ -128,24 +128,24 @@ bool SKGRecurrentOperationObject::isTemplate() const
 
 SKGError SKGRecurrentOperationObject::setPeriodIncrement(int iIncrement)
 {
-    return setAttribute(QStringLiteral("i_period_increment"), SKGServices::intToString(iIncrement));
+    return setAttribute(QLatin1String("i_period_increment"), SKGServices::intToString(iIncrement));
 }
 
 int SKGRecurrentOperationObject::getPeriodIncrement() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_period_increment")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_period_increment")));
 }
 
 SKGRecurrentOperationObject::PeriodUnit SKGRecurrentOperationObject::getPeriodUnit() const
 {
-    QString t_period_unit = getAttribute(QStringLiteral("t_period_unit"));
-    if (t_period_unit == QStringLiteral("D")) {
+    QString t_period_unit = getAttribute(QLatin1String("t_period_unit"));
+    if (t_period_unit == QLatin1String("D")) {
         return SKGRecurrentOperationObject::DAY;
     }
-    if (t_period_unit == QStringLiteral("W")) {
+    if (t_period_unit == QLatin1String("W")) {
         return SKGRecurrentOperationObject::WEEK;
     }
-    if (t_period_unit == QStringLiteral("M")) {
+    if (t_period_unit == QLatin1String("M")) {
         return SKGRecurrentOperationObject::MONTH;
     }
     return SKGRecurrentOperationObject::YEAR;
@@ -153,37 +153,37 @@ SKGRecurrentOperationObject::PeriodUnit SKGRecurrentOperationObject::getPeriodUn
 
 SKGError SKGRecurrentOperationObject::setPeriodUnit(SKGRecurrentOperationObject::PeriodUnit iPeriod)
 {
-    return setAttribute(QStringLiteral("t_period_unit"), (iPeriod == SKGRecurrentOperationObject::DAY ? QStringLiteral("D") : (iPeriod == SKGRecurrentOperationObject::WEEK ? QStringLiteral("W") : (iPeriod == SKGRecurrentOperationObject::MONTH ? QStringLiteral("M") : QStringLiteral("Y")))));
+    return setAttribute(QLatin1String("t_period_unit"), (iPeriod == SKGRecurrentOperationObject::DAY ? QLatin1String("D") : (iPeriod == SKGRecurrentOperationObject::WEEK ? QLatin1String("W") : (iPeriod == SKGRecurrentOperationObject::MONTH ? QLatin1String("M") : QLatin1String("Y")))));
 }
 
 SKGError SKGRecurrentOperationObject::setAutoWriteDays(int iDays)
 {
-    return setAttribute(QStringLiteral("i_auto_write_days"), SKGServices::intToString(iDays));
+    return setAttribute(QLatin1String("i_auto_write_days"), SKGServices::intToString(iDays));
 }
 
 int SKGRecurrentOperationObject::getAutoWriteDays() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_auto_write_days")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_auto_write_days")));
 }
 
 SKGError SKGRecurrentOperationObject::setWarnDays(int iDays)
 {
-    return setAttribute(QStringLiteral("i_warn_days"), SKGServices::intToString(iDays));
+    return setAttribute(QLatin1String("i_warn_days"), SKGServices::intToString(iDays));
 }
 
 int SKGRecurrentOperationObject::getWarnDays() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_warn_days")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_warn_days")));
 }
 
 bool SKGRecurrentOperationObject::hasTimeLimit() const
 {
-    return (getAttribute(QStringLiteral("t_times")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_times")) == QLatin1String("Y"));
 }
 
 SKGError SKGRecurrentOperationObject::timeLimit(bool iTimeLimit)
 {
-    return setAttribute(QStringLiteral("t_times"), iTimeLimit ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_times"), iTimeLimit ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 SKGError SKGRecurrentOperationObject::setTimeLimit(QDate iLastDate)
@@ -216,17 +216,17 @@ SKGError SKGRecurrentOperationObject::setTimeLimit(QDate iLastDate)
 
 SKGError SKGRecurrentOperationObject::setTimeLimit(int iTimeLimit)
 {
-    return setAttribute(QStringLiteral("i_nb_times"), SKGServices::intToString(iTimeLimit));
+    return setAttribute(QLatin1String("i_nb_times"), SKGServices::intToString(iTimeLimit));
 }
 
 int SKGRecurrentOperationObject::getTimeLimit() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_nb_times")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_nb_times")));
 }
 
 SKGError SKGRecurrentOperationObject::setDate(QDate iDate)
 {
-    return setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(iDate));
+    return setAttribute(QLatin1String("d_date"), SKGServices::dateToSqlString(iDate));
 }
 
 QDate SKGRecurrentOperationObject::getNextDate() const
@@ -248,32 +248,32 @@ QDate SKGRecurrentOperationObject::getNextDate() const
 
 QDate SKGRecurrentOperationObject::getDate() const
 {
-    return SKGServices::stringToTime(getAttribute(QStringLiteral("d_date"))).date();
+    return SKGServices::stringToDate(getAttribute(QLatin1String("d_date")));
 }
 
 SKGError SKGRecurrentOperationObject::warnEnabled(bool iWarn)
 {
-    return setAttribute(QStringLiteral("t_warn"), iWarn ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_warn"), iWarn ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGRecurrentOperationObject::isWarnEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_warn")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_warn")) == QLatin1String("Y"));
 }
 
 SKGError SKGRecurrentOperationObject::autoWriteEnabled(bool iAutoWrite)
 {
-    return setAttribute(QStringLiteral("t_auto_write"), iAutoWrite ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_auto_write"), iAutoWrite ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGRecurrentOperationObject::isAutoWriteEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_auto_write")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_auto_write")) == QLatin1String("Y"));
 }
 
 SKGError SKGRecurrentOperationObject::getRecurredOperations(SKGListSKGObjectBase& oOperations) const
 {
-    return getDocument()->getObjects(QStringLiteral("v_operation"), "r_recurrentoperation_id=" % SKGServices::intToString(getID()) % " ORDER BY d_date", oOperations);
+    return getDocument()->getObjects(QLatin1String("v_operation"), "r_recurrentoperation_id=" % SKGServices::intToString(getID()) % " ORDER BY d_date", oOperations);
 }
 
 SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, QDate iDate)
@@ -339,7 +339,7 @@ SKGError SKGRecurrentOperationObject::process(SKGDocumentBank* iDocument, int& o
     // Get all transaction with auto_write
     SKGListSKGObjectBase recuOps;
     if (iDocument != nullptr) {
-        err = iDocument->getObjects(QStringLiteral("v_recurrentoperation"), QLatin1String(""), recuOps);
+        err = iDocument->getObjects(QLatin1String("v_recurrentoperation"), QLatin1String(""), recuOps);
     }
 
     int nb = recuOps.count();
