@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -23,6 +23,7 @@
 #include "skgruleobject.h"
 #include "skgtraces.h"
 #include "skgunitobject.h"
+#include <utility>
 
 SKGReportBank::SKGReportBank(SKGDocument* iDocument) : SKGReport(iDocument)
 {
@@ -37,7 +38,7 @@ SKGReportBank::~SKGReportBank()
 
 QVariantList SKGReportBank::getAlarms()
 {
-    QString cacheId = QStringLiteral("getAlarms");
+    QString cacheId = QLatin1String("getAlarms");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -46,7 +47,7 @@ QVariantList SKGReportBank::getAlarms()
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
             SKGObjectBase::SKGListSKGObjectBase rules;
-            SKGError err = doc->getObjects(QStringLiteral("v_rule"), QStringLiteral("t_action_type='A' ORDER BY i_ORDER"), rules);
+            SKGError err = doc->getObjects(QLatin1String("v_rule"), QLatin1String("t_action_type='A' ORDER BY i_ORDER"), rules);
             int nb = rules.count();
             if (nb != 0) {
                 for (int i = 0; !err && i < nb; ++i) {
@@ -79,7 +80,7 @@ QVariantList SKGReportBank::getAlarms()
 
 QVariantList SKGReportBank::getInterests()
 {
-    QString cacheId = QStringLiteral("getInterests");
+    QString cacheId = QLatin1String("getInterests");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -90,9 +91,9 @@ QVariantList SKGReportBank::getInterests()
             SKGObjectBase::SKGListSKGObjectBase objs;
             auto sqlFilter = getSqlFilter();
             if (sqlFilter.isEmpty()) {
-                sqlFilter = QStringLiteral("1=1");
+                sqlFilter = QLatin1String("1=1");
             }
-            SKGError err = doc->getObjects(QStringLiteral("v_account"), "(" % sqlFilter % QStringLiteral(") AND t_close='N' AND EXISTS(select 1 from interest where interest.rd_account_id=v_account.id) ORDER BY t_name"), objs);
+            SKGError err = doc->getObjects(QLatin1String("v_account"), "(" % sqlFilter % QLatin1String(") AND t_close='N' AND EXISTS(select 1 from interest where interest.rd_account_id=v_account.id) ORDER BY t_name"), objs);
             IFOK(err) {
                 int nb = objs.count();
                 table.reserve(nb + 2);
@@ -141,7 +142,7 @@ QVariantList SKGReportBank::getInterests()
 
 QVariantList SKGReportBank::getBudgetTable()
 {
-    QString cacheId = QStringLiteral("getBudgetTable");
+    QString cacheId = QLatin1String("getBudgetTable");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -154,7 +155,7 @@ QVariantList SKGReportBank::getBudgetTable()
 
 QVariantList SKGReportBank::getPortfolio()
 {
-    QString cacheId = QStringLiteral("getPortfolio");
+    QString cacheId = QLatin1String("getPortfolio");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -169,16 +170,16 @@ QVariantList SKGReportBank::getPortfolio()
                 SKGObjectBase::SKGListSKGObjectBase objs;
                 auto sqlFilter = getSqlFilter();
                 if (sqlFilter.isEmpty()) {
-                    sqlFilter = QStringLiteral("1=1");
+                    sqlFilter = QLatin1String("1=1");
                 }
-                SKGError err = doc->getObjects(QStringLiteral("v_operation_display"), "d_date<'" % SKGServices::dateToSqlString(date) % "' AND rc_unit_id IN (SELECT id FROM v_unit_display WHERE t_type='S' AND (" % sqlFilter % ") AND f_QUANTITYOWNED>0.01) ORDER BY t_UNIT", objs);
+                SKGError err = doc->getObjects(QLatin1String("v_operation_display"), "d_date<'" % SKGServices::dateToSqlString(date) % "' AND rc_unit_id IN (SELECT id FROM v_unit_display WHERE t_type='S' AND (" % sqlFilter % ") AND f_QUANTITYOWNED>0.01) ORDER BY t_UNIT", objs);
                 int nb = objs.count();
                 if (!err && nb > 0) {
                     table.reserve(nb + 1);
 
                     QVariantList line;
-                    line << doc->getDisplay(QStringLiteral("t_symbol"))
-                         << doc->getDisplay(QStringLiteral("t_UNIT"))
+                    line << doc->getDisplay(QLatin1String("t_symbol"))
+                         << doc->getDisplay(QLatin1String("t_UNIT"))
                          << i18nc("Column table title", "Quantity")
                          << i18nc("Column table title", "Purchase amount")
                          << i18nc("Column table title", "Initial amount")
@@ -216,7 +217,7 @@ QVariantList SKGReportBank::getPortfolio()
                             SKGOperationObject obj2(oGroupedOperations.at(0));
                             current.purchaseAmount += obj2.getAmount(obj.getDate());
                         }
-                        current.quantity += SKGServices::stringToDouble(obj.getAttribute(QStringLiteral("f_QUANTITY")));
+                        current.quantity += SKGServices::stringToDouble(obj.getAttribute(QLatin1String("f_QUANTITY")));
                     }
                     if (!current.unit.getName().isEmpty()) {
                         listUnitValues.push_back(current);
@@ -251,7 +252,7 @@ QVariantList SKGReportBank::getPortfolio()
 
 QVariantList SKGReportBank::getUnitTable()
 {
-    QString cacheId = QStringLiteral("getUnitTable");
+    QString cacheId = QLatin1String("getUnitTable");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -265,19 +266,19 @@ QVariantList SKGReportBank::getUnitTable()
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
 
                 SKGObjectBase::SKGListSKGObjectBase units;
-                SKGError err = doc->getObjects(QStringLiteral("v_unit_display"), QStringLiteral("1=1 ORDER BY t_TYPENLS"), units);
+                SKGError err = doc->getObjects(QLatin1String("v_unit_display"), QLatin1String("1=1 ORDER BY t_TYPENLS"), units);
                 int nbUnits = units.count();
                 if (nbUnits != 0) {
                     table.reserve(nbUnits + 1);
                     QVariantList line;
                     line << "sum"
-                         << doc->getDisplay(QStringLiteral("t_UNIT"))
+                         << doc->getDisplay(QLatin1String("t_UNIT"))
                          << QLocale().toString(date1, QLocale::ShortFormat)
                          << QLocale().toString(date2, QLocale::ShortFormat)
                          << "%"
-                         << doc->getDisplay(QStringLiteral("t_symbol"));
+                         << doc->getDisplay(QLatin1String("t_symbol"));
                     table << QVariant(line);
-                    for (const auto& item : qAsConst(units)) {
+                    for (const auto& item : std::as_const(units)) {
                         SKGUnitObject unit(item);
                         double v1 = unit.getAmount(date1);
                         double v2 = unit.getAmount(date2);
@@ -296,7 +297,7 @@ QVariantList SKGReportBank::getUnitTable()
 
 QVariantList SKGReportBank::getAccountTable()
 {
-    QString cacheId = QStringLiteral("getAccountTable");
+    QString cacheId = QLatin1String("getAccountTable");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -316,11 +317,11 @@ QVariantList SKGReportBank::getAccountTable()
                 SKGObjectBase::SKGListSKGObjectBase accounts;
                 auto sqlFilter = getSqlFilter();
                 if (sqlFilter.isEmpty()) {
-                    sqlFilter = QStringLiteral("1=1");
+                    sqlFilter = QLatin1String("1=1");
                 }
-                SKGError err = doc->getObjects(QStringLiteral("v_account"), sqlFilter + QStringLiteral(" ORDER BY t_TYPENLS, t_BANK, t_name"), accounts);
+                SKGError err = doc->getObjects(QLatin1String("v_account"), sqlFilter + QLatin1String(" ORDER BY t_TYPENLS, t_BANK, t_name"), accounts);
                 IFOK(err) {
-                    table.push_back(QVariantList() << "sum" << doc->getDisplay(QStringLiteral("t_ACCOUNT")) << QLocale().toString(date1, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) <<
+                    table.push_back(QVariantList() << "sum" << doc->getDisplay(QLatin1String("t_ACCOUNT")) << QLocale().toString(date1, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) <<
                                     "%" << QLocale().toString(date3, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) << "%");
                     double sumTypeV1 = 0;
                     double sumTypeV2 = 0;
@@ -336,7 +337,7 @@ QVariantList SKGReportBank::getAccountTable()
                         double v1 = account.getAmount(date1);
                         double v2 = account.getAmount(date2);
                         double v3 = account.getAmount(date3);
-                        QString type = account.getAttribute(QStringLiteral("t_TYPENLS"));
+                        QString type = account.getAttribute(QLatin1String("t_TYPENLS"));
                         bool closed = account.isClosed();
                         if (type != currentType) {
                             if (!currentType.isEmpty() && nbAdded > 0) {
@@ -352,7 +353,7 @@ QVariantList SKGReportBank::getAccountTable()
                             currentType = std::move(type);
                         }
                         if (!closed || qAbs(v1) > 0.01 || qAbs(v2) > 0.01 || qAbs(v3) > 0.01) {
-                            QString icon = account.getAttribute(QStringLiteral("t_ICON"));
+                            QString icon = account.getAttribute(QLatin1String("t_ICON"));
                             if (!icon.isEmpty()) {
                                 QString iconfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/" % icon);
                                 if (!iconfile.isEmpty()) {
@@ -360,7 +361,7 @@ QVariantList SKGReportBank::getAccountTable()
                                 }
                             }
                             table.push_back(QVariantList() << false << account.getName() << v1 << v2 << (100.0 * (v2 - v1) / qAbs(v1)) << v3 << v2
-                                            << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute(QStringLiteral("t_BANK")) << icon);
+                                            << (100.0 * (v2 - v3) / qAbs(v3)) << account.getAttribute(QLatin1String("t_BANK")) << icon);
                             nbAdded++;
                         }
                         sumTypeV1 += v1;
@@ -388,7 +389,7 @@ QVariantList SKGReportBank::getAccountTable()
 
 QVariantList SKGReportBank::getBankTable()
 {
-    QString cacheId = QStringLiteral("getBankTable");
+    QString cacheId = QLatin1String("getBankTable");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -407,11 +408,11 @@ QVariantList SKGReportBank::getBankTable()
                 SKGObjectBase::SKGListSKGObjectBase accounts;
                 auto sqlFilter = getSqlFilter();
                 if (sqlFilter.isEmpty()) {
-                    sqlFilter = QStringLiteral("1=1");
+                    sqlFilter = QLatin1String("1=1");
                 }
-                SKGError err = doc->getObjects(QStringLiteral("v_account"), sqlFilter + QStringLiteral(" ORDER BY t_BANK"), accounts);
+                SKGError err = doc->getObjects(QLatin1String("v_account"), sqlFilter + QLatin1String(" ORDER BY t_BANK"), accounts);
                 IFOK(err) {
-                    table.push_back(QVariantList() << "sum" << doc->getDisplay(QStringLiteral("t_BANK")) << QLocale().toString(date1, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) <<
+                    table.push_back(QVariantList() << "sum" << doc->getDisplay(QLatin1String("t_BANK")) << QLocale().toString(date1, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) <<
                                     "%" << QLocale().toString(date3, QLocale::ShortFormat) << QLocale().toString(date2, QLocale::ShortFormat) << "%");
                     double sumTypeV1 = 0;
                     double sumTypeV2 = 0;
@@ -428,8 +429,8 @@ QVariantList SKGReportBank::getBankTable()
                         double v1 = account.getAmount(date1);
                         double v2 = account.getAmount(date2);
                         double v3 = account.getAmount(date3);
-                        QString name = account.getAttribute(QStringLiteral("t_BANK"));
-                        QString icon = account.getAttribute(QStringLiteral("t_ICON"));
+                        QString name = account.getAttribute(QLatin1String("t_BANK"));
+                        QString icon = account.getAttribute(QLatin1String("t_ICON"));
                         if (!icon.isEmpty()) {
                             QString iconfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/" % icon);
                             if (!iconfile.isEmpty()) {
@@ -478,14 +479,14 @@ QVariantList SKGReportBank::getBankTable()
 
 QVariantList SKGReportBank::getScheduledOperations()
 {
-    QString cacheId = QStringLiteral("getScheduledOperations");
+    QString cacheId = QLatin1String("getScheduledOperations");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
         SKGObjectBase::SKGListSKGObjectBase objs;
-        auto scheduled_operation_days_max = m_parameters.value(QStringLiteral("scheduled_operation_days_max"), QStringLiteral("30")).toString();
-        SKGError err = m_document->getObjects(QStringLiteral("v_recurrentoperation_display"),
-                                              QStringLiteral("i_nb_times!=0 AND d_date<=date('now', 'localtime','+") + scheduled_operation_days_max + " day') ORDER BY d_date", objs);
+        auto scheduled_operation_days_max = m_parameters.value(QLatin1String("scheduled_operation_days_max"), QLatin1String("30")).toString();
+        SKGError err = m_document->getObjects(QLatin1String("v_recurrentoperation_display"),
+                                              QLatin1String("i_nb_times!=0 AND d_date<=date('now', 'localtime','+") + scheduled_operation_days_max + " day') ORDER BY d_date", objs);
         QDate d = QDate::currentDate().addDays(SKGServices::stringToInt(scheduled_operation_days_max));
         QString dateFormatShort = QLocale().dateFormat(QLocale::ShortFormat);
         IFOK(err) {
@@ -529,7 +530,7 @@ QVariantList SKGReportBank::getScheduledOperations()
 
 QVariantList SKGReportBank::getMainCategoriesForPeriod()
 {
-    QString cacheId = QStringLiteral("getMainCategoriesForPeriod");
+    QString cacheId = QLatin1String("getMainCategoriesForPeriod");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -542,7 +543,7 @@ QVariantList SKGReportBank::getMainCategoriesForPeriod()
 
 QVariantList SKGReportBank::getMainCategoriesForPreviousPeriod()
 {
-    QString cacheId = QStringLiteral("getMainCategoriesForPreviousPeriod");
+    QString cacheId = QLatin1String("getMainCategoriesForPreviousPeriod");
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -555,7 +556,7 @@ QVariantList SKGReportBank::getMainCategoriesForPreviousPeriod()
 
 QStringList SKGReportBank::get5MainCategoriesVariation()
 {
-    QString cacheId = QStringLiteral("get5MainCategoriesVariation");
+    QString cacheId = QLatin1String("get5MainCategoriesVariation");
     QStringList table = m_cache.value(cacheId).toStringList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -568,7 +569,7 @@ QStringList SKGReportBank::get5MainCategoriesVariation()
 
 QStringList SKGReportBank::get5MainCategoriesVariationIssue()
 {
-    QString cacheId = QStringLiteral("get5MainCategoriesVariationIssue");
+    QString cacheId = QLatin1String("get5MainCategoriesVariationIssue");
     QStringList table = m_cache.value(cacheId).toStringList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
@@ -585,31 +586,31 @@ QVariantMap SKGReportBank::getPersonalFinanceScoreDetails(bool iTransfer, bool i
 
     QVariantMap output;
     double pfs = getPersonalFinanceScore(iTransfer, iTracker);
-    output[QStringLiteral("value")] = pfs;
+    output[QLatin1String("value")] = pfs;
     if (pfs < 0) {
-        output[QStringLiteral("level")] = QStringLiteral("danger");
-        output[QStringLiteral("message")] = i18nc("An advice", "You must try to get out of debt.");
-        output[QStringLiteral("color")] = scheme.foreground(KColorScheme::NegativeText).color().name().right(6);
+        output[QLatin1String("level")] = QLatin1String("danger");
+        output[QLatin1String("message")] = i18nc("An advice", "You must try to get out of debt.");
+        output[QLatin1String("color")] = scheme.foreground(KColorScheme::NegativeText).color().name().right(6);
     } else if (pfs >= 25) {
-        output[QStringLiteral("level")] = QStringLiteral("success");
-        output[QStringLiteral("message")] = i18nc("An advice", "Congratulations, you are now financially independent.");
-        output[QStringLiteral("color")] = scheme.foreground(KColorScheme::PositiveText).color().name().right(6);
+        output[QLatin1String("level")] = QLatin1String("success");
+        output[QLatin1String("message")] = i18nc("An advice", "Congratulations, you are now financially independent.");
+        output[QLatin1String("color")] = scheme.foreground(KColorScheme::PositiveText).color().name().right(6);
     } else if (pfs >= 10) {
-        output[QStringLiteral("level")] = QStringLiteral("success");
-        output[QStringLiteral("message")] = i18nc("An advice", "Congratulations, You saved up ten year’s worth of expenses.");
-        output[QStringLiteral("color")] = scheme.foreground(KColorScheme::PositiveText).color().name().right(6);
+        output[QLatin1String("level")] = QLatin1String("success");
+        output[QLatin1String("message")] = i18nc("An advice", "Congratulations, You saved up ten year’s worth of expenses.");
+        output[QLatin1String("color")] = scheme.foreground(KColorScheme::PositiveText).color().name().right(6);
     } else if (pfs >= 2) {
-        output[QStringLiteral("level")] = QStringLiteral("warning");
-        output[QStringLiteral("message")] = i18nc("An advice", "You saved up %1 year’s worth of expenses. You should continue your effort.", SKGServices::intToString(pfs));
-        output[QStringLiteral("color")] = scheme.foreground(KColorScheme::NeutralText).color().name().right(6);
+        output[QLatin1String("level")] = QLatin1String("warning");
+        output[QLatin1String("message")] = i18nc("An advice", "You saved up %1 year’s worth of expenses. You should continue your effort.", SKGServices::intToString(pfs));
+        output[QLatin1String("color")] = scheme.foreground(KColorScheme::NeutralText).color().name().right(6);
     } else if (pfs >= 1) {
-        output[QStringLiteral("level")] = QStringLiteral("warning");
-        output[QStringLiteral("message")] = i18nc("An advice", "You saved up one year’s worth of expenses. You should maintain your effort.");
-        output[QStringLiteral("color")] = scheme.foreground(KColorScheme::NeutralText).color().name().right(6);
+        output[QLatin1String("level")] = QLatin1String("warning");
+        output[QLatin1String("message")] = i18nc("An advice", "You saved up one year’s worth of expenses. You should maintain your effort.");
+        output[QLatin1String("color")] = scheme.foreground(KColorScheme::NeutralText).color().name().right(6);
     } else {
-        output[QStringLiteral("level")] = QStringLiteral("warning");
-        output[QStringLiteral("message")] = i18nc("An advice", "You do not have debt but you have no margin. You must maintain your effort.");
-        output[QStringLiteral("color")] = scheme.foreground(KColorScheme::NeutralText).color().name().right(6);
+        output[QLatin1String("level")] = QLatin1String("warning");
+        output[QLatin1String("message")] = i18nc("An advice", "You do not have debt but you have no margin. You must maintain your effort.");
+        output[QLatin1String("color")] = scheme.foreground(KColorScheme::NeutralText).color().name().right(6);
     }
     return output;
 }
@@ -622,7 +623,7 @@ double SKGReportBank::getPersonalFinanceScore(bool iTransfer, bool iTracker)
 
 double SKGReportBank::getAnnualSpending(bool iTransfer, bool iTracker)
 {
-    QString cacheId = QStringLiteral("getAnnualSpending-") % (iTransfer ? QStringLiteral("Y") : QStringLiteral("N")) % (iTracker ? QStringLiteral("Y") : QStringLiteral("N"));
+    QString cacheId = QLatin1String("getAnnualSpending-") % (iTransfer ? QLatin1String("Y") : QLatin1String("N")) % (iTracker ? QLatin1String("Y") : QLatin1String("N"));
     double output = m_cache.value(cacheId).toDouble();
     if (!m_cache.contains(cacheId)) {
         SKGTRACEINFUNC(10)
@@ -646,7 +647,7 @@ double SKGReportBank::getAnnualSpending(bool iTransfer, bool iTracker)
 
 double SKGReportBank::getNetWorth(bool iTransfer, bool iTracker)
 {
-    QString cacheId = QStringLiteral("getNetWorth-") % (iTransfer ? QStringLiteral("Y") : QStringLiteral("N")) % (iTracker ? QStringLiteral("Y") : QStringLiteral("N"));
+    QString cacheId = QLatin1String("getNetWorth-") % (iTransfer ? QLatin1String("Y") : QLatin1String("N")) % (iTracker ? QLatin1String("Y") : QLatin1String("N"));
     double output = m_cache.value(cacheId).toDouble();
     if (!m_cache.contains(cacheId)) {
         SKGTRACEINFUNC(10)
@@ -668,14 +669,14 @@ double SKGReportBank::getNetWorth(bool iTransfer, bool iTracker)
 
 QVariantList SKGReportBank::getIncomeVsExpenditure(bool iOnSubOperation, bool iGrouped, bool iTransfer, bool iTracker, const QString& iWhereClause1, const QString& iWhereClause2)
 {
-    QString cacheId = QStringLiteral("getIncomeVsExpenditure-") % (iOnSubOperation ? QStringLiteral("Y") : QStringLiteral("N")) % (iGrouped ? QStringLiteral("Y") : QStringLiteral("N")) % (iTransfer ? QStringLiteral("Y") : QStringLiteral("N")) % (iTracker ? QStringLiteral("Y") : QStringLiteral("N")) % iWhereClause1 % iWhereClause2;
+    QString cacheId = QLatin1String("getIncomeVsExpenditure-") % (iOnSubOperation ? QLatin1String("Y") : QLatin1String("N")) % (iGrouped ? QLatin1String("Y") : QLatin1String("N")) % (iTransfer ? QLatin1String("Y") : QLatin1String("N")) % (iTracker ? QLatin1String("Y") : QLatin1String("N")) % iWhereClause1 % iWhereClause2;
     QVariantList table = m_cache.value(cacheId).toList();
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10)
         auto* doc = qobject_cast<SKGDocumentBank*>(m_document);
         if (doc != nullptr) {
-            QString tableDb = (iOnSubOperation ? QStringLiteral("v_suboperation_consolidated") : QStringLiteral("v_operation_display"));
-            QString amount = (iOnSubOperation ? QStringLiteral("f_REALCURRENTAMOUNT") : QStringLiteral("f_CURRENTAMOUNT"));
+            QString tableDb = (iOnSubOperation ? QLatin1String("v_suboperation_consolidated") : QLatin1String("v_operation_display"));
+            QString amount = (iOnSubOperation ? QLatin1String("f_REALCURRENTAMOUNT") : QLatin1String("f_CURRENTAMOUNT"));
 
             SKGStringListList listTmp;
             auto wc1 = iWhereClause1;
@@ -689,7 +690,7 @@ QVariantList SKGReportBank::getIncomeVsExpenditure(bool iOnSubOperation, bool iG
 
             auto sqlFilter = getSqlFilter();
             if (sqlFilter.isEmpty()) {
-                sqlFilter = QStringLiteral("1=1");
+                sqlFilter = QLatin1String("1=1");
             }
             SKGError err = doc->executeSelectSqliteOrder(
                                "SELECT TOTAL(" % amount % "), '1'  from " % tableDb % " WHERE " % wc1 % " AND " % sqlFilter
@@ -714,13 +715,13 @@ QVariantList SKGReportBank::getIncomeVsExpenditure(bool iOnSubOperation, bool iG
                 for (int i = 1; i < nbval; ++i) {  // Ignore header
                     QString m = listTmp.at(i).at(1);
                     double v = SKGServices::stringToDouble(listTmp.at(i).at(0));
-                    if (v > 0 && m == QStringLiteral("1")) {
+                    if (v > 0 && m == QLatin1String("1")) {
                         income_period = v;
-                    } else if (v < 0 && m == QStringLiteral("1")) {
+                    } else if (v < 0 && m == QLatin1String("1")) {
                         expense_period = v;
-                    } else if (v > 0 && m == QStringLiteral("2")) {
+                    } else if (v > 0 && m == QLatin1String("2")) {
                         income_previous_period = v;
-                    } else if (v < 0 && m == QStringLiteral("2")) {
+                    } else if (v < 0 && m == QLatin1String("2")) {
                         expense_previous_period = v;
                     }
                 }
@@ -728,9 +729,9 @@ QVariantList SKGReportBank::getIncomeVsExpenditure(bool iOnSubOperation, bool iG
                 double saving_previous_period = income_previous_period + expense_previous_period;
                 double saving_period = income_period + expense_period;
 
-                table.push_back(QVariantList() << QStringLiteral("sum") << QLatin1String("") << getPreviousPeriod() << getPeriod() << QStringLiteral("max"));
-                table.push_back(QVariantList() << false << doc->getDisplay(QStringLiteral("f_CURRENTAMOUNT_INCOME")) << qAbs(income_previous_period) << qAbs(income_period));
-                table.push_back(QVariantList() << false << doc->getDisplay(QStringLiteral("f_CURRENTAMOUNT_EXPENSE")) << qAbs(expense_previous_period) << qAbs(expense_period));
+                table.push_back(QVariantList() << QLatin1String("sum") << QLatin1String("") << getPreviousPeriod() << getPeriod() << QLatin1String("max"));
+                table.push_back(QVariantList() << false << doc->getDisplay(QLatin1String("f_CURRENTAMOUNT_INCOME")) << qAbs(income_previous_period) << qAbs(income_period));
+                table.push_back(QVariantList() << false << doc->getDisplay(QLatin1String("f_CURRENTAMOUNT_EXPENSE")) << qAbs(expense_previous_period) << qAbs(expense_period));
                 table.push_back(QVariantList() << true << i18nc("Noun",  "Savings possible") << saving_previous_period << saving_period);
                 table.push_back(QVariantList() << true << i18nc("Noun",  "Max") << qMax(qAbs(income_previous_period), qAbs(expense_previous_period)) << qMax(qAbs(income_period), qAbs(expense_period)));
             }
@@ -743,12 +744,12 @@ QVariantList SKGReportBank::getIncomeVsExpenditure(bool iOnSubOperation, bool iG
 void SKGReportBank::addItemsInMapping(QVariantHash& iMapping)
 {
     SKGReport::addItemsInMapping(iMapping);
-    iMapping.insert(QStringLiteral("about_forumpage"), QStringLiteral("https://forum.kde.org/viewforum.php?f=210"));
-    iMapping.insert(QStringLiteral("about_newspage"), QStringLiteral("https://skrooge.org/news"));
-    iMapping.insert(QStringLiteral("about_operationpage"), QStringLiteral("skg://Skrooge_operation_plugin/"));
-    iMapping.insert(QStringLiteral("about_accountpage"), QStringLiteral("skg://Skrooge_bank_plugin/"));
-    iMapping.insert(QStringLiteral("about_importurl"), QStringLiteral("skg://import_operation/"));
-    iMapping.insert(QStringLiteral("about_maintext"), i18nc("The main text of skrooge",
+    iMapping.insert(QLatin1String("about_forumpage"), QLatin1String("https://forum.kde.org/viewforum.php?f=210"));
+    iMapping.insert(QLatin1String("about_newspage"), QLatin1String("https://skrooge.org/news"));
+    iMapping.insert(QLatin1String("about_operationpage"), QLatin1String("skg://Skrooge_operation_plugin/"));
+    iMapping.insert(QLatin1String("about_accountpage"), QLatin1String("skg://Skrooge_bank_plugin/"));
+    iMapping.insert(QLatin1String("about_importurl"), QLatin1String("skg://import_operation/"));
+    iMapping.insert(QLatin1String("about_maintext"), i18nc("The main text of skrooge",
                     "Skrooge allows you to keep a hold on your expenses, by tracking and budgeting them.<br/>"
                     "What should you do now ?<br/>"
                     "<ul>"
@@ -760,32 +761,32 @@ void SKGReportBank::addItemsInMapping(QVariantHash& iMapping)
                     "For more information about using Skrooge, check the <a href=\"https://skrooge.org\">Skrooge website</a>.</p>"
                     "<p>We hope that you will enjoy Skrooge</p>"
                     "    The Skrooge Team",
-                    iMapping[QStringLiteral("about_accountpage")].toString(), iMapping[QStringLiteral("about_operationpage")].toString(), iMapping[QStringLiteral("about_importurl")].toString()));
-    iMapping.insert(QStringLiteral("logo"), QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("icons/breeze/apps/48/skrooge.svg"))).url());
-    iMapping.insert(QStringLiteral("logo_black"), QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("icons/breeze/apps/48/skrooge-black.svg"))).url());
+                    iMapping[QLatin1String("about_accountpage")].toString(), iMapping[QLatin1String("about_operationpage")].toString(), iMapping[QLatin1String("about_importurl")].toString()));
+    iMapping.insert(QLatin1String("logo"), QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("icons/breeze/apps/48/skrooge.svg"))).url());
+    iMapping.insert(QLatin1String("logo_black"), QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("icons/breeze/apps/48/skrooge-black.svg"))).url());
 
-    iMapping.insert(QStringLiteral("title_main"), i18nc("A monthly report title", "Report for %1", getPeriod()));
-    iMapping.insert(QStringLiteral("title_budget"), i18nc("A monthly report title", "Budget"));
-    iMapping.insert(QStringLiteral("title_main_categories"), i18nc("A monthly report title", "5 main categories of expenditure"));
-    iMapping.insert(QStringLiteral("title_variations"), i18nc("A monthly report title", "5 main variations"));
-    iMapping.insert(QStringLiteral("title_account"), i18nc("A monthly report title", "Amounts in accounts"));
-    iMapping.insert(QStringLiteral("title_unit"), i18nc("A monthly report title", "Amounts of units"));
-    iMapping.insert(QStringLiteral("title_advice"), i18nc("A monthly report title", "Advice"));
-    iMapping.insert(QStringLiteral("title_portfolio"), i18nc("A monthly report title", "Stock portfolio"));
-    iMapping.insert(QStringLiteral("title_interests"), i18nc("A monthly report title", "Estimated interests"));
-    iMapping.insert(QStringLiteral("title_alarms"), i18nc("A monthly report title", "Alarms"));
-    iMapping.insert(QStringLiteral("title_highlighted"), i18nc("A monthly report title", "Highlighted transactions"));
-    iMapping.insert(QStringLiteral("title_networth"), i18nc("A monthly report title", "Net Worth"));
-    iMapping.insert(QStringLiteral("title_annual_spending"), i18nc("A monthly report title", "Annual Spending"));
-    iMapping.insert(QStringLiteral("title_personal_finance_score"), i18nc("A monthly report title", "Personal Finance Score"));
-    iMapping.insert(QStringLiteral("title_incomes"), i18nc("Title of incomes", "Incomes:"));
-    iMapping.insert(QStringLiteral("title_expenditures"), i18nc("Title of expenditures", "Expenditures:"));
-    iMapping.insert(QStringLiteral("title_savings"), i18nc("Title of savings", "Savings:"));
+    iMapping.insert(QLatin1String("title_main"), i18nc("A monthly report title", "Report for %1", getPeriod()));
+    iMapping.insert(QLatin1String("title_budget"), i18nc("A monthly report title", "Budget"));
+    iMapping.insert(QLatin1String("title_main_categories"), i18nc("A monthly report title", "5 main categories of expenditure"));
+    iMapping.insert(QLatin1String("title_variations"), i18nc("A monthly report title", "5 main variations"));
+    iMapping.insert(QLatin1String("title_account"), i18nc("A monthly report title", "Amounts in accounts"));
+    iMapping.insert(QLatin1String("title_unit"), i18nc("A monthly report title", "Amounts of units"));
+    iMapping.insert(QLatin1String("title_advice"), i18nc("A monthly report title", "Advice"));
+    iMapping.insert(QLatin1String("title_portfolio"), i18nc("A monthly report title", "Stock portfolio"));
+    iMapping.insert(QLatin1String("title_interests"), i18nc("A monthly report title", "Estimated interests"));
+    iMapping.insert(QLatin1String("title_alarms"), i18nc("A monthly report title", "Alarms"));
+    iMapping.insert(QLatin1String("title_highlighted"), i18nc("A monthly report title", "Highlighted transactions"));
+    iMapping.insert(QLatin1String("title_networth"), i18nc("A monthly report title", "Net Worth"));
+    iMapping.insert(QLatin1String("title_annual_spending"), i18nc("A monthly report title", "Annual Spending"));
+    iMapping.insert(QLatin1String("title_personal_finance_score"), i18nc("A monthly report title", "Personal Finance Score"));
+    iMapping.insert(QLatin1String("title_incomes"), i18nc("Title of incomes", "Incomes:"));
+    iMapping.insert(QLatin1String("title_expenditures"), i18nc("Title of expenditures", "Expenditures:"));
+    iMapping.insert(QLatin1String("title_savings"), i18nc("Title of savings", "Savings:"));
 
-    iMapping.insert(QStringLiteral("msg_no_variation"), i18nc("A monthly report message", "No variation found."));
-    iMapping.insert(QStringLiteral("msg_no_scheduled"), i18nc("A monthly report message", R"(No scheduled transactions defined on the "<a href="%1">Scheduled transactions</a>" page.)", "skg://Skrooge_scheduled_plugin/"));
-    iMapping.insert(QStringLiteral("msg_no_highlighted"), i18nc("A monthly report message", R"(No highlighted transactions defined on the "<a href="%1">Transactions</a>" page.)", "skg://Skrooge_operation_plugin/"));
-    iMapping.insert(QStringLiteral("msg_no_budget"), i18nc("A monthly report message", R"(No budget defined on the "<a href="%1">Budget</a>" page.)", "skg://Skrooge_budget_plugin/"));
-    iMapping.insert(QStringLiteral("msg_no_share"), i18nc("A monthly report message", R"(No share defined on the "<a href="%1">Unit</a>" page.)", "skg://Skrooge_unit_plugin/"));
-    iMapping.insert(QStringLiteral("msg_amount_unit_date"), i18nc("A monthly report message", "All amounts are calculated using the unit rates of the last day of the corresponding period."));
+    iMapping.insert(QLatin1String("msg_no_variation"), i18nc("A monthly report message", "No variation found."));
+    iMapping.insert(QLatin1String("msg_no_scheduled"), i18nc("A monthly report message", R"(No scheduled transactions defined on the "<a href="%1">Scheduled transactions</a>" page.)", "skg://Skrooge_scheduled_plugin/"));
+    iMapping.insert(QLatin1String("msg_no_highlighted"), i18nc("A monthly report message", R"(No highlighted transactions defined on the "<a href="%1">Transactions</a>" page.)", "skg://Skrooge_operation_plugin/"));
+    iMapping.insert(QLatin1String("msg_no_budget"), i18nc("A monthly report message", R"(No budget defined on the "<a href="%1">Budget</a>" page.)", "skg://Skrooge_budget_plugin/"));
+    iMapping.insert(QLatin1String("msg_no_share"), i18nc("A monthly report message", R"(No share defined on the "<a href="%1">Unit</a>" page.)", "skg://Skrooge_unit_plugin/"));
+    iMapping.insert(QLatin1String("msg_amount_unit_date"), i18nc("A monthly report message", "All amounts are calculated using the unit rates of the last day of the corresponding period."));
 }
