@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGREPORTBANK_H
@@ -300,5 +300,5 @@ private:
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO(SKGReportBank, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(SKGReportBank, Q_COMPLEX_TYPE);
 #endif  // SKGREPORTBANK_H
