@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -21,7 +21,7 @@
 SKGSubOperationObject::SKGSubOperationObject(): SKGSubOperationObject(nullptr)
 {}
 
-SKGSubOperationObject::SKGSubOperationObject(SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, QStringLiteral("v_suboperation"), iID)
+SKGSubOperationObject::SKGSubOperationObject(SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, QLatin1String("v_suboperation"), iID)
 {}
 
 SKGSubOperationObject::~SKGSubOperationObject()
@@ -32,10 +32,10 @@ SKGSubOperationObject::SKGSubOperationObject(const SKGSubOperationObject& iObjec
 
 SKGSubOperationObject::SKGSubOperationObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable() == QStringLiteral("suboperation")) {
+    if (iObject.getRealTable() == QLatin1String("suboperation")) {
         copyFrom(iObject);
     } else {
-        *this = SKGObjectBase(iObject.getDocument(), QStringLiteral("v_suboperation"), iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), QLatin1String("v_suboperation"), iObject.getID());
     }
 }
 
@@ -53,47 +53,47 @@ SKGSubOperationObject& SKGSubOperationObject::operator= (const SKGSubOperationOb
 
 SKGError SKGSubOperationObject::setDate(QDate iDate)
 {
-    return setAttribute(QStringLiteral("d_date"), iDate.isValid() ? SKGServices::dateToSqlString(iDate) : QLatin1String(""));
+    return setAttribute(QLatin1String("d_date"), iDate.isValid() ? SKGServices::dateToSqlString(iDate) : QLatin1String(""));
 }
 
 QDate SKGSubOperationObject::getDate() const
 {
-    return SKGServices::stringToTime(getAttribute(QStringLiteral("d_date"))).date();
+    return SKGServices::stringToDate(getAttribute(QLatin1String("d_date")));
 }
 
 SKGError SKGSubOperationObject::setOrder(int iOrder)
 {
-    return setAttribute(QStringLiteral("i_order"), SKGServices::intToString(iOrder));
+    return setAttribute(QLatin1String("i_order"), SKGServices::intToString(iOrder));
 }
 
 int SKGSubOperationObject::getOrder() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_order")));
+    return SKGServices::stringToInt(getAttribute(QLatin1String("i_order")));
 }
 
 SKGError SKGSubOperationObject::setComment(const QString& iComment)
 {
-    return setAttribute(QStringLiteral("t_comment"), iComment);
+    return setAttribute(QLatin1String("t_comment"), iComment);
 }
 
 QString SKGSubOperationObject::getComment() const
 {
-    return getAttribute(QStringLiteral("t_comment"));
+    return getAttribute(QLatin1String("t_comment"));
 }
 
 QString SKGSubOperationObject::getFormula() const
 {
-    return getAttribute(QStringLiteral("t_formula"));
+    return getAttribute(QLatin1String("t_formula"));
 }
 
 SKGError SKGSubOperationObject::setFormula(const QString& iFormula)
 {
-    return setAttribute(QStringLiteral("t_formula"), iFormula);
+    return setAttribute(QLatin1String("t_formula"), iFormula);
 }
 
 SKGError SKGSubOperationObject::getParentOperation(SKGOperationObject& oOperation) const
 {
-    SKGError err = getDocument()->getObject(QStringLiteral("v_operation"), "id=" % getAttribute(QStringLiteral("rd_operation_id")), oOperation);
+    SKGError err = getDocument()->getObject(QLatin1String("v_operation"), "id=" % getAttribute(QLatin1String("rd_operation_id")), oOperation);
     return err;
 }
 
@@ -103,29 +103,29 @@ SKGError SKGSubOperationObject::setParentOperation(const SKGOperationObject& iOp
     if (!getDate().isValid()) {
         err = setDate(iOperation.getDate());
     }
-    IFOKDO(err, setAttribute(QStringLiteral("rd_operation_id"), SKGServices::intToString(iOperation.getID())))
+    IFOKDO(err, setAttribute(QLatin1String("rd_operation_id"), SKGServices::intToString(iOperation.getID())))
     return err;
 }
 
 SKGError SKGSubOperationObject::getCategory(SKGCategoryObject& oCategory) const
 {
-    SKGError err = getDocument()->getObject(QStringLiteral("v_category"), "id=" % getAttribute(QStringLiteral("r_category_id")), oCategory);
+    SKGError err = getDocument()->getObject(QLatin1String("v_category"), "id=" % getAttribute(QLatin1String("r_category_id")), oCategory);
     return err;
 }
 
 SKGError SKGSubOperationObject::setCategory(const SKGCategoryObject& iCategory)
 {
-    return setAttribute(QStringLiteral("r_category_id"), SKGServices::intToString(iCategory.getID()));
+    return setAttribute(QLatin1String("r_category_id"), SKGServices::intToString(iCategory.getID()));
 }
 
 SKGError SKGSubOperationObject::setQuantity(double iValue)
 {
-    return setAttribute(QStringLiteral("f_value"), SKGServices::doubleToString(iValue));
+    return setAttribute(QLatin1String("f_value"), SKGServices::doubleToString(iValue));
 }
 
 double SKGSubOperationObject::getQuantity() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_value")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_value")));
 }
 
 
@@ -140,7 +140,7 @@ SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker, boo
         } else if (!iForce && iTracker.isClosed()) {
             err = SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add a transaction in a closed tracker"));
         } else {
-            err = setAttribute(QStringLiteral("r_refund_id"), SKGServices::intToString(iTracker.getID()));
+            err = setAttribute(QLatin1String("r_refund_id"), SKGServices::intToString(iTracker.getID()));
         }
     }
     return err;
@@ -148,13 +148,13 @@ SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker, boo
 
 SKGError SKGSubOperationObject::getTracker(SKGTrackerObject& oTracker) const
 {
-    QString idS = getAttribute(QStringLiteral("r_refund_id"));
+    QString idS = getAttribute(QLatin1String("r_refund_id"));
     if (idS.isEmpty()) {
         idS = '0';
     }
     SKGError err;
-    if ((getDocument() != nullptr) && idS != QStringLiteral("0")) {
-        err = getDocument()->getObject(QStringLiteral("v_refund"), "id=" % idS, oTracker);
+    if ((getDocument() != nullptr) && idS != QLatin1String("0")) {
+        err = getDocument()->getObject(QLatin1String("v_refund"), "id=" % idS, oTracker);
     }
     return err;
 }
