@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -19,7 +19,7 @@
 SKGTrackerObject::SKGTrackerObject(): SKGTrackerObject(nullptr)
 {}
 
-SKGTrackerObject::SKGTrackerObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QStringLiteral("v_refund"), iID)
+SKGTrackerObject::SKGTrackerObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QLatin1String("v_refund"), iID)
 {}
 
 SKGTrackerObject::~SKGTrackerObject()
@@ -30,10 +30,10 @@ SKGTrackerObject::SKGTrackerObject(const SKGTrackerObject& iObject) = default;
 SKGTrackerObject::SKGTrackerObject(const SKGObjectBase& iObject)
 
 {
-    if (iObject.getRealTable() == QStringLiteral("refund")) {
+    if (iObject.getRealTable() == QLatin1String("refund")) {
         copyFrom(iObject);
     } else {
-        *this = SKGNamedObject(iObject.getDocument(), QStringLiteral("v_refund"), iObject.getID());
+        *this = SKGNamedObject(iObject.getDocument(), QLatin1String("v_refund"), iObject.getID());
     }
 }
 
@@ -61,7 +61,7 @@ SKGError SKGTrackerObject::createTracker(SKGDocumentBank* iDocument,
     if (iName.isEmpty()) {
         oTracker = SKGTrackerObject(nullptr, 0);
     } else if (iDocument != nullptr) {
-        iDocument->getObject(QStringLiteral("v_refund"), "t_name='" % SKGServices::stringToSqlString(iName) % '\'', oTracker);
+        iDocument->getObject(QLatin1String("v_refund"), "t_name='" % SKGServices::stringToSqlString(iName) % QLatin1Char('\''), oTracker);
         if (oTracker.getID() == 0) {
             // No, we have to create it
             oTracker = SKGTrackerObject(iDocument);
@@ -79,7 +79,7 @@ SKGError SKGTrackerObject::createTracker(SKGDocumentBank* iDocument,
 
 SKGError SKGTrackerObject::getSubOperations(SKGListSKGObjectBase& oSubOperations) const
 {
-    SKGError err = getDocument()->getObjects(QStringLiteral("v_suboperation"),
+    SKGError err = getDocument()->getObjects(QLatin1String("v_suboperation"),
                    "r_refund_id=" % SKGServices::intToString(getID()),
                    oSubOperations);
     return err;
@@ -87,27 +87,27 @@ SKGError SKGTrackerObject::getSubOperations(SKGListSKGObjectBase& oSubOperations
 
 SKGError SKGTrackerObject::setClosed(bool iClosed)
 {
-    return setAttribute(QStringLiteral("t_close"), iClosed ? QStringLiteral("Y") : QStringLiteral("N"));
+    return setAttribute(QLatin1String("t_close"), iClosed ? QLatin1String("Y") : QLatin1String("N"));
 }
 
 bool SKGTrackerObject::isClosed() const
 {
-    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y"));
+    return (getAttribute(QLatin1String("t_close")) == QLatin1String("Y"));
 }
 
 SKGError SKGTrackerObject::setComment(const QString& iComment)
 {
-    return setAttribute(QStringLiteral("t_comment"), iComment);
+    return setAttribute(QLatin1String("t_comment"), iComment);
 }
 
 QString SKGTrackerObject::getComment() const
 {
-    return getAttribute(QStringLiteral("t_comment"));
+    return getAttribute(QLatin1String("t_comment"));
 }
 
 double SKGTrackerObject::getCurrentAmount() const
 {
-    return SKGServices::stringToDouble(getAttributeFromView(QStringLiteral("v_refund_amount"), QStringLiteral("f_CURRENTAMOUNT")));
+    return SKGServices::stringToDouble(getAttributeFromView(QLatin1String("v_refund_amount"), QLatin1String("f_CURRENTAMOUNT")));
 }
 
 SKGError SKGTrackerObject::merge(const SKGTrackerObject& iTracker)
