@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -18,17 +18,17 @@
 SKGUnitValueObject::SKGUnitValueObject() : SKGUnitValueObject(nullptr)
 {}
 
-SKGUnitValueObject::SKGUnitValueObject(SKGDocument* iDocument, int iID) : SKGObjectBase(iDocument, QStringLiteral("v_unitvalue"), iID)
+SKGUnitValueObject::SKGUnitValueObject(SKGDocument* iDocument, int iID) : SKGObjectBase(iDocument, QLatin1String("v_unitvalue"), iID)
 {}
 
 SKGUnitValueObject::SKGUnitValueObject(const SKGUnitValueObject& iObject) = default;
 
 SKGUnitValueObject::SKGUnitValueObject(const SKGObjectBase& iObject)
 {
-    if (iObject.getRealTable() == QStringLiteral("unitvalue")) {
+    if (iObject.getRealTable() == QLatin1String("unitvalue")) {
         copyFrom(iObject);
     } else {
-        *this = SKGObjectBase(iObject.getDocument(), QStringLiteral("v_unitvalue"), iObject.getID());
+        *this = SKGObjectBase(iObject.getDocument(), QLatin1String("v_unitvalue"), iObject.getID());
     }
 }
 
@@ -49,22 +49,22 @@ SKGUnitValueObject::~SKGUnitValueObject()
 
 SKGError SKGUnitValueObject::setQuantity(double iValue)
 {
-    return setAttribute(QStringLiteral("f_quantity"), SKGServices::doubleToString(iValue));
+    return setAttribute(QLatin1String("f_quantity"), SKGServices::doubleToString(iValue));
 }
 
 double SKGUnitValueObject::getQuantity() const
 {
-    return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_quantity")));
+    return SKGServices::stringToDouble(getAttribute(QLatin1String("f_quantity")));
 }
 
 SKGError SKGUnitValueObject::setDate(QDate iDate)
 {
-    return setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(iDate));
+    return setAttribute(QLatin1String("d_date"), SKGServices::dateToSqlString(iDate));
 }
 
 QDate SKGUnitValueObject::getDate() const
 {
-    return SKGServices::stringToTime(getAttribute(QStringLiteral("d_date"))).date();
+    return SKGServices::stringToDate(getAttribute(QLatin1String("d_date")));
 }
 
 QString SKGUnitValueObject::getWhereclauseId() const
@@ -73,8 +73,8 @@ QString SKGUnitValueObject::getWhereclauseId() const
     QString output = SKGObjectBase::getWhereclauseId();
     if (output.isEmpty()) {
         // No, so we use the date and parent
-        if (!(getAttribute(QStringLiteral("d_date")).isEmpty()) && !(getAttribute(QStringLiteral("rd_unit_id")).isEmpty())) {
-            output = "d_date='" % getAttribute(QStringLiteral("d_date")) % "' AND rd_unit_id=" % getAttribute(QStringLiteral("rd_unit_id"));
+        if (!(getAttribute(QLatin1String("d_date")).isEmpty()) && !(getAttribute(QLatin1String("rd_unit_id")).isEmpty())) {
+            output = "d_date='" % getAttribute(QLatin1String("d_date")) % "' AND rd_unit_id=" % getAttribute(QLatin1String("rd_unit_id"));
         }
     }
     return output;
@@ -84,7 +84,7 @@ SKGError SKGUnitValueObject::getUnit(SKGUnitObject& oUnit) const
 {
     SKGError err;
     if (getDocument() != nullptr) {
-        err = getDocument()->getObject(QStringLiteral("v_unit"), "id=" % getAttribute(QStringLiteral("rd_unit_id")), oUnit);
+        err = getDocument()->getObject(QLatin1String("v_unit"), "id=" % getAttribute(QLatin1String("rd_unit_id")), oUnit);
     }
     return err;
 }
