@@ -28,7 +28,6 @@
 #include <qabstractitemview.h>
 #include <qapplication.h>
 #include <qcompleter.h>
-#include <qdesktopwidget.h>
 #include <qevent.h>
 #include <qlineedit.h>
 #include <qscreen.h>
@@ -47,8 +46,8 @@ KDateEdit::KDateEdit(QWidget* iParent)
 
     // Check if we can use the QLocale::ShortFormat
     mAlternativeDateFormatToUse = QLocale().dateFormat(QLocale::ShortFormat);
-    if (!mAlternativeDateFormatToUse.contains(QStringLiteral("yyyy"))) {
-        mAlternativeDateFormatToUse = mAlternativeDateFormatToUse.replace(QStringLiteral("yy"), QStringLiteral("yyyy"));
+    if (!mAlternativeDateFormatToUse.contains(QLatin1String("yyyy"))) {
+        mAlternativeDateFormatToUse = mAlternativeDateFormatToUse.replace(QLatin1String("yy"), QLatin1String("yyyy"));
     }
 
     mDate = QDate::currentDate();
