@@ -52,8 +52,8 @@ KDateValidator::KDateValidator(QObject* iParent)
 {
     // Check if we can use the QLocale::ShortFormat
     d->mAlternativeDateFormatToUse = QLocale().dateFormat(QLocale::ShortFormat);
-    if (!d->mAlternativeDateFormatToUse.contains(QStringLiteral("yyyy"))) {
-        d->mAlternativeDateFormatToUse = d->mAlternativeDateFormatToUse.replace(QStringLiteral("yy"), QStringLiteral("yyyy"));
+    if (!d->mAlternativeDateFormatToUse.contains(QLatin1String("yyyy"))) {
+        d->mAlternativeDateFormatToUse = d->mAlternativeDateFormatToUse.replace(QLatin1String("yy"), QLatin1String("yyyy"));
     }
 }
 
