@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -33,7 +33,7 @@ SKGBoardWidget::SKGBoardWidget(QWidget* iParent, SKGDocument* iDocument, const Q
     horizontalLayout->setSpacing(0);
     horizontalLayout->setContentsMargins(0, 0, 0, 0);
     m_frame = new QFrame(this);
-    m_frame->setObjectName(QStringLiteral("frame"));
+    m_frame->setObjectName(QLatin1String("frame"));
     m_frame->setFrameShape(QFrame::StyledPanel);
     m_frame->setFrameShadow(QFrame::Raised);
     m_gridLayout = new QGridLayout(m_frame);
@@ -76,7 +76,7 @@ SKGBoardWidget::SKGBoardWidget(QWidget* iParent, SKGDocument* iDocument, const Q
 
     auto pbFirst = new QPushButton(w);
     pbFirst->setToolTip(i18nc("Move tooltip", "Move first"));
-    pbFirst->setIcon(SKGServices::fromTheme(QStringLiteral("go-first-view")));
+    pbFirst->setIcon(SKGServices::fromTheme(QLatin1String("go-first-view")));
     pbFirst->setMaximumSize(QSize(22, 22));
     pbFirst->setFlat(true);
     connect(pbFirst, &QPushButton::clicked, this, &SKGBoardWidget::requestMoveFirst);
@@ -84,7 +84,7 @@ SKGBoardWidget::SKGBoardWidget(QWidget* iParent, SKGDocument* iDocument, const Q
 
     auto pbBefore = new QPushButton(w);
     pbBefore->setToolTip(i18nc("Move tooltip", "Move before"));
-    pbBefore->setIcon(SKGServices::fromTheme(QStringLiteral("go-previous-view")));
+    pbBefore->setIcon(SKGServices::fromTheme(QLatin1String("go-previous-view")));
     pbBefore->setMaximumSize(QSize(22, 22));
     pbBefore->setFlat(true);
     connect(pbBefore, &QPushButton::clicked, this, &SKGBoardWidget::requestMoveBefore);
@@ -92,7 +92,7 @@ SKGBoardWidget::SKGBoardWidget(QWidget* iParent, SKGDocument* iDocument, const Q
 
     auto pbDelete = new QPushButton(w);
     pbDelete->setToolTip(i18nc("Move tooltip", "Delete"));
-    pbDelete->setIcon(SKGServices::fromTheme(QStringLiteral("edit-delete")));
+    pbDelete->setIcon(SKGServices::fromTheme(QLatin1String("edit-delete")));
     pbDelete->setMaximumSize(QSize(22, 22));
     pbDelete->setFlat(true);
     connect(pbDelete, &QPushButton::clicked, this, &SKGBoardWidget::requestRemove);
@@ -100,7 +100,7 @@ SKGBoardWidget::SKGBoardWidget(QWidget* iParent, SKGDocument* iDocument, const Q
 
     auto pbAfter = new QPushButton(w);
     pbAfter->setToolTip(i18nc("Move tooltip", "Move after"));
-    pbAfter->setIcon(SKGServices::fromTheme(QStringLiteral("go-next-view")));
+    pbAfter->setIcon(SKGServices::fromTheme(QLatin1String("go-next-view")));
     pbAfter->setMaximumSize(QSize(22, 22));
     pbAfter->setFlat(true);
     connect(pbAfter, &QPushButton::clicked, this, &SKGBoardWidget::requestMoveAfter);
@@ -108,7 +108,7 @@ SKGBoardWidget::SKGBoardWidget(QWidget* iParent, SKGDocument* iDocument, const Q
 
     auto pbLast = new QPushButton(w);
     pbLast->setToolTip(i18nc("Move tooltip", "Move last"));
-    pbLast->setIcon(SKGServices::fromTheme(QStringLiteral("go-last-view")));
+    pbLast->setIcon(SKGServices::fromTheme(QLatin1String("go-last-view")));
     pbLast->setMaximumSize(QSize(22, 22));
     pbLast->setFlat(true);
     connect(pbLast, &QPushButton::clicked, this, &SKGBoardWidget::requestMoveLast);
@@ -129,7 +129,7 @@ SKGBoardWidget::SKGBoardWidget(QWidget* iParent, SKGDocument* iDocument, const Q
         addAction(zoomWidget);
     }
 
-    m_menuRename = new QAction(SKGServices::fromTheme(QStringLiteral("edit-rename")), i18nc("Verb, change the name of an item", "Rename"), this);
+    m_menuRename = new QAction(SKGServices::fromTheme(QLatin1String("edit-rename")), i18nc("Verb, change the name of an item", "Rename"), this);
     connect(m_menuRename, &QAction::triggered, this, &SKGBoardWidget::onRenameTitle);
     addAction(m_menuRename);
 
@@ -141,7 +141,7 @@ SKGBoardWidget::SKGBoardWidget(QWidget* iParent, SKGDocument* iDocument, const Q
     setMainTitle(iTitle);
 
     // Set default icon
-    m_toolButton->setIcon(SKGServices::fromTheme(QStringLiteral("configure")));
+    m_toolButton->setIcon(SKGServices::fromTheme(QLatin1String("configure")));
 }
 
 SKGBoardWidget::~SKGBoardWidget()
@@ -210,11 +210,11 @@ void SKGBoardWidget::setZoomRatio(double iRatio)
 
 void SKGBoardWidget::setState(const QString& iState)
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     if (doc.setContent(iState)) {
         QDomElement root = doc.documentElement();
 
-        QString title = root.attribute(QStringLiteral("title"));
+        QString title = root.attribute(QLatin1String("title"));
         if (!title.isEmpty()) {
             m_title = title;
             setMainTitle(title);
@@ -224,11 +224,11 @@ void SKGBoardWidget::setState(const QString& iState)
 
 QString SKGBoardWidget::getState()
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("title"), m_title);
+    root.setAttribute(QLatin1String("title"), m_title);
     return doc.toString();
 }
 
@@ -259,7 +259,7 @@ void SKGBoardWidget::insertAction(int iPos, QAction* iAction)
 
     // Change icon
     if (!iAction->isCheckable() && !iAction->isSeparator()) {
-        m_toolButton->setIcon(SKGServices::fromTheme(QStringLiteral("run-build-configure")));
+        m_toolButton->setIcon(SKGServices::fromTheme(QLatin1String("run-build-configure")));
     }
 }
 
@@ -285,7 +285,7 @@ void SKGBoardWidget::addAction(QAction* iAction)
 
     // Change icon
     if (!iAction->isCheckable() && !iAction->isSeparator()) {
-        m_toolButton->setIcon(SKGServices::fromTheme(QStringLiteral("run-build-configure")));
+        m_toolButton->setIcon(SKGServices::fromTheme(QLatin1String("run-build-configure")));
     }
 }
 
