@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -24,8 +24,8 @@ SKGFilteredTableView::SKGFilteredTableView(QWidget* iParent)
     ui.kTitle->hide();
     ui.kResetInternalFilter->hide();
     connect(ui.kResetInternalFilter, &QToolButton::clicked, this, &SKGFilteredTableView::resetFilter);
-    ui.kResetInternalFilter->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-cancel")));
-    ui.kConfigure->setIcon(SKGServices::fromTheme(QStringLiteral("configure")));
+    ui.kResetInternalFilter->setIcon(SKGServices::fromTheme(QLatin1String("dialog-cancel")));
+    ui.kConfigure->setIcon(SKGServices::fromTheme(QLatin1String("configure")));
 
     ui.kConfigure->setPopupMode(QToolButton::InstantPopup);
     ui.kConfigure->setAutoRaise(true);
@@ -49,26 +49,26 @@ SKGFilteredTableView::~SKGFilteredTableView()
 
 QString SKGFilteredTableView::getState()
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("show"), ui.kShow->getState());
-    root.setAttribute(QStringLiteral("filter"), getSearchField()->text());
+    root.setAttribute(QLatin1String("show"), ui.kShow->getState());
+    root.setAttribute(QLatin1String("filter"), getSearchField()->text());
 
     // Memorize table settings
-    root.setAttribute(QStringLiteral("view"), ui.kView->getState());
+    root.setAttribute(QLatin1String("view"), ui.kView->getState());
     return doc.toString();
 }
 
 void SKGFilteredTableView::setState(const QString& iState)
 {
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString show2 = root.attribute(QStringLiteral("show"));
-    QString filter = root.attribute(QStringLiteral("filter"));
+    QString show2 = root.attribute(QLatin1String("show"));
+    QString filter = root.attribute(QLatin1String("filter"));
 
     if (!show2.isEmpty()) {
         ui.kShow->setState(show2);
@@ -82,7 +82,7 @@ void SKGFilteredTableView::setState(const QString& iState)
     }
 
     // !!! Must be done here after onFilterChanged
-    ui.kView->setState(root.attribute(QStringLiteral("view")));
+    ui.kView->setState(root.attribute(QLatin1String("view")));
 }
 
 SKGShow* SKGFilteredTableView::getShowWidget() const
