@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -13,6 +13,7 @@
 
 #include <qlayout.h>
 #include <qwidget.h>
+#include <utility>
 
 SKGFlowLayout::SKGFlowLayout(QWidget* iParent, int iMargin, int hSpacing, int vSpacing)
     : QLayout(iParent), m_hSpace(hSpacing), m_vSpace(vSpacing)
@@ -113,7 +114,7 @@ QSize SKGFlowLayout::sizeHint() const
 QSize SKGFlowLayout::minimumSize() const
 {
     QSize size;
-    for (auto item : qAsConst(m_itemList)) {
+    for (auto item : std::as_const(m_itemList)) {
         size = size.expandedTo(item->minimumSize());
     }
     int left, top, right, bottom;
@@ -133,7 +134,7 @@ int SKGFlowLayout::doLayout(const QRect rect, bool testOnly) const
     int x1 = x;
     int y1 = y;
 
-    for (auto item : qAsConst(m_itemList)) {
+    for (auto item : std::as_const(m_itemList)) {
         QWidget* wid = item->widget();
         if (wid != nullptr) {
             // Get spaces
