@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGFLOWLAYOUT_H
@@ -55,7 +55,11 @@ public:
      * Set horizontal and vertical spacing
      * @param space the space
      */
+#ifdef SKG_QT6
+    virtual void setSpacing(int space) override;
+#else
     virtual void setSpacing(int space);
+#endif
 
     /**
      * Get horizontal spacing
