@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -27,6 +27,7 @@
 #include "skgmainpanel.h"
 #include "skgreport.h"
 #include "skgtraces.h"
+#include <utility>
 
 SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, QStringList  iTablesRefreshing, SKGSimplePeriodEdit::Modes iOptions, const QStringList& iAttributesForFilter)
     : SKGBoardWidget(iParent, iDocument, iTitle), m_Quick(nullptr), m_Report(iDocument->getReport()),  m_Text(nullptr), m_Template(iTemplate), m_TablesRefreshing(std::move(iTablesRefreshing)), m_refreshNeeded(false), m_period(nullptr), m_filter(nullptr), m_attributes(iAttributesForFilter)
@@ -42,7 +43,7 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
         QDate date = QDate::currentDate();
         QStringList list;
         // TODO(Stephane MANKOWSKI): v_operation_display must be generic
-        getDocument()->getDistinctValues(QStringLiteral("v_operation_display"), QStringLiteral("MIN(d_DATEMONTH)"), QStringLiteral("d_date<=CURRENT_DATE"), list);
+        getDocument()->getDistinctValues(QLatin1String("v_operation_display"), QLatin1String("MIN(d_DATEMONTH)"), QLatin1String("d_date<=CURRENT_DATE"), list);
         if (!list.isEmpty()) {
             if (!list[0].isEmpty()) {
                 date = SKGServices::periodToDate(list[0]);
@@ -72,14 +73,14 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
 
     // Create main widget
     QString ext = QFileInfo(iTemplate).suffix().toLower();
-    if (ext == QStringLiteral("qml")) {
+    if (ext == QLatin1String("qml")) {
         // Mode QML
         m_Quick = new QQuickWidget(this);
         m_Quick->setResizeMode(QQuickWidget::SizeViewToRootObject);
         m_Quick->setClearColor(Qt::transparent);
         m_Quick->setAttribute(Qt::WA_AlwaysStackOnTop);
         m_Quick->setAttribute(Qt::WA_TranslucentBackground);
-        m_Quick->setObjectName(QStringLiteral("m_Quick"));
+        m_Quick->setObjectName(QLatin1String("m_Quick"));
         QSizePolicy newSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
         newSizePolicy.setHorizontalStretch(0);
         newSizePolicy.setVerticalStretch(0);
@@ -88,18 +89,18 @@ SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument,
         // Set properties
         QVariantHash mapping = m_Report->getContextProperty();
         auto keys = mapping.keys();
-        for (const auto& k : qAsConst(keys)) {
+        for (const auto& k : std::as_const(keys)) {
             m_Quick->rootContext()->setContextProperty(k, mapping[k]);
         }
-        m_Quick->rootContext()->setContextProperty(QStringLiteral("periodWidget"), m_period);
-        m_Quick->rootContext()->setContextProperty(QStringLiteral("filterWidget"), m_filter);
-        m_Quick->rootContext()->setContextProperty(QStringLiteral("panel"), SKGMainPanel::getMainPanel());
+        m_Quick->rootContext()->setContextProperty(QLatin1String("periodWidget"), m_period);
+        m_Quick->rootContext()->setContextProperty(QLatin1String("filterWidget"), m_filter);
+        m_Quick->rootContext()->setContextProperty(QLatin1String("panel"), SKGMainPanel::getMainPanel());
 
         setMainWidget(m_Quick);
     } else {
         // Mode template HTML
         m_Text = new QLabel(this);
-        m_Text->setObjectName(QStringLiteral("m_Text"));
+        m_Text->setObjectName(QLatin1String("m_Text"));
         m_Text->setTextFormat(Qt::RichText);
         m_Text->setAlignment(Qt::AlignLeading | Qt::AlignLeft | Qt::AlignTop);
         m_Text->setTextInteractionFlags(Qt::TextBrowserInteraction);
@@ -134,23 +135,26 @@ SKGHtmlBoardWidget::~SKGHtmlBoardWidget()
     }
     if (m_Quick != nullptr) {
         m_Quick->setParent(nullptr); // To be sure that deletion is well managed
-        m_Quick->rootObject()->deleteLater();
+        auto tmp = m_Quick->rootObject();
+        if (tmp) {
+            tmp->deleteLater();
+        }
     }
 }
 
 QString SKGHtmlBoardWidget::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
     // Get state
     if (m_period != nullptr) {
-        root.setAttribute(QStringLiteral("period"), m_period->text());
+        root.setAttribute(QLatin1String("period"), m_period->text());
     }
     if (m_filter != nullptr) {
-        root.setAttribute(QStringLiteral("filter"), m_filter->text());
+        root.setAttribute(QLatin1String("filter"), m_filter->text());
     }
     return doc.toString();
 }
@@ -160,24 +164,24 @@ void SKGHtmlBoardWidget::setState(const QString& iState)
     SKGTRACEINFUNC(10)
     SKGBoardWidget::setState(iState);
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     // Set state
     if (m_period != nullptr) {
-        QString oldMode = root.attribute(QStringLiteral("previousMonth"));
+        QString oldMode = root.attribute(QLatin1String("previousMonth"));
         if (oldMode.isEmpty()) {
-            QString period = root.attribute(QStringLiteral("period"));
+            QString period = root.attribute(QLatin1String("period"));
             if (!period.isEmpty() && m_period->contains(period)) {
                 m_period->setText(period);
             }
         } else {
-            m_period->setText(oldMode == QStringLiteral("N") ? i18nc("The current month", "Current month") : i18nc("The month before the current month", "Last month"));
+            m_period->setText(oldMode == QLatin1String("N") ? i18nc("The current month", "Current month") : i18nc("The month before the current month", "Last month"));
         }
     }
     if (m_filter != nullptr) {
-        QString filter = root.attribute(QStringLiteral("filter"));
+        QString filter = root.attribute(QLatin1String("filter"));
         m_filter->setText(filter);
     }
     dataModified(QLatin1String(""), 0);
@@ -236,13 +240,13 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
     // Set title
     QString period = (m_period != nullptr ? m_period->period() : QLatin1String(""));
     QString title = getOriginalTitle();
-    if (title.contains(QStringLiteral("%1"))) {
+    if (title.contains(QLatin1String("%1"))) {
         setMainTitle(title.arg(period));
     }
     QString filterSQL;
     QString filterTXT;
     if (m_Report != nullptr) {
-        m_Report->setPeriod((m_period != nullptr ? m_period->period() : SKGServices::dateToPeriod(QDate::currentDate(), QStringLiteral("M"))));
+        m_Report->setPeriod((m_period != nullptr ? m_period->period() : SKGServices::dateToPeriod(QDate::currentDate(), QLatin1String("M"))));
         if (m_filter) {
             filterSQL = SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(m_filter->text()),
                         m_attributes,
@@ -267,8 +271,8 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
 
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         if (m_Quick != nullptr) {
-            m_Quick->rootContext()->setContextProperty(QStringLiteral("filterWidget_sql"), filterSQL);
-            m_Quick->rootContext()->setContextProperty(QStringLiteral("filterWidget_txt"), filterTXT);
+            m_Quick->rootContext()->setContextProperty(QLatin1String("filterWidget_sql"), filterSQL);
+            m_Quick->rootContext()->setContextProperty(QLatin1String("filterWidget_txt"), filterTXT);
 
             // Set the source
             if (!m_Quick->source().isValid()) {
@@ -300,12 +304,12 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
             QString stream;
             SKGError err = SKGReport::getReportFromTemplate(m_Report, m_Template, stream);
             IFKO(err) stream = err.getFullMessage();
-            stream = stream.remove(QRegularExpression(QStringLiteral("<img[^>]*/>")));
+            stream = stream.remove(QRegularExpression(QLatin1String("<img[^>]*/>")));
 
             // Remove color of hyperlinks
             KColorScheme scheme(QPalette::Normal, KColorScheme::Window);
             auto color = scheme.foreground(KColorScheme::NormalText).color().name().right(6);
-            stream = stream.replace(QStringLiteral("<a href"), QStringLiteral("<a style=\"color: #") + color + ";\" href");
+            stream = stream.replace(QLatin1String("<a href"), QLatin1String("<a style=\"color: #") + color + ";\" href");
 
             m_Text->setText(stream);
 
@@ -316,7 +320,7 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
 
     // TODO(Stephane MANKOWSKI): No widget if no account (must not be hardcoded)
     bool exist = false;
-    getDocument()->existObjects(QStringLiteral("account"), QLatin1String(""), exist);
+    getDocument()->existObjects(QLatin1String("account"), QLatin1String(""), exist);
     if (parentWidget() != nullptr) {
         setVisible(exist);
     }
