@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -26,6 +26,7 @@
 #include "skgpropertyobject.h"
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
+#include <utility>
 
 SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
                                        const QString& iTable,
@@ -114,7 +115,7 @@ void SKGObjectModelBase::setSupportedAttributes(const QStringList& iListAttribut
             m_listSupported.push_back(att);
             bool visible = true;
             if (nbValues > 1) {
-                visible = (i == 0 || values.at(1) == QStringLiteral("Y"));    // First column is always visible to support grouping
+                visible = (i == 0 || values.at(1) == QLatin1String("Y"));    // First column is always visible to support grouping
             }
             m_listVisibility.push_back(visible);
             if (nbValues > 2) {
@@ -192,9 +193,9 @@ SKGDocument* SKGObjectModelBase::getDocument() const
 void SKGObjectModelBase::buidCache()
 {
     SKGTRACEINFUNC(1)
-    m_doctransactionTable = (getRealTable() == QStringLiteral("doctransaction"));
-    m_nodeTable = (getRealTable() == QStringLiteral("node"));
-    m_parametersTable = (getRealTable() == QStringLiteral("parameters"));
+    m_doctransactionTable = (getRealTable() == QLatin1String("doctransaction"));
+    m_nodeTable = (getRealTable() == QLatin1String("node"));
+    m_parametersTable = (getRealTable() == QLatin1String("parameters"));
 
     // Get std colors
     KColorScheme scheme(QPalette::Normal);
@@ -267,8 +268,8 @@ void SKGObjectModelBase::refresh()
                 nb = m_listAttibutes.count();
                 for (int i = nb - 1 ; i >= 0 ; --i) {
                     QString att = m_listAttibutes.at(i);
-                    if (att.contains(QStringLiteral("_REAL"))) {
-                        att.replace(QStringLiteral("_REAL"), QStringLiteral("_"));
+                    if (att.contains(QLatin1String("_REAL"))) {
+                        att.replace(QLatin1String("_REAL"), QLatin1String("_"));
                         int p = m_listAttibutes.indexOf(att);
                         if (p == -1) {
                             att = att.toLower();
@@ -289,7 +290,7 @@ void SKGObjectModelBase::refresh()
             QString wc = m_whereClause;
             if (!m_groupby.isEmpty()) {
                 if (wc.isEmpty()) {
-                    wc = QStringLiteral("1=1");
+                    wc = QLatin1String("1=1");
                 }
                 if (m_groupby.startsWith(QLatin1String("p_"))) {
                     wc += " ORDER BY (SELECT t_value FROM parameters WHERE t_uuid_parent=" % getTable() % ".id||'-" % getRealTable() % "' AND t_name='" % m_groupby % "')";
@@ -313,7 +314,7 @@ void SKGObjectModelBase::refresh()
 
             bool groupByNum = (m_groupby.startsWith(QLatin1String("f_")) || m_groupby.startsWith(QLatin1String("i_")));
             int nb = m_listObjects.count();
-            SKGTRACEL(1) << nb << " objects found" << SKGENDL;
+            SKGTRACEL(1) << nb << " objects found" << Qt::endl;
             for (int t = 0; t < nb; ++t) {
                 auto c = new SKGObjectBase(m_listObjects.at(t));
                 int id = (c != nullptr ? c->getID() : 0);
@@ -331,7 +332,7 @@ void SKGObjectModelBase::refresh()
                     // Grouping on specified attribute
                     QString att = getAttributeForGrouping(*c, m_groupby);
                     if (groupByDate) {
-                        QDate date = SKGServices::stringToTime(att).date();
+                        QDate date = SKGServices::stringToDate(att);
                         if (date == QDate::currentDate()) {
                             att = i18nc("A group name for grouping by date attibute", "Today");
                         } else if (date > QDate::currentDate()) {
@@ -406,7 +407,7 @@ void SKGObjectModelBase::refresh()
                         currentGroup = std::move(att);
                         currentGoupId--;
                         auto group = new SKGObjectBase(m_document, QLatin1String(""), currentGoupId);
-                        group->setAttribute(QStringLiteral("t_title"), currentGroup);
+                        group->setAttribute(QLatin1String("t_title"), currentGroup);
 
                         m_childParentRelations.insert(currentGoupId, 0);
 
@@ -489,7 +490,7 @@ QModelIndex SKGObjectModelBase::index(int row, int column, const QModelIndex& iP
 
     int idChild = m_parentChildRelations.value(idParent).at(row);
 
-    // SKGTRACE << table << "-" << idParent << "(" << row << ") ==> " << idChild << SKGENDL;
+    // SKGTRACE << table << "-" << idParent << "(" << row << ") ==> " << idChild << Qt::endl;
     return (idChild != 0 ? createIndex(row, column, idChild) : QModelIndex());
 }
 
@@ -507,7 +508,7 @@ QModelIndex SKGObjectModelBase::parent(const QModelIndex& iIndex) const
 
     int idParent = m_childParentRelations.value(idChild);
     int row = m_objectsHashTableRows.value(idParent);
-    // SKGTRACE << table << "-" << idChild << "(" << row << ") <== " << idParent << SKGENDL;
+    // SKGTRACE << table << "-" << idChild << "(" << row << ") <== " << idParent << Qt::endl;
     return idParent != 0 ? createIndex(row, 0, idParent) : QModelIndex();
 }
 
@@ -515,7 +516,7 @@ int SKGObjectModelBase::getIndexAttribute(const QString& iAttributeName) const
 {
     int output = m_listAttibutes.indexOf(iAttributeName);
     if (output == -1) {
-        SKGTRACE << "[" << iAttributeName << "] not found in [" << getRealTable() << "]" << SKGENDL;
+        SKGTRACE << "[" << iAttributeName << "] not found in [" << getRealTable() << "]" << Qt::endl;
     }
     return output;
 }
@@ -543,7 +544,7 @@ QVariant SKGObjectModelBase::headerData(int iSection, Qt::Orientation iOrientati
                 att = SKGServices::intToString(iSection);
             }
 
-            return getDocument()->getDisplay(getTable() % '.' % att).remove(getTable() % '.');
+            return getDocument()->getDisplay(getTable() % QLatin1Char('.') % att).remove(getTable() % QLatin1Char('.'));
         }
         if (iRole == Qt::UserRole) {
             QString att;
@@ -555,14 +556,14 @@ QVariant SKGObjectModelBase::headerData(int iSection, Qt::Orientation iOrientati
 
             int indexAtt = m_listSupported.indexOf(att);
 
-            att = getDocument()->getDisplay(getTable() % '.' % att).remove(getTable() % '.');
+            att = getDocument()->getDisplay(getTable() % QLatin1Char('.') % att).remove(getTable() % QLatin1Char('.'));
 
 
             if (indexAtt >= 0 && indexAtt < m_listVisibility.count()) {
                 bool visible = m_listVisibility.at(indexAtt);
-                att += QStringLiteral("|") % (visible ? QStringLiteral("Y") : QStringLiteral("N"));
+                att += QLatin1String("|") % (visible ? QLatin1String("Y") : QLatin1String("N"));
                 if (indexAtt >= 0 && indexAtt < m_listSize.count()) {
-                    att += '|' % SKGServices::intToString(m_listSize.at(indexAtt));
+                    att += QLatin1Char('|') % SKGServices::intToString(m_listSize.at(indexAtt));
                 }
             }
             return att;
@@ -575,7 +576,7 @@ QVariant SKGObjectModelBase::headerData(int iSection, Qt::Orientation iOrientati
                 att = SKGServices::intToString(iSection);
             }
 
-            return getDocument()->getIcon(getTable() % '.' % att);
+            return getDocument()->getIcon(getTable() % QLatin1Char('.') % att);
         }
     }
     return QVariant();
@@ -648,9 +649,9 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
                 int nb = rowCount(iIndex);
 
                 // Is it possible to compute sums of f_CURRENTAMOUNT ?
-                int posAmount = m_listAttibutes.indexOf(QStringLiteral("f_CURRENTAMOUNT"));
+                int posAmount = m_listAttibutes.indexOf(QLatin1String("f_CURRENTAMOUNT"));
                 if (posAmount == -1) {
-                    posAmount = m_listAttibutes.indexOf(QStringLiteral("f_REALCURRENTAMOUNT"));
+                    posAmount = m_listAttibutes.indexOf(QLatin1String("f_REALCURRENTAMOUNT"));
                 }
                 if (posAmount != -1 && nb > 0) {
                     // Compute sums
@@ -668,7 +669,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
 
                     return i18nc("How to display a grouping title. Here \"title (count) Sum= [min , average , max]\"", "%1: %2 (%3) Sum=%4 [%5 , %6 , %7]",
                                  getDocument()->getDisplay(m_groupby),
-                                 obj->getAttribute(QStringLiteral("t_title")),
+                                 obj->getAttribute(QLatin1String("t_title")),
                                  nb,
                                  formatMoney(sum),
                                  formatMoney(min),
@@ -677,7 +678,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
                 }
                 return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
                              getDocument()->getDisplay(m_groupby),
-                             obj->getAttribute(QStringLiteral("t_title")),
+                             obj->getAttribute(QLatin1String("t_title")),
                              nb);
             }
             return "";
@@ -685,7 +686,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
         QString val;
         if (att.startsWith(QLatin1String("p_"))) {
             // This is a property
-            val = obj->getProperty(att.right(att.count() - 2));
+            val = obj->getProperty(att.right(att.size() - 2));
         } else {
             // This is a real attribute
             val = obj->getAttribute(att);
@@ -699,7 +700,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
                 return SKGServices::stringToInt(val);
             }
             case SKGServices::DATE: {
-                QDate dval = SKGServices::stringToTime(val).date();
+                QDate dval = SKGServices::stringToDate(val);
                 if (iRole == Qt::DisplayRole) {
                     return SKGMainPanel::dateToString(dval);
                 }
@@ -711,7 +712,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
             }
             }
 
-            if (m_doctransactionTable && att == QStringLiteral("t_savestep")) {
+            if (m_doctransactionTable && att == QLatin1String("t_savestep")) {
                 return "";
             }
         }
@@ -779,7 +780,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
         if (obj->getTable().isEmpty()) {
             // This is a group
             if (iIndex.column() == 0) {
-                return QVariant::fromValue(SKGServices::fromTheme(QStringLiteral("arrow-right")));
+                return QVariant::fromValue(SKGServices::fromTheme(QLatin1String("arrow-right")));
             };
             return "";
         }
@@ -788,11 +789,11 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
             return QVariant::fromValue(node.getIcon());
         }
         if (iIndex.column() == 0 && m_doctransactionTable) {
-            return QVariant::fromValue(SKGServices::fromTheme(obj->getAttribute(QStringLiteral("t_mode")) == QStringLiteral("U") ? QStringLiteral("edit-undo") : QStringLiteral("edit-redo")));
+            return QVariant::fromValue(SKGServices::fromTheme(obj->getAttribute(QLatin1String("t_mode")) == QLatin1String("U") ? QLatin1String("edit-undo") : QLatin1String("edit-redo")));
         }
-        if (m_doctransactionTable && att == QStringLiteral("t_savestep")) {
-            if (obj->getAttribute(QStringLiteral("t_savestep")) == QStringLiteral("Y")) {
-                return QVariant::fromValue(SKGServices::fromTheme(QStringLiteral("document-save")));
+        if (m_doctransactionTable && att == QLatin1String("t_savestep")) {
+            if (obj->getAttribute(QLatin1String("t_savestep")) == QLatin1String("Y")) {
+                return QVariant::fromValue(SKGServices::fromTheme(QLatin1String("document-save")));
             }
         }
 
@@ -820,7 +821,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
                 QString att = m_listAttibutes.at(iIndex.column());
                 QString val = obj->getAttribute(att);
 
-                QDate dval = SKGServices::stringToTime(val).date();
+                QDate dval = SKGServices::stringToDate(val);
                 QString fancyDate = QLocale().toString(dval, QLocale::LongFormat);
                 QString shortDate = QLocale().toString(dval, QLocale::ShortFormat);
 
@@ -834,7 +835,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
             if (!props.isEmpty() && !toolTipString.isEmpty()) {
                 toolTipString += '\n';
             }
-            for (const auto& prop : qAsConst(props)) {
+            for (const auto& prop : std::as_const(props)) {
                 if (!toolTipString.isEmpty()) {
                     toolTipString += '\n';
                 }
@@ -851,7 +852,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
     case 99: {
         SKGObjectBase* obj = getObjectPointer(iIndex);
         if (obj != nullptr) {
-            return SKGServices::stringToDouble(obj->getAttribute(QStringLiteral("f_sortorder")));
+            return SKGServices::stringToDouble(obj->getAttribute(QLatin1String("f_sortorder")));
         }
         break;
     }
@@ -860,11 +861,11 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
         // Is it a URL ?
         QString att = m_listAttibutes.at(iIndex.column());
         if (att.startsWith(QLatin1String("p_"))) {
-            SKGPropertyObject p(obj->getPropertyObject(att.right(att.count() - 2)));
+            SKGPropertyObject p(obj->getPropertyObject(att.right(att.size() - 2)));
             if (!p.getUrl().scheme().isEmpty()) {
                 return QVariant::fromValue(p.getID());
             }
-        } else if (m_parametersTable && att == QStringLiteral("t_value")) {
+        } else if (m_parametersTable && att == QLatin1String("t_value")) {
             SKGPropertyObject p(*obj);
             if (!p.getUrl().scheme().isEmpty()) {
                 return QVariant::fromValue(p.getID());
@@ -951,8 +952,8 @@ QStringList SKGObjectModelBase::mimeTypes() const
 {
     QStringList types;
     types << "application/skg." % getRealTable() % ".ids";
-    types << QStringLiteral("application/data");
-    types << QStringLiteral("text/uri-list");
+    types << QLatin1String("application/data");
+    types << QLatin1String("text/uri-list");
     return types;
 }
 
@@ -964,7 +965,7 @@ QMimeData* SKGObjectModelBase::mimeData(const QModelIndexList& iIndexes) const
     QDataStream stream(&encodedData, QIODevice::WriteOnly);
 
     QString t = getTable();
-    for (const auto& idx : qAsConst(iIndexes)) {
+    for (const auto& idx : std::as_const(iIndexes)) {
         if (idx.isValid() && idx.column() == 0) {
             SKGObjectBase obj = getObject(idx);
             t = obj.getRealTable();
@@ -986,7 +987,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
     if (iAction == Qt::IgnoreAction) {
         return true;
     }
-    if ((iData == nullptr) || !(iData->hasFormat(QStringLiteral("application/skg.node.ids")) || iData->hasUrls())) {
+    if ((iData == nullptr) || !(iData->hasFormat(QLatin1String("application/skg.node.ids")) || iData->hasUrls())) {
         return false;    // TODO(Stephane MANKOWSKI): accept all
     }
     if (iColumn > 0) {
@@ -995,7 +996,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
 
     SKGError err;
     // Drop files
-    if (iData->hasUrls() && iParent.isValid() && getRealTable() != QStringLiteral("node")) {
+    if (iData->hasUrls() && iParent.isValid() && getRealTable() != QLatin1String("node")) {
         QList<QUrl> urls = iData->urls();
         int nb = urls.count();
         {
@@ -1007,7 +1008,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
                 int idx = 1;
                 while (!err && !obj.getProperty(name).isEmpty()) {
                     idx++;
-                    name = i18n("File") % " (" % SKGServices::intToString(idx) % ')';
+                    name = i18n("File") % " (" % SKGServices::intToString(idx) % QLatin1Char(')');
                 }
                 QString f = urls.at(i).toLocalFile();
                 err = obj.setProperty(name, f, iAction == Qt::LinkAction ? QLatin1String("") : f);
@@ -1017,9 +1018,9 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
                 IFOKDO(err, getDocument()->stepForward(i + 1))
             }
         }
-    } else if (iData->hasFormat(QStringLiteral("application/skg.node.ids"))) {
+    } else if (iData->hasFormat(QLatin1String("application/skg.node.ids"))) {
         // Drop nodes
-        QByteArray encodedData = iData->data(QStringLiteral("application/skg.node.ids"));
+        QByteArray encodedData = iData->data(QLatin1String("application/skg.node.ids"));
         QDataStream stream(&encodedData, QIODevice::ReadOnly);
         QStringList newItems;
 
@@ -1099,8 +1100,8 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
 {
     if (getTable() == iTableName || iTableName.isEmpty()) {
         SKGTRACEINFUNC(1)
-        SKGTRACEL(1) << "getTable=" << getRealTable() << SKGENDL;
-        SKGTRACEL(1) << "Parameters=" << iTableName << " , " << iIdTransaction << SKGENDL;
+        SKGTRACEL(1) << "getTable=" << getRealTable() << Qt::endl;
+        SKGTRACEL(1) << "Parameters=" << iTableName << " , " << iIdTransaction << Qt::endl;
         SKGTabPage* page = SKGTabPage::parentTabPage(qobject_cast< QWidget* >(this->QObject::parent()));
         SKGTabPage* cpage = SKGMainPanel::getMainPanel() != nullptr ? SKGMainPanel::getMainPanel()->currentPage() : nullptr;
         if (page != nullptr && page != cpage) {
@@ -1120,7 +1121,7 @@ QString SKGObjectModelBase::getAttributeForGrouping(const SKGObjectBase& iObject
 {
     if (iAttribute.startsWith(QLatin1String("p_"))) {
         // This is a property
-        return iObject.getProperty(iAttribute.right(iAttribute.count() - 2));
+        return iObject.getProperty(iAttribute.right(iAttribute.size() - 2));
     }
     // This is a real attribute
     return iObject.getAttribute(iAttribute);
