@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -55,19 +55,19 @@ SKGPeriodEdit::~SKGPeriodEdit()
 QString SKGPeriodEdit::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("period"), SKGServices::intToString(mode()));
+    root.setAttribute(QLatin1String("period"), SKGServices::intToString(mode()));
     if (mode() == CUSTOM) {
-        root.setAttribute(QStringLiteral("date_begin"), SKGServices::intToString(ui.kDateBegin->date().toJulianDay()));
-        root.setAttribute(QStringLiteral("date_end"), SKGServices::intToString(ui.kDateEnd->date().toJulianDay()));
+        root.setAttribute(QLatin1String("date_begin"), SKGServices::intToString(ui.kDateBegin->date().toJulianDay()));
+        root.setAttribute(QLatin1String("date_end"), SKGServices::intToString(ui.kDateEnd->date().toJulianDay()));
     }
-    root.setAttribute(QStringLiteral("interval"), SKGServices::intToString(ui.kInterval->itemData(ui.kInterval->currentIndex()).toInt()));
-    root.setAttribute(QStringLiteral("nb_intervals"), SKGServices::intToString(ui.kNbIntervals->value()));
-    root.setAttribute(QStringLiteral("timeline"), SKGServices::intToString(ui.kTimeline->value()));
-    root.setAttribute(QStringLiteral("future"), ui.kFuture->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QLatin1String("interval"), SKGServices::intToString(ui.kInterval->itemData(ui.kInterval->currentIndex()).toInt()));
+    root.setAttribute(QLatin1String("nb_intervals"), SKGServices::intToString(ui.kNbIntervals->value()));
+    root.setAttribute(QLatin1String("timeline"), SKGServices::intToString(ui.kTimeline->value()));
+    root.setAttribute(QLatin1String("future"), ui.kFuture->isChecked() ? QLatin1String("Y") : QLatin1String("N"));
 
     return doc.toString();
 }
@@ -76,17 +76,17 @@ void SKGPeriodEdit::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    QString period = root.attribute(QStringLiteral("period"));
-    QString interval = root.attribute(QStringLiteral("interval"));
-    QString nb_interval = root.attribute(QStringLiteral("nb_intervals"));
-    QString timeline = root.attribute(QStringLiteral("timeline"));
-    QString date_begin = root.attribute(QStringLiteral("date_begin"));
-    QString date_end = root.attribute(QStringLiteral("date_end"));
-    QString future = root.attribute(QStringLiteral("future"));
+    QString period = root.attribute(QLatin1String("period"));
+    QString interval = root.attribute(QLatin1String("interval"));
+    QString nb_interval = root.attribute(QLatin1String("nb_intervals"));
+    QString timeline = root.attribute(QLatin1String("timeline"));
+    QString date_begin = root.attribute(QLatin1String("date_begin"));
+    QString date_end = root.attribute(QLatin1String("date_end"));
+    QString future = root.attribute(QLatin1String("future"));
 
     // Default values
     if (period.isEmpty()) {
@@ -105,7 +105,7 @@ void SKGPeriodEdit::setState(const QString& iState)
     ui.kInterval->setCurrentIndex(ui.kInterval->findData(SKGServices::stringToInt(interval)));
     ui.kTimeline->setValue(SKGServices::stringToInt(timeline));
     ui.kNbIntervals->setValue(SKGServices::stringToInt(nb_interval));
-    ui.kFuture->setChecked(future == QStringLiteral("Y"));
+    ui.kFuture->setChecked(future == QLatin1String("Y"));
     if (!date_begin.isEmpty()) {
         ui.kDateBegin->setDate(QDate::fromJulianDay(SKGServices::stringToInt(date_begin)));
     }
@@ -408,46 +408,46 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
     switch (interval) {
     case DAY:
         // Interval is in days
-        sqlAttribute = QStringLiteral("d_date");
-        strfFormat = QStringLiteral("'D'");
-        sqlInterval = QStringLiteral("DAY");
+        sqlAttribute = QLatin1String("d_date");
+        strfFormat = QLatin1String("'D'");
+        sqlInterval = QLatin1String("DAY");
         break;
     case WEEK:
         // Interval is in weeks
-        sqlAttribute = QStringLiteral("d_DATEWEEK");
-        strfFormat = QStringLiteral("'W'");
-        sqlInterval = QStringLiteral("DAY");
+        sqlAttribute = QLatin1String("d_DATEWEEK");
+        strfFormat = QLatin1String("'W'");
+        sqlInterval = QLatin1String("DAY");
         val *= 7;
         one *= 7;
         break;
     case MONTH:
     default:
         // Interval is in months
-        sqlAttribute = QStringLiteral("d_DATEMONTH");
-        strfFormat = QStringLiteral("'M'");
-        sqlInterval = QStringLiteral("MONTH");
+        sqlAttribute = QLatin1String("d_DATEMONTH");
+        strfFormat = QLatin1String("'M'");
+        sqlInterval = QLatin1String("MONTH");
         break;
     case QUARTER:
         // Interval is in quarter
-        sqlAttribute = QStringLiteral("d_DATEQUARTER");
-        strfFormat = QStringLiteral("'Q'");
-        sqlInterval = QStringLiteral("MONTH");
+        sqlAttribute = QLatin1String("d_DATEQUARTER");
+        strfFormat = QLatin1String("'Q'");
+        sqlInterval = QLatin1String("MONTH");
         val *= 3;
         one *= 3;
         break;
     case SEMESTER:
         // Interval is in quarter
-        sqlAttribute = QStringLiteral("d_DATESEMESTER");
-        strfFormat = QStringLiteral("'S'");
-        sqlInterval = QStringLiteral("MONTH");
+        sqlAttribute = QLatin1String("d_DATESEMESTER");
+        strfFormat = QLatin1String("'S'");
+        sqlInterval = QLatin1String("MONTH");
         val *= 6;
         one *= 6;
         break;
     case YEAR:
         // Interval is in years
-        sqlAttribute = QStringLiteral("d_DATEYEAR");
-        strfFormat = QStringLiteral("'Y'");
-        sqlInterval = QStringLiteral("YEAR");
+        sqlAttribute = QLatin1String("d_DATEYEAR");
+        strfFormat = QLatin1String("'Y'");
+        sqlInterval = QLatin1String("YEAR");
         break;
     }
 
@@ -461,28 +461,28 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         ui.kDateEnd->setDate(b);
         wc = sqlAttribute % " = (SELECT period(date('now', 'localtime'), " % strfFormat % "))";
         if (ui.kFuture->isChecked()) {
-            wc +=  QStringLiteral(" OR d_date > (SELECT date('now', 'localtime'))");
+            wc +=  QLatin1String(" OR d_date > (SELECT date('now', 'localtime'))");
         }
         if (oWhereClausForPreviousData != nullptr) {
             *oWhereClausForPreviousData = sqlAttribute % " < (SELECT period(date('now', 'localtime'), " % strfFormat % "))";
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
+            *oWhereClausForForecastData = QLatin1String("d_date > (SELECT date('now', 'localtime'))");
         }
         break;
     case PREVIOUS:
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
-        startOf = QStringLiteral("start of ") % sqlInterval.toLower();
-        wc = sqlAttribute % ">=(SELECT period(date('now', 'localtime','" % startOf % "', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
+        startOf = QLatin1String("start of ") % sqlInterval.toLower();
+        wc = sqlAttribute % ">=(SELECT period(date('now', 'localtime','" % startOf % "', '-" % SKGServices::intToString(val) % QLatin1Char(' ') % sqlInterval % "')," % strfFormat % "))";
         if (iForecast) {
-            wc += " AND period(d_date, " % strfFormat % ")<=(SELECT period(date('now', 'localtime','" % startOf % "', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";    // For forecast based on scheduled transactions
+            wc += " AND period(d_date, " % strfFormat % ")<=(SELECT period(date('now', 'localtime','" % startOf % "', '-" % SKGServices::intToString(one) % QLatin1Char(' ') % sqlInterval % "')," % strfFormat % "))";    // For forecast based on scheduled transactions
 
             if (oWhereClausForPreviousData != nullptr) {
-                *oWhereClausForPreviousData = sqlAttribute % " <= (SELECT period(date('now', 'localtime','" % startOf % "', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
+                *oWhereClausForPreviousData = sqlAttribute % " <= (SELECT period(date('now', 'localtime','" % startOf % "', '-" % SKGServices::intToString(val) % QLatin1Char(' ') % sqlInterval % "')," % strfFormat % "))";
             }
             if (oWhereClausForForecastData != nullptr) {
-                *oWhereClausForForecastData = sqlAttribute % " > (SELECT period(date('now', 'localtime','" % startOf % "', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";
+                *oWhereClausForForecastData = sqlAttribute % " > (SELECT period(date('now', 'localtime','" % startOf % "', '-" % SKGServices::intToString(one) % QLatin1Char(' ') % sqlInterval % "')," % strfFormat % "))";
             }
         }
         break;
@@ -494,47 +494,47 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
 
-        wc = "d_date >= (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "', '+1 DAY'))";
+        wc = "d_date >= (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % QLatin1Char(' ') % sqlInterval % "', '+1 DAY'))";
         if (iForecast) {
-            wc += QStringLiteral(" AND d_date<=(SELECT date('now', 'localtime'))");    // For forecast based on scheduled transactions
+            wc += QLatin1String(" AND d_date<=(SELECT date('now', 'localtime'))");    // For forecast based on scheduled transactions
         }
 
         if (ui.kFuture->isChecked()) {
-            wc += QStringLiteral(" OR d_date > (SELECT date('now', 'localtime'))");
+            wc += QLatin1String(" OR d_date > (SELECT date('now', 'localtime'))");
         }
         if (oWhereClausForPreviousData != nullptr) {
-            *oWhereClausForPreviousData = "d_date <= (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
+            *oWhereClausForPreviousData = "d_date <= (SELECT date('now', 'localtime','-" % SKGServices::intToString(val) % QLatin1Char(' ') % sqlInterval % "'))";
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
+            *oWhereClausForForecastData = QLatin1String("d_date > (SELECT date('now', 'localtime'))");
         }
         break;
     case CUSTOM:
         // Custom Date
-        wc = "d_date>='" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % '\'';
+        wc = "d_date>='" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % QLatin1Char('\'');
         if (iForecast) {
-            wc += "AND d_date<='" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % '\'';    // For forecast based on scheduled transactions
+            wc += "AND d_date<='" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % QLatin1Char('\'');    // For forecast based on scheduled transactions
         }
         if (oWhereClausForPreviousData != nullptr) {
-            *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % '\'';
+            *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % QLatin1Char('\'');
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
+            *oWhereClausForForecastData = QLatin1String("d_date > (SELECT date('now', 'localtime'))");
         }
         break;
     case TIMELINE:
         // Timeline
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
-        wc = "d_date>='" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % '\'';
+        wc = "d_date>='" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % QLatin1Char('\'');
         if (iForecast) {
-            wc += "AND d_date<='" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % '\'';    // For forecast based on scheduled transactions
+            wc += "AND d_date<='" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % QLatin1Char('\'');    // For forecast based on scheduled transactions
         }
         if (oWhereClausForPreviousData != nullptr) {
-            *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % '\'';
+            *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(ui.kDateBegin->date()) % QLatin1Char('\'');
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = "d_date>'" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % '\'';
+            *oWhereClausForForecastData = "d_date>'" % SKGServices::dateToSqlString(ui.kDateEnd->date()) % QLatin1Char('\'');
         }
         break;
     default:
@@ -542,12 +542,12 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         a = a.addYears(-1);
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
-        wc = QStringLiteral("1=1");
+        wc = QLatin1String("1=1");
         if (oWhereClausForPreviousData != nullptr) {
-            *oWhereClausForPreviousData = QStringLiteral("1=0");
+            *oWhereClausForPreviousData = QLatin1String("1=0");
         }
         if (oWhereClausForForecastData != nullptr) {
-            *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now', 'localtime'))");
+            *oWhereClausForForecastData = QLatin1String("d_date > (SELECT date('now', 'localtime'))");
         }
         break;
     }
