@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -91,12 +91,12 @@ bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
         // Special sort order
         if (d->m_current != -1) {
             auto columname = model->getAttribute(d->m_current);
-            if (columname.startsWith(QStringLiteral("f_BALANCE"))) {
-                auto d_date_index = model->getIndexAttribute(QStringLiteral("d_date"));
+            if (columname.startsWith(QLatin1String("f_BALANCE"))) {
+                auto d_date_index = model->getIndexAttribute(QLatin1String("d_date"));
                 if (d_date_index != -1) {
                     d->m_current = d_date_index;
                     d->m_previous = -1;
-                    SKGTRACEL(5) << "SKGSortFilterProxyModel::lessThan-Special sort order on " << columname << SKGENDL;
+                    SKGTRACEL(5) << "SKGSortFilterProxyModel::lessThan-Special sort order on " << columname << Qt::endl;
                 }
             }
         }
@@ -137,29 +137,29 @@ bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
 bool SKGSortFilterProxyModel::lessThan(const QVariant& iLeftData, const QVariant& iRightData) const
 {
     switch (iLeftData.userType()) {
-    case QVariant::Invalid:
-        return (iRightData.type() != QVariant::Invalid);
-    case QVariant::Int:
+    case QMetaType::UnknownType:
+        return (iRightData.userType() != QMetaType::UnknownType);
+    case QMetaType::Int:
         return iLeftData.toInt() < iRightData.toInt();
-    case QVariant::UInt:
+    case QMetaType::UInt:
         return iLeftData.toUInt() < iRightData.toUInt();
-    case QVariant::LongLong:
+    case QMetaType::LongLong:
         return iLeftData.toLongLong() < iRightData.toLongLong();
-    case QVariant::ULongLong:
+    case QMetaType::ULongLong:
         return iLeftData.toULongLong() < iRightData.toULongLong();
     case QMetaType::Float:
         return iLeftData.toFloat() < iRightData.toFloat();
-    case QVariant::Double:
+    case QMetaType::Double:
         return iLeftData.toDouble() < iRightData.toDouble();
-    case QVariant::Char:
+    case QMetaType::QChar:
         return iLeftData.toChar() < iRightData.toChar();
-    case QVariant::Date:
+    case QMetaType::QDate:
         return iLeftData.toDate() < iRightData.toDate();
-    case QVariant::Time:
+    case QMetaType::QTime:
         return iLeftData.toTime() < iRightData.toTime();
-    case QVariant::DateTime:
+    case QMetaType::QDateTime:
         return iLeftData.toDateTime() < iRightData.toDateTime();
-    case QVariant::String:
+    case QMetaType::QString:
     default:
         if (this->isSortLocaleAware()) {
             return iLeftData.toString().localeAwareCompare(iRightData.toString()) < 0;
@@ -172,29 +172,29 @@ bool SKGSortFilterProxyModel::lessThan(const QVariant& iLeftData, const QVariant
 bool SKGSortFilterProxyModel::moreThan(const QVariant& iLeftData, const QVariant& iRightData) const
 {
     switch (iLeftData.userType()) {
-    case QVariant::Invalid:
-        return (iRightData.type() != QVariant::Invalid);
-    case QVariant::Int:
+    case QMetaType::UnknownType:
+        return (iRightData.userType() != QMetaType::UnknownType);
+    case QMetaType::Int:
         return iLeftData.toInt() > iRightData.toInt();
-    case QVariant::UInt:
+    case QMetaType::UInt:
         return iLeftData.toUInt() > iRightData.toUInt();
-    case QVariant::LongLong:
+    case QMetaType::LongLong:
         return iLeftData.toLongLong() > iRightData.toLongLong();
-    case QVariant::ULongLong:
+    case QMetaType::ULongLong:
         return iLeftData.toULongLong() > iRightData.toULongLong();
     case QMetaType::Float:
         return iLeftData.toFloat() > iRightData.toFloat();
-    case QVariant::Double:
+    case QMetaType::Double:
         return iLeftData.toDouble() > iRightData.toDouble();
-    case QVariant::Char:
+    case QMetaType::Char:
         return iLeftData.toChar() > iRightData.toChar();
-    case QVariant::Date:
+    case QMetaType::QDate:
         return iLeftData.toDate() > iRightData.toDate();
-    case QVariant::Time:
+    case QMetaType::QTime:
         return iLeftData.toTime() > iRightData.toTime();
-    case QVariant::DateTime:
+    case QMetaType::QDateTime:
         return iLeftData.toDateTime() > iRightData.toDateTime();
-    case QVariant::String:
+    case QMetaType::QString:
     default:
         if (this->isSortLocaleAware()) {
             return iLeftData.toString().localeAwareCompare(iRightData.toString()) > 0;
@@ -209,10 +209,18 @@ bool SKGSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex
     _SKGTRACEINFUNC(10)
 
     // Initialisation
+#ifdef SKG_QT6
+    bool output = (filterRegularExpression().pattern().isEmpty());
+#else
     bool output = (filterRegExp().isEmpty());
+#endif
     if (!output) {
         // Build list of criterias
+#ifdef SKG_QT6
+        SKGServices::SKGSearchCriteriaList criterias = SKGServices::stringToSearchCriterias(filterRegularExpression().pattern());
+#else
         SKGServices::SKGSearchCriteriaList criterias = SKGServices::stringToSearchCriterias(filterRegExp().pattern());
+#endif
 
         // Check if at least one group validate the line
         int nbList = criterias.count();
@@ -260,13 +268,13 @@ bool SKGSortFilterProxyModel::filterAcceptsRowWords(int source_row, const QModel
             QString op(':');
             bool modeStartWith = true;
 
-            int pos = word.indexOf(QStringLiteral(":"));
-            int pos2 = word.indexOf(QStringLiteral("<="));
-            int pos3 = word.indexOf(QStringLiteral(">="));
-            int pos4 = word.indexOf(QStringLiteral("="));
-            int pos5 = word.indexOf(QStringLiteral("<"));
-            int pos6 = word.indexOf(QStringLiteral(">"));
-            int pos7 = word.indexOf(QStringLiteral("#"));
+            int pos = word.indexOf(QLatin1String(":"));
+            int pos2 = word.indexOf(QLatin1String("<="));
+            int pos3 = word.indexOf(QLatin1String(">="));
+            int pos4 = word.indexOf(QLatin1String("="));
+            int pos5 = word.indexOf(QLatin1String("<"));
+            int pos6 = word.indexOf(QLatin1String(">"));
+            int pos7 = word.indexOf(QLatin1String("#"));
             int opLength = 1;
             if (pos2 != -1 && (pos2 < pos || pos == -1)) {
                 pos = pos2;
@@ -291,12 +299,12 @@ bool SKGSortFilterProxyModel::filterAcceptsRowWords(int source_row, const QModel
 
             if (pos != -1) {
                 att = word.left(pos);
-                if (att.endsWith(QStringLiteral("."))) {
+                if (att.endsWith(QLatin1String("."))) {
                     modeStartWith = false;
-                    att = att.left(att.count() - 1);
+                    att = att.left(att.size() - 1);
                 }
                 op = word.mid(pos, opLength);
-                word = word.right(word.count() - pos - op.count());
+                word = word.right(word.size() - pos - op.size());
             }
 
             // Is this word validated by at least one column ?
@@ -310,27 +318,27 @@ bool SKGSortFilterProxyModel::filterAcceptsRowWords(int source_row, const QModel
                         (modeStartWith && model->headerData(i, Qt::Horizontal).toString().startsWith(att, Qt::CaseInsensitive)) ||
                         (!modeStartWith && model->headerData(i, Qt::Horizontal).toString().compare(att, Qt::CaseInsensitive) == 0)) {
                         // Check if the value validate the attribute
-                        if (op == QStringLiteral(":")) {
+                        if (op == QLatin1String(":")) {
                             output = model->data(index0).toString().contains(word, Qt::CaseInsensitive);
                             if (!output) {
                                 output = model->data(index0, Qt::UserRole).toString().contains(word, Qt::CaseInsensitive);
                             }
-                        } else if (op == QStringLiteral("<")) {
+                        } else if (op == QLatin1String("<")) {
                             QVariant var = model->data(index0, Qt::UserRole);
                             output = lessThan(var, QVariant(word));
-                        } else if (op == QStringLiteral(">")) {
+                        } else if (op == QLatin1String(">")) {
                             QVariant var = model->data(index0, Qt::UserRole);
                             output = moreThan(var, QVariant(word));
-                        } else if (op == QStringLiteral("<=")) {
+                        } else if (op == QLatin1String("<=")) {
                             QVariant var = model->data(index0, Qt::UserRole);
                             output = (var == QVariant(word)) || lessThan(var, QVariant(word));
-                        } else if (op == QStringLiteral(">=")) {
+                        } else if (op == QLatin1String(">=")) {
                             QVariant var = model->data(index0, Qt::UserRole);
                             output = (var == QVariant(word)) || moreThan(var, QVariant(word));
-                        } else if (op == QStringLiteral("=")) {
+                        } else if (op == QLatin1String("=")) {
                             QVariant var = model->data(index0, Qt::UserRole);
                             output = (var == QVariant(word));
-                        } else if (op == QStringLiteral("#")) {
+                        } else if (op == QLatin1String("#")) {
                             QVariant var = model->data(index0, Qt::UserRole);
                             QRegularExpression pattern(QRegularExpression::anchoredPattern(word), QRegularExpression::CaseInsensitiveOption);
                             output = pattern.match(var.toString()).hasMatch();
