@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -18,6 +18,7 @@
 #include <algorithm>
 
 #include "skgtraces.h"
+#include <utility>
 
 SKGTableWidget::SKGTableWidget(QWidget* iParent)
     : QTableWidget(iParent), stickH(false), stickV(false)
@@ -136,7 +137,7 @@ void SKGTableWidget::copy()
         QString header_text;
         bool header_done = false;
         QString selected_text;
-        for (const auto& current : qAsConst(indexes)) {
+        for (const auto& current : std::as_const(indexes)) {
             selected_text.append(model()->data(previous).toString());
             if (!header_done) {
                 header_text.append(model()->headerData(previous.column(), Qt::Horizontal).toString());
