@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -17,10 +17,7 @@
 #ifdef SKG_WEBENGINE
 #include <qwebengineview.h>
 #endif
-#ifdef SKG_WEBKIT
-#include <qwebview.h>
-#endif
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#if !defined(SKG_WEBENGINE)
 #include <qlabel.h>
 #endif
 #include <qmath.h>
@@ -35,6 +32,7 @@
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
 #include "skgtreeview.h"
+#include <utility>
 
 SKGTabPage::SKGTabPage(QWidget* iParent, SKGDocument* iDocument)
     : SKGWidget(iParent, iDocument), m_pin(false)
@@ -53,37 +51,19 @@ SKGTabPage::~SKGTabPage()
 bool SKGTabPage::close(bool iForce)
 {
     SKGTRACEINFUNC(5)
-#ifdef SKG_KF_5102
     int conf = KMessageBox::PrimaryAction;
-#else
-    int conf = KMessageBox::Yes;
-#endif
-
     if (!iForce && isPin()) {
         QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-#ifdef SKG_KF_5102
         conf = KMessageBox::questionTwoActions(this,
                                                i18nc("Question", "Do you really want to close this pinned page?"),
                                                i18nc("Question", "Pinned page"),
                                                KStandardGuiItem::apply(),
                                                KStandardGuiItem::cancel(),
-                                               QStringLiteral("closepinnedpage"));
-#else
-        conf = KMessageBox::questionYesNo(this,
-                                          i18nc("Question", "Do you really want to close this pinned page?"),
-                                          i18nc("Question", "Pinned page"),
-                                          KStandardGuiItem::yes(),
-                                          KStandardGuiItem::no(),
-                                          QStringLiteral("closepinnedpage"));
-#endif
+                                               QLatin1String("closepinnedpage"));
         QApplication::restoreOverrideCursor();
     }
     overwrite();
-#ifdef SKG_KF_5102
     if (conf == KMessageBox::SecondaryAction) {
-#else
-    if (conf == KMessageBox::No) {
-#endif
         return false;
     }
     return QWidget::close();
@@ -131,9 +111,9 @@ bool SKGTabPage::isOverwriteNeeded()
                 QString oldState = d[2].trimmed();
                 currentState.remove('\n');
                 oldState.remove('\n');
-                SKGTRACEL(20) << "oldState      =[" << oldState << ']' << SKGENDL;
-                SKGTRACEL(20) << "currentState  =[" << currentState << ']' << SKGENDL;
-                SKGTRACEL(20) << "Bookmark diff =" << (currentState != oldState ? "TRUE" : "FALSE") << SKGENDL;
+                SKGTRACEL(20) << "oldState      =[" << oldState << ']' << Qt::endl;
+                SKGTRACEL(20) << "currentState  =[" << currentState << ']' << Qt::endl;
+                SKGTRACEL(20) << "Bookmark diff =" << (currentState != oldState ? "TRUE" : "FALSE") << Qt::endl;
                 return (currentState != oldState);
             }
         }
@@ -145,9 +125,9 @@ bool SKGTabPage::isOverwriteNeeded()
             QString oldState = getDocument()->getParameter(name);
             currentState.remove('\n');
             oldState.remove('\n');
-            SKGTRACEL(20) << "oldState      =[" << oldState << ']' << SKGENDL;
-            SKGTRACEL(20) << "currentState  =[" << currentState << ']' << SKGENDL;
-            SKGTRACEL(20) << "Page diff =" << (currentState != oldState ? "TRUE" : "FALSE") << SKGENDL;
+            SKGTRACEL(20) << "oldState      =[" << oldState << ']' << Qt::endl;
+            SKGTRACEL(20) << "currentState  =[" << currentState << ']' << Qt::endl;
+            SKGTRACEL(20) << "Page diff =" << (currentState != oldState ? "TRUE" : "FALSE") << Qt::endl;
             return (currentState != oldState);
         }
     }
@@ -169,38 +149,21 @@ void SKGTabPage::overwrite(bool iUserConfirmation)
                 QString oldState = d[2].trimmed();
                 currentState.remove('\n');
                 oldState.remove('\n');
-                SKGTRACEL(20) << "oldState      =[" << oldState << ']' << SKGENDL;
-                SKGTRACEL(20) << "currentState  =[" << currentState << ']' << SKGENDL;
+                SKGTRACEL(20) << "oldState      =[" << oldState << ']' << Qt::endl;
+                SKGTRACEL(20) << "currentState  =[" << currentState << ']' << Qt::endl;
                 if (currentState != oldState) {
                     QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-#ifdef SKG_KF_5102
                     int conf = KMessageBox::PrimaryAction;
-#else
-                    int conf = KMessageBox::Yes;
-#endif
                     if (iUserConfirmation && !oldState.isEmpty()) {
-#ifdef SKG_KF_5102
                         conf = KMessageBox::questionTwoActions(this,
                                                                i18nc("Question", "Bookmark '%1' has been modified. Do you want to update it with the current state?", fullname),
                                                                i18nc("Question", "Bookmark has been modified"),
                                                                KStandardGuiItem::apply(),
                                                                KStandardGuiItem::cancel(),
-                                                               QStringLiteral("updateBookmarkOnClose"));
-#else
-                        conf = KMessageBox::questionYesNo(this,
-                                                          i18nc("Question", "Bookmark '%1' has been modified. Do you want to update it with the current state?", fullname),
-                                                          i18nc("Question", "Bookmark has been modified"),
-                                                          KStandardGuiItem::yes(),
-                                                          KStandardGuiItem::no(),
-                                                          QStringLiteral("updateBookmarkOnClose"));
-#endif
+                                                               QLatin1String("updateBookmarkOnClose"));
                     }
                     QApplication::restoreOverrideCursor();
-#ifdef SKG_KF_5102
                     if (conf == KMessageBox::PrimaryAction) {
-#else
-                    if (conf == KMessageBox::Yes) {
-#endif
                         SKGError err;
                         {
                             SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update '%1'", fullname), err)
@@ -220,40 +183,23 @@ void SKGTabPage::overwrite(bool iUserConfirmation)
         if (!name.isEmpty()) {
             QString currentState = getState().trimmed();
             QString oldState = getDocument()->getParameter(name);
-            SKGTRACEL(20) << "oldState      =[" << oldState << ']' << SKGENDL;
-            SKGTRACEL(20) << "currentState  =[" << currentState << ']' << SKGENDL;
+            SKGTRACEL(20) << "oldState      =[" << oldState << ']' << Qt::endl;
+            SKGTRACEL(20) << "currentState  =[" << currentState << ']' << Qt::endl;
             currentState.remove('\n');
             oldState.remove('\n');
             if (currentState != oldState) {
                 QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-#ifdef SKG_KF_5102
                 int conf = KMessageBox::PrimaryAction;
-#else
-                int conf = KMessageBox::Yes;
-#endif
                 if (iUserConfirmation && !oldState.isEmpty()) {
-#ifdef SKG_KF_5102
                     conf = KMessageBox::questionTwoActions(this,
                                                            i18nc("Question", "Page has been modified. Do you want to update it with the current state?"),
                                                            i18nc("Question", "Page has been modified"),
                                                            KStandardGuiItem::apply(),
                                                            KStandardGuiItem::cancel(),
-                                                           QStringLiteral("updateContextOnClose"));
-#else
-                    conf = KMessageBox::questionYesNo(this,
-                                                      i18nc("Question", "Page has been modified. Do you want to update it with the current state?"),
-                                                      i18nc("Question", "Page has been modified"),
-                                                      KStandardGuiItem::yes(),
-                                                      KStandardGuiItem::no(),
-                                                      QStringLiteral("updateContextOnClose"));
-#endif
+                                                           QLatin1String("updateContextOnClose"));
                 }
                 QApplication::restoreOverrideCursor();
-#ifdef SKG_KF_5102
                 if (conf == KMessageBox::PrimaryAction) {
-#else
-                if (conf == KMessageBox::Yes) {
-#endif
                     SKGError err;
                     {
                         SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Save default state"), err)
@@ -302,10 +248,7 @@ void SKGTabPage::setZoomPosition(int iValue)
 #ifdef SKG_WEBENGINE
         auto webView = qobject_cast<QWebEngineView*>(widget);
 #endif
-#ifdef SKG_WEBKIT
-        auto webView = qobject_cast<QWebView*>(widget);
-#endif
-#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
+#if defined(SKG_WEBENGINE)
         if (webView != nullptr) {
             webView->setZoomFactor(qPow(10, static_cast<qreal>(iValue) / 30.0));
         } else {
@@ -315,7 +258,7 @@ void SKGTabPage::setZoomPosition(int iValue)
             widget->setFont(f);
 
             auto cs = widget->findChildren<SKGHtmlBoardWidget*>();
-            for (auto c : qAsConst(cs)) {
+            for (auto c : std::as_const(cs)) {
                 c->setPointSize(pointSize);
             }
         }
@@ -334,10 +277,7 @@ int SKGTabPage::zoomPosition()
 #ifdef SKG_WEBENGINE
         auto webView = qobject_cast<QWebEngineView*>(widget);
 #endif
-#ifdef SKG_WEBKIT
-        auto webView = qobject_cast<QWebView*>(widget);
-#endif
-#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
+#if defined(SKG_WEBENGINE)
         if (webView != nullptr) {
             output = qRound(30.0 * log10(webView->zoomFactor()));
         } else if (widget != nullptr) {
