@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -46,7 +46,7 @@ void SKGTabWidget::onCurrentChanged()
     if ((currentWidget() != nullptr) && !m_tabIndexSaveButton.contains(currentWidget())) {
         // Build widgets
         auto kSave = new QPushButton(this);
-        kSave->setIcon(SKGServices::fromTheme(QStringLiteral("document-save")));
+        kSave->setIcon(SKGServices::fromTheme(QLatin1String("document-save")));
         kSave->setToolTip(i18nc("Verb", "Save this tab"));
         kSave->setFlat(true);
         kSave->setMaximumSize(QSize(16, 16));
@@ -111,16 +111,16 @@ void SKGTabWidget::onRefreshSaveIcon()
                 save->setEnabled(true);
                 QStringList overlay;
                 if (page->isPin()) {
-                    overlay.push_back(QStringLiteral("document-encrypt"));
+                    overlay.push_back(QLatin1String("document-encrypt"));
                 }
                 if (!page->getBookmarkID().isEmpty()) {
-                    overlay.push_back(QStringLiteral("bookmarks"));
+                    overlay.push_back(QLatin1String("bookmarks"));
                 }
-                save->setIcon(SKGServices::fromTheme(QStringLiteral("document-save"), overlay));
+                save->setIcon(SKGServices::fromTheme(QLatin1String("document-save"), overlay));
             } else if (page->isPin()) {
                 save->show();
                 save->setEnabled(false);
-                save->setIcon(SKGServices::fromTheme(QStringLiteral("document-encrypt")));
+                save->setIcon(SKGServices::fromTheme(QLatin1String("document-encrypt")));
             } else {
                 save->hide();
             }
