@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -13,6 +13,7 @@
 #include <klocalizedstring.h>
 #include <kstandardaction.h>
 
+#include <qactiongroup.h>
 #include <qapplication.h>
 #include <qbasictimer.h>
 #include <qclipboard.h>
@@ -30,7 +31,11 @@
 #include <qscrollbar.h>
 #include <qsvggenerator.h>
 #include <qtextbrowser.h>
+#ifdef SKG_QT6
+#include <QtCore5Compat/QTextCodec>
+#else
 #include <qtextcodec.h>
+#endif
 #include <qtextdocumentwriter.h>
 #include <qtextobject.h>
 #include <qtexttable.h>
@@ -49,6 +54,7 @@
 #include "skgtableview.h"
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
+#include <utility>
 
 SKGTreeView::SKGTreeView(QWidget* iParent)
     : QTreeView(iParent),
@@ -86,21 +92,21 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
     m_actCopy->setProperty("isShortcutConfigurable", false);
     m_actCopy->setShortcutContext(Qt::WidgetShortcut);
 
-    m_actExpandAll = new QAction(SKGServices::fromTheme(QStringLiteral("format-indent-more")), i18nc("Noun, user action", "Expand all"), this);
-    m_actExpandAll->setShortcut(Qt::ALT + Qt::Key_Plus);
+    m_actExpandAll = new QAction(SKGServices::fromTheme(QLatin1String("format-indent-more")), i18nc("Noun, user action", "Expand all"), this);
+    m_actExpandAll->setShortcut(Qt::ALT | Qt::Key_Plus);
     m_actExpandAll->setProperty("isShortcutConfigurable", false);
     m_actExpandAll->setShortcutContext(Qt::WidgetShortcut);
     connect(m_actExpandAll, &QAction::triggered, this, &SKGTreeView::expandAll);
 
-    m_actCollapseAll = new QAction(SKGServices::fromTheme(QStringLiteral("format-indent-less")), i18nc("Noun, user action", "Collapse all"), this);
-    m_actCollapseAll->setShortcut(Qt::ALT + Qt::Key_Minus);
+    m_actCollapseAll = new QAction(SKGServices::fromTheme(QLatin1String("format-indent-less")), i18nc("Noun, user action", "Collapse all"), this);
+    m_actCollapseAll->setShortcut(Qt::ALT | Qt::Key_Minus);
     m_actCollapseAll->setProperty("isShortcutConfigurable", false);
     m_actCollapseAll->setShortcutContext(Qt::WidgetShortcut);
     connect(m_actCollapseAll, &QAction::triggered, this, &SKGTreeView::collapseAll);
     if (SKGMainPanel::getMainPanel() != nullptr) {
-        SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("edit_copy"), m_actCopy);
-        SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("edit_expandall"), m_actExpandAll);
-        SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("edit_collapseall"), m_actCollapseAll);
+        SKGMainPanel::getMainPanel()->registerGlobalAction(QLatin1String("edit_copy"), m_actCopy);
+        SKGMainPanel::getMainPanel()->registerGlobalAction(QLatin1String("edit_expandall"), m_actExpandAll);
+        SKGMainPanel::getMainPanel()->registerGlobalAction(QLatin1String("edit_collapseall"), m_actCollapseAll);
     }
 
     // Scroll bars
@@ -152,21 +158,21 @@ bool SKGTreeView::isAutoResized()
 QString SKGTreeView::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
 
     QHeaderView* hHeader = header();
     if ((hHeader != nullptr) && (m_model != nullptr)) {
         if (isSortingEnabled()) {
-            root.setAttribute(QStringLiteral("sortOrder"), SKGServices::intToString(static_cast<int>(hHeader->sortIndicatorOrder())));
-            root.setAttribute(QStringLiteral("sortColumn"), m_model->getAttribute(hHeader->sortIndicatorSection()));
+            root.setAttribute(QLatin1String("sortOrder"), SKGServices::intToString(static_cast<int>(hHeader->sortIndicatorOrder())));
+            root.setAttribute(QLatin1String("sortColumn"), m_model->getAttribute(hHeader->sortIndicatorSection()));
 
             if (m_proxyModel != nullptr) {
-                root.setAttribute(QStringLiteral("sortPreviousColumn"), SKGServices::intToString(m_proxyModel->getPreviousSortColumn()));
+                root.setAttribute(QLatin1String("sortPreviousColumn"), SKGServices::intToString(m_proxyModel->getPreviousSortColumn()));
             }
         }
-        root.setAttribute(QStringLiteral("groupBy"), m_groupby);
+        root.setAttribute(QLatin1String("groupBy"), m_groupby);
 
         // Memorize order
         int nb = hHeader->count();
@@ -189,31 +195,31 @@ QString SKGTreeView::getState()
                 if (i != 0) {
                     columnsVisibility += ';';
                 }
-                columnsVisibility += (hHeader->isSectionHidden(idx) ? QStringLiteral("N") : QStringLiteral("Y"));
+                columnsVisibility += (hHeader->isSectionHidden(idx) ? QLatin1String("N") : QLatin1String("Y"));
             }
-            root.setAttribute(QStringLiteral("columns"), columns);
+            root.setAttribute(QLatin1String("columns"), columns);
             if (!m_autoResize) {
-                root.setAttribute(QStringLiteral("columnsSize"), columnsSize);
+                root.setAttribute(QLatin1String("columnsSize"), columnsSize);
             }
-            root.setAttribute(QStringLiteral("columnsVisibility"), columnsVisibility);
-            root.setAttribute(QStringLiteral("columnsAutoResize"), m_autoResize ? QStringLiteral("Y") : QStringLiteral("N"));
+            root.setAttribute(QLatin1String("columnsVisibility"), columnsVisibility);
+            root.setAttribute(QLatin1String("columnsAutoResize"), m_autoResize ? QLatin1String("Y") : QLatin1String("N"));
         }
 
         // Memorize expanded groups
         if (!m_groupby.isEmpty()) {
-            root.setAttribute(QStringLiteral("expandedGroups"), m_expandedNodes.join(QStringLiteral(";")));
+            root.setAttribute(QLatin1String("expandedGroups"), m_expandedNodes.join(QLatin1String(";")));
         }
     }
-    root.setAttribute(QStringLiteral("alternatingRowColors"), alternatingRowColors() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("zoomPosition"), SKGServices::intToString(zoomPosition()));
+    root.setAttribute(QLatin1String("alternatingRowColors"), alternatingRowColors() ? QLatin1String("Y") : QLatin1String("N"));
+    root.setAttribute(QLatin1String("zoomPosition"), SKGServices::intToString(zoomPosition()));
 
     QScrollBar* scroll2 = horizontalScrollBar();
     if ((scroll2 != nullptr) && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) {
-        root.setAttribute(QStringLiteral("stickH"), QStringLiteral("Y"));
+        root.setAttribute(QLatin1String("stickH"), QLatin1String("Y"));
     }
     scroll2 = verticalScrollBar();
     if ((scroll2 != nullptr) && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) {
-        root.setAttribute(QStringLiteral("stickV"), QStringLiteral("Y"));
+        root.setAttribute(QLatin1String("stickV"), QLatin1String("Y"));
     }
     return doc.toString(-1);
 }
@@ -223,7 +229,7 @@ void SKGTreeView::setState(const QString& iState)
     SKGTRACEINFUNC(10)
     resetColumnsOrder();
 
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
 
     QString viewState = iState;
     if (viewState.isEmpty() && (m_document != nullptr)) {
@@ -235,19 +241,19 @@ void SKGTreeView::setState(const QString& iState)
     if (doc.setContent(viewState)) {
         QDomElement root = doc.documentElement();
 
-        QString sortOrder = root.attribute(QStringLiteral("sortOrder"));
-        QString sortColumn = root.attribute(QStringLiteral("sortColumn"));
-        QString sortPreviousColumn = root.attribute(QStringLiteral("sortPreviousColumn"));
-        m_groupby = root.attribute(QStringLiteral("groupBy"));
-        QString columns = root.attribute(QStringLiteral("columns"));
-        QString columnsSize = root.attribute(QStringLiteral("columnsSize"));
-        QString columnsVisibility = root.attribute(QStringLiteral("columnsVisibility"));
-        QString columnsAutoResize = root.attribute(QStringLiteral("columnsAutoResize"));
-        QString alternatingRowColors2 = root.attribute(QStringLiteral("alternatingRowColors"));
-        QString zoomPositionString = root.attribute(QStringLiteral("zoomPosition"));
-        QString expandedGroups = root.attribute(QStringLiteral("expandedGroups"));
-        stickH = (root.attribute(QStringLiteral("stickH")) == QStringLiteral("Y"));
-        stickV = (root.attribute(QStringLiteral("stickV")) == QStringLiteral("Y"));
+        QString sortOrder = root.attribute(QLatin1String("sortOrder"));
+        QString sortColumn = root.attribute(QLatin1String("sortColumn"));
+        QString sortPreviousColumn = root.attribute(QLatin1String("sortPreviousColumn"));
+        m_groupby = root.attribute(QLatin1String("groupBy"));
+        QString columns = root.attribute(QLatin1String("columns"));
+        QString columnsSize = root.attribute(QLatin1String("columnsSize"));
+        QString columnsVisibility = root.attribute(QLatin1String("columnsVisibility"));
+        QString columnsAutoResize = root.attribute(QLatin1String("columnsAutoResize"));
+        QString alternatingRowColors2 = root.attribute(QLatin1String("alternatingRowColors"));
+        QString zoomPositionString = root.attribute(QLatin1String("zoomPosition"));
+        QString expandedGroups = root.attribute(QLatin1String("expandedGroups"));
+        stickH = (root.attribute(QLatin1String("stickH")) == QLatin1String("Y"));
+        stickV = (root.attribute(QLatin1String("stickV")) == QLatin1String("Y"));
 
         // Set column order
         QStringList listAtt;
@@ -261,9 +267,9 @@ void SKGTreeView::setState(const QString& iState)
             int nbsizes = sizes.count();
             for (int i = 0; i < nb; ++i) {
                 if (nbvisibilities == nb) {
-                    listAtt[i] = listAtt.at(i) % '|' % visibilities.at(i);
+                    listAtt[i] = listAtt.at(i) % QLatin1Char('|') % visibilities.at(i);
                     if (nbsizes == nb) {
-                        listAtt[i] = listAtt.at(i) % '|' % sizes.at(i);
+                        listAtt[i] = listAtt.at(i) % QLatin1Char('|') % sizes.at(i);
                     }
                 }
             }
@@ -274,7 +280,7 @@ void SKGTreeView::setState(const QString& iState)
 
         // Set autoResize
         if (!columnsAutoResize.isEmpty()) {
-            m_autoResize = (columnsAutoResize == QStringLiteral("Y"));
+            m_autoResize = (columnsAutoResize == QLatin1String("Y"));
             header()->setSectionResizeMode(m_autoResize ? QHeaderView::Fixed : QHeaderView::Interactive);
             if (!m_autoResize) {
                 m_timerDelayedResize.stop();
@@ -300,7 +306,7 @@ void SKGTreeView::setState(const QString& iState)
 
         if (m_model != nullptr) {
             QString att = m_groupby;
-            if (att == QStringLiteral("#")) {
+            if (att == QLatin1String("#")) {
                 att = sortColumn;
             }
             m_model->setGroupBy(att);
@@ -311,7 +317,7 @@ void SKGTreeView::setState(const QString& iState)
 
         // Set alternatingRowColors
         if (!alternatingRowColors2.isEmpty()) {
-            setAlternatingRowColors(alternatingRowColors2 == QStringLiteral("Y"));
+            setAlternatingRowColors(alternatingRowColors2 == QLatin1String("Y"));
         }
         if (!zoomPositionString.isEmpty()) {
             setZoomPosition(SKGServices::stringToInt(zoomPositionString));
@@ -453,7 +459,7 @@ void SKGTreeView::setupHeaderMenu()
     if ((m_model != nullptr) && (m_headerMenu != nullptr)) {
         // Corner button on tables to show the contextual menu
         auto btn = new QPushButton(this);
-        btn->setIcon(SKGServices::fromTheme(QStringLiteral("configure")));
+        btn->setIcon(SKGServices::fromTheme(QLatin1String("configure")));
         btn->setFocusPolicy(Qt::NoFocus);
         connect(btn, &QPushButton::clicked, this, static_cast<void (SKGTreeView::*)()>(&SKGTreeView::showHeaderMenu));
         setCornerWidget(btn);
@@ -466,12 +472,12 @@ void SKGTreeView::setupHeaderMenu()
         // Get current groupby column
         QMenu* groupbymenu = nullptr;
         QActionGroup* groupby = nullptr;
-        if (!m_model->getWhereClause().contains(QStringLiteral("ORDER BY"))) {
+        if (!m_model->getWhereClause().contains(QLatin1String("ORDER BY"))) {
             groupbymenu = m_headerMenu->addMenu(i18nc("Noun, Menu name", "Group by"));
             groupby = new QActionGroup(groupbymenu);
             m_actGroupByNone = groupbymenu->addAction(i18nc("Noun, grouping option", "None"));
             if (m_actGroupByNone != nullptr) {
-                m_actGroupByNone->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-cancel")));
+                m_actGroupByNone->setIcon(SKGServices::fromTheme(QLatin1String("dialog-cancel")));
                 m_actGroupByNone->setCheckable(true);
                 m_actGroupByNone->setChecked(m_groupby.isEmpty());
                 m_actGroupByNone->setData(QLatin1String(""));
@@ -480,10 +486,10 @@ void SKGTreeView::setupHeaderMenu()
             if (m_proxyModel != nullptr) {
                 QAction* actSort = groupbymenu->addAction(i18nc("Noun, grouping option", "Sorted column"));
                 if (actSort != nullptr) {
-                    actSort->setIcon(SKGServices::fromTheme(QStringLiteral("view-sort-ascending")));
+                    actSort->setIcon(SKGServices::fromTheme(QLatin1String("view-sort-ascending")));
                     actSort->setCheckable(true);
-                    actSort->setChecked(m_groupby == QStringLiteral("#"));
-                    actSort->setData(QStringLiteral("#"));
+                    actSort->setChecked(m_groupby == QLatin1String("#"));
+                    actSort->setData(QLatin1String("#"));
                     groupby->addAction(actSort);
                 }
             }
@@ -494,7 +500,7 @@ void SKGTreeView::setupHeaderMenu()
         SKGDocument::SKGModelTemplateList schemas = m_model->getSchemas();
         int nbSchemas = schemas.count();
         if (nbSchemas != 0) {
-            QMenu* viewAppearanceMenu = columns->addMenu(SKGServices::fromTheme(QStringLiteral("view-file-columns")), i18nc("Noun, user action", "View appearance"));
+            QMenu* viewAppearanceMenu = columns->addMenu(SKGServices::fromTheme(QLatin1String("view-file-columns")), i18nc("Noun, user action", "View appearance"));
 
             for (int i = 0; i < nbSchemas; ++i) {
                 SKGDocument::SKGModelTemplate schema = schemas.at(i);
@@ -508,10 +514,10 @@ void SKGTreeView::setupHeaderMenu()
             }
         }
 
-        QAction* actResize = columns->addAction(SKGServices::fromTheme(QStringLiteral("zoom-fit-width")), i18nc("Noun, user action", "Resize to content"));
+        QAction* actResize = columns->addAction(SKGServices::fromTheme(QLatin1String("zoom-fit-width")), i18nc("Noun, user action", "Resize to content"));
         connect(actResize, &QAction::triggered, this, &SKGTreeView::resizeColumnsToContents);
 
-        m_actAutoResize = columns->addAction(SKGServices::fromTheme(QStringLiteral("zoom-fit-width"), QStringList() << QStringLiteral("run-build")), i18nc("Noun, user action", "Auto resize"));
+        m_actAutoResize = columns->addAction(SKGServices::fromTheme(QLatin1String("zoom-fit-width"), QStringList() << QLatin1String("run-build")), i18nc("Noun, user action", "Auto resize"));
         m_actAutoResize->setCheckable(true);
         m_actAutoResize->setChecked(m_autoResize);
         connect(m_actAutoResize, &QAction::triggered, this, &SKGTreeView::switchAutoResize);
@@ -524,7 +530,7 @@ void SKGTreeView::setupHeaderMenu()
         }
 
         if (m_document != nullptr) {
-            QAction* actDefault = m_headerMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-save")), i18nc("Noun, user action", "Save parameters"));
+            QAction* actDefault = m_headerMenu->addAction(SKGServices::fromTheme(QLatin1String("document-save")), i18nc("Noun, user action", "Save parameters"));
             connect(actDefault, &QAction::triggered, this, &SKGTreeView::saveDefaultClicked);
         }
 
@@ -540,7 +546,7 @@ void SKGTreeView::setupHeaderMenu()
 
             if (!m_autoResizeDone) {
                 if (values.count() > 1) {
-                    hHeader->setSectionHidden(idx, values.at(1) == QStringLiteral("N"));
+                    hHeader->setSectionHidden(idx, values.at(1) == QLatin1String("N"));
                 }
                 if (values.count() > 2) {
                     auto s = SKGServices::stringToInt(values.at(2));
@@ -581,7 +587,7 @@ void SKGTreeView::setupHeaderMenu()
         }
         m_headerMenu->addSeparator();
 
-        QAction* actExport = m_headerMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Noun, user action", "Export…"));
+        QAction* actExport = m_headerMenu->addAction(SKGServices::fromTheme(QLatin1String("document-export")), i18nc("Noun, user action", "Export…"));
         connect(actExport, &QAction::triggered, this, &SKGTreeView::onExport);
 
         if (m_autoResize) {
@@ -614,7 +620,7 @@ void SKGTreeView::onSelectionChanged()
             int nb = indexes.count();
             QVector<QModelIndex> indexesToSource;
             indexesToSource.reserve(indexes.count());
-            for (const auto& index : qAsConst(indexes)) {
+            for (const auto& index : std::as_const(indexes)) {
                 indexesToSource.push_back(m_proxyModel != nullptr ? m_proxyModel->mapToSource(index) : index);
             }
 
@@ -687,7 +693,7 @@ void SKGTreeView::groupByChanged(QAction* iAction)
     if ((iAction != nullptr) && (m_model != nullptr)) {
         m_groupby = iAction->data().toString();
         QString att = m_groupby;
-        if (att == QStringLiteral("#") && (m_proxyModel != nullptr)) {
+        if (att == QLatin1String("#") && (m_proxyModel != nullptr)) {
             att = m_model->getAttribute(m_proxyModel->sortColumn());
         }
         m_model->setGroupBy(att);
@@ -701,7 +707,7 @@ void SKGTreeView::groupByChanged(QAction* iAction)
 void SKGTreeView::onSortChanged(int iIndex, Qt::SortOrder iOrder)
 {
     Q_UNUSED(iOrder)
-    if (m_groupby == QStringLiteral("#") && (m_model != nullptr)) {
+    if (m_groupby == QLatin1String("#") && (m_model != nullptr)) {
         m_model->setGroupBy(m_model->getAttribute(iIndex));
         m_model->refresh();
     }
@@ -766,8 +772,8 @@ QStringList SKGTreeView::getCurrentSchema() const
             for (int i = 0; i < nb; ++i) {
                 int idx = hHeader->logicalIndex(i);
                 att = m_model->getAttribute(idx);
-                att += QStringLiteral("|") % (hHeader->isSectionHidden(idx) ? QStringLiteral("N") : QStringLiteral("Y"));
-                att += QStringLiteral("|") % SKGServices::intToString(hHeader->sectionSize(idx));
+                att += QLatin1String("|") % (hHeader->isSectionHidden(idx) ? QLatin1String("N") : QLatin1String("Y"));
+                att += QLatin1String("|") % SKGServices::intToString(hHeader->sectionSize(idx));
 
                 list.push_back(att);
             }
@@ -810,7 +816,7 @@ void SKGTreeView::saveSelection()
             m_selection.push_back(id);
         }
     }
-    SKGTRACEL(10) << m_selection.count() << " objects saved" << SKGENDL;
+    SKGTRACEL(10) << m_selection.count() << " objects saved" << Qt::endl;
 }
 
 void SKGTreeView::selectObject(const QString& iUniqueID)
@@ -824,7 +830,7 @@ void SKGTreeView::selectObject(const QString& iUniqueID)
 void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirstOne)
 {
     SKGTRACEINFUNC(10)
-    SKGTRACEL(10) << iUniqueIDs.count() << " objects to select" << SKGENDL;
+    SKGTRACEL(10) << iUniqueIDs.count() << " objects to select" << Qt::endl;
     int nbset = 0;
     QItemSelectionModel* selModel = selectionModel();
     if (selModel != nullptr) {
@@ -856,7 +862,7 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
                     QString id = obj.getUniqueID();
                     if (obj.getTable().isEmpty()) {
                         // This is a group
-                        id = obj.getAttribute(QStringLiteral("t_title"));
+                        id = obj.getAttribute(QLatin1String("t_title"));
                     }
                     if (m_expandedNodes.contains(id)) {
                         QModelIndex idxs = (m_proxyModel != nullptr ? m_proxyModel->mapFromSource(index) : index);
@@ -886,7 +892,7 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
         selModel->blockSignals(previous);
     }
 
-    SKGTRACEL(10) << nbset << " objects selected" << SKGENDL;
+    SKGTRACEL(10) << nbset << " objects selected" << Qt::endl;
 
     onSelectionChanged();
 }
@@ -937,7 +943,7 @@ void SKGTreeView::onExpand(const QModelIndex& index)
         QString id = obj.getUniqueID();
         if (obj.getTable().isEmpty()) {
             // This is a group
-            id = obj.getAttribute(QStringLiteral("t_title"));
+            id = obj.getAttribute(QLatin1String("t_title"));
         }
         m_expandedNodes.push_back(id);
     }
@@ -968,7 +974,7 @@ void SKGTreeView::onCollapse(const QModelIndex& index)
         QString id = obj.getUniqueID();
         if (obj.getTable().isEmpty()) {
             // This is a group
-            id = obj.getAttribute(QStringLiteral("t_title"));
+            id = obj.getAttribute(QLatin1String("t_title"));
         }
         m_expandedNodes.removeOne(id);
     }
@@ -999,27 +1005,30 @@ void SKGTreeView::copy()
         std::sort(indexes.begin(), indexes.end());
 
         QStringList colums_title;
-        colums_title.reserve(indexes.count());
+        colums_title.reserve(2 * indexes.count());
         SKGStringListList columns_values;
-        for (const auto& current : qAsConst(indexes)) {
-            auto header_title = model()->headerData(current.column(), Qt::Horizontal).toString();
+        auto initial_r = -1;
+        for (const auto& current : std::as_const(indexes)) {
+            const auto c = current.column();
+            const auto r = current.row();
+            if (initial_r == -1) {
+                initial_r = r;
+            }
+            auto header_title = model()->headerData(c, Qt::Horizontal).toString();
             if (header_title.isEmpty()) {
-                header_title = SKGServices::splitCSVLine(model()->headerData(current.column(), Qt::Horizontal, Qt::UserRole).toString(), QLatin1Char('|')).at(0);
+                header_title = SKGServices::splitCSVLine(model()->headerData(c, Qt::Horizontal, Qt::UserRole).toString(), QLatin1Char('|')).at(0);
             }
 
-            auto pos = colums_title.indexOf(header_title);
-            if (pos == -1) {
+            if (initial_r == r) {
                 colums_title.append(header_title);
                 colums_title.append(header_title + QLatin1String("_raw"));
 
                 columns_values.append(QStringList());
                 columns_values.append(QStringList());
-
-                pos = colums_title.count() - 2;
             }
 
-            columns_values[pos].append(model()->data(current).toString());
-            columns_values[pos + 1].append(model()->data(current, Qt::UserRole).toString());
+            columns_values[2 * c].append(model()->data(current).toString());
+            columns_values[2 * c + 1].append(model()->data(current, Qt::UserRole).toString());
         }
 
         // Remove useless raw columns (when all raw values = displayed values)
@@ -1265,24 +1274,28 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
     _SKGTRACEINFUNC(10)
     QString codec = QTextCodec::codecForLocale()->name();
     QString extension = QFileInfo(iFileName).suffix().toUpper();
-    if (extension == QStringLiteral("CSV")) {
+    if (extension == QLatin1String("CSV")) {
         // Write file
         QSaveFile file(iFileName);
         if (!file.open(QIODevice::WriteOnly)) {
             err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", iFileName));
         } else {
             QTextStream out(&file);
+#ifdef SKG_QT6
+            out.setEncoding(QStringConverter::encodingForName(codec.toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
             out.setCodec(codec.toLatin1().constData());
+#endif
             QStringList dump = SKGServices::tableToDump(getTable(), SKGServices::DUMP_CSV);
             int nbl = dump.count();
             for (int i = 0; i < nbl; ++i) {
-                out << dump.at(i) << SKGENDL;
+                out << dump.at(i) << Qt::endl;
             }
 
             // Close file
             file.commit();
         }
-    } else if (extension == QStringLiteral("PDF")) {
+    } else if (extension == QLatin1String("PDF")) {
         QImage image(this->size(), QImage::Format_ARGB32);
         QPainter painter(&image);
         this->render(&painter);
@@ -1301,7 +1314,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
             newPainter.drawImage(0, 0, image);
             newPainter.end();
         }
-    } else if (extension == QStringLiteral("SVG")) {
+    } else if (extension == QLatin1String("SVG")) {
         QSvgGenerator generator;
         generator.setFileName(iFileName);
         generator.setTitle(i18nc("Title of the content SVG export", "Skrooge SVG export"));
@@ -1314,17 +1327,21 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
         generator.setViewBox(QRect(0, 0, w->widthMM(), w->heightMM()));
 
         painter.end();
-    } else if (extension == QStringLiteral("HTML")) {
+    } else if (extension == QLatin1String("HTML")) {
         // Write file
         QSaveFile file(iFileName);
         if (!file.open(QIODevice::WriteOnly)) {
             err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", iFileName));
         } else {
             QTextStream out(&file);
+#ifdef SKG_QT6
+            out.setEncoding(QStringConverter::encodingForName(codec.toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
             out.setCodec(codec.toLatin1().constData());
+#endif
             QTextBrowser* tb = getTextBrowser();
             if (tb != nullptr) {
-                out << tb->toHtml().replace(QStringLiteral("<meta name=\"qrichtext\" content=\"1\" />"), QStringLiteral("<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />")) << SKGENDL;
+                out << tb->toHtml().replace(QLatin1String("<meta name=\"qrichtext\" content=\"1\" />"), QLatin1String("<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />")) << Qt::endl;
 
                 delete tb;
             }
@@ -1332,7 +1349,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
             // Close file
             file.commit();
         }
-    } else if (extension == QStringLiteral("ODT")) {
+    } else if (extension == QLatin1String("ODT")) {
         QTextBrowser* tb = getTextBrowser();
         if (tb != nullptr) {
             QTextDocument doc;
@@ -1350,11 +1367,15 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
             err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", iFileName));
         } else {
             QTextStream out(&file);
+#ifdef SKG_QT6
+            out.setEncoding(QStringConverter::encodingForName(codec.toLatin1().constData()).value_or(QStringConverter::Utf8));
+#else
             out.setCodec(codec.toLatin1().constData());
+#endif
             QStringList dump = SKGServices::tableToDump(getTable(), SKGServices::DUMP_TEXT);
             int nbl = dump.count();
             for (int i = 0; i < nbl; ++i) {
-                out << dump.at(i) << SKGENDL;
+                out << dump.at(i) << Qt::endl;
             }
 
             // Close file
@@ -1368,7 +1389,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
 void SKGTreeView::onExport()
 {
     _SKGTRACEINFUNC(10)
-    QString fileName = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"), QStringLiteral("text/csv text/plain text/html application/vnd.oasis.opendocument.text  image/svg+xml application/pdf"), this);
+    QString fileName = SKGMainPanel::getSaveFileName(QLatin1String("kfiledialog:///IMPEXP"), QLatin1String("text/csv text/plain text/html application/vnd.oasis.opendocument.text  image/svg+xml application/pdf"), this);
     if (!fileName.isEmpty()) {
         SKGError err = exportInFile(fileName);
         SKGMainPanel::displayErrorMessage(err);
