@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -21,9 +21,9 @@
 #include <qtextdocumentwriter.h>
 #ifdef SKG_WEBENGINE
 #include <qwebenginepage.h>
+#ifdef SKG_QT6
+#include <qwebenginesettings.h>
 #endif
-#ifdef SKG_WEBKIT
-#include <qwebframe.h>
 #endif
 #include <qfileinfo.h>
 #include <qmath.h>
@@ -55,7 +55,7 @@ public:
     {
         if (type == QWebEnginePage::NavigationTypeLinkClicked) {
             if (url.toString().startsWith(QLatin1String("https://linkclicked/"))) {
-                SKGWebView* v = qobject_cast<SKGWebView*>(this->view());
+                SKGWebView* v = qobject_cast<SKGWebView*>(this->parent());
                 if (v) {
                     v->emitLinkClicked(url);
                     return false;
@@ -73,7 +73,12 @@ SKGWebView::SKGWebView(QWidget* iParent, const char* name, bool iWithContextualM
     : QWebEngineView(iParent), m_ContextualMenu(iWithContextualMenu)
 {
     setObjectName(name);
-    setPage(new SKGWebEnginePage(this));
+    const auto &p = new SKGWebEnginePage(this);
+#ifdef SKG_QT6
+    p->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, true);
+    p->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, true);
+#endif
+    setPage(p);
     if (m_ContextualMenu) {
         this->installEventFilter(this);
         page()->installEventFilter(this);
@@ -88,47 +93,7 @@ void SKGWebView::emitLinkClicked(const QUrl& iURL)
 {
     Q_EMIT linkClicked(iURL);
 }
-#endif
-#ifdef SKG_WEBKIT
-SKGWebView::SKGWebView(QWidget* iParent, const char* name)
-    : QWebView(iParent)
-{
-    setObjectName(name);
-    this->installEventFilter(this);
-    page()->installEventFilter(this);
-
-    connect(this, &SKGWebView::fileExporter, this, [](const QString & iFileName) {
-        QDesktopServices::openUrl(QUrl::fromLocalFile(iFileName));
-    });
-
-    connect(this, &SKGWebView::linkClicked, this, [ = ](const QUrl & val) {
-        SKGMainPanel::getMainPanel()->openPage(val);
-    });
-
-    this->page()->setForwardUnsupportedContent(true);
-    connect(this->page(), &QWebPage::unsupportedContent, this, [ = ](QNetworkReply * reply) {
-        openReply(reply);
-    });
-    connect(this->page(), &QWebPage::downloadRequested, this, [ = ](const QNetworkRequest & request) {
-        QNetworkAccessManager manager;
-        openReply(manager.get(request));
-    });
-}
-
-void SKGWebView::openReply(QNetworkReply* reply)
-{
-    QString fileName = QDir::tempPath() + '/' + "export.csv";
-    QFile file(fileName);
-    if (file.open(QIODevice::WriteOnly | QIODevice::Text)) {
-        file.write(reply->readAll());
-        file.close();
-    }
-    QDesktopServices::openUrl(QUrl::fromLocalFile(fileName));
-    reply->deleteLater();
-}
-#endif
-
-#if !defined(SKG_WEBENGINE) && !defined(SKG_WEBKIT)
+#else
 SKGWebView::SKGWebView(QWidget* iParent, const char* name) : QScrollArea(iParent)
 {
     auto label = new QLabel(this);
@@ -149,11 +114,11 @@ SKGWebView::~SKGWebView()
 QString SKGWebView::getState()
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
-    QDomElement root = doc.createElement(QStringLiteral("parameters"));
+    QDomDocument doc(QLatin1String("SKGML"));
+    QDomElement root = doc.createElement(QLatin1String("parameters"));
     doc.appendChild(root);
-#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
-    root.setAttribute(QStringLiteral("zoomFactor"), SKGServices::intToString(qMax(qRound(30.0 * log10(zoomFactor())), -10)));
+#if defined(SKG_WEBENGINE)
+    root.setAttribute(QLatin1String("zoomFactor"), SKGServices::intToString(qMax(qRound(30.0 * log10(zoomFactor())), -10)));
 #endif
     return doc.toString();
 }
@@ -161,11 +126,11 @@ QString SKGWebView::getState()
 void SKGWebView::setState(const QString& iState)
 {
     SKGTRACEINFUNC(10)
-    QDomDocument doc(QStringLiteral("SKGML"));
+    QDomDocument doc(QLatin1String("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
-#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
-    QString zoomPosition = root.attribute(QStringLiteral("zoomFactor"));
+#if defined(SKG_WEBENGINE)
+    QString zoomPosition = root.attribute(QLatin1String("zoomFactor"));
     if (zoomPosition.isEmpty()) {
         zoomPosition = '0';
     }
@@ -175,7 +140,7 @@ void SKGWebView::setState(const QString& iState)
 #endif
 }
 
-#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
+#if defined(SKG_WEBENGINE)
 void SKGWebView::contextMenuEvent(QContextMenuEvent* iEvent)
 {
     if (iEvent != nullptr) {
@@ -183,16 +148,12 @@ void SKGWebView::contextMenuEvent(QContextMenuEvent* iEvent)
 #ifdef SKG_WEBENGINE
         menu->addAction(pageAction(QWebEnginePage::Copy));
 #endif
-#ifdef SKG_WEBKIT
-        menu->addAction(pageAction(QWebPage::Copy));
-#endif
-
-        QAction* actPrint = menu->addAction(SKGServices::fromTheme(QStringLiteral("printer")), i18nc("Action", "Print…"));
+        QAction* actPrint = menu->addAction(SKGServices::fromTheme(QLatin1String("printer")), i18nc("Action", "Print…"));
         connect(actPrint, &QAction::triggered, this, &SKGWebView::onPrint);
 
         menu->addAction(KStandardAction::printPreview(this, SLOT(onPrintPreview()), this));
 
-        QAction* actExport = menu->addAction(SKGServices::fromTheme(QStringLiteral("document-export")), i18nc("Noun, user action", "Export…"));
+        QAction* actExport = menu->addAction(SKGServices::fromTheme(QLatin1String("document-export")), i18nc("Noun, user action", "Export…"));
         connect(actExport, &QAction::triggered, this, &SKGWebView::onExport);
 
         menu->popup(this->mapToGlobal(iEvent->pos()));
@@ -227,7 +188,7 @@ bool SKGWebView::eventFilter(QObject* iObject, QEvent* iEvent)
 void SKGWebView::onZoomIn()
 {
     _SKGTRACEINFUNC(10)
-#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
+#if defined(SKG_WEBENGINE)
     int z = qMin(static_cast<int>(qRound(30.0 * log10(zoomFactor()))) + 1, 10);
     setZoomFactor(qPow(10, static_cast<qreal>(z) / 30.0));
     Q_EMIT zoomChanged(z);
@@ -237,7 +198,7 @@ void SKGWebView::onZoomIn()
 void SKGWebView::onZoomOut()
 {
     _SKGTRACEINFUNC(10)
-#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
+#if defined(SKG_WEBENGINE)
     int z = qMax(static_cast<int>(qRound(30.0 * log10(zoomFactor()))) - 1, -10);
     setZoomFactor(qPow(10, static_cast<qreal>(z) / 30.0));
     Q_EMIT zoomChanged(z);
@@ -247,7 +208,7 @@ void SKGWebView::onZoomOut()
 void SKGWebView::onZoomOriginal()
 {
     _SKGTRACEINFUNC(10)
-#if defined(SKG_WEBENGINE) || defined(SKG_WEBKIT)
+#if defined(SKG_WEBENGINE)
     setZoomFactor(0);
     Q_EMIT zoomChanged(0);
 #endif
@@ -256,7 +217,7 @@ void SKGWebView::onZoomOriginal()
 void SKGWebView::exportInFile(const QString& iFileName)
 {
     QString extension = QFileInfo(iFileName).suffix().toUpper();
-    if (extension == QStringLiteral("ODT")) {
+    if (extension == QLatin1String("ODT")) {
 #ifdef SKG_WEBENGINE
         page()->toHtml([ = ](const QString & result) {
             QTextDocument doc;
@@ -267,27 +228,12 @@ void SKGWebView::exportInFile(const QString& iFileName)
             Q_EMIT fileExporter(iFileName);
         });
 #endif
-#ifdef SKG_WEBKIT
-        QTextDocument doc;
-        QTextDocumentWriter docWriter(iFileName);
-        doc.setHtml(page()->mainFrame()->toHtml());
-        docWriter.write(&doc);
-
-        Q_EMIT fileExporter(iFileName);
-#endif
-    } else if (extension == QStringLiteral("PDF")) {
+    } else if (extension == QLatin1String("PDF")) {
 #ifdef SKG_WEBENGINE
         page()->printToPdf(iFileName);
         connect(page(), &QWebEnginePage::pdfPrintingFinished, this, &SKGWebView::fileExporter);
 #endif
-#ifdef SKG_WEBKIT
-        QPrinter printer;
-        printer.setOutputFileName(iFileName);
-        print(&printer);
-
-        Q_EMIT fileExporter(iFileName);
-#endif
-    } else if (extension == QStringLiteral("HTML") || extension == QStringLiteral("HTM")) {
+    } else if (extension == QLatin1String("HTML") || extension == QLatin1String("HTM")) {
 #ifdef SKG_WEBENGINE
         page()->toHtml([ = ](const QString & result) {
             QSaveFile file(iFileName);
@@ -300,17 +246,6 @@ void SKGWebView::exportInFile(const QString& iFileName)
                 Q_EMIT fileExporter(iFileName);
             }
         });
-#endif
-#ifdef SKG_WEBKIT
-        QSaveFile file(iFileName);
-        if (file.open(QIODevice::WriteOnly)) {
-            QTextStream out(&file);
-            out << page()->mainFrame()->toHtml();
-
-            // Close file
-            file.commit();
-            Q_EMIT fileExporter(iFileName);
-        }
 #endif
     } else {
         QImage image(this->size(), QImage::Format_ARGB32);
@@ -326,7 +261,7 @@ void SKGWebView::exportInFile(const QString& iFileName)
 void SKGWebView::onExport()
 {
     _SKGTRACEINFUNC(10)
-    QString fileName = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"), QStringLiteral("application/pdf text/html application/vnd.oasis.opendocument.text image/png image/jpeg image/gif image/tiff"), this);
+    QString fileName = SKGMainPanel::getSaveFileName(QLatin1String("kfiledialog:///IMPEXP"), QLatin1String("application/pdf text/html application/vnd.oasis.opendocument.text image/png image/jpeg image/gif image/tiff"), this);
     if (fileName.isEmpty()) {
         return;
     }
@@ -341,13 +276,13 @@ void SKGWebView::onPrintPreview()
 #ifdef SKG_WEBENGINE
     // TODO(SMI): QWebEngine
     connect(dialog.data(), &QPrintPreviewDialog::paintRequested, page(), [&](QPrinter * printer) {
+#ifdef SKG_QT6
+        print(printer);
+#else
         page()->print(printer, [](bool) {});
+#endif
     });
 #endif
-#ifdef SKG_WEBKIT
-    connect(dialog.data(), &QPrintPreviewDialog::paintRequested, this, &SKGWebView::print);
-#endif
-
     dialog->exec();
 }
 
@@ -358,10 +293,11 @@ void SKGWebView::onPrint()
     if (dialog->exec() == QDialog::Accepted) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 #ifdef SKG_WEBENGINE
+#ifdef SKG_QT6
+        print(&m_printer);
+#else
         page()->print(&m_printer, [](bool) {});
 #endif
-#ifdef SKG_WEBKIT
-        print(&m_printer);
 #endif
         QApplication::restoreOverrideCursor();
     }
