@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -12,6 +12,7 @@
 #include "skgdefine.h"
 
 #include <qtoolbutton.h>
+#include <utility>
 
 SKGWidgetSelector::SKGWidgetSelector(QWidget* iParent)
     : QWidget(iParent), m_currentMode(-1), m_alwaysOneOpen(false)
@@ -49,7 +50,7 @@ void SKGWidgetSelector::addButton(const QIcon& iIcon, const QString& iTitle, con
 
     // Hide widgets
     SKGWidgetSelector::SKGListQWidget list;
-    for (auto w : qAsConst(iListOfShownWidgets)) {
+    for (auto w : std::as_const(iListOfShownWidgets)) {
         if (w != nullptr) {
             // Addition of an intermediate widget
             /*auto widget = new QWidget(w->parentWidget());
@@ -81,7 +82,7 @@ void SKGWidgetSelector::setSelectedMode(int iMode)
             m_listButton.at(m_currentMode)->setChecked(false);
             SKGListQWidget list = m_listWidgets.at(m_currentMode);
 
-            for (auto w : qAsConst(list)) {
+            for (auto w : std::as_const(list)) {
                 if (w != nullptr) {
                     /*if (iMode == -1) {
                         auto anim1 = new QPropertyAnimation(w, "geometry");
@@ -112,7 +113,7 @@ void SKGWidgetSelector::setSelectedMode(int iMode)
         // Show widgets
         if (m_currentMode >= 0) {
             m_listButton.at(m_currentMode)->setChecked(true);
-            for (auto w : qAsConst(m_listWidgets.at(m_currentMode))) {
+            for (auto w : std::as_const(m_listWidgets.at(m_currentMode))) {
                 if (w != nullptr) {
                     w->show();
                     /*if (previousmode == -1) {
