@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -17,9 +17,9 @@ SKGZoomSelector::SKGZoomSelector(QWidget* iParent)
     ui.setupUi(this);
 
     // Set icons
-    ui.kZoomIn->setIcon(SKGServices::fromTheme(QStringLiteral("zoom-in")));
-    ui.kZoomOut->setIcon(SKGServices::fromTheme(QStringLiteral("zoom-out")));
-    ui.kZoomOriginal->setIcon(SKGServices::fromTheme(QStringLiteral("zoom-original")));
+    ui.kZoomIn->setIcon(SKGServices::fromTheme(QLatin1String("zoom-in")));
+    ui.kZoomOut->setIcon(SKGServices::fromTheme(QLatin1String("zoom-out")));
+    ui.kZoomOriginal->setIcon(SKGServices::fromTheme(QLatin1String("zoom-original")));
 
     connect(ui.kZoomOriginal, &QToolButton::clicked, this, &SKGZoomSelector::initializeZoom);
     connect(ui.kZoomOut, &QToolButton::clicked, this, &SKGZoomSelector::zoomOut);
