@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -43,27 +43,27 @@ QWidget* SKGCalculatorEditDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGCalculatorEditDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGCalculatorEdit");
+    return QLatin1String("SKGCalculatorEdit");
 }
 
 QString SKGCalculatorEditDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGCalculatorEditDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGCalculatorEditDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A QLineEdit with calculator included");
+    return QLatin1String("A QLineEdit with calculator included");
 }
 
 QString SKGCalculatorEditDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A QLineEdit with calculator included");
+    return QLatin1String("A QLineEdit with calculator included");
 }
 
 bool SKGCalculatorEditDesignerPlugin::isContainer() const
@@ -73,20 +73,20 @@ bool SKGCalculatorEditDesignerPlugin::isContainer() const
 
 QString SKGCalculatorEditDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGCalculatorEdit\" name=\"SKGCalculatorEdit\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>10</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGCalculatorEdit\" name=\"SKGCalculatorEdit\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>10</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGCalculatorEditDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgcalculatoredit.h");
+    return QLatin1String("skgcalculatoredit.h");
 }
 
