@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -41,27 +41,27 @@ QWidget* SKGColorButtonDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGColorButtonDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGColorButton");
+    return QLatin1String("SKGColorButton");
 }
 
 QString SKGColorButtonDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGColorButtonDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGColorButtonDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A color button with more features");
+    return QLatin1String("A color button with more features");
 }
 
 QString SKGColorButtonDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A color button with more features");
+    return QLatin1String("A color button with more features");
 }
 
 bool SKGColorButtonDesignerPlugin::isContainer() const
@@ -71,20 +71,20 @@ bool SKGColorButtonDesignerPlugin::isContainer() const
 
 QString SKGColorButtonDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGColorButton\" name=\"SKGColorButton\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>10</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGColorButton\" name=\"SKGColorButton\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>10</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGColorButtonDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgcolorbutton.h");
+    return QLatin1String("skgcolorbutton.h");
 }
 
