@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -41,27 +41,27 @@ QWidget* SKGComboBoxDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGComboBoxDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGComboBox");
+    return QLatin1String("SKGComboBox");
 }
 
 QString SKGComboBoxDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGComboBoxDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGComboBoxDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A combo box with more features");
+    return QLatin1String("A combo box with more features");
 }
 
 QString SKGComboBoxDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A combo box with more features");
+    return QLatin1String("A combo box with more features");
 }
 
 bool SKGComboBoxDesignerPlugin::isContainer() const
@@ -71,20 +71,20 @@ bool SKGComboBoxDesignerPlugin::isContainer() const
 
 QString SKGComboBoxDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGComboBox\" name=\"SKGComboBox\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>10</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGComboBox\" name=\"SKGComboBox\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>10</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGComboBoxDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgcombobox.h");
+    return QLatin1String("skgcombobox.h");
 }
 
