@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -44,27 +44,27 @@ QWidget* SKGFilteredTableViewDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGFilteredTableViewDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGFilteredTableView");
+    return QLatin1String("SKGFilteredTableView");
 }
 
 QString SKGFilteredTableViewDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGFilteredTableViewDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGFilteredTableViewDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A filetered SKGTableView");
+    return QLatin1String("A filetered SKGTableView");
 }
 
 QString SKGFilteredTableViewDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A filetered SKGTableView");
+    return QLatin1String("A filetered SKGTableView");
 }
 
 bool SKGFilteredTableViewDesignerPlugin::isContainer() const
@@ -74,20 +74,20 @@ bool SKGFilteredTableViewDesignerPlugin::isContainer() const
 
 QString SKGFilteredTableViewDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGFilteredTableView\" name=\"SKGFilteredTableView\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>10</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGFilteredTableView\" name=\"SKGFilteredTableView\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>10</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGFilteredTableViewDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgfilteredtableview.h");
+    return QLatin1String("skgfilteredtableview.h");
 }
 
