@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -43,27 +43,27 @@ QWidget* SKGGraphicsViewDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGGraphicsViewDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGGraphicsView");
+    return QLatin1String("SKGGraphicsView");
 }
 
 QString SKGGraphicsViewDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGGraphicsViewDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGGraphicsViewDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A Graphic view");
+    return QLatin1String("A Graphic view");
 }
 
 QString SKGGraphicsViewDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A Graphic view");
+    return QLatin1String("A Graphic view");
 }
 
 bool SKGGraphicsViewDesignerPlugin::isContainer() const
@@ -73,20 +73,20 @@ bool SKGGraphicsViewDesignerPlugin::isContainer() const
 
 QString SKGGraphicsViewDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGGraphicsView\" name=\"SKGGraphicsView\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>100</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGGraphicsView\" name=\"SKGGraphicsView\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>100</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGGraphicsViewDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skggraphicsview.h");
+    return QLatin1String("skggraphicsview.h");
 }
 
