@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -43,27 +43,27 @@ QWidget* SKGPeriodEditDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGPeriodEditDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGPeriodEdit");
+    return QLatin1String("SKGPeriodEdit");
 }
 
 QString SKGPeriodEditDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGPeriodEditDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGPeriodEditDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A period editor");
+    return QLatin1String("A period editor");
 }
 
 QString SKGPeriodEditDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A period editor");
+    return QLatin1String("A period editor");
 }
 
 bool SKGPeriodEditDesignerPlugin::isContainer() const
@@ -73,20 +73,20 @@ bool SKGPeriodEditDesignerPlugin::isContainer() const
 
 QString SKGPeriodEditDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGPeriodEdit\" name=\"SKGPeriodEdit\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>10</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGPeriodEdit\" name=\"SKGPeriodEdit\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>10</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGPeriodEditDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgperiodedit.h");
+    return QLatin1String("skgperiodedit.h");
 }
 
