@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -43,27 +43,27 @@ QWidget* SKGProgressBarDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGProgressBarDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGProgressBar");
+    return QLatin1String("SKGProgressBar");
 }
 
 QString SKGProgressBarDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGProgressBarDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGProgressBarDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A progress bar with colors");
+    return QLatin1String("A progress bar with colors");
 }
 
 QString SKGProgressBarDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A progress bar with colors");
+    return QLatin1String("A progress bar with colors");
 }
 
 bool SKGProgressBarDesignerPlugin::isContainer() const
@@ -73,20 +73,20 @@ bool SKGProgressBarDesignerPlugin::isContainer() const
 
 QString SKGProgressBarDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGProgressBar\" name=\"SKGProgressBar\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>10</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGProgressBar\" name=\"SKGProgressBar\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>10</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGProgressBarDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgprogressbar.h");
+    return QLatin1String("skgprogressbar.h");
 }
 
