@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -42,27 +42,27 @@ QWidget* SKGTableViewDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGTableViewDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGTableView");
+    return QLatin1String("SKGTableView");
 }
 
 QString SKGTableViewDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGTableViewDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGTableViewDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A table view with more features");
+    return QLatin1String("A table view with more features");
 }
 
 QString SKGTableViewDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A table view with more features");
+    return QLatin1String("A table view with more features");
 }
 
 bool SKGTableViewDesignerPlugin::isContainer() const
@@ -72,20 +72,20 @@ bool SKGTableViewDesignerPlugin::isContainer() const
 
 QString SKGTableViewDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGTableView\" name=\"SKGTableView\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>100</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGTableView\" name=\"SKGTableView\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>100</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGTableViewDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgtableview.h");
+    return QLatin1String("skgtableview.h");
 }
 
