@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -44,27 +44,27 @@ QWidget* SKGTableWithGraphDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGTableWithGraphDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGTableWithGraph");
+    return QLatin1String("SKGTableWithGraph");
 }
 
 QString SKGTableWithGraphDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGTableWithGraphDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGTableWithGraphDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A Table with graph");
+    return QLatin1String("A Table with graph");
 }
 
 QString SKGTableWithGraphDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A Table with graph");
+    return QLatin1String("A Table with graph");
 }
 
 bool SKGTableWithGraphDesignerPlugin::isContainer() const
@@ -74,20 +74,20 @@ bool SKGTableWithGraphDesignerPlugin::isContainer() const
 
 QString SKGTableWithGraphDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGTableWithGraph\" name=\"SKGTableWithGraph\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>100</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGTableWithGraph\" name=\"SKGTableWithGraph\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>100</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGTableWithGraphDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgtablewithgraph.h");
+    return QLatin1String("skgtablewithgraph.h");
 }
 
