@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -42,27 +42,27 @@ QWidget* SKGTreeViewDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGTreeViewDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGTreeView");
+    return QLatin1String("SKGTreeView");
 }
 
 QString SKGTreeViewDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGTreeViewDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGTreeViewDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A tree view with more features");
+    return QLatin1String("A tree view with more features");
 }
 
 QString SKGTreeViewDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A tree view with more features");
+    return QLatin1String("A tree view with more features");
 }
 
 bool SKGTreeViewDesignerPlugin::isContainer() const
@@ -72,20 +72,20 @@ bool SKGTreeViewDesignerPlugin::isContainer() const
 
 QString SKGTreeViewDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGTreeView\" name=\"SKGTreeView\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>100</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGTreeView\" name=\"SKGTreeView\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>100</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGTreeViewDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgtreeview.h");
+    return QLatin1String("skgtreeview.h");
 }
 
