@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -43,27 +43,27 @@ QWidget* SKGWebViewDesignerPlugin::createWidget(QWidget* iParent)
 
 QString SKGWebViewDesignerPlugin::name() const
 {
-    return QStringLiteral("SKGWebView");
+    return QLatin1String("SKGWebView");
 }
 
 QString SKGWebViewDesignerPlugin::group() const
 {
-    return QStringLiteral("SKG Widgets");
+    return QLatin1String("SKG Widgets");
 }
 
 QIcon SKGWebViewDesignerPlugin::icon() const
 {
-    return SKGServices::fromTheme(QStringLiteral("quickopen"));
+    return SKGServices::fromTheme(QLatin1String("quickopen"));
 }
 
 QString SKGWebViewDesignerPlugin::toolTip() const
 {
-    return QStringLiteral("A web viewer with more features");
+    return QLatin1String("A web viewer with more features");
 }
 
 QString SKGWebViewDesignerPlugin::whatsThis() const
 {
-    return QStringLiteral("A web viewer with more features");
+    return QLatin1String("A web viewer with more features");
 }
 
 bool SKGWebViewDesignerPlugin::isContainer() const
@@ -73,20 +73,20 @@ bool SKGWebViewDesignerPlugin::isContainer() const
 
 QString SKGWebViewDesignerPlugin::domXml() const
 {
-    return QStringLiteral("<widget class=\"SKGWebView\" name=\"SKGWebView\">\n"
-                          " <property name=\"geometry\">\n"
-                          "  <rect>\n"
-                          "   <x>0</x>\n"
-                          "   <y>0</y>\n"
-                          "   <width>100</width>\n"
-                          "   <height>10</height>\n"
-                          "  </rect>\n"
-                          " </property>\n"
-                          "</widget>\n");
+    return QLatin1String("<widget class=\"SKGWebView\" name=\"SKGWebView\">\n"
+                         " <property name=\"geometry\">\n"
+                         "  <rect>\n"
+                         "   <x>0</x>\n"
+                         "   <y>0</y>\n"
+                         "   <width>100</width>\n"
+                         "   <height>10</height>\n"
+                         "  </rect>\n"
+                         " </property>\n"
+                         "</widget>\n");
 }
 
 QString SKGWebViewDesignerPlugin::includeFile() const
 {
-    return QStringLiteral("skgwebview.h");
+    return QLatin1String("skgwebview.h");
 }
 
