@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -10,6 +10,7 @@
 */
 #include "skgadvice.h"
 #include "skgdefine.h"
+#include <utility>
 
 SKGAdvice::SKGAdvice() :  QObject()
 {}
@@ -93,7 +94,7 @@ void SKGAdvice::setAutoCorrections(const QStringList& iCorrections)
 {
     SKGAdvice::SKGAdviceActionList tmp;
     tmp.reserve(iCorrections.count());
-    for (const auto& c : qAsConst(iCorrections)) {
+    for (const auto& c : std::as_const(iCorrections)) {
         SKGAdviceAction a;
         a.Title = c;
         a.IsRecommended = false;
