@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGDEFINE_H
@@ -17,19 +17,11 @@
 
 #include "skgbasemodeler_export.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-#define SKGENDL endl
-#define SKGFLUSH flush
-#else
-#define SKGENDL Qt::endl
-#define SKGFLUSH Qt::flush
-#endif
-
 /**
  * @var OBJECTSEPARATOR
  * Define the separator between object and subobject
  */
-#define OBJECTSEPARATOR QStringLiteral(" > ")
+#define OBJECTSEPARATOR QLatin1String(" > ")
 
 /**
  * @var DUMPSQLITE
@@ -166,7 +158,7 @@
 /**
  * @brief For a not modified field
  **/
-#define NOUPDATE QStringLiteral("-------")
+#define NOUPDATE QLatin1String("-------")
 
 /**
   * @var EPSILON
