@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGDOCUMENT_H
@@ -316,7 +316,7 @@ public:
      */
     virtual SKGError setParameter(const QString& iName, const QString& iValue,
                                   const QString& iFileName = QString(),
-                                  const QString& iParentUUID = QStringLiteral("document"),
+                                  const QString& iParentUUID = QLatin1String("document"),
                                   SKGPropertyObject* oObjectCreated = nullptr) const;
 
     /**
@@ -333,7 +333,7 @@ public:
      */
     virtual SKGError setParameter(const QString& iName, const QString& iValue,
                                   const QVariant& iBlob,
-                                  const QString& iParentUUID = QStringLiteral("document"),
+                                  const QString& iParentUUID = QLatin1String("document"),
                                   SKGPropertyObject* oObjectCreated = nullptr) const;
 
     /**
@@ -350,7 +350,7 @@ public:
      * @param iParentUUID the unique identifier of the object owning this parameter.
      * @return the value.
      */
-    virtual QString getParameter(const QString& iName, const QString& iParentUUID = QStringLiteral("document")) const;
+    virtual QString getParameter(const QString& iName, const QString& iParentUUID = QLatin1String("document")) const;
 
     /**
      * Get a parameter blob
@@ -358,7 +358,7 @@ public:
      * @param iParentUUID the unique identifier of the object owning this parameter.
      * @return the blob.
      */
-    virtual QVariant getParameterBlob(const QString& iName, const QString& iParentUUID = QStringLiteral("document")) const;
+    virtual QVariant getParameterBlob(const QString& iName, const QString& iParentUUID = QLatin1String("document")) const;
 
     /**
      * Get the database pointer.
@@ -407,7 +407,7 @@ public:
                                          const QString& iOpAtt,
                                          const QString& iWhereClause,
                                          SKGStringListList& oTable,
-                                         const QString& iMissingValue = QStringLiteral("0")) const;
+                                         const QString& iMissingValue = QLatin1String("0")) const;
 
     /**
      * Get the display string for any modeler object (table, attribute)
@@ -903,10 +903,11 @@ public Q_SLOTS:
 
     /**
      * close the current SKGDocument.
+     * @param iDeletingDocument to know if the deletion of the document is ongoing.
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError close();
+    SKGError close(bool iDeletingDocument = false);
 
     /**
      * Add a sql result in the cache. Cache is cleaned after each transaction
@@ -1016,5 +1017,5 @@ private:
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO(SKGDocument, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(SKGDocument, Q_COMPLEX_TYPE);
 #endif
