@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -23,8 +23,8 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers(bool iForce) const
     */
     QString rd_node_id;
     QStringList attsOfNodes;
-    err = getAttributesList(QStringLiteral("node"), attsOfNodes);
-    rd_node_id = (attsOfNodes.contains(QStringLiteral("rd_node_id")) ? QStringLiteral("rd_node_id") : QStringLiteral("r_node_id"));
+    err = getAttributesList(QLatin1String("node"), attsOfNodes);
+    rd_node_id = (attsOfNodes.contains(QLatin1String("rd_node_id")) ? QLatin1String("rd_node_id") : QLatin1String("r_node_id"));
 
     QStringList InitialDataModelTrigger;
     InitialDataModelTrigger
@@ -32,13 +32,13 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers(bool iForce) const
             << DELETECASCADEPARAMETER("node")
 
             // Compute fullname
-            << QStringLiteral("DROP TRIGGER IF EXISTS cpt_node_fullname3")
+            << QLatin1String("DROP TRIGGER IF EXISTS cpt_node_fullname3")
             /*<< "CREATE TRIGGER cpt_node_fullname1 " // This trigger must be the first
             "AFTER UPDATE OF t_fullname ON node BEGIN "
             "UPDATE node SET t_name=t_name WHERE rd_node_id=new.id;"
             "END"*/
 
-            << QStringLiteral("DROP TRIGGER IF EXISTS cpt_node_fullname1")
+            << QLatin1String("DROP TRIGGER IF EXISTS cpt_node_fullname1")
             << "CREATE TRIGGER cpt_node_fullname1 "
             "AFTER INSERT ON node BEGIN "
             "UPDATE node SET t_fullname="
@@ -46,7 +46,7 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers(bool iForce) const
             "WHERE id=new.id;"
             "END"
 
-            << QStringLiteral("DROP TRIGGER IF EXISTS cpt_node_fullname2")
+            << QLatin1String("DROP TRIGGER IF EXISTS cpt_node_fullname2")
             << "CREATE TRIGGER cpt_node_fullname2 "
             "AFTER UPDATE OF t_name, " % rd_node_id % " ON node BEGIN "
             "UPDATE node SET t_fullname="
@@ -55,44 +55,44 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers(bool iForce) const
             "UPDATE node SET t_name=t_name WHERE " % rd_node_id % "=new.id;"
             "END"
 
-            << QStringLiteral("DROP TRIGGER IF EXISTS fkdc_node_parent_id_node_id");
+            << QLatin1String("DROP TRIGGER IF EXISTS fkdc_node_parent_id_node_id");
 
     /**
     * This constant is used to initialized the data model (index creation)
     */
     QStringList InitialDataModelIndex;
-    InitialDataModelIndex << QStringLiteral("CREATE UNIQUE INDEX uidx_parameters_uuid_parent_name ON parameters (t_uuid_parent, t_name)")
+    InitialDataModelIndex << QLatin1String("CREATE UNIQUE INDEX uidx_parameters_uuid_parent_name ON parameters (t_uuid_parent, t_name)")
 
                           << "CREATE UNIQUE INDEX uidx_node_parent_id_name ON node(t_name," % rd_node_id % ")"
-                          << QStringLiteral("CREATE INDEX idx_node_fullname ON node(t_fullname)")
+                          << QLatin1String("CREATE INDEX idx_node_fullname ON node(t_fullname)")
 
-                          << QStringLiteral("CREATE INDEX idx_doctransaction_parent ON doctransaction (i_parent)")
-                          << QStringLiteral("CREATE INDEX idx_doctransactionitem_i_object_id ON doctransactionitem (i_object_id)")
-                          << QStringLiteral("CREATE INDEX idx_doctransactionitem_t_object_table ON doctransactionitem (t_object_table)")
-                          << QStringLiteral("CREATE INDEX idx_doctransactionitem_t_action ON doctransactionitem (t_action)")
-                          << QStringLiteral("CREATE INDEX idx_doctransactionitem_rd_doctransaction_id ON doctransactionitem (rd_doctransaction_id)")
-                          << QStringLiteral("CREATE INDEX idx_doctransactionitem_optimization ON doctransactionitem (rd_doctransaction_id, i_object_id, t_object_table, t_action, t_sqlorder, id)");
+                          << QLatin1String("CREATE INDEX idx_doctransaction_parent ON doctransaction (i_parent)")
+                          << QLatin1String("CREATE INDEX idx_doctransactionitem_i_object_id ON doctransactionitem (i_object_id)")
+                          << QLatin1String("CREATE INDEX idx_doctransactionitem_t_object_table ON doctransactionitem (t_object_table)")
+                          << QLatin1String("CREATE INDEX idx_doctransactionitem_t_action ON doctransactionitem (t_action)")
+                          << QLatin1String("CREATE INDEX idx_doctransactionitem_rd_doctransaction_id ON doctransactionitem (rd_doctransaction_id)")
+                          << QLatin1String("CREATE INDEX idx_doctransactionitem_optimization ON doctransactionitem (rd_doctransaction_id, i_object_id, t_object_table, t_action, t_sqlorder, id)");
 
     /**
     * This constant is used to initialized the data model (view creation)
     */
     QStringList InitialDataModelView;
-    InitialDataModelView << QStringLiteral("CREATE VIEW  v_node AS SELECT * from node")
-                         << QStringLiteral("CREATE VIEW v_node_displayname AS SELECT *, t_fullname AS t_displayname from node")
-                         << QStringLiteral("CREATE VIEW v_parameters_displayname AS SELECT *, t_name AS t_displayname from parameters")
-                         << QStringLiteral("CREATE VIEW v_doctransaction_displayname AS SELECT *, t_name AS t_displayname from doctransaction");
+    InitialDataModelView << QLatin1String("CREATE VIEW  v_node AS SELECT * from node")
+                         << QLatin1String("CREATE VIEW v_node_displayname AS SELECT *, t_fullname AS t_displayname from node")
+                         << QLatin1String("CREATE VIEW v_parameters_displayname AS SELECT *, t_name AS t_displayname from parameters")
+                         << QLatin1String("CREATE VIEW v_doctransaction_displayname AS SELECT *, t_name AS t_displayname from doctransaction");
 
-    IFOKDO(err, dropViewsAndIndexes(QStringList() << QStringLiteral("node") << QStringLiteral("parameters") << QStringLiteral("doctransactionitem") << QStringLiteral("doctransaction")))
+    IFOKDO(err, dropViewsAndIndexes(QStringList() << QLatin1String("node") << QLatin1String("parameters") << QLatin1String("doctransactionitem") << QLatin1String("doctransaction")))
     IFOKDO(err, executeSqliteOrders(InitialDataModelIndex))
     IFOKDO(err, executeSqliteOrders(InitialDataModelView))
     IFOKDO(err, executeSqliteOrders(InitialDataModelTrigger))
     IFOK(err) {
         // Refresh dynamic triggers
-        QRegularExpression rx_rd(QStringLiteral("rd_([^_]+)_([^_]+).*"));
-        QRegularExpression rx_rc(QStringLiteral("rc_([^_]+)_([^_]+).*"));
-        QRegularExpression rx_r(QStringLiteral("r_([^_]+)_([^_]+).*"));
+        QRegularExpression rx_rd(QLatin1String("rd_([^_]+)_([^_]+).*"));
+        QRegularExpression rx_rc(QLatin1String("rc_([^_]+)_([^_]+).*"));
+        QRegularExpression rx_r(QLatin1String("r_([^_]+)_([^_]+).*"));
         QStringList dbTables;
-        err = this->getDistinctValues(QStringLiteral("sqlite_master"), QStringLiteral("name"), QStringLiteral("type='table'"), dbTables);
+        err = this->getDistinctValues(QLatin1String("sqlite_master"), QLatin1String("name"), QLatin1String("type='table'"), dbTables);
         int nb = dbTables.count();
         for (int i = 0; !err && i < nb; ++i) {
             const QString& table = dbTables.at(i);
@@ -128,14 +128,14 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers(bool iForce) const
                             sqlOrders << FOREIGNCONSTRAINTUPDATE(tab2, att2, table, att);
                             err = executeSqliteOrders(sqlOrders);
                             // The following sql order error is not caught because this repair order is not mandatory
-                            executeSqliteOrder("UPDATE " % table % " SET " % att % "=0 WHERE " % att % "!=0 AND " % att % " NOT IN (SELECT DISTINCT(" % att2 % ") FROM " % tab2 % ')');
+                            executeSqliteOrder("UPDATE " % table % " SET " % att % "=0 WHERE " % att % "!=0 AND " % att % " NOT IN (SELECT DISTINCT(" % att2 % ") FROM " % tab2 % QLatin1Char(')'));
                         }
                     }
                 }
             }
         }
     }
-    IFOKDO(err, executeSqliteOrder(QStringLiteral("ANALYZE")))
+    IFOKDO(err, executeSqliteOrder(QLatin1String("ANALYZE")))
 
     return err;
 }
