@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -125,7 +125,7 @@ QString SKGError::getProperty() const
 QString SKGError::getFullMessage() const
 {
     QString output('[');
-    output += (m_rc == 0 ? QStringLiteral("SUC") : (m_rc > 0 ? QStringLiteral("ERR") : QStringLiteral("WAR")));
+    output += (m_rc == 0 ? QLatin1String("SUC") : (m_rc > 0 ? QLatin1String("ERR") : QLatin1String("WAR")));
     output += '-';
 
     QString tmp;
