@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -39,12 +39,12 @@ SKGNamedObject::~SKGNamedObject()
 
 SKGError SKGNamedObject::setName(const QString& iName)
 {
-    return setAttribute(QStringLiteral("t_name"), iName);
+    return setAttribute(QLatin1String("t_name"), iName);
 }
 
 QString SKGNamedObject::getName() const
 {
-    return getAttribute(QStringLiteral("t_name"));
+    return getAttribute(QLatin1String("t_name"));
 }
 
 QString SKGNamedObject::getWhereclauseId() const
@@ -55,7 +55,7 @@ QString SKGNamedObject::getWhereclauseId() const
         // No, so we use the name
         QString name = SKGServices::stringToSqlString(getName());
         if (!name.isEmpty() || getID() == 0) {
-            output = "t_name='" % name % '\'';
+            output = QLatin1String("t_name='") % name % QLatin1Char('\'');
         }
     }
     return output;
@@ -63,5 +63,5 @@ QString SKGNamedObject::getWhereclauseId() const
 
 SKGError SKGNamedObject::getObjectByName(SKGDocument* iDocument, const QString& iTable, const QString& iName, SKGObjectBase& oObject)
 {
-    return iDocument != nullptr ? iDocument->getObject(iTable, "t_name='" % SKGServices::stringToSqlString(iName) % '\'', oObject) : SKGError();
+    return iDocument != nullptr ? iDocument->getObject(iTable, "t_name='" % SKGServices::stringToSqlString(iName) % QLatin1Char('\''), oObject) : SKGError();
 }
