@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -104,21 +104,21 @@ bool SKGObjectBase::operator!=(const SKGObjectBase& iObject) const
 
 bool SKGObjectBase::operator<(const SKGObjectBase& iObject) const
 {
-    double d1 = SKGServices::stringToDouble(getAttribute(QStringLiteral("f_sortorder")));
-    double d2 = SKGServices::stringToDouble(iObject.getAttribute(QStringLiteral("f_sortorder")));
+    double d1 = SKGServices::stringToDouble(getAttribute(QLatin1String("f_sortorder")));
+    double d2 = SKGServices::stringToDouble(iObject.getAttribute(QLatin1String("f_sortorder")));
     return (d1 < d2);
 }
 
 bool SKGObjectBase::operator>(const SKGObjectBase& iObject) const
 {
-    double d1 = SKGServices::stringToDouble(getAttribute(QStringLiteral("f_sortorder")));
-    double d2 = SKGServices::stringToDouble(iObject.getAttribute(QStringLiteral("f_sortorder")));
+    double d1 = SKGServices::stringToDouble(getAttribute(QLatin1String("f_sortorder")));
+    double d2 = SKGServices::stringToDouble(iObject.getAttribute(QLatin1String("f_sortorder")));
     return (d1 > d2);
 }
 
 QString SKGObjectBase::getUniqueID() const
 {
-    return SKGServices::intToString(d->id) % '-' % getRealTable();
+    return SKGServices::intToString(d->id) % QLatin1Char('-') % getRealTable();
 }
 
 int SKGObjectBase::getID() const
@@ -148,7 +148,7 @@ QString SKGObjectBase::getAttributeFromView(const QString& iView, const QString&
 
 QString SKGObjectBase::getDisplayName() const
 {
-    return getAttributeFromView("v_" % getRealTable() % "_displayname", QStringLiteral("t_displayname"));
+    return getAttributeFromView("v_" % getRealTable() % "_displayname", QLatin1String("t_displayname"));
 }
 
 void SKGObjectBase::copyFrom(const SKGObjectBase& iObject)
@@ -220,7 +220,7 @@ SKGError SKGObjectBase::setAttributes(const QStringList& iNames, const QStringLi
         const auto& att = iNames.at(i);
         const auto& val = iValues.at(i);
 
-        if (Q_LIKELY(att != QStringLiteral("id"))) {
+        if (Q_LIKELY(att != QLatin1String("id"))) {
             err = setAttribute(att, val);
         } else {
             d->id = SKGServices::stringToInt(val);
@@ -239,7 +239,7 @@ SKGError SKGObjectBase::setAttribute(const QString& iName, const QString& iValue
         if (this->getRealTable() == this->getTable() && iName != iName.toLower()) {
             QString realAttribute = d->document->getRealAttribute(iName);
             if (!realAttribute.isEmpty()) {
-                QStringList l = realAttribute.split('.');
+                QStringList l = realAttribute.split(QLatin1Char('.'));
                 if (l.size() == 3) {
                     SKGObjectBase obj;
                     QString refId = getAttribute(l.at(1));
@@ -280,7 +280,7 @@ QString SKGObjectBase::getAttribute(const QString& iName) const
     QString output;
     if (Q_LIKELY(d->attributes.contains(iName))) {
         output = d->attributes[iName];
-    } else if (iName == QStringLiteral("id")) {
+    } else if (iName == QLatin1String("id")) {
         output = SKGServices::intToString(getID());
     }  if (iName.startsWith(QLatin1String("p_"))) {
         output = getProperty(iName.right(iName.length() - 2));
@@ -297,7 +297,7 @@ QString SKGObjectBase::getAttribute(const QString& iName) const
             }
         } else {
             // Case modification on marked document iName1.(iTable2)iName2 or iName1.iName2
-            int pos = iName.indexOf('.');
+            int pos = iName.indexOf(QLatin1Char('.'));
             if (pos != -1) {
                 QString attributeref = iName.left(pos);
                 QString refId = getAttribute(attributeref);
@@ -306,13 +306,13 @@ QString SKGObjectBase::getAttribute(const QString& iName) const
 
                     QString table;
                     QString att;
-                    auto rx = QRegularExpression(QStringLiteral("^\\(([^\\)]*)\\)(.*)$")).match(rest);
+                    auto rx = QRegularExpression(QLatin1String("^\\(([^\\)]*)\\)(.*)$")).match(rest);
                     if (rx.hasMatch()) {
                         // Case iName1.(iTable2)iName2
                         table = rx.captured(1);
                         att = rx.captured(2);
                     } else {
-                        auto rx2 = QRegularExpression(QStringLiteral("^.*_(.*)_.*$")).match(attributeref);
+                        auto rx2 = QRegularExpression(QLatin1String("^.*_(.*)_.*$")).match(attributeref);
                         if (rx2.hasMatch()) {
                             // Case iName1.iName2
                             table = "v_" % rx2.captured(1);
@@ -350,7 +350,7 @@ bool SKGObjectBase::exist() const
     if (getDocument() != nullptr) {
         getDocument()->executeSelectSqliteOrder(sql, result, false);
     }
-    return (result.size() >= 2 && result.at(1).at(0) != QStringLiteral("0"));
+    return (result.size() >= 2 && result.at(1).at(0) != QLatin1String("0"));
 }
 
 SKGError SKGObjectBase::load()
@@ -428,28 +428,28 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
                 QString att = SKGServices::stringToSqlString(it.key());
                 QString attlower = att.toLower();
                 if (att.length() > 2 && att == attlower) {  // We must ignore attributes coming from views
-                    QString value = '\'' % SKGServices::stringToSqlString(it.value()) % '\'';
+                    QString value = '\'' % SKGServices::stringToSqlString(it.value()) % QLatin1Char('\'');
 
                     if (!part1Insert.isEmpty()) {
-                        part1Insert.append(',');
-                        part2Insert.append(',');
-                        partUpdate.append(',');
+                        part1Insert.append(QLatin1Char(','));
+                        part2Insert.append(QLatin1Char(','));
+                        partUpdate.append(QLatin1Char(','));
                     }
                     // Attribute
-                    part1Insert.append('\'' % att % '\'');
+                    part1Insert.append('\'' % att % QLatin1Char('\''));
 
                     // Value
                     part2Insert.append(value);
 
                     // Attribute=Value for update
-                    partUpdate.append(att % '=' % value);
+                    partUpdate.append(att % QLatin1Char('=') % value);
                 }
             }
 
             // We try an Insert
             if (d->id == 0) {
                 // We have to try un insert
-                err = getDocument()->executeSqliteOrder("INSERT INTO " % tablename % " (" % part1Insert % ") VALUES (" % part2Insert % ')', &(d->id));
+                err = getDocument()->executeSqliteOrder("INSERT INTO " % tablename % " (" % part1Insert % ") VALUES (" % part2Insert % QLatin1Char(')'), &(d->id));
             } else {
                 // We must try an update
                 err = SKGError(ERR_ABORT, QLatin1String(""));  // Just to go in UPDATE code
@@ -486,7 +486,7 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
         err = d->document->checkExistingTransaction();
 
         // delete order
-        QString viewForDelete = QStringLiteral("v_") % getRealTable() % "_delete";
+        QString viewForDelete = QLatin1String("v_") % getRealTable() % "_delete";
 
         // Check if the delete view exist
         SKGStringListList temporaryResult;
@@ -519,12 +519,12 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
 SKGError SKGObjectBase::dump() const
 {
     // dump
-    SKGTRACE << "=== START DUMP [" << getUniqueID() << "]===" << SKGENDL;
+    SKGTRACE << "=== START DUMP [" << getUniqueID() << "]===" << Qt::endl;
     SKGQStringQStringMap::const_iterator it;
     for (it = d->attributes.constBegin() ; it != d->attributes.constEnd(); ++it) {
-        SKGTRACE << it.key() << "=[" << it.value() << ']' << SKGENDL;
+        SKGTRACE << it.key() << "=[" << it.value() << ']' << Qt::endl;
     }
-    SKGTRACE << "=== END DUMP [" << getUniqueID() << "]===" << SKGENDL;
+    SKGTRACE << "=== END DUMP [" << getUniqueID() << "]===" << Qt::endl;
     return SKGError();
 }
 
@@ -542,8 +542,8 @@ SKGObjectBase SKGObjectBase::getPropertyObject(const QString& iName) const
 {
     SKGObjectBase property;
     if (getDocument() != nullptr) {
-        getDocument()->getObject(QStringLiteral("parameters"), "t_name='" % SKGServices::stringToSqlString(iName) %
-                                 "' AND t_uuid_parent='" % SKGServices::stringToSqlString(getUniqueID()) % '\'', property);
+        getDocument()->getObject(QLatin1String("parameters"), "t_name='" % SKGServices::stringToSqlString(iName) %
+                                 "' AND t_uuid_parent='" % SKGServices::stringToSqlString(getUniqueID()) % QLatin1Char('\''), property);
     }
     return property;
 }
