@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -14,7 +14,7 @@
 SKGPropertyObject::SKGPropertyObject(): SKGPropertyObject(nullptr)
 {}
 
-SKGPropertyObject::SKGPropertyObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QStringLiteral("parameters"), iID)
+SKGPropertyObject::SKGPropertyObject(SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, QLatin1String("parameters"), iID)
 {}
 
 SKGPropertyObject::~SKGPropertyObject()
@@ -39,29 +39,29 @@ SKGPropertyObject& SKGPropertyObject::operator= (const SKGPropertyObject& iObjec
 
 SKGError SKGPropertyObject::setParentId(const QString& iParentId)
 {
-    return setAttribute(QStringLiteral("t_uuid_parent"), iParentId);
+    return setAttribute(QLatin1String("t_uuid_parent"), iParentId);
 }
 
 QString SKGPropertyObject::getParentId() const
 {
-    return getAttribute(QStringLiteral("t_uuid_parent"));
+    return getAttribute(QLatin1String("t_uuid_parent"));
 }
 
 SKGError SKGPropertyObject::setValue(const QString& iValue)
 {
-    return setAttribute(QStringLiteral("t_value"), iValue);
+    return setAttribute(QLatin1String("t_value"), iValue);
 }
 
 QString SKGPropertyObject::getValue() const
 {
-    return getAttribute(QStringLiteral("t_value"));
+    return getAttribute(QLatin1String("t_value"));
 }
 
 QUrl SKGPropertyObject::getUrl(bool iBuildTemporaryFile) const
 {
     QUrl url;
     if (getID() != 0) {
-        QStringList uuid = getParentId().split('-');
+        QStringList uuid = getParentId().split(QLatin1Char('-'));
         if (uuid.count() == 2) {
             SKGObjectBase p(getDocument(), uuid.at(1), SKGServices::stringToInt(uuid.at(0)));
             QVariant blob = p.getPropertyBlob(getName());
@@ -71,7 +71,7 @@ QUrl SKGPropertyObject::getUrl(bool iBuildTemporaryFile) const
                 QByteArray blob_bytes = blob.toByteArray();
                 if (blob_bytes.length() > 0) {
                     // Yes, this is a file
-                    QString fileName = QDir::tempPath() % '/' % QFileInfo(getValue()).fileName();
+                    QString fileName = QDir::tempPath() % QLatin1Char('/') % QFileInfo(getValue()).fileName();
                     if (iBuildTemporaryFile) {
                         // Save temporary file
                         QFile file(fileName);
@@ -105,14 +105,14 @@ QString SKGPropertyObject::getWhereclauseId() const
     // Could we use the id
     QString output = SKGObjectBase::getWhereclauseId();  // clazy:exclude=skipped-base-method
     if (output.isEmpty()) {
-        if (!(getAttribute(QStringLiteral("t_name")).isEmpty())) {
-            output = "t_name='" % SKGServices::stringToSqlString(getAttribute(QStringLiteral("t_name"))) % '\'';
+        if (!(getAttribute(QLatin1String("t_name")).isEmpty())) {
+            output = "t_name='" % SKGServices::stringToSqlString(getAttribute(QLatin1String("t_name"))) % QLatin1Char('\'');
         }
         if (!(getParentId().isEmpty())) {
             if (!output.isEmpty()) {
-                output += QStringLiteral(" AND ");
+                output += QLatin1String(" AND ");
             }
-            output += "t_uuid_parent='" % getParentId() % '\'';
+            output += "t_uuid_parent='" % getParentId() % QLatin1Char('\'');
         }
     }
     return output;
