@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGREPORT_H
@@ -11,11 +11,16 @@
  * @author Stephane MANKOWSKI
  */
 #include <qobject.h>
+#include <qtypeinfo.h>
 #include <qvariant.h>
 
 #include "skgbasemodeler_export.h"
 #include "skgerror.h"
 
+#ifndef SKG_QT6
+#define KTextTemplate Grantlee
+#endif
+
 class SKGDocument;
 /**
  * A report class for document
@@ -205,5 +210,5 @@ private:
 /**
  * Declare the class
  */
-Q_DECLARE_TYPEINFO(SKGReport, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(SKGReport, Q_COMPLEX_TYPE);
 #endif  // SKGREPORT_H
