@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGSERVICES_H
@@ -17,6 +17,8 @@
 #include <qicon.h>
 #include <qstringlist.h>
 
+#include <kpluginmetadata.h>
+
 #include "skgbasemodeler_export.h"
 #include "skgdefine.h"
 #include "skgerror.h"
@@ -275,6 +277,13 @@ public:
      */
     static QDateTime stringToTime(const QString& iDateString);
 
+    /**
+     * Convert a QString to QDate.
+     * @param iDateString the date. The format must be "%Y-%m-%d"
+     * @return the converted QDate
+     */
+    static QDate stringToDate(const QString& iDateString);
+
     /**
      * Convert a QString to QDate.
      * @param iDateString the date string. Could be a partial date like 1/12.
@@ -321,7 +330,7 @@ public:
      * @param iComparator the sql comparator (= by default. But you can use < or >)
      * @return the where clause
      */
-    static QString getPeriodWhereClause(const QString& iPeriod, const QString& iDateAttribute = QStringLiteral("d_date"), const QString& iComparator = QStringLiteral("="));
+    static QString getPeriodWhereClause(const QString& iPeriod, const QString& iDateAttribute = QLatin1String("d_date"), const QString& iComparator = QLatin1String("="));
 
     /**
      * Get the last date of a period.
@@ -646,6 +655,13 @@ public:
      */
     static QString getNextString(const QString& iString);
 
+    /**
+     * Search data plugin
+     * @param type the type of plugins
+     * @return the plugins found
+     */
+    static QVector<KPluginMetaData> findDataPlugins(const QString& type);
+
 private:
     Q_DISABLE_COPY(SKGServices)
     static SKGError m_lastCallbackError;
