@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGTRACES_H
@@ -28,7 +28,7 @@
 /**
 * Macro for traces
 */
-#define SKGTRACESEPARATOR SKGTRACE << "##############################################\n" << SKGFLUSH;
+#define SKGTRACESEPARATOR SKGTRACE << "##############################################\n" << Qt::flush;
 
 #ifdef SKGNOTRACES
 /**
