@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -11,6 +11,7 @@
 #include "skgtreemap.h"
 
 #include "skgtraces.h"
+#include <utility>
 
 SKGTreeMap::SKGTreeMap(QString  iID,
                        double iValue,
@@ -112,10 +113,10 @@ QMap<QString, SKGTreeMap> SKGTreeMap::getAllTilesById() const
 {
     QMap<QString, SKGTreeMap> output;
     output.insert(getID(), *this);
-    for (const auto& item : qAsConst(m_children)) {
+    for (const auto& item : std::as_const(m_children)) {
         output.insert(item.getID(), item);
         auto children = item.getAllTilesById();
-        for (const auto& item2 : qAsConst(children)) {
+        for (const auto& item2 : std::as_const(children)) {
             output.insert(item2.getID(), item2);
         }
     }
