@@ -61,6 +61,7 @@
 #endif
 
 #include <sqlite3.h>
+#include <utility>
 
 Q_DECLARE_OPAQUE_POINTER(sqlite3*)
 Q_DECLARE_METATYPE(sqlite3*)
@@ -476,14 +477,14 @@ bool QSQLiteResult::exec()
                     break;
                 case QVariant::DateTime: {
                     const QDateTime dateTime = value.toDateTime();
-                    const QString str = dateTime.toString(QStringLiteral("yyyy-MM-ddThh:mm:ss.zzz"));
+                    const QString str = dateTime.toString(QLatin1String("yyyy-MM-ddThh:mm:ss.zzz"));
                     res = sqlite3_bind_text16(d->stmt, i + 1, str.utf16(),
                                               str.size() * sizeof(ushort), SQLITE_TRANSIENT);
                     break;
                 }
                 case QVariant::Time: {
                     const QTime time = value.toTime();
-                    const QString str = time.toString(QStringLiteral("hh:mm:ss.zzz"));
+                    const QString str = time.toString(QLatin1String("hh:mm:ss.zzz"));
                     res = sqlite3_bind_text16(d->stmt, i + 1, str.utf16(),
                                               str.size() * sizeof(ushort), SQLITE_TRANSIENT);
                     break;
@@ -690,7 +691,7 @@ void QSQLiteDriver::close()
 {
     Q_D(QSQLiteDriver);
     if (isOpen()) {
-        for (QSQLiteResult* result : qAsConst(d->results)) {
+        for (QSQLiteResult* result : std::as_const(d->results)) {
             result->d_func()->finalize();
         }
 
@@ -716,7 +717,7 @@ bool QSQLiteDriver::beginTransaction()
     }
 
     QSqlQuery q(createResult());
-    if (!q.exec(QStringLiteral("BEGIN"))) {
+    if (!q.exec(QLatin1String("BEGIN"))) {
         setLastError(QSqlError(tr("Unable to begin transaction"),
                                q.lastError().databaseText(), QSqlError::TransactionError));
         return false;
@@ -732,7 +733,7 @@ bool QSQLiteDriver::commitTransaction()
     }
 
     QSqlQuery q(createResult());
-    if (!q.exec(QStringLiteral("COMMIT"))) {
+    if (!q.exec(QLatin1String("COMMIT"))) {
         setLastError(QSqlError(tr("Unable to commit transaction"),
                                q.lastError().databaseText(), QSqlError::TransactionError));
         return false;
@@ -748,7 +749,7 @@ bool QSQLiteDriver::rollbackTransaction()
     }
 
     QSqlQuery q(createResult());
-    if (!q.exec(QStringLiteral("ROLLBACK"))) {
+    if (!q.exec(QLatin1String("ROLLBACK"))) {
         setLastError(QSqlError(tr("Unable to rollback transaction"),
                                q.lastError().databaseText(), QSqlError::TransactionError));
         return false;
@@ -767,14 +768,14 @@ QStringList QSQLiteDriver::tables(QSql::TableType type) const
     QSqlQuery q(createResult());
     q.setForwardOnly(true);
 
-    QString sql = QStringLiteral("SELECT name FROM sqlite_master WHERE %1 "
-                                 "UNION ALL SELECT name FROM sqlite_temp_master WHERE %1");
+    QString sql = QLatin1String("SELECT name FROM sqlite_master WHERE %1 "
+                                "UNION ALL SELECT name FROM sqlite_temp_master WHERE %1");
     if (((type & QSql::Tables) != 0) && ((type & QSql::Views) != 0)) {
-        sql = sql.arg(QStringLiteral("type='table' OR type='view'"));
+        sql = sql.arg(QLatin1String("type='table' OR type='view'"));
     } else if ((type & QSql::Tables) != 0) {
-        sql = sql.arg(QStringLiteral("type='table'"));
+        sql = sql.arg(QLatin1String("type='table'"));
     } else if ((type & QSql::Views) != 0) {
-        sql = sql.arg(QStringLiteral("type='view'"));
+        sql = sql.arg(QLatin1String("type='view'"));
     } else {
         sql.clear();
     }
@@ -787,7 +788,7 @@ QStringList QSQLiteDriver::tables(QSql::TableType type) const
 
     if ((type & QSql::SystemTables) != 0) {
         // there are no internal tables beside this one:
-        res.append(QStringLiteral("sqlite_master"));
+        res.append(QLatin1String("sqlite_master"));
     }
 
     return res;
