@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -8,8 +8,11 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-
+#ifdef SKG_QT6
+#include "q6sql_sqlite_p.h"
+#else
 #include "qsql_sqlite_p.h"
+#endif
 #include <qsqldriverplugin.h>
 #include <qstringlist.h>
 
@@ -26,7 +29,7 @@ public:
 
     QSqlDriver* create(const QString& iName) override
     {
-        if (iName == QStringLiteral("SKGSQLCIPHER")) {
+        if (iName == QLatin1String("SKGSQLCIPHER")) {
             auto driver = new QSQLiteDriver();
             return driver;
         }
