@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -16,7 +16,9 @@
 #ifdef SKG_DBUS
 #include <kdbusservice.h>
 #endif
+#ifndef SKG_QT6
 #include <kdelibs4configmigrator.h>
+#endif
 #include <klocalizedstring.h>
 
 #include <qbitmap.h>
@@ -43,19 +45,19 @@ void SKGMessageOutput(QtMsgType type, const QMessageLogContext& context, const Q
     Q_UNUSED(context)
     switch (type) {
     case QtDebugMsg:
-        SKGTRACEL(1) << "DEBUG: " << msg << SKGENDL;
+        SKGTRACEL(1) << "DEBUG: " << msg << Qt::endl;
         break;
     case QtWarningMsg:
-        SKGTRACE << "WARNING: " << msg << SKGENDL;
+        SKGTRACE << "WARNING: " << msg << Qt::endl;
         break;
     case QtCriticalMsg:
-        SKGTRACE << "CRITICAL: " << msg << SKGENDL;
+        SKGTRACE << "CRITICAL: " << msg << Qt::endl;
         break;
     case QtFatalMsg:
-        SKGTRACE << "FATAL: " << msg << SKGENDL;
+        SKGTRACE << "FATAL: " << msg << Qt::endl;
         abort();
     default:
-        SKGTRACE << "INFO: " << msg << SKGENDL;
+        SKGTRACE << "INFO: " << msg << Qt::endl;
         break;
     }
 }
@@ -73,67 +75,67 @@ int main(int argc, char** argv)
 #endif
 
     qInstallMessageHandler(SKGMessageOutput);
-    if (!SKGServices::getEnvVariable(QStringLiteral("SKGHIGHDPI")).isEmpty()) {
+#ifndef SKG_QT6
+    if (!SKGServices::getEnvVariable(QLatin1String("SKGHIGHDPI")).isEmpty()) {
         QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
         QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     }
+#endif
     QApplication app(argc, argv);
-    QIcon appIcon = SKGServices::fromTheme(QStringLiteral("skrooge"));
+    QIcon appIcon = SKGServices::fromTheme(QLatin1String("skrooge"));
     if (!appIcon.isNull()) {
         app.setWindowIcon(appIcon);
     }
 
+#ifndef SKG_QT6
     // Migration kf4 => kf5
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("skrooge"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("skroogerc"));
+    Kdelibs4ConfigMigrator migrate(QLatin1String("skrooge"));
+    migrate.setConfigFiles(QStringList() << QLatin1String("skroogerc"));
     migrate.migrate();
-
+#endif
     // To use CPU instead CPU for QML (needed for printing)
     qputenv("QMLSCENE_DEVICE", "softwarecontext");
 
 #ifdef SKG_WEBENGINE
     // DrKonqi
     // https://www.dvratil.cz/2018/10/drkonqi-and-qtwebengine/
-    const auto chromiumFlags = qgetenv("QTWEBENGINE_CHROMIUM_FLAGS");
-    if (!chromiumFlags.contains("disable-in-process-stack-traces")) {
-        qputenv("QTWEBENGINE_CHROMIUM_FLAGS", chromiumFlags + " --disable-in-process-stack-traces");
-    }
+    qputenv("QTWEBENGINE_CHROMIUM_FLAGS", " --disable-in-process-stack-traces");
 #endif
     KLocalizedString::setApplicationDomain("skrooge");
 
-    KAboutData about(QStringLiteral("skrooge"),
+    KAboutData about(QLatin1String("skrooge"),
                      i18nc("The name of the application", "Skrooge"),
-                     QStringLiteral(VER),
+                     QLatin1String(VER),
                      i18nc("The description of the application", "Personal finances management made simple"),
                      KAboutLicense::GPL_V3,
-                     i18nc("Fullname", "(c) 2007-%1 Stephane MANKOWSKI & Guillaume DE BURE", QDate::currentDate().toString(QStringLiteral("yyyy"))),
+                     i18nc("Fullname", "(c) 2007-%1 Stephane MANKOWSKI & Guillaume DE BURE", QDate::currentDate().toString(QLatin1String("yyyy"))),
                      QLatin1String(""),
-                     QStringLiteral("https://skrooge.org"));
+                     QLatin1String("https://skrooge.org"));
 
-    about.addAuthor(i18nc("Fullname", "Stephane MANKOWSKI"), i18nc("A job description", "Architect & Developer"), QStringLiteral("stephane@mankowski.fr"), QLatin1String("")
-                    , QStringLiteral("miraks")
+    about.addAuthor(i18nc("Fullname", "Stephane MANKOWSKI"), i18nc("A job description", "Architect & Developer"), QLatin1String("stephane@mankowski.fr"), QLatin1String("")
+                    , QLatin1String("miraks")
                    );
-    about.addAuthor(i18nc("Fullname", "Guillaume DE BURE"), i18nc("A job description", "Developer"), QStringLiteral("guillaume.debure@gmail.com"), QLatin1String("")
-                    , QStringLiteral("willy9")
+    about.addAuthor(i18nc("Fullname", "Guillaume DE BURE"), i18nc("A job description", "Developer"), QLatin1String("guillaume.debure@gmail.com"), QLatin1String("")
+                    , QLatin1String("willy9")
                    );
-    about.addAuthor(i18nc("Fullname", "Siddharth SHARMA"), i18nc("A job description", "Developer - Google Summer Of Code 2010"), QStringLiteral("siddharth.kde@gmail.com"), QLatin1String("")
-                    , QStringLiteral("h4xordood")
-                   );
-    about.addAuthor(i18nc("Fullname", "Michael LONGMIRE"), i18nc("A job description", "Splash screen photographer"), QLatin1String(""), QLatin1String("")
-                    , QStringLiteral("")
+    about.addAuthor(i18nc("Fullname", "Siddharth SHARMA"), i18nc("A job description", "Developer - Google Summer Of Code 2010"), QLatin1String("siddharth.kde@gmail.com"), QLatin1String("")
+                    , QLatin1String("h4xordood")
                    );
+    /*about.addAuthor(i18nc("Fullname", "Michael LONGMIRE"), i18nc("A job description", "Splash screen photographer"), QLatin1String(""), QLatin1String("")
+                    , QLatin1String("")
+                   );*/
     about.setOtherText(i18nc("The description of the application", "The application name is inspired by Charles Dicken's tale <i>A Christmas Carol</i>, where the main character, Ebenezer Scrooge, a grumpy old narrow man, gets visited by three ghosts who change the way he sees the world, in a good way."));
     about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     about.setOrganizationDomain("kde.org");
-    about.setDesktopFileName(QStringLiteral("org.kde.skrooge"));
+    about.setDesktopFileName(QLatin1String("org.kde.skrooge"));
 
-    about.addCredit(QStringLiteral("vicnet, noidea, rbruce, JesusM, schunka, SylvaiNN, Wolf, Hizoka, neutron68, blep0, BigaAl, steffie, skierpage …"), i18nc("Reason of the about/credit", "Users helping us to improve this application"));
+    about.addCredit(QLatin1String("vicnet, noidea, rbruce, JesusM, schunka, SylvaiNN, Wolf, Hizoka, neutron68, blep0, BigaAl, steffie, skierpage …"), i18nc("Reason of the about/credit", "Users helping us to improve this application"));
 
     KAboutData::setApplicationData(about);
 
     QCommandLineParser parser;
-    parser.addPositionalArgument(QStringLiteral("URL"), i18nc("Application argument", "Document to open"));
-    QCommandLineOption envOption(QStringList() << QStringLiteral("e") << QStringLiteral("env"), i18nc("Application argument", "Display environment variables used by this application."));
+    parser.addPositionalArgument(QLatin1String("URL"), i18nc("Application argument", "Document to open"));
+    QCommandLineOption envOption(QStringList() << QLatin1String("e") << QLatin1String("env"), i18nc("Application argument", "Display environment variables used by this application."));
     parser.addOption(envOption);
 
     about.setupCommandLine(&parser);
@@ -141,18 +143,18 @@ int main(int argc, char** argv)
     about.processCommandLine(&parser);
 
     if (parser.isSet(envOption)) {
-        SKGTRACESUITE << parser.helpText() << SKGENDL;
-        SKGTRACESUITE << i18nc("Help", "Environment variables:") << SKGENDL;
-        SKGTRACESUITE << i18nc("Help, do not translate x", "  %1: To enable traces. x is the level of traces expected. This enables the debug mode too.", "export SKGTRACE=x") << SKGENDL;
-        SKGTRACESUITE << i18nc("Help", "  %1: To enable the profiling. This enables the debug mode too.", "export SKGTRACEPERFO=1") << SKGENDL;
-        SKGTRACESUITE << i18nc("Help do not translate x", "  %1: To dump sql order taking more than x ms.", "export SKGTRACESQL=x") << SKGENDL;
-        SKGTRACESUITE << i18nc("Help", "  %1: To enable the high DPI mode.", "export SKGHIGHDPI=1") << SKGENDL;
+        SKGTRACESUITE << parser.helpText() << Qt::endl;
+        SKGTRACESUITE << i18nc("Help", "Environment variables:") << Qt::endl;
+        SKGTRACESUITE << i18nc("Help, do not translate x", "  %1: To enable traces. x is the level of traces expected. This enables the debug mode too.", "export SKGTRACE=x") << Qt::endl;
+        SKGTRACESUITE << i18nc("Help", "  %1: To enable the profiling. This enables the debug mode too.", "export SKGTRACEPERFO=1") << Qt::endl;
+        SKGTRACESUITE << i18nc("Help do not translate x", "  %1: To dump sql order taking more than x ms.", "export SKGTRACESQL=x") << Qt::endl;
+        SKGTRACESUITE << i18nc("Help", "  %1: To enable the high DPI mode.", "export SKGHIGHDPI=1") << Qt::endl;
         return 0;
     }
 
     // Manage unicity
 #ifdef SKG_DBUS
-    KDBusService service(SKGServices::getEnvVariable(QStringLiteral("SKGNOTUNIQUE")).isEmpty() ? KDBusService::Unique : KDBusService::Multiple);
+    KDBusService service(SKGServices::getEnvVariable(QLatin1String("SKGNOTUNIQUE")).isEmpty() ? KDBusService::Unique : KDBusService::Multiple);
     QObject::connect(&service, &KDBusService::activateRequested, &service, [ = ](const QStringList & arguments, const QString & workingDirectory) {
         Q_UNUSED(workingDirectory)
         SKGMainPanel::getMainPanel()->processArguments(arguments);
@@ -161,7 +163,7 @@ int main(int argc, char** argv)
 
     // Creating a main panel on a bank document
     SKGDocumentBank doc;
-    if (!SKGServices::getEnvVariable(QStringLiteral("SKGTEST")).isEmpty()) {
+    if (!SKGServices::getEnvVariable(QLatin1String("SKGTEST")).isEmpty()) {
         QTimer::singleShot(5000, Qt::CoarseTimer, &app, &QApplication::quit);
     }
 
@@ -172,7 +174,7 @@ int main(int argc, char** argv)
     QSplashScreen* m_splash = nullptr;
     KConfigGroup pref = SKGMainPanel::getMainConfigGroup();
     if (pref.readEntry("show_splash_screen", true)) {
-        QString splashPathRelativePath = KAboutData::applicationData().componentName() % "/images/splash.png";
+        QString splashPathRelativePath = KAboutData::applicationData().componentName() % QLatin1String("/images/splash.png");
         QString splashPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, splashPathRelativePath.toLatin1());
         if (!splashPath.isEmpty()) {
             QPixmap pix(splashPath);
@@ -184,13 +186,13 @@ int main(int argc, char** argv)
                 m_splash->showMessage(i18nc("Splash screen message", "Loading …"), Qt::AlignLeft, QColor(221, 130, 8));  // krazy:exclude=qmethods
             }
         } else {
-            SKGTRACE << "WARNING: Splash screen (" << splashPathRelativePath << ") not found !" << SKGENDL;
+            SKGTRACE << "WARNING: Splash screen (" << splashPathRelativePath << ") not found !" << Qt::endl;
         }
     }
 
     // First instance
     QApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
-    QQuickStyle::setStyle("Breeze");
+    QQuickStyle::setFallbackStyle("Material");
     auto m_widget = new SKGMainPanel(m_splash, &doc);
     m_widget->processArguments(argument);
     m_widget->setUnifiedTitleAndToolBarOnMac(true);
