@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -47,32 +47,32 @@ int main(int argc, char** argv)
     QCoreApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("skrooge");
 
-    KAboutData about(QStringLiteral("skroogeconvert"),
+    KAboutData about(QLatin1String("skroogeconvert"),
                      i18nc("The name of the application", "Skrooge Convert"),
-                     QStringLiteral(VER),
+                     QLatin1String(VER),
                      i18nc("The description of the application", "A conversion tool for financial files (KMyMoney, GnuCash, Skrooge, …)"),
                      KAboutLicense::GPL_V3,
-                     i18nc("Fullname", "(c) 2007-%1 Stephane MANKOWSKI & Guillaume DE BURE", QDate::currentDate().toString(QStringLiteral("yyyy"))),
+                     i18nc("Fullname", "(c) 2007-%1 Stephane MANKOWSKI & Guillaume DE BURE", QDate::currentDate().toString(QLatin1String("yyyy"))),
                      QString(),
-                     QStringLiteral("https://skrooge.org"));
+                     QLatin1String("https://skrooge.org"));
 
-    about.addAuthor(i18nc("Fullname", "Stephane MANKOWSKI"), i18nc("A job description", "Architect & Developer"), QStringLiteral("stephane@mankowski.fr"), QString()
-                    , QStringLiteral("miraks")
+    about.addAuthor(i18nc("Fullname", "Stephane MANKOWSKI"), i18nc("A job description", "Architect & Developer"), QLatin1String("stephane@mankowski.fr"), QString()
+                    , QLatin1String("miraks")
                    );
-    about.addAuthor(i18nc("Fullname", "Guillaume DE BURE"), i18nc("A job description", "Developer"), QStringLiteral("guillaume.debure@gmail.com"), QString()
-                    , QStringLiteral("willy9")
+    about.addAuthor(i18nc("Fullname", "Guillaume DE BURE"), i18nc("A job description", "Developer"), QLatin1String("guillaume.debure@gmail.com"), QString()
+                    , QLatin1String("willy9")
                    );
     about.setOtherText(i18nc("The description of the application", "The application name is inspired by Charles Dicken's tale <i>A Christmas Carol</i>, where the main character, Ebenezer Scrooge, a grumpy old narrow man, gets visited by three ghosts who change the way he sees the world, in a good way."));
     about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     KAboutData::setApplicationData(about);
 
     QCommandLineParser parser;
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("in"), i18nc("Application argument", "Input file. Supported formats:\n%1", SKGImportExportManager().getImportMimeTypeFilter(false)), QStringLiteral("file")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("out"), i18nc("Application argument", "Output file. Supported formats:\n%1", SKGImportExportManager().getExportMimeTypeFilter(false)), QStringLiteral("file")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("param"), i18nc("Application argument", "Name of a parameter"), QStringLiteral("name")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("value"), i18nc("Application argument", "Value of a parameter"), QStringLiteral("value")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("param_export"), i18nc("Application argument", "Name of a parameter for export"), QStringLiteral("name_export")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("value_export"), i18nc("Application argument", "Value of a parameter for export"), QStringLiteral("value_export")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("in"), i18nc("Application argument", "Input file. Supported formats:\n%1", SKGImportExportManager().getImportMimeTypeFilter(false)), QLatin1String("file")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("out"), i18nc("Application argument", "Output file. Supported formats:\n%1", SKGImportExportManager().getExportMimeTypeFilter(false)), QLatin1String("file")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("param"), i18nc("Application argument", "Name of a parameter"), QLatin1String("name")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("value"), i18nc("Application argument", "Value of a parameter"), QLatin1String("value")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("param_export"), i18nc("Application argument", "Name of a parameter for export"), QLatin1String("name_export")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("value_export"), i18nc("Application argument", "Value of a parameter for export"), QLatin1String("value_export")));
 
     about.setupCommandLine(&parser);
     parser.process(app);
@@ -81,9 +81,9 @@ int main(int argc, char** argv)
 
     // Build list of arguments
     SKGError err;
-    if (!parser.isSet(QStringLiteral("in"))) {
+    if (!parser.isSet(QLatin1String("in"))) {
         err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Missing -in option"));
-    } else if (!parser.isSet(QStringLiteral("out"))) {
+    } else if (!parser.isSet(QLatin1String("out"))) {
         err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Missing -out option"));
     }
 
@@ -93,15 +93,15 @@ int main(int argc, char** argv)
     IFOKDO(err, document.initialize())
     IFOK(err) {
         // Import
-        QString file = parser.value(QStringLiteral("in"));
+        QString file = parser.value(QLatin1String("in"));
         QFileInfo fi(file);
         if (fi.exists()) {
             file = fi.absoluteFilePath();
         }
         SKGImportExportManager imp(&document, QUrl::fromLocalFile(file));
         QMap<QString, QString>  parameters = imp.getImportParameters();
-        QStringList params = parser.values(QStringLiteral("param"));
-        QStringList values = parser.values(QStringLiteral("value"));
+        QStringList params = parser.values(QLatin1String("param"));
+        QStringList values = parser.values(QLatin1String("value"));
         int nb = qMin(params.count(), values.count());
         for (int i = 0; i < nb; ++i) {
             parameters[params.at(i)] = values.at(i);
@@ -109,32 +109,32 @@ int main(int argc, char** argv)
         imp.setImportParameters(parameters);
 
         SKGTRACESEPARATOR;
-        SKGTRACE << i18nc("Title of a console trace section", " Import parameters") << SKGENDL;
+        SKGTRACE << i18nc("Title of a console trace section", " Import parameters") << Qt::endl;
         QMapIterator<QString, QString> i(imp.getImportParameters());
         while (i.hasNext()) {
             i.next();
-            SKGTRACE << " " << i.key() << "=" << i.value() << SKGENDL;
+            SKGTRACE << " " << i.key() << "=" << i.value() << Qt::endl;
         }
         SKGTRACESEPARATOR;
-        SKGTRACE << i18nc("Title of a console trace section", " Imported file:") << imp.getFileName().toDisplayString()  << SKGENDL;
-        if (fi.suffix().toUpper() == QStringLiteral("SKG") || fi.suffix().toUpper() == QStringLiteral("SQLITE") || fi.suffix().toUpper() == QStringLiteral("SQLCIPHER")) {
-            err = document.load(file, parameters[QStringLiteral("password")]);
+        SKGTRACE << i18nc("Title of a console trace section", " Imported file:") << imp.getFileName().toDisplayString()  << Qt::endl;
+        if (fi.suffix().toUpper() == QLatin1String("SKG") || fi.suffix().toUpper() == QLatin1String("SQLITE") || fi.suffix().toUpper() == QLatin1String("SQLCIPHER")) {
+            err = document.load(file, parameters[QLatin1String("password")]);
         } else {
-            SKGBEGINTRANSACTION(document, QStringLiteral("IMPORT"), err)
+            SKGBEGINTRANSACTION(document, QLatin1String("IMPORT"), err)
             IFOKDO(err, imp.importFile())
         }
     }
     IFOK(err) {
         // Export
-        QString file = parser.value(QStringLiteral("out"));
+        QString file = parser.value(QLatin1String("out"));
         QFileInfo fi(file);
         if (fi.exists()) {
             file = fi.absoluteFilePath();
         }
         SKGImportExportManager exp(&document, QUrl::fromLocalFile(file));
         QMap<QString, QString>  parameters = exp.getExportParameters();
-        QStringList params = parser.values(QStringLiteral("param_export"));
-        QStringList values = parser.values(QStringLiteral("value_export"));
+        QStringList params = parser.values(QLatin1String("param_export"));
+        QStringList values = parser.values(QLatin1String("value_export"));
         int nb = qMin(params.count(), values.count());
         for (int i = 0; i < nb; ++i) {
             parameters[params.at(i)] = values.at(i);
@@ -142,15 +142,15 @@ int main(int argc, char** argv)
         exp.setExportParameters(parameters);
 
         SKGTRACESEPARATOR;
-        SKGTRACE << i18nc("Title of a console trace section", " Export parameters") << SKGENDL;
+        SKGTRACE << i18nc("Title of a console trace section", " Export parameters") << Qt::endl;
         QMapIterator<QString, QString> i(exp.getExportParameters());
         while (i.hasNext()) {
             i.next();
-            SKGTRACE << " " << i.key() << "=" << i.value() << SKGENDL;
+            SKGTRACE << " " << i.key() << "=" << i.value() << Qt::endl;
         }
         SKGTRACESEPARATOR;
-        SKGTRACE << i18nc("Title of a console trace section", " Exported file:") << exp.getFileName().toDisplayString()  << SKGENDL;
-        if (fi.suffix().toUpper() == QStringLiteral("SKG")) {
+        SKGTRACE << i18nc("Title of a console trace section", " Exported file:") << exp.getFileName().toDisplayString()  << Qt::endl;
+        if (fi.suffix().toUpper() == QLatin1String("SKG")) {
             err = document.saveAs(file, true);
         } else {
             err = exp.exportFile();
@@ -164,18 +164,18 @@ int main(int argc, char** argv)
     if (nb > 0) {
         SKGTRACESEPARATOR;
         for (int i = 0; i < nb; ++i) {
-            SKGTRACE << oMessages.at(i).Text << SKGENDL;
+            SKGTRACE << oMessages.at(i).Text << Qt::endl;
         }
     }
 
     IFKO(err) {
-        SKGTRACESUITE << err.getFullMessageWithHistorical() << SKGENDL;
+        SKGTRACESUITE << err.getFullMessageWithHistorical() << Qt::endl;
         SKGTRACESEPARATOR;
-        SKGTRACE << i18nc("Title of a console trace section", " FAILED") << SKGENDL;
+        SKGTRACE << i18nc("Title of a console trace section", " FAILED") << Qt::endl;
         SKGTRACESEPARATOR;
     } else {
         SKGTRACESEPARATOR;
-        SKGTRACE << i18nc("Title of a console trace section", " SUCCESSFUL") << SKGENDL;
+        SKGTRACE << i18nc("Title of a console trace section", " SUCCESSFUL") << Qt::endl;
         SKGTRACESEPARATOR;
     }
 
