@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -21,17 +21,17 @@ void SKGTESTTreeView::Test()
 
     // Initialize document
     SKGDocumentBank doc;
-    QVERIFY2(!doc.load(SKGTest::getTestPath(QStringLiteral("OUT")) % "/advice.skg"), "Load document failed");
+    QVERIFY2(!doc.load(SKGTest::getTestPath(QLatin1String("OUT")) % "/advice.skg"), "Load document failed");
 
     // Initilialization view and model
     SKGFilteredTableView tableView(nullptr);
-    auto m_objectModel = new SKGObjectModel(&doc, QStringLiteral("v_account_display"), QLatin1String(""), nullptr);
+    auto m_objectModel = new SKGObjectModel(&doc, QLatin1String("v_account_display"), QLatin1String(""), nullptr);
     tableView.setModel(m_objectModel);
-    m_objectModel->setTable(QStringLiteral("v_operation_display_all"));
+    m_objectModel->setTable(QLatin1String("v_operation_display_all"));
     QCOMPARE(m_objectModel->getGroupBy(), QLatin1String(""));
-    m_objectModel->setGroupBy(QStringLiteral("d_date"));
-    QCOMPARE(m_objectModel->getGroupBy(), QStringLiteral("d_date"));
-    m_objectModel->setGroupBy(QStringLiteral("t_status"));
+    m_objectModel->setGroupBy(QLatin1String("d_date"));
+    QCOMPARE(m_objectModel->getGroupBy(), QLatin1String("d_date"));
+    m_objectModel->setGroupBy(QLatin1String("t_status"));
     m_objectModel->refresh();
     QTest::qWait(300);
 
@@ -42,12 +42,12 @@ void SKGTESTTreeView::Test()
 
     // SKGTreeView
     SKGTreeView* tree = tableView.getView();
-    tree->exportInFile(SKGTest::getTestPath(QStringLiteral("OUT")) % "/skgtesttreeview/SKGTreeView.csv");
-    tree->exportInFile(SKGTest::getTestPath(QStringLiteral("OUT")) % "/skgtesttreeview/SKGTreeView.txt");
-    tree->exportInFile(SKGTest::getTestPath(QStringLiteral("OUT")) % "/skgtesttreeview/SKGTreeView.svg");
-    tree->exportInFile(SKGTest::getTestPath(QStringLiteral("OUT")) % "/skgtesttreeview/SKGTreeView.pdf");
-    tree->exportInFile(SKGTest::getTestPath(QStringLiteral("OUT")) % "/skgtesttreeview/SKGTreeView.html");
-    tree->exportInFile(SKGTest::getTestPath(QStringLiteral("OUT")) % "/skgtesttreeview/SKGTreeView.odt");
+    tree->exportInFile(SKGTest::getTestPath(QLatin1String("OUT")) % "/skgtesttreeview/SKGTreeView.csv");
+    tree->exportInFile(SKGTest::getTestPath(QLatin1String("OUT")) % "/skgtesttreeview/SKGTreeView.txt");
+    tree->exportInFile(SKGTest::getTestPath(QLatin1String("OUT")) % "/skgtesttreeview/SKGTreeView.svg");
+    tree->exportInFile(SKGTest::getTestPath(QLatin1String("OUT")) % "/skgtesttreeview/SKGTreeView.pdf");
+    tree->exportInFile(SKGTest::getTestPath(QLatin1String("OUT")) % "/skgtesttreeview/SKGTreeView.html");
+    tree->exportInFile(SKGTest::getTestPath(QLatin1String("OUT")) % "/skgtesttreeview/SKGTreeView.odt");
 
     tree->getTable();
     tree->getFirstSelectedObject();
@@ -67,7 +67,7 @@ void SKGTESTTreeView::Test()
 
     tree->getCurrentSchema();
 
-    tableView.getSearchField()->setText(QStringLiteral("e +a -i"));
+    tableView.getSearchField()->setText(QLatin1String("e +a -i"));
     tree->copy();
 
     for (int i = 0; i < 10; ++i) {
