@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -31,9 +31,9 @@ int main(int argc, char** argv)
     {
         // Test unit et unitvalue
         SKGDocumentBank document1;
-        SKGTESTERROR(QStringLiteral("document1.load()"), document1.load(SKGTest::getTestPath(QStringLiteral("IN")) % QStringLiteral("/advice.skg")), true)
+        SKGTESTERROR(QLatin1String("document1.load()"), document1.load(SKGTest::getTestPath(QLatin1String("IN")) % QLatin1String("/advice.skg")), true)
         auto* rep = qobject_cast<SKGReportBank*>(document1.getReport());
-        rep->setPeriod(QStringLiteral("2013"));
+        rep->setPeriod(QLatin1String("2013"));
         rep->get5MainCategoriesVariation();
         rep->getAlarms();
         rep->getInterests();
@@ -57,16 +57,16 @@ int main(int argc, char** argv)
         rep->getTipOfDay();
         rep->getTipsOfDay();
 
-        rep->setTipsOfDay(QStringList() << QStringLiteral("Hello") << QStringLiteral("world"));
+        rep->setTipsOfDay(QStringList() << QLatin1String("Hello") << QLatin1String("world"));
 
         rep->getTipOfDay();
         rep->getTipsOfDay();
 
         rep->setPointSize(10);
-        SKGTEST(QStringLiteral("REP:getPointSize"), rep->getPointSize(), 10)
+        SKGTEST(QLatin1String("REP:getPointSize"), rep->getPointSize(), 10)
 
         QString html;
-        SKGTESTERROR(QStringLiteral("SKGReportBank::getReportFromTemplate"), SKGReportBank::getReportFromTemplate(rep, SKGTest::getTestPath(QStringLiteral("IN")) % QStringLiteral("/template.txt"), html), true)
+        SKGTESTERROR(QLatin1String("SKGReportBank::getReportFromTemplate"), SKGReportBank::getReportFromTemplate(rep, SKGTest::getTestPath(QLatin1String("IN")) % QLatin1String("/template.txt"), html), true)
         delete rep;
     }
     // End test
