@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -28,14 +28,14 @@ int main(int argc, char** argv)
     {
         // Test import KMY
         SKGDocumentBank document1;
-        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
+        SKGTESTERROR(QLatin1String("document1.initialize()"), document1.initialize(), true)
         SKGError err;
         {
             // Scope of the transaction
-            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_KMY"), err)
+            SKGBEGINTRANSACTION(document1, QLatin1String("IMPORT_KMY"), err)
 
-            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportkmy2/to_skrooge.anon.kmy"));
-            SKGTESTERROR(QStringLiteral("KMY.importFile"), imp1.importFile(), true)
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QLatin1String("IN")) % "/skgtestimportkmy2/to_skrooge.anon.kmy"));
+            SKGTESTERROR(QLatin1String("KMY.importFile"), imp1.importFile(), true)
         }
     }
 
