@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -14,8 +14,8 @@
 void SKGTESTColorButton::Test()
 {
     SKGColorButton color(nullptr);
-    color.setText(QStringLiteral("Hello"));
-    QCOMPARE(color.text(), QStringLiteral("Hello"));
+    color.setText(QLatin1String("Hello"));
+    QCOMPARE(color.text(), QLatin1String("Hello"));
     color.setColor(Qt::white);
     QCOMPARE(color.color(), QColor(Qt::white));
     color.setDefaultColor(Qt::black);
