@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
 
 
  * SPDX-License-Identifier: GPL-3.0-or-later
@@ -22,16 +22,16 @@ void SKGTESTComboBox::Test()
 {
     SKGComboBox combo;
     QVERIFY(combo.text() == QLatin1String(""));
-    combo.setText(QStringLiteral("Hello"));
-    QVERIFY(combo.text() == QStringLiteral("Hello"));
+    combo.setText(QLatin1String("Hello"));
+    QVERIFY(combo.text() == QLatin1String("Hello"));
 
     combo.setEditable(false);
-    QTest::keyClicks(&combo, QStringLiteral("ABCD"));
-    QCOMPARE(combo.text(), QStringLiteral("Hello"));
+    QTest::keyClicks(&combo, QLatin1String("ABCD"));
+    QCOMPARE(combo.text(), QLatin1String("Hello"));
 
     combo.setEditable(true);
-    QTest::keyClicks(&combo, QStringLiteral("ABCD"));
-    QCOMPARE(combo.text(), QStringLiteral("HelloABCD"));
+    QTest::keyClicks(&combo, QLatin1String("ABCD"));
+    QCOMPARE(combo.text(), QLatin1String("HelloABCD"));
 
     combo.setPalette(combo.palette());
 }
