@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 #ifndef SKGTESTMACRO_H
@@ -36,7 +36,7 @@ public:
     {
         QString pPath = SKGServices::getEnvVariable(iPath);
         if (pPath.isEmpty()) {
-            return QStringLiteral("./tests/") % (iPath == QStringLiteral("IN") ? "input" : (iPath == QStringLiteral("OUT") ? "output" : "ref"));
+            return QLatin1String("./tests/") % (iPath == QLatin1String("IN") ? "input" : (iPath == QLatin1String("OUT") ? "output" : "ref"));
         }
         return pPath;
     }
@@ -48,14 +48,16 @@ public:
  */
 #define SKGINITTEST(SHOWERRONLY) \
     QCoreApplication app(argc, argv); \
-    app.setApplicationName(QStringLiteral("qttest")); \
-    KAboutData::setApplicationData(KAboutData(QStringLiteral("qttest"), QStringLiteral("qttest"), QStringLiteral("1.0"))); \
+    app.setApplicationName(QLatin1String("qttest")); \
+    KAboutData::setApplicationData(KAboutData(QLatin1String("qttest"), QLatin1String("qttest"), QLatin1String("1.0"))); \
     KLocalizedString::setApplicationDomain("skrooge"); \
+    KLocalizedString::setLanguages(QStringList() << QLatin1String("en_GB")); \
+    QLocale::setDefault(QLocale(QLocale::English)); \
     SKGTRACESEPARATOR; \
-    SKGTRACE << "STARTING TEST" << SKGENDL << SKGFLUSH; \
+    SKGTRACE << "STARTING TEST" << Qt::endl << Qt::flush; \
     SKGTRACESEPARATOR; \
     bool showonlyfailures = SHOWERRONLY; \
-    if (showonlyfailures) {SKGTRACE << "Only failures will be displayed" << SKGENDL;}\
+    if (showonlyfailures) {SKGTRACE << "Only failures will be displayed" << Qt::endl;}\
     int nberror = 0;  \
     int nbcheck = 0;
 
@@ -66,7 +68,7 @@ public:
 #define SKGENDTEST()\
     if (nbcheck > 0) \
     { \
-        SKGTRACE << nberror << " errors / " << nbcheck << " checks =" << (100.0*(static_cast<double>(nberror)) / (static_cast<double>(nbcheck))) << "%" << SKGENDL;\
+        SKGTRACE << nberror << " errors / " << nbcheck << " checks =" << (100.0*(static_cast<double>(nberror)) / (static_cast<double>(nbcheck))) << "%" << Qt::endl;\
     } \
     SKGTraces::dumpProfilingStatistics();\
     return nberror;
@@ -78,7 +80,7 @@ public:
 #define SKGRETURNTEST()\
     if (nbcheck > 0) \
     { \
-        SKGTRACE << nberror << " errors / " << nbcheck << " checks =" << (100.0*(static_cast<double>(nberror)) / (static_cast<double>(nbcheck))) << "%" << SKGENDL;\
+        SKGTRACE << nberror << " errors / " << nbcheck << " checks =" << (100.0*(static_cast<double>(nberror)) / (static_cast<double>(nbcheck))) << "%" << Qt::endl;\
     } \
     return nberror;
 
@@ -87,19 +89,19 @@ public:
  * To check the return of a method
  * Example of usage:
  * @code
- * SKGTEST(QStringLiteral("ERR:getHistoricalSize"), err.getHistoricalSize(), 0)
+ * SKGTEST(QLatin1String("ERR:getHistoricalSize"), err.getHistoricalSize(), 0)
  * @endcode
  */
 #define SKGTEST(MESSAGE, RESULT, EXPECTEDRESULT) \
     if ((RESULT) == (EXPECTEDRESULT))\
     {\
-        if (!showonlyfailures) {SKGTRACE << "Test [" << (MESSAGE) << "] : OK" << SKGENDL;}\
+        if (!showonlyfailures) {SKGTRACE << "Test [" << (MESSAGE) << "] : OK" << Qt::endl;}\
     }\
     else\
     {\
-        SKGTRACE << "!!! Test [" << (MESSAGE) << "] : KO in line " << __LINE__ << SKGENDL;\
-        SKGTRACE << "     Expected: [" << (EXPECTEDRESULT) << ']' << SKGENDL;\
-        SKGTRACE << "     Result  : [" << (RESULT) << ']' << SKGENDL;\
+        SKGTRACE << "!!! Test [" << (MESSAGE) << "] : KO in line " << __LINE__ << Qt::endl;\
+        SKGTRACE << "     Expected: [" << (EXPECTEDRESULT) << ']' << Qt::endl;\
+        SKGTRACE << "     Result  : [" << (RESULT) << ']' << Qt::endl;\
         ++nberror;\
     }\
     ++nbcheck;
@@ -114,13 +116,13 @@ public:
 #define SKGTESTBOOL(MESSAGE, RESULT, EXPECTEDRESULT) \
     if ((RESULT) == (EXPECTEDRESULT))\
     {\
-        if (!showonlyfailures) {SKGTRACE << "Test [" << (MESSAGE) << "] : OK" << SKGENDL;}\
+        if (!showonlyfailures) {SKGTRACE << "Test [" << (MESSAGE) << "] : OK" << Qt::endl;}\
     }\
     else\
     {\
-        SKGTRACE << "!!! Test [" << (MESSAGE) << "] : KO in line " << __LINE__ << SKGENDL;\
-        SKGTRACE << "     Expected: [" << ((EXPECTEDRESULT) ? "TRUE" : "FALSE") << ']' << SKGENDL;\
-        SKGTRACE << "     Result  : [" << ((RESULT) ? "TRUE" : "FALSE") << ']' << SKGENDL;\
+        SKGTRACE << "!!! Test [" << (MESSAGE) << "] : KO in line " << __LINE__ << Qt::endl;\
+        SKGTRACE << "     Expected: [" << ((EXPECTEDRESULT) ? "TRUE" : "FALSE") << ']' << Qt::endl;\
+        SKGTRACE << "     Result  : [" << ((RESULT) ? "TRUE" : "FALSE") << ']' << Qt::endl;\
         ++nberror;\
     }\
     ++nbcheck;
@@ -130,7 +132,7 @@ public:
  * To check the return of a method
  * Example of usage:
  * @code
- * SKGTESTERROR(QStringLiteral("DOC:setParameter"), document1.setParameter(QStringLiteral("ATT1"), QStringLiteral("VAL1")), true)
+ * SKGTESTERROR(QLatin1String("DOC:setParameter"), document1.setParameter(QLatin1String("ATT1"), QLatin1String("VAL1")), true)
  * @endcode
  */
 #define SKGTESTERROR(MESSAGE, RESULT, EXPECTEDRESULT) \
@@ -138,16 +140,16 @@ public:
         SKGError _err_ = RESULT; \
         if (!_err_ == (EXPECTEDRESULT)) { \
             if (!showonlyfailures) { \
-                SKGTRACE << "Test [" << (MESSAGE) << "] : OK" << SKGENDL; \
+                SKGTRACE << "Test [" << (MESSAGE) << "] : OK" << Qt::endl; \
                 if (!(EXPECTEDRESULT)) { \
-                    SKGTRACE << "     Error Message  :\n" << _err_.getFullMessageWithHistorical()  << SKGENDL; \
+                    SKGTRACE << "     Error Message  :\n" << _err_.getFullMessageWithHistorical()  << Qt::endl; \
                 }     \
             }\
         } else {\
-            SKGTRACE << "!!! Test [" << (MESSAGE) << "] : KO in line " << __LINE__ << SKGENDL;\
-            SKGTRACE << "     Expected: [" << ((EXPECTEDRESULT) ? "TRUE" : "FALSE") << ']' << SKGENDL;\
-            SKGTRACE << "     Result  : [" << (!_err_ ? "TRUE" : "FALSE") << ']' << SKGENDL;\
-            SKGTRACE << "     Error Message  :\n" << _err_.getFullMessageWithHistorical()  << SKGENDL;\
+            SKGTRACE << "!!! Test [" << (MESSAGE) << "] : KO in line " << __LINE__ << Qt::endl;\
+            SKGTRACE << "     Expected: [" << ((EXPECTEDRESULT) ? "TRUE" : "FALSE") << ']' << Qt::endl;\
+            SKGTRACE << "     Result  : [" << (!_err_ ? "TRUE" : "FALSE") << ']' << Qt::endl;\
+            SKGTRACE << "     Error Message  :\n" << _err_.getFullMessageWithHistorical()  << Qt::endl;\
             ++nberror;\
         }\
         ++nbcheck;\
@@ -158,16 +160,16 @@ public:
  * To check the account amount
  * Example of usage:
  * @code
- * SKGTESTACCOUNT(document1, QStringLiteral("act1"), 12345);
+ * SKGTESTACCOUNT(document1, QLatin1String("act1"), 12345);
  * @endcode
  */
 #define SKGTESTACCOUNT(DOC, ACCOUNT, AMOUNT) \
     { \
         SKGAccountObject account(&(DOC)); \
-        SKGTESTERROR((ACCOUNT) % ".setName(QStringLiteral(" % (ACCOUNT) % "))", account.setName(ACCOUNT), true) \
-        SKGTESTERROR((ACCOUNT) % ".load(QStringLiteral(" % (ACCOUNT) % "))", account.load(), true) \
+        SKGTESTERROR((ACCOUNT) % ".setName(QLatin1String(" % (ACCOUNT) % "))", account.setName(ACCOUNT), true) \
+        SKGTESTERROR((ACCOUNT) % ".load(QLatin1String(" % (ACCOUNT) % "))", account.load(), true) \
         if (qAbs(account.getCurrentAmount()-AMOUNT) > 10e-4) {\
-            SKGTEST((ACCOUNT) % ".getCurrentAmount(" % (ACCOUNT) % ")", SKGServices::toCurrencyString(account.getCurrentAmount(), QStringLiteral("Euros"), 2), SKGServices::toCurrencyString(AMOUNT, QStringLiteral("Euros"), 2))\
+            SKGTEST((ACCOUNT) % ".getCurrentAmount(" % (ACCOUNT) % ")", SKGServices::toCurrencyString(account.getCurrentAmount(), QLatin1String("Euros"), 2), SKGServices::toCurrencyString(AMOUNT, QLatin1String("Euros"), 2))\
         }\
     }
 #endif
