@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -26,16 +26,16 @@ int main(int argc, char** argv)
     // Test inserts
     {
         SKGDocument document1;
-        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
+        SKGTESTERROR(QLatin1String("document1.initialize()"), document1.initialize(), true)
         SKGError err;
         {
             // Scope of the transaction
-            SKGBEGINTRANSACTION(document1, QStringLiteral("INSERT"), err)
+            SKGBEGINTRANSACTION(document1, QLatin1String("INSERT"), err)
 
             for (int i = 0; i < 10000; ++i) {
                 QString v = QString::number(i);
-                SKGTESTERROR(QStringLiteral("PARAM:setParameter"), document1.setParameter(v, v), true)
-                SKGTEST(QStringLiteral("PARAM:getParameter"), document1.getParameter(v), v)
+                SKGTESTERROR(QLatin1String("PARAM:setParameter"), document1.setParameter(v, v), true)
+                SKGTEST(QLatin1String("PARAM:getParameter"), document1.getParameter(v), v)
             }
         }
     }
