@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -25,20 +25,20 @@ int main(int argc, char** argv)
     SKGINITTEST(true)
 
     SKGDocument document1;
-    SKGTESTERROR(QStringLiteral("PARAM:initialize"), document1.initialize(), true)
+    SKGTESTERROR(QLatin1String("PARAM:initialize"), document1.initialize(), true)
 
     SKGReport* rep = document1.getReport();
     rep->getPeriod();
-    rep->setPeriod(QStringLiteral("2013-01"));
+    rep->setPeriod(QLatin1String("2013-01"));
     rep->getPrevious();
-    SKGTEST(QStringLiteral("REP:getMonth"), rep->getPeriod(), QStringLiteral("2013-01"))
-    SKGTEST(QStringLiteral("REP:getPreviousMonth"), rep->getPreviousPeriod(), QStringLiteral("2012-12"))
+    SKGTEST(QLatin1String("REP:getMonth"), rep->getPeriod(), QLatin1String("2013-01"))
+    SKGTEST(QLatin1String("REP:getPreviousMonth"), rep->getPreviousPeriod(), QLatin1String("2012-12"))
 
     QString html;
-    SKGTESTERROR(QStringLiteral("REP:getReportFromTemplate"),  SKGReport::getReportFromTemplate(rep, SKGTest::getTestPath(QStringLiteral("IN")) % "/missing.txt", html), false)
+    SKGTESTERROR(QLatin1String("REP:getReportFromTemplate"),  SKGReport::getReportFromTemplate(rep, SKGTest::getTestPath(QLatin1String("IN")) % "/missing.txt", html), false)
 
     rep->getPrevious();
-    rep->setPeriod(QStringLiteral("2013-02"));
+    rep->setPeriod(QLatin1String("2013-02"));
     rep->cleanCache();
     delete rep;
 
