@@ -1,6 +1,6 @@
 /***************************************************************************
- * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
- * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2024 G. DE BURE support@mankowski.fr
  * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
@@ -31,7 +31,7 @@ int main(int argc, char** argv)
                      "0.1.0",
                      ki18nc("The description of the application", "Blablabla"),
                      KAboutLicense::GPL_V3,
-                     i18nc("Fullname", "(c) 2007-%1 Stephane MANKOWSKI & Guillaume DE BURE", QDate::currentDate().toString(QStringLiteral("yyyy"))),
+                     i18nc("Fullname", "(c) 2007-%1 Stephane MANKOWSKI & Guillaume DE BURE", QDate::currentDate().toString(QLatin1String("yyyy"))),
                      "",
                      "https://skrooge.org");
 
@@ -52,7 +52,7 @@ int main(int argc, char** argv)
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[URL]"), i18nc("Application argument", "Document to open")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("+[URL]"), i18nc("Application argument", "Document to open")));
 
     int rc = 0;
     if (!SKGUniqueApplication::start()) {
